<?php

namespace App\AppContext;

use App\Resolvers\Resolver;
use App\Traits\Guard;
use Illuminate\Support\Facades\Auth;

class ClientScope
{
    use Guard;
    public $client;
    protected $resolver;

    /**
     * @var array
     */
    private $guards = [];

    public function guards(array $guards = []): ClientScope
    {
        $this->guards = array_merge($this->guards, $guards);
        return $this;
    }

    public function resolver(Resolver $resolver): ClientScope
    {
        $this->resolver = $resolver;
        return $this;
    }

    /**
     * Check to see if the Scope is valid
     *
     * @return self
     */
    public function check(): ClientScope
    {
        $client = $this->get();
        $user = Auth::user();
        $this->guard($this->guards, compact('client', 'user'));
        return $this;
    }

    public function get()
    {
        if ($this->client) {
            return $this->client;
        }
        if ($this->resolver) {
            return $this->client = $this->resolver->resolve();
        }
        return null;
    }
}