<?php

namespace App\AppContext;
use Exception;
use Illuminate\Support\Arr;

class ContextManager
{
    /**
     * @var array
     */
    private $contexts;

    /**
     * @param array $contexts
     * @return void
     */
    public function __construct(array $contexts)
    {
        $this->contexts = $contexts;
    }

    /**
     * Return the Context
     *
     * @param string $key
     * @throws Exception
     */
    public function get(string $key)
    {
        $context = Arr::get($this->contexts, $key);
        if ($context) {
            return app($context);
        }

        throw new Exception(sprintf('%s is not a valid Context', $key));
    }

    /**
     * @return UserContext
     * @throws Exception
     */
    public function user(): UserContext
    {
        return $this->get('user');
    }

    /**
     * @return ClientContext
     * @throws Exception
     */
    public function client(): ClientContext
    {
        return $this->get('client');
    }

    /**
     * @return RequestContext
     * @throws Exception
     */
    public function request(): RequestContext
    {
        return $this->get('request');
    }
} 