<?php

namespace App\AppContext;

use App\Enum\FilterTypes;
use App\Enum\SortTypes;
use Illuminate\Http\Request;
use Illuminate\Validation\ValidationException;

class RequestContext extends ContextBase
{
    private $options = array();

    public function fromRequest(Request $request): RequestContext
    {
        if ($request->has('page')) {
            $this->setPageOptions($request->page);
        }

        if ($request->has('sort')) {
            $this->setSortOptions($request->sort);
        }

        if ($request->has('filter')) {
            $this->setFilterOptions($request->filter);
        }
        return $this;
    }

    function get(): array
    {
        return [
            'options' => $this->options
        ];
    }

    function getOptions(): array
    {
        return $this->options;
    }

    /**
     * @param $page
     */
    private function setPageOptions($page)
    {
        $this->options['page']['size'] = $page['size'] ?? 10;
        $this->options['page']['number'] = $page['number'] ?? 1;
    }

    /**
     * @param $sort
     */
    private function setSortOptions($sort)
    {
        $sortTypes = [SortTypes::ASC, SortTypes::DESC];
        //Check is request single sort?
        $sortArray = array();
        if (is_array($sort) && isset($sort['column'])) {
            $sortArray[] = $sort;
        } else {
            $sortArray = $sort;
        }
        foreach ($sortArray as &$sortItem) {
            if (!isset($sortItem['column'])) {
                throw ValidationException::withMessages(['sort[column]' => __('validation.required', ['attribute' => 'sort[column]'])]);
            }
            $sortItem['direction'] = $sortItem['direction'] ?? SortTypes::ASC;
            if (!in_array($sortItem['direction'], $sortTypes)) {
                throw ValidationException::withMessages(['sort[direction]' => __('validation.invalid', ['attribute' => 'sort[direction]'])]);
            }
        }
        $this->options['sort'] = $sortArray;
    }

    /**
     * @param $filters
     * @throws ValidationException
     */
    private function setFilterOptions($filters)
    {
        $filterTypes = FilterTypes::ALLOW_FILTERS;
        foreach ($filters as &$filter) {
            if (!isset($filter['value'])) {
                throw ValidationException::withMessages(['filter[value]' => __('validation.required', ['attribute' => 'filter[value]'])]);
            }
            if (!isset($filter['column'])) {
                throw ValidationException::withMessages(['filter[column]' => __('validation.required', ['attribute' => 'filter[column]'])]);
            }
            if (isset($filter['type'])) {
                if (!in_array($filter['type'], $filterTypes)) {
                    throw ValidationException::withMessages(['filter[type]' => __('validation.invalid', ['attribute' => 'filter[type]'])]);
                }
            } else {
                $filter['type'] = FilterTypes::IS;
            }
        }
        $this->options['filter'] = $filters;
    }

    function check(): bool
    {
        return !empty($this->options);
    }
}