<?php

namespace App\Console\Commands;

use App\Enum\NotificationTypes;
use App\Helpers\ActionRequestHelper;
use App\Helpers\DateHelper;
use App\Jobs\SendNotification;
use App\Models\Action\Action;
use App\Models\ContentPhoto\ContentPhoto;
use App\Models\IDVerification\IDVerification;
use App\Models\Journey\Journey;
use App\Models\Quiz\Quiz;
use App\Models\Survey\Survey;
use Illuminate\Console\Command;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Auth;

class ActionReminderNotification extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'actionssss:notification';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Create notification for scheduled journeys';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $oneDayAfter = Carbon::today()->setTimezone('Asia/Singapore')->hour(9)->addDays(1);
        $sendTime = Carbon::today()->setTimezone('Asia/Singapore')->hour(9);

        // A new action is pending
        // Need check and get action not done
        $actions = Action::where('due_by', '<', $oneDayAfter)->get();
        foreach ($actions as $action) {
            $users = $this->usersHavenDoAction($action);
            if(!empty($users)) {
                $arguments = array(
                    "userIds" => $users,
                    "headings" => __("A new action is pending"),
                    "contents" => __("Tap to open action"),
                    "data"=>[
                        "type" => NotificationTypes::ACTION_IS_PENDING,
                        'code' => $action->code,
                        'id' => $action->id,
                        'action_type' => ActionRequestHelper::getActionTypeForNotification($action->actionRequest)
                    ],
                    'send_after' => DateHelper::format($sendTime)
                );
                SendNotification::dispatch($arguments);
            }
        }

        // An action is due today
        $todayTime = Carbon::today()->setTimezone('Asia/Singapore')->hour(1);
        $tomorrowTime = $todayTime->addDays(1);
        $actions = Action::whereBetween('due_by', [$todayTime, $tomorrowTime])->get();
        foreach ($actions as $action) {
            $users = $this->usersHavenDoAction($action);
            if(!empty($users)) {
                $arguments = array(
                    "userIds" => $users,
                    "headings" => __("An action is due today"),
                    "contents" => __("Tap to open action"),
                    "data"=>[
                        "type" => NotificationTypes::ACTION_NEARLY_DUE,
                        'code' => $action->code,
                        'id' => $action->id,
                        'action_type' => ActionRequestHelper::getActionTypeForNotification($action->actionRequest)
                    ],
                    'send_after' => DateHelper::format($sendTime)
                );
                SendNotification::dispatch($arguments);
            }
        }

        // An action is overdue
        $actions = Action::where('due_by', '>', Carbon::today()->hour(1))->get();
        foreach ($actions as $action) {
            $users = $this->usersHavenDoAction($action);
            if(!empty($users)) {
                $arguments = array(
                    "userIds" => $users,
                    "headings" => __("An action is overdue"),
                    "contents" => __("Tap to open action"),
                    "data" => [
                        "type" => NotificationTypes::ACTION_OVERDUE,
                        'code' => $action->code,
                        'id' => $action->id,
                        'action_type' => ActionRequestHelper::getActionTypeForNotification($action->actionRequest)
                    ],
                    'send_after' => DateHelper::format($sendTime)
                );
                SendNotification::dispatch($arguments);
            }
        }

        return 0;
    }

    /**
     * Get users didn't done an action
     *
     * @param $action
     * @return mixed
     */
    public function usersHavenDoAction($action) {
        return $action->users->pluck('code')->toArray();
    }


}
