<?php

namespace App\Console\Commands;

use Illuminate\Console\GeneratorCommand;
use Symfony\Component\Console\Input\InputOption;

class ApiController extends GeneratorCommand
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $name = 'make:api-controller';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Make api controller';

    /**
     * The type of class being generated.
     *
     * @var string
     */

    protected $type = 'ApiController';

    /**
     * Get the stub file for the generator.
     *
     * @return string
     */
    protected function getStub()
    {
        $stub = app_path().'/Console/Stubs/controller.api.stub';
        if($this->option('resource'))
            $stub = app_path().'/Console/Stubs/controller.api.resource.stub';
        return  $stub;
    }

    /**
     * Build the class with the given name.
     *
     * Remove the base controller import if we are already in base namespace.
     *
     * @param  string  $name
     * @return string
     */
    protected function buildClass($name)
    {
        $controllerNamespace = $this->getNamespace($name);


        $replace["use {$controllerNamespace}\Controller;\n"] = '';
        $replace["{{version}}"] = $this->getVersion();

        return str_replace(
            array_keys($replace), array_values($replace), parent::buildClass($name)
        );
    }



    /**
     * Get the default namespace for the class.
     *
     * @param  string  $rootNamespace
     * @return string
     */
    protected function getDefaultNamespace($rootNamespace)
    {
        return $rootNamespace.'\Http\Controllers\Api\\' . $this->getVersion() ;
    }

    /**
     * Get the default namespace for the class.
     *
     * @param  string  $rootNamespace
     * @return string
     */
    protected function getVersion()
    {
        return $this->option('apiVersion') ? $this->option('apiVersion') : config('api.version');
    }



    /**
     * Get the console command options.
     *
     * @return array
     */
    protected function getOptions()
    {
        return [
            ['resource', 'r', InputOption::VALUE_NONE, 'Generate a resource controller class.'],
            ['apiVersion', null, InputOption::VALUE_OPTIONAL, 'Version of api.'],
        ];

    }
}
