<?php

namespace App\Console\Commands;

use App\Services\Schedule\GetValidExpireDate;
use App\Services\Schedule\UnpublishSchedule;
use Illuminate\Console\Command;
use Illuminate\Support\Carbon;
use App\Enum\ScheduleEnum;
use App\Models\Schedule\ScheduleSurvey;
use App\Models\Schedule\ScheduleFrequencySetting;
use App\Services\Schedule\CreateScheduleRoundsAndDistributes;
use App\Models\Schedule\ScheduleSegments;
use App\Models\Segment\Segment;
use App\Enum\Roles;
use App\Facades\Context;
use App\Models\Client\Client;

class AutoGenerateDailySchedule extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'auto-generate-daily:schedule';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Create schedule for auto renewal date';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $clientDemo = Client::where('is_demo', true)->first();
        $clientDemoId = !empty($clientDemo) ? $clientDemo->id : null;

        $schedules = ScheduleSurvey::where('status', ScheduleEnum::ACTIVE)
            ->where('client_id', '!=', $clientDemoId)
            ->whereDate('renewal_date', '<=', Carbon::today()->toDateString())
            ->get();

        if($schedules->count() == 0) return true;

        foreach ($schedules as $key => $schedule) {
            // Get client demo and user demo
            $client = Client::where('id', $schedule->client_id)->first();
            $admin = $client->users()->role(Roles::ADMIN)->where('id', $schedule->created_by)->first();
            if (empty($client) || empty($admin)) continue;

            Context::user()->set($admin);
            Context::client()->set($client);

            // auto generate renewal date
            $frequencySetting = ScheduleFrequencySetting::where('schedule_frequency_id', $schedule->schedule_frequency_id)->first();
            if (empty($frequencySetting)) continue;

            $start_date = Carbon::parse($schedule->renewal_date)->addDay(1)->format('Y-m-d');
            $expire_date = app(GetValidExpireDate::class)
                ->execute([
                    'start_date'            => $start_date,
                    'schedule_frequency_id' => $schedule->schedule_frequency_id
                ]);

            $renewal_date = $expire_date->addDay(1)->format('Y-m-d');

            $scheduleSegment = ScheduleSegments::where('schedule_survey_id', $schedule->id)->first();
            if (empty($scheduleSegment)) continue;

            $send_to_id = $scheduleSegment->send_to;
            $excludes = $scheduleSegment->exclude_id;

            $send_to = Segment::whereIn('id', explode(",", $send_to_id))->pluck('code')->toArray();
            $exclude_id = Segment::whereIn('id', explode(",", $excludes))->pluck('code')->toArray();
            $send_to_ids = !empty($send_to) ? implode(",", $send_to) : "";
            $exclude_ids = !empty($exclude_id) ? implode(",", $exclude_id) : null;
            $request = [
                "name" => $schedule->name,
                "description" => (string) $schedule->description,
                "schedule_frequency_id" => $schedule->schedule_frequency_id,
                "send_to" => $send_to_ids,
                "exclude_id" => $exclude_ids,
                "client_id" => $schedule->client_id,
                "start_date" => $start_date,
                "renewal_date" => $renewal_date,
                "created_by" => $schedule->created_by,
                "status" => ScheduleEnum::ACTIVE
            ];
            app(CreateScheduleRoundsAndDistributes::class)->execute($request);
            app(UnpublishSchedule::class)->execute(['id' => $schedule->id]);
        }
        return true;
    }
}
