<?php

namespace App\Console\Commands;

use App\Enum\EmploymentTypes;
use App\Enum\RoleLevels;
use App\Enum\Roles;
use App\Facades\Context;
use App\Models\MasterData\Industry;
use App\Models\User\User;
use App\Models\Client\Client;
use App\Services\Client\CreateClientDemo;
use App\Services\Employee\CreateEmployee;
use App\Services\Library\CreateDocumentProfile;
use App\Services\Subscription\CreateSubscriptionPlan;
use Illuminate\Console\Command;
use Illuminate\Http\UploadedFile;
use DateTime;

class CreateDemoData extends Command
{
    const DEMO_PLAN = [
        "name" => "Demo",
        "description" => "Subscription for Demo client",
        "cost" => 0,
        "price_per_employee" => 0,
        "stripe_price" => "price_demo",
        "stripe_prod" => "product_demo",
        "is_public" => 0,
        "status" => "active",
        "config" => [
            "package_employee" => 9999,
            "package_journey" => 99,
            "package_document" => 99,
            "package_quiz" => 99,
            "package_survey" => 99,
            "package_administrator" => 99,
            "package_support_type" => "email",
            "package_dedicated_engagement_specialist" => 1,
            "package_engagement_module" => 1,
            "package_custom_colour" => 1,
            "package_message" => 1,
            "package_form" => 1,
            "package_checklist" => 1,
            "package_ai_document_search" => 1,
            "package_id_verification" => 1,
            "package_sso" => 1,
            "package_integration" => 1,
            "package_message_translation" => 1
        ]
    ];


    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'qualee:createdemodata';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command will be created demo data';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     * @throws \Exception
     */
    public function handle()
    {

        $superAdmin = User::role(Roles::SUPER_ADMIN)->first();
        if (!$superAdmin) {
            $this->info(
                "Does not have super admin, please run db:seed first"
            );
        }
        Context::user()->set($superAdmin);
        $subscriptionPlan = app(CreateSubscriptionPlan::class)->execute(self::DEMO_PLAN);

        //Create client
        if (!$client = Client::where('is_demo', true)->first()) {
            $logoFile = new UploadedFile(public_path("images/Qualee-Logo-White.png"), 'Qualee-Logo-White.png', null, null, true);
            $clientDemo = [
                "name" => 'Qualee demo',
                "plan_id" => $subscriptionPlan->getBusinessKey(),
                "logo" => $logoFile,
                "industry_id" => Industry::query()->first()->getKey(),
                "stripe_cus_id" => 'stripe_demo',
                "phone_number" => '0123456789',
                "phone_country" => '+65',
            ];
            $client = app(CreateClientDemo::class)->execute($clientDemo);
            $client->is_demo = true;
            $client->save();
            Context::client()->set($client);
            $documentProfileData = [
                'name' => 'Demo'
            ];
            $documentProfile = app(CreateDocumentProfile::class)->execute($documentProfileData);

            //Create admin demo
            $adminDemo = [
                'first_name' => 'Admin',
                'surname' => 'Demo',
                'email' => 'admin@qualee.demo.com',
                'date_of_birth' => new DateTime('1995-01-01'),
                'start_date' => new DateTime(),
                'document_profiles' => [$documentProfile->getKey()],
                'employment_type' => EmploymentTypes::FULL_TIME,
                'role' => Roles::ADMIN,
                'action' => 'invite',
            ];
            $admin = app(CreateEmployee::class)->execute($adminDemo);
            $admin->is_demo = true;
            $admin->email_verified_at = new DateTime();
            $admin->save();

            //Create employee demo
            $employeeDemo = [
                'first_name' => 'Employee',
                'surname' => 'Demo',
                'email' => 'employee@qualee.demo.com',
                'date_of_birth' => new DateTime('1995-01-01'),
                'start_date' => new DateTime(),
                'document_profiles' => [$documentProfile->getKey()],
                'employment_type' => EmploymentTypes::FULL_TIME,
                'role' => Roles::FRONT_USER,
                'action' => 'invite',
            ];
            $employee = app(CreateEmployee::class)->execute($employeeDemo);
            $employee->is_demo = true;
            $employee->email_verified_at = new DateTime();
            $employee->save();
        }
    }
}