<?php

namespace App\Console\Commands;

use App\Enum\Roles;
use App\Models\User\User;
use App\Models\Client\Client;
use App\Models\Segment\Segment;
use App\Models\Segment\SegmentType;
use App\Models\User\Employee;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Schema;
use Faker\Factory as Faker;
use Illuminate\Support\Facades\Hash;
use DateTime;
use App\Models\User\UserAdminDetail;
class CreateUser extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'qualee:createuser {--quantity=}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command will be created dummy users';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     * @throws \Exception
     */
    public function handle()
    {
        if (!$quantity = $this->option('quantity')) {
            $quantity = 1;
        }

        $superAdmin = User::role(Roles::SUPER_ADMIN)->first();
        if (!$superAdmin)
        {
            $this->info(
                "Does not have super admin, please run db:seed first"
            );
        }

        //Create client
        if(!$client = Client::where('name','Qualee')->first())
        {
            $client = Client::create([
                "name"=>'Qualee',
                "status"=>'1',
                "is_subscription"=>'1',
                "created_by"=>$superAdmin->id,
                "email_verified_at"=>now(),
                "is_photo_id_enabled"=>0,
                "is_profile_photo_enabled"=>0,
                "support_type"=>'email',
            ]);
        }
        //Create segment type
        if(! $segmentType = SegmentType::where('name','Department')->first())
        {
            $segmentType = SegmentType::create([
                'name' => 'Department'
            ]);
        }

        $departmentArray = ["Finance","Engineering","Production","Marketing"];
        $departmentArrayResult = array();

        foreach($departmentArray as $key=>$department){
            //Create department
            if(!$departmentObject = Segment::where('name',$department)->first())
            {
                $departmentObject =  Segment::create([
                    'segment_type_id'=>$segmentType->id,
                    'client_id'=>$client->id,
                    'name'=>$department
                ]);
            }
            $departmentArrayResult[$key] = $departmentObject;
        }

        for($i=0; $i < $quantity; $i++)
        {
            $faker =  Faker::create();
            $tablePermissionNames = config('permission.table_names');
            if(!Schema::hasTable($tablePermissionNames['roles']))
            {
                $this->info(
                    "Does not have roles table, please run migrate"
                );
            }
            for($i=0 ; $i < 5; $i++){
                $admin = User::create([
                    'name' => $faker->name,
                    'first_name' => $faker->firstName,
                    'last_name' => $faker->lastName,
                    'email' => $faker->email,
                    'password' =>Hash::make('test'),
                    'status' => 1,
                    'is_subscription' => 0,
                    'phone' => $faker->phoneNumber,
                    'profile_pic' => '',
                    'is_default' => 1,
                    'remaining' => 0,
                    'complete' => 1,
                    'trial_ends_at' => new DateTime('2222-03-15 11:15:00'),
                ]);
                $admin->assignRole(Roles::ADMIN);
                UserAdminDetail::create([
                    "user_id"=>$admin->id,
                    "department_id"=>'34',
                    "city_id"=>'1',
                    "client_id"=>$client->id,
                    "preffered_name"=>'',
                    "business_phone"=>$faker->phoneNumber,
                    "job_title"=>'Admin',
                    "profile_url"=>'',
                    "two_step_login"=>'0',
                    "linkedinprofilepic"=>'',
                    "profile_pic"=>'',
                    "is_access_setup_enabled"=>1,

                ]);


                $admin->segments()->attach($departmentArrayResult[rand(0,3)]);
            }
            for($i=0 ; $i < 15; $i++){
                $front_user = User::create([
                    'name' => $faker->name,
                    'first_name' => $faker->firstName,
                    'last_name' => $faker->lastName,
                    'email' => $faker->email,
                    'password' =>Hash::make('test'),
                    'status' => 1,
                    'is_subscription' => 0,
                    'phone' => $faker->phoneNumber,
                    'profile_pic' => '',
                    'is_default' => 1,
                    'remaining' => 0,
                    'complete' => 1,
                    'trial_ends_at' => new DateTime('2222-03-15 11:15:00'),
                ]);
                $front_user->assignRole(Roles::FRONT_USER);
                Employee::create([
                    "user_id" => $front_user->id,
                    "department_id" => '34',
                    "city_id" => '1',
                    "document_profile_id" => '12',
                    "surname" => $faker->streetName,
                    "client_id" => $client->id,
                    "preffered_name" => $faker->firstName,
                    "job_title" => 'Admin',
                ]);
                $front_user->segments()->attach($departmentArrayResult[rand(0, 3)]);
            }
        }
    }
}