<?php

namespace App\Console\Commands;

use App\Enum\NotificationTypes;
use App\Helpers\DateHelper;
use App\Helpers\EventHelper;
use App\Jobs\SendNotification;
use App\Models\Event\Event;
use App\Models\Journey\Journey;
use Illuminate\Console\Command;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;

class EventReminderNotification extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'event:notification';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Create notification for remind up coming each ';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        // RUN EVERY 30 MINUTES
        $now = Carbon::now(new \DateTimeZone('Asia/Singapore'));
        $events = Event::where('is_published', 1)
            ->where('is_full_day', 0)
            ->whereDate('start_date', Carbon::today())->get();

        if ($events->count() == 0) return true;

        foreach ($events as $event) {
            $minutesLeft = Carbon::instance($event->start_date)->setTimezone('Asia/Singapore')->diffInMinutes($now);
            if ($minutesLeft < 30 && $minutesLeft >= 15) {
                $userCodes = EventHelper::getUserCodesByEvent($event)->toArray();
                if (empty($userCodes)) continue;
                $time = Carbon::instance($event->start_date)->setTimezone('Asia/Singapore')->addMinutes(-15);
                $arguments = array(
                    "userIds" => $userCodes,
                    "headings" => __("Event starting soon"),
                    "contents" => __($event->name . ", 15 minutes from now"),
                    "data"=>[
                        "type" => NotificationTypes::EVENT_STARTED_SOON,
                        'code' => $event->code,
                        'id'   => $event->id
                    ],
                    'send_after' => $time
                );
                SendNotification::dispatch($arguments);

                //Send reminder when event start
                $arguments = array(
                    "userIds" => $userCodes,
                    "headings" => __("An event is starting"),
                    "contents" => __("Tap to view details"),
                    "data"=>[
                        "type" => NotificationTypes::EVENT_STARTED,
                        'code' => $event->code,
                        'id'   => $event->id
                    ],
                    'send_after' => Carbon::instance($event->start_date)->setTimezone('Asia/Singapore')
                );
                SendNotification::dispatch($arguments);
            }
        }

        return 0;
    }
}
