<?php


namespace App\Console\Commands;


use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Jobs\IndexPowerSearch;
use App\Models\Event\Event;
use App\Models\Journey\Journey;
use App\Models\Library\LibraryItem;
use App\Models\Message\Conversation;
use App\Models\PowerSearch\SearchableObject;
use App\Models\Quiz\Quiz;
use App\Models\Survey\Survey;
use App\Models\User\User;
use Exception;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\DB;

class IndexMissingPowerSearch extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'powersearch:index';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command will be indexed missing data PowerSearch';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     * @throws Exception
     */
    public function handle()
    {
        //Index missing library
        $libraries = LibraryItem::query()->whereNotIn('id', SearchableObject::where('object_type', PowerSearchTypes::LIBRARY)->pluck('object_id'))->get();
        foreach($libraries as $library){
            IndexPowerSearch::dispatch($library->id,PowerSearchTypes::LIBRARY, PowerSearchActions::ADD, $library->client_id);
        }

        //Index missing case id
        $conversations = Conversation::query()->whereNotIn('id', SearchableObject::where('object_type', PowerSearchTypes::CASE_ID)->pluck('object_id'))->get();
        foreach ($conversations as $conversation) {
            IndexPowerSearch::dispatch($conversation->id,PowerSearchTypes::CASE_ID, PowerSearchActions::ADD, $conversation->client_id);
        }

        //Index missing user
        $users = User::query()->has('employee')->whereNotIn('code', SearchableObject::where('object_type', PowerSearchTypes::EMPLOYEE)->pluck('object_id'))->get();
        foreach($users as $user){
            IndexPowerSearch::dispatch($user->code, PowerSearchTypes::EMPLOYEE, PowerSearchActions::ADD, $user->employee->client_id);
            $newText = $user->employee->social_security_number;
            $this->savePowerSearch($newText, $user->code, $user->employee->client_id, PowerSearchTypes::SOCIAL_SECURITY_NUMBER);
            $this->savePowerSearch($user->employee->employee_client_id, $user->code, $user->employee->client_id, PowerSearchTypes::EMPLOYEE_CLIENT_ID);
            $this->savePowerSearch($user->employee->phone_number, $user->code, $user->employee->client_id, PowerSearchTypes::PHONE_NUMBER);
        }

        // Index missing user email
        $userEmails = User::query()->has('employee')->whereNotIn('code', SearchableObject::where('object_type', PowerSearchTypes::EMPLOYEE_EMAIL)->pluck('object_id'))->get();
        foreach($userEmails as $user){
            $this->savePowerSearch($user->email, $user->code, $user->employee->client_id, PowerSearchTypes::EMPLOYEE_EMAIL);
        }

        //Index missing event
        $events = Event::query()->whereNotIn('code', SearchableObject::where('object_type', PowerSearchTypes::EVENT)->pluck('object_id'))->get();
        foreach($events as $event){
            IndexPowerSearch::dispatch($event->code,PowerSearchTypes::EVENT, PowerSearchActions::ADD, $event->client_id);
        }

        //Index missing journey
        $journeys = Journey::query()->whereNotIn('code', SearchableObject::where('object_type', PowerSearchTypes::JOURNEY)->pluck('object_id'))->get();
        foreach($journeys as $journey){
            IndexPowerSearch::dispatch($journey->code,PowerSearchTypes::JOURNEY, PowerSearchActions::ADD, $journey->client_id);
        }

        //Index missing quiz
        $quizzes = Quiz::query()->whereNotIn('code', SearchableObject::where('object_type', PowerSearchTypes::QUIZ)->pluck('object_id'))->get();
        foreach($quizzes as $quiz){
            IndexPowerSearch::dispatch($quiz->code,PowerSearchTypes::QUIZ, PowerSearchActions::ADD, $quiz->client_id);
        }

        //Index missing survey
        $surveys = Survey::query()->whereNotIn('code', SearchableObject::where('object_type', PowerSearchTypes::SURVEY)->pluck('object_id'))->get();
        foreach($surveys as $survey){
            IndexPowerSearch::dispatch($survey->code,PowerSearchTypes::SURVEY, PowerSearchActions::ADD, $survey->client_id);
        }
    }

    private function savePowerSearch($newText, $code, $clientId, $type) {
        if ($newText && !empty($clientId)) {
            $searchableObj = SearchableObject::where('client_id', $clientId)
                ->where('object_type', $type)
                ->where('object_id', $code)->first();
            if ($searchableObj) {
                $searchableObj->object_content = $newText;
            } else {
                $searchableObj = new SearchableObject();
                $searchableObj->object_content = $newText;
                $searchableObj->client_id = $clientId;
                $searchableObj->object_type = $type;
                $searchableObj->object_id = $code;
            }
            $searchableObj->save();
        }
    }

}