<?php

namespace App\Console\Commands;

use App\Enum\PowerSearchTypes;
use App\Models\PowerSearch\SearchableObject;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;

class ReindexPowerSearch extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'reindex:powersearch';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command will be reindexed table PowerSearch';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     * @throws \Exception
     */
    public function handle()
    {
        Log::stack(['stdout'])->info("Clear all data PowerSearch");

        SearchableObject::truncate();
        //Index event
        Log::stack(['stdout'])->info("Start indexing event");
        DB::insert(
            sprintf("INSERT INTO searchable_objects (object_content, client_id, object_type, object_id) 
            SELECT name, client_id, '%s', code FROM events where deleted_at is null", PowerSearchTypes::EVENT)
        );
        Log::stack(['stdout'])->info("Indexing event done");

        //Index library
        Log::stack(['stdout'])->info("Start indexing library");
        DB::insert(
            sprintf("INSERT INTO searchable_objects (object_content, client_id, object_type, object_id) 
            SELECT name, client_id, '%s', id FROM library_items", PowerSearchTypes::LIBRARY)
        );
        Log::stack(['stdout'])->info("Indexing library done");

        //Index journey
        Log::stack(['stdout'])->info("Start indexing journey");
        DB::insert(
            sprintf("INSERT INTO searchable_objects (object_content, client_id, object_type, object_id) 
            SELECT name, client_id, '%s', code FROM journeys where deleted_at is null", PowerSearchTypes::JOURNEY)
        );
        Log::stack(['stdout'])->info("Indexing journey done");

        //Index quiz
        Log::stack(['stdout'])->info("Start indexing quiz");
        DB::insert(
            sprintf("INSERT INTO searchable_objects (object_content, client_id, object_type, object_id) 
            SELECT name, client_id, '%s', code FROM quizzes where deleted_at is null", PowerSearchTypes::QUIZ)
        );
        Log::stack(['stdout'])->info("Indexing quiz done");

        //Index survey
        Log::stack(['stdout'])->info("Start indexing survey");
        DB::insert(
            sprintf("INSERT INTO searchable_objects (object_content, client_id, object_type, object_id) 
            SELECT name, client_id, '%s', code FROM surveys where deleted_at is null", PowerSearchTypes::SURVEY)
        );
        Log::stack(['stdout'])->info("Indexing survey done");

        //Index employee
        Log::stack(['stdout'])->info("Start indexing employee");
        DB::insert(
            sprintf("INSERT INTO searchable_objects (object_content, client_id, object_type, object_id) 
            SELECT 
                CASE 
                    WHEN  u.surname IS NULL OR u.surname = '' THEN u.first_name
                    WHEN  u.first_name IS NULL OR u.first_name = '' THEN u.surname
                    ELSE  CONCAT(u.surname, ', ', u.first_name)
                END, 
                e.client_id,
                 '%s', u.code
            FROM users u INNER JOIN employees e on u.id = e.user_id
            where u.deleted_at is null", PowerSearchTypes::EMPLOYEE)
        );
        DB::insert(
            sprintf("INSERT INTO searchable_objects (object_content, client_id, object_type, object_id) 
            SELECT 
                e.social_security_number, 
                e.client_id,
                 '%s', u.code
            FROM users u INNER JOIN employees e on u.id = e.user_id
            where u.deleted_at is null", PowerSearchTypes::SOCIAL_SECURITY_NUMBER)
        );
        Log::stack(['stdout'])->info("Indexing employee done");
    }

}