<?php

namespace App\Console\Commands;

use App\Helpers\PandaDocHelper;
use App\Models\Form\FormDocument;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;

class SendPendingDocument extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'form:send-pending-documents';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Send pending documents';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     * @return void
     */
    public function handle()
    {
        $pendingDocuments = FormDocument::with('user.employee.client.formAuthenticate')
            ->where('is_sent', false)
            ->get();
        
        $sentDocumentIds = [];
        $pandaDocHelper = new PandaDocHelper();
        
        foreach ($pendingDocuments as $document) {
            if (!empty($document->user->employee->client)) {
                $client = $document->user->employee->client;
                if (!empty($client->formAuthenticate)) {
                    $pandaDocHelper->setToken($client->formAuthenticate->access_token);
                    $sentDocument = $pandaDocHelper->setLogging(false)->sendDocument($document->document_id);
                    if ($sentDocument && isset($sentDocument['status']) && $sentDocument['status'] === $pandaDocHelper::DOCUMENT_SENT_STATUS) {
                        $sentDocumentIds[] = $document->getKey();
                    }
                }
            }
        }
        
        FormDocument::whereIntegerInRaw('id', $sentDocumentIds)->update(['is_sent' => true]);
        
        if (count($sentDocumentIds) > 0 ) {
            Log::debug('Sent ' . count($sentDocumentIds) .' documents successfully');
        }
    }
}
