<?php

namespace App\Console\Commands;

use App\Helpers\AwsQuickSightHelper;
use App\Helpers\StripeHelper;
use App\Models\Client\Client;
use App\Services\User\RevokeUserToken;
use Carbon\Carbon;
use Illuminate\Console\Command;

class UpdateClientSubscriptionPeriod extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'client:update-subscription-period';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Update client subscription status';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     * @return void
     * @throws \Stripe\Exception\ApiErrorException
     */
    public function handle()
    {
        $clients = Client::all();
        
        $stripeSubscriptions = collect((new StripeHelper())->getAllSubscriptions());
        
        foreach ($clients as $client) {
            if (!empty($client->stripe_cus_id)) {
                $subscription = $stripeSubscriptions->where('customer', $client->stripe_cus_id)->first();
                if (!empty($subscription)) {
                    $client->subscription_period_end = $subscription->current_period_end;
                    $client->save();
                }

                // Revoke client user tokens if client subscription is expired or no exist
                if (empty($client->subscription_period_end) || $client->subscription_period_end < Carbon::today()->unix()) {
                    $users = $client->frontUsers()->with('tokens')->get();
                    foreach ($users as $user) {
                        app(RevokeUserToken::class)->execute($user);
                    }
                }
            }
        }
    }
}
