<?php

namespace App\Console\Commands;

use App\Helpers\AwsQuickSightHelper;
use App\Helpers\StripeHelper;
use App\Models\Client\Client;
use App\Models\Schedule\ScheduleSegmentUser as ScheduleSegmentUserModel;
use App\Models\Schedule\ScheduleSurvey;
use App\Models\Segment\Segment;
use App\Services\User\RevokeUserToken;
use Carbon\Carbon;
use Illuminate\Console\Command;

class UpdateScheduleSegmentUser extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'schedule:update-schedule-segment-user';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Update Schedule Segment User';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     * @return void
     * @throws \Stripe\Exception\ApiErrorException
     */
    public function handle()
    {
        $this->info('Start command');
        $schedules = ScheduleSurvey::all();
        foreach ($schedules as $schedule) {
            $this->info('Start check schedule: '.$schedule->name);

            $scheduleSegments = $schedule->scheduleSegments->first();
            if (empty($scheduleSegments)) continue;

            $sendToSegmentsString = $scheduleSegments->send_to;
            $sendToSegments = array_filter(explode(',', $sendToSegmentsString));

            $excludeSegmentsString = $scheduleSegments->exclude_id ?? '';
            $excludeSegments = array_filter(explode(',', $excludeSegmentsString));
            $allSegmentSubmitted = array_merge($sendToSegments, $excludeSegments);

            foreach ($allSegmentSubmitted as $segmentId) {
                $segment = Segment::find($segmentId);
                if(empty($segment)) continue;

                $segmentUsers = $segment->users->pluck('id')->toArray();
                // Save schedule segment user
                ScheduleSegmentUserModel::updateOrCreate([
                    'schedule_id' => $schedule->id,
                    'segment_id' => $segment->id,
                ],[
                    'user_id' => json_encode($segmentUsers)
                ]);
            }
        }
        $this->info('End command');
    }
}
