<?php

namespace App\Console;

use App\Console\Commands\DeleteApiMessage;
use App\Console\Commands\DeleteApiUsageLog;
use App\Console\Commands\EventDailyNotification;
use App\Console\Commands\EventReminderNotification;
use App\Console\Commands\EventUpcomingAlert;
use App\Console\Commands\IndexMissingPowerSearch;
use App\Console\Commands\JourneyDailyNotification;
use App\Console\Commands\ManagerDailyNotification;
use App\Console\Commands\QuestionnaireNotification;
use App\Console\Commands\SendPendingDocument;
use App\Console\Commands\AnalyzeCommentEngagement;
use App\Console\Commands\UpdateClientSubscriptionPeriod;
use Illuminate\Console\Scheduling\Schedule;
use Illuminate\Foundation\Console\Kernel as ConsoleKernel;
use App\Console\Commands\AutoGenerateDailySchedule;
use Illuminate\Support\Facades\Log;
use App\Console\Commands\AdminDailyNotification;

class Kernel extends ConsoleKernel
{
    /**
     * The Artisan commands provided by your application.
     *
     * @var array
     */
    protected $commands = [
        //
    ];

    /**
     * Define the application's command schedule.
     *
     * @param  \Illuminate\Console\Scheduling\Schedule  $schedule
     * @return void
     */
    protected function schedule(Schedule $schedule)
    {
        $schedule->command(SendPendingDocument::class)->everyMinute()->withoutOverlapping();

        $schedule->command(JourneyDailyNotification::class)->hourly();

        $schedule->command(EventDailyNotification::class)->hourly();
        $schedule->command(EventReminderNotification::class)->everyFifteenMinutes();
        $schedule->command(EventUpcomingAlert::class)->everyMinute()->withoutOverlapping();
        $schedule->command(QuestionnaireNotification::class)->hourly();
        $schedule->command(ManagerDailyNotification::class)->dailyAt('00:00');

        // auto generate renewal schedule
        $schedule->command(AutoGenerateDailySchedule::class)->dailyAt('00:00');

        //Auto index missing power search
        $schedule->command(IndexMissingPowerSearch::class)->everyTenMinutes();

        $schedule->command(AnalyzeCommentEngagement::class)->everyFiveMinutes()->withoutOverlapping();

        $schedule->command(UpdateClientSubscriptionPeriod::class)->dailyAt('00:00');

        $schedule->command(DeleteApiUsageLog::class)->dailyAt('00:00');
        $schedule->command(AdminDailyNotification::class)->dailyAt('00:00');
//        $schedule->command(DeleteApiMessage::class)->dailyAt('00:00');
    }

    /**
     * Register the commands for the application.
     *
     * @return void
     */
    protected function commands()
    {
        $this->load(__DIR__.'/Commands');

        require base_path('routes/console.php');
    }
}
