<?php


namespace App\Guards;


use App\Enum\ClientStatus;
use App\Enum\ErrorCode;
use App\Exceptions\UnauthorizedHttpException;
use Carbon\Carbon;
use Illuminate\Support\Arr;

class ClientSubscriptionIsExpired extends Guard
{
    /**
     * @param array $args
     * @return bool
     */
    public function check(array $args): bool
    {
        $client = Arr::get($args, 'client');
        if ($client) {
            if (empty($client->subscription_period_end) || $client->subscription_period_end < Carbon::today()->unix()) {
                throw new UnauthorizedHttpException(
                    "This client subscription has expired.",
                    ErrorCode::CLIENT_SUBSCRIPTION_IS_EXPIRED
                );
            };
            return true;
        }
        return false;
    }
}