<?php


namespace App\Helpers;

use Aws\Comprehend\ComprehendClient;

class AwsComprehendHelper
{
    CONST LATEST_VERSION = 'latest';
    CONST SUPPORT_LANGUAGES = ['en', 'es', 'fr', 'de', 'it', 'pt', 'ar', 'hi', 'ja', 'ko', 'zh', 'zh-TW', 'zh-tw'];

    protected $awsComprehend;

    public function __construct()
    {
        $this->awsComprehend = new ComprehendClient([
            'credentials' => [
                'key'    => config('aws.comprehend.access_key'),
                'secret' => config('aws.comprehend.secret_key'),
            ],
            'region' => config('aws.comprehend.region'),
            'version'  => self::LATEST_VERSION,
        ]);
    }

    public function detectDominantLanguage($text)
    {
        $detectLanguage = $this->awsComprehend->detectDominantLanguage([
            "Text" => $text,
        ]);
        $language = !empty($detectLanguage) && !empty($detectLanguage['Languages']) && in_array($detectLanguage['Languages'][0]['LanguageCode'], self::SUPPORT_LANGUAGES)
            ? $detectLanguage['Languages'][0]['LanguageCode'] : 'en';
        return $language;
    }

    public function detectEntities($text = '')
    {
        $languages = $this->detectDominantLanguage($text);
        $entities = $this->awsComprehend->detectEntities([
            'Text' => $text,
            'LanguageCode' => $languages
        ]);
        return $entities->get('Entities');
    }

    public function detectEntitiesMultiple($texts = [])
    {
        $result = [];
        foreach ($texts as $text) {
            $detectEntities = $this->detectEntities($text);
            if (empty($detectEntities)) continue;

            $result[] = $this->detectEntities($text);
        }

        return $result;
    }

    public function detectDominantLanguages($textList = [])
    {
        $detectLanguage = $this->awsComprehend->batchDetectDominantLanguage([
            "TextList" => $textList,
        ]);
        if (!empty($detectLanguage) && !empty($detectLanguage['ResultList'])) {
            return array_map(function ($item) {
                if (in_array($item['Languages'][0]['LanguageCode'], self::SUPPORT_LANGUAGES)) {
                    return $item['Languages'][0]['LanguageCode'];
                }
                return 'en';
            }, $detectLanguage['ResultList']);
        }
        return [];
    }

    public function detechSentiment($text = '')
    {
        $language = $this->detectDominantLanguage($text);
        $result = $this->awsComprehend->detectSentiment([
            'LanguageCode' => $language,
            'Text' => $text,
        ]);
        return $result;
    }

    public function batchDetectSentiment($textList = [], $language)
    {
        $result = $this->awsComprehend->batchDetectSentiment([
            'LanguageCode' => $language,
            'TextList' => $textList,
        ]);

        return $result['ResultList'];
    }

}