<?php


namespace App\Helpers;


use App\Models\Event\Event;
use Illuminate\Support\Collection;

/**
 * Class EventHelper
 * @package App\Helpers
 */
class EventHelper
{
    /**
     * Get user codes array by event model
     *
     * @param Event $event
     * @param array $timezones
     * @return Collection
     */
    public static function getUserCodesByEvent(Event $event, $timezones = [])
    {
        $timezones = collect($timezones);
        return $event->users()->when($timezones->count() > 0, function($query) use ($timezones) {
            $query->byTimezone($timezones);
        })->get()->pluck('code')
            ->merge(self::getUserCodesSegmentByEvent($event, $timezones))
            ->unique();
    }

    public static function getUserCodesSegmentByEvent($event, $timezones)
    {
        $result = collect([]);
        foreach ($event->segments as $segment) {
            $result = $result->merge($segment->users()->when($timezones->count() > 0, function($query) use ($timezones) {
                $query->byTimezone($timezones);
            })->get()->pluck('code'));
        }
        return $result;
    }
}
