<?php

namespace App\Helpers;

use App\DataTransferObject\StreamedFile;
use App\Models\Attachment;
use Illuminate\Http\UploadedFile;
use Storage;

class FileHelper {
    
    public static function getSignedUrl (string $resourceUrl) {
        $url = Storage::disk('s3')->temporaryUrl(
            $resourceUrl, now()->addMinutes(60)
        );

        return $url;
    }

    public static function getSignedUrlForAIDocSearch (string $resourceUrl) {
        $url = Storage::disk('s3AiDocSearch')->temporaryUrl(
            $resourceUrl, now()->addMinutes(60)
        );

        return $url;
    }

    /**
     * Get attachment url
     *
     * @return string
     */
    static function getPublicUrl ($attachment) {
        $path = "";
        if ($attachment instanceof Attachment) {
            $path = $attachment->path;
        } else {
            $path = $attachment;
        }
        return config('filesystems.file_domain_url') . '/' . $path;
    }

    /**
     * Store a file
     *
     * @param StreamedFile|UploadedFile $file
     * @param string $path
     * @param string $fileName
     * @param string $disk
     * @return false|string
     */
    public static function storeFile($file, string $path, string $fileName, string $disk = 's3')
    {
        if ($file instanceof UploadedFile) {
            $path = $file->storeAs($path, $fileName, $disk);
        }

        if ($file instanceof StreamedFile) {
            $path = trim($path . '/' . $fileName, '/');
            Storage::disk($disk)->put($path, $file->getContent());
        }

        return $path;
    }

    /**
     * Get file original name with extension
     *
     * @param StreamedFile|UploadedFile $file
     * @return string
     */
    public static function getOriginalName($file)
    {
        $originalName = $file->getClientOriginalName();
        $extension = pathinfo($originalName, PATHINFO_EXTENSION);
        if ($extension) {
            return $originalName;
        }

        return $originalName . '.' . $file->extension();
    }
}