<?php


namespace App\Helpers;

use App\Enum\ImageDimensions;
use Intervention\Image\ImageManager;

class ImageHelper
{

    /**
     * Resize given image and return file content
     * 
     * @param string $imagePath
     * @return string
     */
    public static function resizeFitAvatar(string $imagePath)
    {
        $image = (new ImageManager())->make($imagePath)->orientate();
        
        $width = $image->width();
        $height = $image->height();
        
        if ($width < $height) {
            $width = ImageDimensions::AVATAR_WIDTH;
            $height = null;
        } else {
            $width = null;
            $height = ImageDimensions::AVATAR_HEIGHT;
        }

        $streamedFile = $image->resize($width, $height, function ($constraint) {
            $constraint->aspectRatio();
        });

        $streamedFile->crop(ImageDimensions::AVATAR_WIDTH, ImageDimensions::AVATAR_WIDTH);

        return $streamedFile->stream()->__toString();
    }

    /**
     * Get image dimension
     * 
     * @param string $path
     * @return array
     */
    public static function getDimension(string $path)
    {
        $image = (new ImageManager())->make($path);
        
        return [$image->width(), $image->height()];
    }

    /**
     * Check valid image dimension
     * 
     * @param string $path
     * @param int $minWidth
     * @param int $minHeight
     * @return bool
     */
    public static function checkImageDimension(string $path, int $minWidth, int $minHeight)
    {
        [$width, $height] = ImageHelper::getDimension($path);
        if ($width < $minWidth || $height < $minHeight) {
            return false;
        }

        return true;
    }
}