<?php

namespace App\Helpers;

class ResourceLocationBuilder {
    
    private $clientId;
    private $userId;
    private $documentProfileId;

    function setClient(string $clientId): ResourceLocationBuilder {
        $this->clientId = $clientId;
        return $this;
    }

    function setUser(string $userId): ResourceLocationBuilder {
        $this->userId = $userId;
        return $this;
    }

    function setDocumentProfile(int $documentProfileId): ResourceLocationBuilder {
        $this->documentProfileId = $documentProfileId;
        return $this;
    }

    /*
      Get location path
    */
    function getDocumentProfilePath () {
       return "clients/$this->clientId/document_profiles/$this->documentProfileId";
    }

    /*
      Get location path
    */
    function getLogoPath () {
        return "clients/$this->clientId/logo";
     }

    /*
      Get asset path
    */
    function getAssetPath () {
        if (empty($this->clientId)) {
            return "qualee/assets";
        }
        return "clients/$this->clientId/assets";
     }

    /*
        Get content photo path
    */
    function getContentPhotoPath () {
        if (empty($this->clientId) || empty($this->userId)) {
            return "user/content-photo";
        }

        return "clients/$this->clientId/users/$this->userId/content-photo";
    }

     /*
      Get asset path
    */
    function getMessageAttachmentPath () {
        if (empty($this->clientId)) {
            return "qualee/messages";
        }
        return "clients/$this->clientId/message-attachments";
     }

    function getQuestionnairePath () {
        return "qualee/questionnaires";
    }

    function getDriverPath () {
        return "qualee/drivers";
    }

    /**
     * Get signed document path
     * 
     * @return string
     */
    function getSignedDocumentPath(){
        if (empty($this->clientId) || empty($this->userId)) {
            return "user/signed-document";
        }

        return "clients/$this->clientId/users/$this->userId/signed-document";
    }

    /**
     * Get user path
     *
     * @return string
     */
    public function getUserPath()
    {
        return "clients/$this->clientId/users/$this->userId";
    }

    /**
     * Get user path
     *
     * @return string
     */
    public function getUserSubmissionPath($type)
    {
        return $this->getUserPath() . "/" . $type;
    }

    /*
        Get content file path
    */
    function getContentFilePath () {
        if (empty($this->clientId) || empty($this->userId)) {
            return "user/content-file";
        }

        return "clients/$this->clientId/users/$this->userId/content-file";
    }
}