<?php


namespace App\Helpers;


use Aacotroneo\Saml2\Saml2Auth;
use App\Exceptions\InvalidRequestException;
use App\Models\Client\Client;
use App\Services\SSO\CheckConfigurationSSOValid;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\URL;
use OneLogin\Saml2\Auth as OneLogin_Saml2_Auth;

/**
 * Class Saml2AuthHelper
 * @package App\Helpers
 */
class Saml2AuthHelper extends Saml2Auth
{
    /**
     * Saml2AuthHelper constructor.
     * @param  OneLogin_Saml2_Auth  $auth
     */
    public function __construct(OneLogin_Saml2_Auth $auth)
    {
        parent::__construct($auth);
    }

    /**
     * Load SSO Config by client
     * @param $clientId
     * @return OneLogin_Saml2_Auth
     * @throws \OneLogin\Saml2\Error
     */
    public static function loadSSOConfigByClientId($clientId)
    {
        if (empty($clientId)) {
            throw new InvalidRequestException("ClientId required.");
        }
        $client = Client::findByBusinessKey($clientId);

        //Check client has valid configuration for SSO
        $clientConfiguration = app(CheckConfigurationSSOValid::class)->execute(['client' => $client]);

        $config = Saml2AuthHelper::getSampleConfigSSO($client->getBusinessKey());

        $config['idp']['entityId'] = $clientConfiguration['sso_entityid_url'];
        $config['idp']['singleSignOnService'] = ['url' => $clientConfiguration['sso_log_in_url']];
        $config['idp']['singleLogoutService'] = ['url' => $clientConfiguration['sso_log_out_url']];
        $config['idp']['x509cert'] = $clientConfiguration['sso_certificate'];
        return new OneLogin_Saml2_Auth($config);
    }

    /**
     * @param $clientCode
     * @return array|\Illuminate\Config\Repository|\Illuminate\Contracts\Foundation\Application|mixed
     * @throws \Exception
     */
    public static function getSampleConfigSSO($clientCode)
    {
        $config = config('saml2.sample_idp_settings');
        if (empty($config['sp']['entityId'])) {
            $config['sp']['entityId'] = URL::route('saml2_metadata', $clientCode);
        }
        if (empty($config['sp']['assertionConsumerService']['url'])) {
            $config['sp']['assertionConsumerService']['url'] = URL::route('saml2_acs', $clientCode);
        }
        if (!empty($config['sp']['singleLogoutService']) &&
            empty($config['sp']['singleLogoutService']['url'])) {
            $config['sp']['singleLogoutService']['url'] = URL::route('saml2_sls', $clientCode);
        }
        if (strpos($config['sp']['privateKey'], 'file://') === 0) {
            $config['sp']['privateKey'] = static::extractPkeyFromFile($config['sp']['privateKey']);
        }
        if (strpos($config['sp']['x509cert'], 'file://') === 0) {
            $config['sp']['x509cert'] = static::extractCertFromFile($config['sp']['x509cert']);
        }
        if (strpos($config['idp']['x509cert'], 'file://') === 0) {
            $config['idp']['x509cert'] = static::extractCertFromFile($config['idp']['x509cert']);
        }
        return $config;
    }

    /**
     * @return \Illuminate\Routing\Route|mixed|object|string|null
     */
    public static function getCurrentClientCode()
    {
        return Config::get('ssoClientCode') ?? request()->route('clientCode');
    }

}