<?php


namespace App\Helpers;


use App\Enum\SegmentTypes;
use App\Facades\Context;
use App\Http\Resources\Mobile\Segment\SegmentTypeDetailBasic as SegmentTypeDetailBasicMobileResource;
use App\Http\Resources\Segment\Segment as SegmentResource;
use App\Http\Resources\Segment\SegmentManager;
use App\Http\Resources\Segment\SegmentManagerextends;
use App\Http\Resources\Segment\SegmentTypeDetailAge as SegmentTypeDetailAgeResource;
use App\Http\Resources\Segment\SegmentTypeDetailBasic as SegmentTypeDetailBasicResource;
use App\Http\Resources\Segment\SegmentTypeDetailEmployment as SegmentTypeDetailEmploymentResource;
use App\Http\Resources\Segment\SegmentTypeDetailManager as SegmentTypeDetailManagerResource;
use App\Models\Segment\AgeSegment;
use App\Models\Segment\EmploymentPhaseSegment;
use App\Models\Segment\Segment;
use App\Models\Segment\SegmentType;
use App\Models\User\User;

/**
 * Class SegmentHelper
 * @package App\Helpers
 */
class SegmentHelper
{
    /**
     * Return resource by segment type
     * @param $code
     * @param $segments
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public static function getSegmentTypeResource($code, $segments)
    {
        $segmentTypeId = SegmentType::findByBusinessKey($code)->getKey();
        if (in_array($segmentTypeId, SegmentTypes::SEGMENT_TYPES_BASIC)) {
            return SegmentTypeDetailBasicResource::collection($segments);
        } else if ($segmentTypeId === SegmentTypes::MANAGER) {
            return SegmentTypeDetailManagerResource::collection($segments);
        } else if ($segmentTypeId === SegmentTypes::AGE) {
            return SegmentTypeDetailAgeResource::collection($segments);
        } else if ($segmentTypeId === SegmentTypes::EMPLOYMENT) {
            return SegmentTypeDetailEmploymentResource::collection($segments);
        }
    }

    /**
     * Return resource by segment type
     * @param $code
     * @param $segments
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public static function getSegmentResource($segment)
    {
        if ($segment instanceof User) {
            return new SegmentManager($segment);
        }
        return new SegmentResource($segment);
    }

    public static function getModelSegmentBySegmentType($segmentType, $segmentCode)
    {
        switch ($segmentType->id) {
            case SegmentTypes::MANAGER:
                return User::where('code', $segmentCode)->whereHas('employee', function($query) {
                    $query->where('client_id', Context::client()->get()->getKey());
                })->firstOrFail();
                break;
            case SegmentTypes::AGE:
                return AgeSegment::findByBusinessKey($segmentCode);
                break;
            case SegmentTypes::EMPLOYMENT:
                return EmploymentPhaseSegment::findByBusinessKey($segmentCode);
                break;

        }
        return Segment::where('code', $segmentCode)->where('client_id', Context::client()->get()->getKey())->firstOrFail();

    }

    /**
     * Return resource by segment type
     * @param $code
     * @param $segments
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public static function getSegmentTypeResourceMobile($code, $segments)
    {
        $segmentTypeId = SegmentType::findByBusinessKey($code)->getKey();
        if (in_array($segmentTypeId, SegmentTypes::SEGMENT_TYPES_BASIC)) {
            return SegmentTypeDetailBasicMobileResource::collection($segments);
        } else if ($segmentTypeId === SegmentTypes::MANAGER) {
            return SegmentTypeDetailManagerResource::collection($segments);
        } else if ($segmentTypeId === SegmentTypes::AGE) {
            return SegmentTypeDetailAgeResource::collection($segments);
        } else if ($segmentTypeId === SegmentTypes::EMPLOYMENT) {
            return SegmentTypeDetailEmploymentResource::collection($segments);
        }
    }

    /**
     * Get first segment or create it
     *
     * @param $segmentType
     * @param $segmentName
     * @param $clientId
     * @return Segment
     */
    public static function firstOrCreateSegment($segmentType, $segmentName, $clientId)
    {
        $departmentSegment = Segment::where('name', 'like', $segmentName)
            ->where('segment_type_id', $segmentType)
            ->where('client_id', $clientId)
            ->first();
        if (!$departmentSegment) {
            $departmentSegment = Segment::create([
                'name' => $segmentName,
                'segment_type_id' => $segmentType,
                'client_id' => $clientId,
            ]);
        }

        return $departmentSegment;
    }
}
