<?php


namespace App\Helpers;


class StringHelper
{
    /**
     * @param int $length
     * @param string[] $types
     * @return string
     */
    public static function generateRandomString($length = 10, $types = ['UPPER', 'NUMBER']): string
    {
        $characters = '';
        foreach ($types as $type) {
            $characters .= static::getCharacterByType($type);
        }
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }

    /**
     * @param $type
     * @return string
     */
    private static function getCharacterByType($type): string
    {
        switch ($type) {
            case 'UPPER':
                $character = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
                break;
            case 'LOWER':
                $character = 'abcdefghijklmnopqrstuvwxyz';
                break;
            default:
                $character = '0123456789';
                break;
        }
        return $character;
    }

    /**
     * @param array $keys
     * @param string $string
     * @return array
     */
    public static function findExactlyCharacter(array $keys,string $string)
    {
        $matches = array();
        $matchFound = preg_match_all(
            "/\b(" . implode("|", $keys) . ")\b/i",
            $string,
            $matches
        );
        if($matchFound){
            return (collect($matches)->unique()->toArray());
        }
        return [];
    }

    /**
     * Calculate and encode payload signature
     *
     * @param $payload
     * @param $key
     * @return string
     */
    public static function encodePayloadSignature($payload, $key)
    {
        $encodedSignature = base64_encode(hash_hmac('sha256', (string)$payload, $key, true));
        $encodedSignature = str_replace(['+','/'], ['-','_'], $encodedSignature);

        return $encodedSignature;
    }
}