<?php


namespace App\Helpers;


use App\Enum\TimeTypes;
use Carbon\Carbon;

/**
 * Class TimeHelper
 * @package App\Helpers
 */
class TimeHelper
{
    /**
     * @param $start
     * @param $end
     * @param $min
     * @param string $typeMin
     * @param $max
     * @param string $typeMax
     * @return bool
     * @throws \Exception
     */
    public static function isTimeOnRange($start, $end, $min, $typeMin = TimeTypes::YEAR, $max, $typeMax = TimeTypes::YEAR)
    {
        if (is_string($start)) {
            $start = new Carbon($start);
        }
        if (is_string($end)) {
            $end = new Carbon($end);
        }
        if (is_null($start) || is_null($end)) {
            return false;
        }

        if (!is_null($min) && self::getTimeDiff($start, $end, $typeMin) < $min) {
            return false;
        }
        if (!is_null($max) && self::getTimeDiff($start, $end, $typeMax) >= $max) {
            return false;
        }
        return true;
    }

    /**
     * @param Carbon $start
     * @param Carbon $end
     * @param string $type
     * @return int
     */
    public static function getTimeDiff(Carbon $start, Carbon $end, $type = TimeTypes::YEAR)
    {
        switch ($type) {
            case TimeTypes::SECOND:
                return $start->diffInSeconds($end, false);
                break;
            case TimeTypes::MINUTE:
                return $start->diffInMinutes($end, false);
                break;
            case TimeTypes::HOUR:
                return $start->diffInHours($end, false);
                break;
            case TimeTypes::DAY:
                return $start->diffInDays($end, false);
                break;
            case TimeTypes::MONTH:
                return $start->diffInMonths($end, false);
                break;
            case TimeTypes::YEAR:
                return $start->diffInYears($end, false);
                break;
        }
    }
}