<?php


namespace App\Helpers;

use App\Enum\CacheAgeLevel;
use App\Models\AppRating\AppRating;
use App\Models\Segment\Segment;
use App\Models\User\User;
use Illuminate\Support\Facades\Cache;

class UserHelper
{
    public static function getClientByUserCode($code) {
        $codeKey = "user_" . $code . "_client";
        return Cache::remember($codeKey, CacheAgeLevel::LONG, function () use ($code) {
            $user = User::findByBusinessKey($code);
            return $user->getClient();
        });
    }

    public static function getClientByUserId($id) {
        $idKey = "user_" . $id . "_client";
        return Cache::remember($idKey, CacheAgeLevel::LONG, function () use ($id) {
            $user = User::findOrFail($id);
            return $user->getClient();
        });
    }

    /**
     * Get user ids by segments
     *
     * @param string|array $segmentCode
     * @return array
     */
    static function getUserIdBySegment($segmentCode) : array
    {
        $userIds = [];

        if (is_array($segmentCode)) {
            foreach ($segmentCode as $code) {
                if (!empty($code)) {
                    $userIds = array_merge($userIds, self::getUserIdBySegment($code));
                }
            }
        } else {
            $segment = Segment::findByBusinessKey($segmentCode);
            PermissionHelper::hasAccessOn($segment);
            $userIds = $segment->includedCustomSegmentTypeUsers()->pluck('users.id')->toArray();
        }

        return $userIds;
    }

    /**
     * Check is mobile in app rating available
     *
     * @param $user
     * @return bool
     */
    public static function isRatingAvailable($user)
    {
        $appRating = AppRating::where([
            'user_id' => $user->id,
            'client_id' => $user->employee->client_id
        ])->first();

        if($appRating) {
            $date =  new \Carbon\Carbon('-3 months');
            if($date > $appRating->updated_at) {
                return true;
            }
        }

        return false;
    }

    /**
     * Check first time of mobile in app rating
     *
     * @param $user
     * @return bool
     */
    public static function isFirstRating($user)
    {
        $count = AppRating::where([
            'user_id' => $user->id,
            'client_id' => $user->employee->client_id
        ])->count();

        if($count) return false;

        return true;
    }
}