<?php


namespace App\Helpers;

use RecursiveDirectoryIterator;
use RecursiveIteratorIterator;
use ZipArchive;

class ZipHelper
{
    /**
     * Zip a folder
     * 
     * @param string $folderPath
     * @return bool|string
     */
    public static function zipFolder(string $folderPath)
    {
        $files = new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator($folderPath), 
            RecursiveIteratorIterator::LEAVES_ONLY
        );
        
        $filesToZip = [];

        foreach ($files as $name => $file) {
            // Skip directories (they would be added automatically)
            if (!$file->isDir()) {
                // Get real and relative path for current file
                $filePath = $file->getRealPath();
                $relativePath = substr($filePath, strlen($folderPath) + 1);
                $filesToZip[] = [
                    'path' => $filePath,
                    'relative_path' => $relativePath
                ];
            }
        }

        if (count($filesToZip) > 0) {
            $zipFile = $folderPath . '.zip';
            $zip = new \ZipArchive();
            $zip->open($zipFile, ZipArchive::CREATE | ZipArchive::OVERWRITE);
            
            foreach ($filesToZip as $file) {
                // Add current file to archive
                $zip->addFile($file['path'], $file['relative_path']);
            }

            $zip->close();

            return $zipFile;
        }
        
        return false;
    }
}