<?php

namespace App\Http\Controllers\Api;

use App\Facades\Context;
use App\Helpers\ResourceLocationBuilder;
use App\Services\Attachment\ResponseAttachment;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use App\Http\Controllers\Api\ApiController;
use Storage;
use App\Traits\JsonRespondController;

class FileController extends ApiController
{
    use JsonRespondController;

    /**
     * Get logo files
     *
     * @param Request $request
     */
    public function getLogoFile(Request $request, $filename)
    {
        $code = Context::client()->get()->getBusinessKey();
        $url = "clients/$code/logo/$filename";
        return app(ResponseAttachment::class)->execute(["url" => $url]);
    }

    /**
     * Get logo files
     *
     * @param Request $request
     */
    public function getLibraryFile(Request $request, $documentProfileId, $filename)
    {
        $code = Context::client()->get()->getBusinessKey();
        $url = "clients/$code/document_profiles/$documentProfileId/$filename";
        return app(ResponseAttachment::class)->execute(["url" => $url]);
    }

    /**
     * Get client asset files
     *
     * @param Request $request
     */
    public function getAssetFile(Request $request, $filename)
    {
        $code = Context::client()->get()->getBusinessKey();
        $url = "clients/$code/assets/$filename";
        return app(ResponseAttachment::class)->execute(["url" => $url]);
    }

    /**
     * Get public asset files
     *
     * @param Request $request
     */
    public function getPublicAssetFile(Request $request, $filename)
    {
        $url = "qualee/assets/$filename";
        return app(ResponseAttachment::class)->execute(["url" => $url]);
    }

    /**
     * Get public questionaire files
     *
     * @param Request $request
     */
    public function getPublicQuestionnaireFile(Request $request, $filename)
    {
        $url = (new ResourceLocationBuilder())->getQuestionnairePath() . "/$filename";
        return app(ResponseAttachment::class)->execute(["url" => $url]);
    }

    /**
     * Get public driver files
     *
     * @param Request $request
     */
    public function getPublicDriverFile(Request $request, $filename)
    {
        $url = (new ResourceLocationBuilder())->getDriverPath() . "/$filename";
        return app(ResponseAttachment::class)->execute(["url" => $url]);
    }

    /**
     * Get public asset files
     *
     * @param Request $request
     */
    public function getMessageAttachment(Request $request, $filename)
    {
        $code = Context::client()->get()->getBusinessKey();
        $url = "clients/$code/message-attachments/$filename";
        return app(ResponseAttachment::class)->execute(["url" => $url]);
    }

    /**
     * Get public asset files
     *
     * @param Request $request
     */
    public function getAvatarUserAttachment(Request $request, $usercode, $filename)
    {
        $code = Context::client()->get()->getBusinessKey();
        $url = "clients/$code/users/$usercode/content-photo/$filename";
        return app(ResponseAttachment::class)->execute(["url" => $url]);
    }

    /**
     * Get signed document file
     *
     * @param Request $request
     * @param $code
     * @param $userCode
     * @param $filename
     * @return JsonResponse
     */
    public function getSignedDocument(Request $request, $userCode, $filename)
    {
        $code = Context::client()->get()->getBusinessKey();
        $url = "clients/$code/users/$userCode/signed-document/$filename";
        return app(ResponseAttachment::class)->execute(["url" => $url]);
    }

    public function getContentFileAttachment(Request $request, $usercode, $filename)
    {
        $code = Context::client()->get()->getBusinessKey();
        $url = "clients/$code/users/$usercode/content-file/$filename";
        return app(ResponseAttachment::class)->execute(["url" => $url]);
    }
}
