<?php

namespace App\Http\Controllers\Api\Mobile_V1\Auth;

use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Http\Controllers\Api\ApiController;
use App\Models\Mobile\User\PasswordReset;
use App\Services\Mobile\Auth\ForgotPassword;
use App\Services\Mobile\Auth\RedirectBySchemaUrl;
use App\Services\Mobile\Auth\ResetDefaultPassword;
use App\Services\Mobile\Auth\ResetPassword;
use App\Traits\MobileJsonResponseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Password;
use Jenssegers\Agent\Agent;

class ForgotPasswordController extends ApiController
{
    use MobileJsonResponseController;

    /**
     * Send forgot password email
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function forgot(Request $request)
    {
        $response = app(ForgotPassword::class)->execute($request->all());

        if ($response == Password::RESET_LINK_SENT) {
            return $this->responseWithSuccessMessage(trans($response));
        }

        throw new InvalidRequestException(trans($response), $response);
    }

    /**
     * Reset password
     *
     * @param Request $request
     * @param $token
     * @param $email
     * @return \Illuminate\Http\JsonResponse
     */
    public function reset(Request $request)
    {
        $response = app(ResetPassword::class)->execute($request->all());

        if ($response == Password::PASSWORD_RESET) {
            return $this->responseWithSuccessMessage(trans($response));
        }

        throw new InvalidRequestException(trans($response), $response);
    }

    /**
     * Reset default password
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function resetDefaultPassword(Request $request)
    {
        try {
            $data = $request->all();
            app(ResetDefaultPassword::class)->execute($data);
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }

        return $this->successResponse(__('Password reset successfully.'));
    }

    /**
     * Redirect by scheme url
     *
     * Go to suitable platform (web/mobile) screen when user enter reset password link
     *
     * @param Request $request
     * @param $token
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function redirectBySchemaUrl(Request $request, $token)
    {
        $data = $request->all();
        $data['token'] = $token;
        $url = app(redirectBySchemaUrl::class)->execute($data);
        return redirect($url);
    }
}
