<?php

namespace App\Http\Controllers\Api\Mobile_V1\Journey;

use App\Facades\Context;
use App\Http\Controllers\Api\ApiController;
use App\Mail\JourneyStepNotification;
use App\Services\Mobile\Journey\GetStepDetail;
use App\Services\Mobile\Journey\GetStepResults;
use App\Services\Mobile\Journey\GetSteps;
use App\Services\Mobile\Journey\SkipStepDetails;
use App\Services\Mobile\Journey\SubmitStepDetails;
use App\Services\Mobile\Journey\GetJourneyByStepId;
use App\Services\Mobile\Journey\GetDocumentStatus;
use App\Traits\MobileJsonResponseController;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Mockery\Exception;

class JourneyController extends ApiController
{
    use MobileJsonResponseController;

    /**
     * Get Journey Steps
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function getSteps(Request $request): JsonResponse
    {
        try {
            $result = app(GetSteps::class)->execute($request->all());
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }

        return $this->successResponse(__('Fetch data successfully.'), $result);
    }

    /**
     * Get Step Details
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function getStepDetail(Request $request): JsonResponse
    {
        $data = $request->all();
        try {
            $result = app(GetStepDetail::class)->execute($data);
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }

        return $this->successResponse(__('Fetch data successfully.'), $result);
    }

    /**
     * Save Step Details
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function submitStepDetails(Request $request): JsonResponse
    {
        try {
            $result = app(SubmitStepDetails::class)->execute($request->all());
            $journey_step_result = app(GetStepDetail::class)->execute($request->all());
            $step = $journey_step_result->jsonSerialize();
            if ($step['is_notify']) {
                $journey = app(GetJourneyByStepId::class)->execute(['id' => $step['journey_id']]);
                $emails = explode(";", $step['emails_notify']);
                $user = Context::user()->get();
                foreach ($emails as $email) {
                    $name = explode("@", $email);
                    Mail::to($email)->send(new JourneyStepNotification($user, $step['step_name'], $journey->name, $name[0]));
                }
            }
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }

        return $this->successResponse(__('Submit data successfully.'), $result);
    }

    /**
     * Skip a step
     */
    public function skipStep(Request $request): JsonResponse
    {
        try {
            $result = app(SkipStepDetails::class)->execute($request->all());
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }
        return $this->successResponse(__('Submit data successfully.'), $result);
    }

    /**
     * Get Step details
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function getStepResults(Request $request): JsonResponse
    {
        try {
            $result = app(GetStepResults::class)->execute($request->all());
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }

        return $this->successResponse(__('Fetch data successfully.'), $result);
    }

    public function getFormDocumentStatus(string $documentId, Request $request): JsonResponse
    {
        $data = array_merge($request->all(), ['document_id' => $documentId]);
        try {
            $result = app(GetDocumentStatus::class)->execute($data);
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }

        return $this->successResponse(__('Fetch data successfully.'), $result);
    }
}
