<?php

namespace App\Http\Controllers\Api\Mobile_V1\Message;

use App\Enum\ConversationStatues;
use App\Enum\Roles;
use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\Message\AnonymousConversationCategory as AnonymousConversationCategoryResource;
use App\Http\Resources\Message\Conversation;
use App\Http\Resources\Mobile\Message\Conversation as ConversationResource;
use App\Http\Resources\Mobile\Message\ConversationMessage as ConversationMessageResource;
use App\Http\Resources\Mobile\Message\MessageLite as MessageLiteResource;
use App\Services\AnonymousConversationCategory\GetAnonymousConversationCategory;
use App\Services\Message\ChangeAnonymousConversationStatus;
use App\Services\Message\CreateMessage;
use App\Services\Message\DeleteConversation;
use App\Services\Message\GetMessageConversation;
use App\Services\Message\GetNumberUnreadMessage;
use App\Services\Message\ManageWhistleblowingCategoryConversation;
use App\Services\Message\MarkConversationAsRead;
use App\Services\Message\TransferWhistleblower;
use App\Services\Mobile\Message\CreateConversationEmployee;
use App\Services\Mobile\Message\GetConversations;
use App\Traits\MobileJsonResponseController;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;

/**
 * Class MessageController
 * @package App\Http\Controllers\Api\v1\Message
 */
class MessageController extends ApiController
{
    use MobileJsonResponseController;

    /**
     * @param Request $request
     * @return JsonResponse
     */
    public function store(Request $request)
    {
        $message = app(CreateMessage::class)->execute($request->except('sender_id'));

        return $this->successResponse(__('Submit data successfully'), new MessageLiteResource($message));
    }

    /**
     * @param Request $request
     * @return ConversationResource
     */
    public function createConversationEmployee(Request $request)
    {
        $data = $request->all();
        $conversation = app(CreateConversationEmployee::class)->execute($data);
        return $this->successResponse(__('Submit data successfully'), new ConversationResource($conversation));
    }

    /**
     * @param Request $request
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public function getConversations(Request $request)
    {
        $conversations = app(GetConversations::class)->execute($request->all());
        return ConversationResource::collection($conversations);
    }

    /**
     * @param Request $request
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public function getConversationDetail(string $id, Request $request)
    {
        $data = array_merge($request->all(), ['id' => $id]);
        $conversation = app(GetConversations::class)->execute($data)->first();
        return new ConversationResource($conversation);
    }

    /**
     * @param string $id
     * @param Request $request
     * @return ConversationMessageResource
     */
    public function getMessageConversation(string $id, Request $request)
    {
        $options = array_merge(['id' => $id], $request->all());
        $conversation = app(GetMessageConversation::class)->execute($options);
        return new ConversationMessageResource($conversation);
    }

    /**
     * @param string $id
     * @param Request $request
     * @return JsonResponse
     */
    public function markConversationAsRead(string $id, Request $request)
    {
        $data = array_merge(['id' => $id], $request->all());
        app(MarkConversationAsRead::class)->execute($data);

        return $this->responseWithStatusCode(200, "Mark conversation as read successfully");
    }

    /**
     * @param string $id
     * @param Request $request
     * @return JsonResponse
     */
    public function deleteConversation(string $id, Request $request)
    {
        $data = array_merge(['id' => $id], $request->all());
        app(DeleteConversation::class)->execute($data);

        return $this->responseWithStatusCode(200, "Delete conversation successfully");
    }

    /**
     * @return JsonResponse
     */
    public function getNumberUnreadMessage()
    {
        $count = app(GetNumberUnreadMessage::class)->execute(['type'=>Roles::FRONT_USER]);
        return $this->responseData(['count' => $count]);
    }

    /**
     *
     */
    public function getAnonymousConversationCategory()
    {
        $categories = app(GetAnonymousConversationCategory::class)->execute();
        return AnonymousConversationCategoryResource::collection($categories);
    }

    /**
     * @param  string  $id
     * @param  Request  $request
     * @return Conversation
     */
    public function manageWhistlegblowingCategoryConversation(string $id,Request $request)
    {
        $input = array_merge($request->all(), ['id' => $id]);
        $conversation = app(ManageWhistleblowingCategoryConversation::class)->execute($input);
        return new ConversationResource($conversation);
    }

    /**
     * @param  string  $id
     * @param  Request  $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function transferWhistleblower(string $id, Request $request)
    {
        $input = array_merge($request->all(), ['id' => $id]);
        app(TransferWhistleblower::class)->execute($input);
        return $this->responseWithStatusCode(200, "Transfer conversation successfully");
    }

    /**
     * @param  string  $id
     * @param  Request  $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function closeAnonymousConversation(string $id, Request $request)
    {
        $input = array_merge($request->all(), ['id' => $id, 'status' => ConversationStatues::CLOSE]);
        app(ChangeAnonymousConversationStatus::class)->execute($input);
        return $this->responseWithStatusCode(200, "Close conversation successfully");
    }

    /**
     * @param  string  $id
     * @param  Request  $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function reopenAnonymousConversation(string $id, Request $request)
    {
        $input = array_merge($request->all(), ['id' => $id, 'status' => ConversationStatues::ACTIVE]);
        $conversation = app(ChangeAnonymousConversationStatus::class)->execute($input);
        return $this->responseWithStatusCode(200, "Reopen conversation successfully");
    }
}
