<?php


namespace App\Http\Controllers\Api\Mobile_V1\Segment;

use App\Helpers\SegmentHelper;
use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\Mobile\Segment\SegmentEmployee;
use App\Http\Resources\Mobile\User\Employee as EmployeeResource;
use App\Models\Segment\SegmentType;
use App\Services\Employee\GetEmployeeDetail;
use App\Services\Mobile\Employee\SearchByKeyword;
use App\Services\Mobile\Segment\Segments;
use App\Http\Resources\Mobile\Segment\Segments as SegmentResource;
use App\Services\Segment\Employee\NotBelongToTeam;
use App\Services\Segment\SegmentType\GetSegmentEmployee;
use App\Services\Segment\SegmentType\GetSegmentTypeDetail;
use App\Traits\MobileJsonResponseController;
use App\Enum\SegmentTypes;
use Illuminate\Http\Request;
use App\Http\Resources\User\Employee as EmployeeDetailResource;

class SegmentController extends ApiController
{
    use MobileJsonResponseController;

    /**
     * Get all departments
     *
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public function getSegments()
    {
        $segments = app(Segments::class)->execute($this->options);
        return SegmentResource::collection($segments);
    }

    /**
     * Get teams of one department
     *
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public function getSegmentTeams()
    {
        //Get segment code by enum of team
        $code = SegmentType::where('id', SegmentTypes::TEAM)->first()->code;
        $data = array_merge($this->options, ['code' => $code, 'filter_on_mobile' => true]);
        $segments = app(GetSegmentTypeDetail::class)->execute($data);
        $segmentResource = SegmentHelper::getSegmentTypeResourceMobile($code, $segments);
        $employees = app(NotBelongToTeam::class)->execute(
            array_merge($this->options, ['segments' => $segmentResource->resource->toArray()])
        );

        return $segmentResource->additional(['employees_not_belong_to_any_team' =>  EmployeeResource::collection($employees)]);
    }

    /**
     * Get employees of team
     *
     * @param string $segmentCode
     * @param Request $request
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public function getSegmentEmployees(string $segmentCode, Request $request)
    {
        //Get segment code by enum of team
        $code = SegmentType::where('id', SegmentTypes::TEAM)->first()->code;
        $data = array_merge($this->options, ['code' => $code, 'segment_code' => $segmentCode, 'filter_on_mobile' => true]);
        $employees = app(GetSegmentEmployee::class)->execute($data);

        return EmployeeResource::collection($employees);
    }

    public function getEmployeeByCode(string $code)
    {
        $employee = app(GetEmployeeDetail::class)->execute(['code' => $code]);
        return new EmployeeDetailResource($employee);
    }

    /**
     * Search employee
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public function searchEmployee(Request $request)
    {
        if(strlen(trim($request->keyword)) < 3) {
            return $this->successResponse(__('There are no result for your keyword.'), []);
        }
        $data = array_merge($this->options, ['keyword' => trim($request->keyword)]);
        $employee = app(SearchByKeyword::class)->execute($data);

        return SegmentEmployee::collection($employee);
    }
}
