<?php

namespace App\Http\Controllers\Api\Mobile_V1\Setting;

use App\Http\Controllers\Controller;
use App\Services\Mobile\Setting\GetProfile;
use App\Services\Mobile\Setting\ReportBug;
use App\Services\Mobile\Setting\UpdateAvatar;
use App\Services\Mobile\Setting\UpdatePassword;
use App\Services\Mobile\Setting\UpdateProfile;
use App\Traits\MobileJsonResponseController;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Mockery\Exception;

class SettingController extends Controller
{
    use MobileJsonResponseController;

    /**
     * Update user profile
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function updateProfile(Request $request): JsonResponse
    {
        try {
            $result = app(UpdateProfile::class)->execute($request->all());
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }

        return $this->successResponse(__('Update data successfully.'), $result);
    }

    /**
     * Get user profile
     *
     * @return JsonResponse
     */
    public function getProfile(): JsonResponse
    {
        try {
            $result =  app(GetProfile::class)->execute();
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }

        return $this->successResponse(__('Fetch data successfully.'), $result);
    }

    /**
     * @param Request $request
     * @return JsonResponse
     */
    public function reportBug(Request $request) : JsonResponse
    {
        try {
            $data = $request->all();
            $result = app(ReportBug::class)->execute($data);
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }

        return $this->successResponse(__('Submit data successfully.'));
    }

    /**
     * @param Request $request
     * @return JsonResponse
     */
    public function updatePassword(Request $request): JsonResponse
    {
        try {
            $result =  app(UpdatePassword::class)->execute($request->all());
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }

        if(!$result) {
            return $this->errorResponse(__('Wrong password information.'));
        }

        return $this->successResponse(__('Change password successfully.'), $result);
    }

    public function updateAvatar(Request $request)
    {
        try {
            $result =  app(UpdateAvatar::class)->execute($request->all());
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }

        return $this->successResponse(__('Update avatar successfully.'), $result);
    }
}
