<?php

namespace App\Http\Controllers\Api\Mobile_V1\User;

use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\Mobile\User\UserLite;
use App\Services\Mobile\Action\GetPendingActionResults;
use App\Services\Mobile\Employee\GetEmployees;
use App\Traits\MobileJsonResponseController;
use Illuminate\Http\Request;
use Mockery\Exception;
use App\Services\Mobile\Action\GetPendingActions;
use App\Services\Mobile\Action\GetPendingAction;

class UserController extends ApiController
{
    use MobileJsonResponseController;

    /**
     * Get list of all pending actions
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function getPendingActions(Request $request)
    {
        try {
            $result = app(GetPendingActions::class)->execute($request->all());
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }
        return $this->successResponse(__('Fetch data successfully.'), $result);
    }

    /**
     * Get pending action steps by id
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function getPendingAction(Request $request)
    {
        try {
            $result = app(GetPendingAction::class)->execute($request->all());
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }
        return $this->successResponse(__('Fetch data successfully.'), $result);
    }

    /**
     * Get results of pending actions has been finished/submitted
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function getPendingActionResults(Request $request)
    {
        try {
            $result = app(GetPendingActionResults::class)->execute($request->all());
        } catch (Exception $e) {
            return $this->errorResponse($e->getMessage(), $e->getCode());
        }
        return $this->successResponse(__('Fetch data successfully.'), $result);
    }

    /**
     * Get results of pending actions has been finished/submitted
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function getEmployees(Request $request)
    {
        $users = app(GetEmployees::class)->execute($request->all());
        return UserLite::collection($users);
    }
}
