<?php
namespace App\Http\Controllers\Api\v1\AlertMessage;

use App\Services\AlertMessage\CreateAlertMessage;
use App\Services\AlertMessage\DeleteAlertMessage;
use App\Services\AlertMessage\GetAlertMessage;
use App\Services\AlertMessage\GetSAAlertMessage;
use App\Services\AlertMessage\MarkAsRead;
use App\Services\AlertMessage\UpdateAlertMessage;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\AlertMessage\AdminAlertMessage as AdminAlertMessageResource;
use App\Http\Resources\AlertMessage\SAAlertMessage as SAAlertMessageResource;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;

class AlertMessageController extends ApiController
{
    /**
     * Create alert message
     * 
     * @param Request $request
     * @return SAAlertMessageResource
     */
    public function create(Request $request)
    {
        $alertMessage = app(CreateAlertMessage::class)->execute($request->all());
        
        return new SAAlertMessageResource($alertMessage);
    }

    /**
     * Update alert message
     * 
     * @param Request $request
     * @param $id
     * @return SAAlertMessageResource
     */
    public function update(Request $request, $id)
    {
        $input = array_merge(['id' => $id], $request->all());
        $alertMessage = app(UpdateAlertMessage::class)->execute($input);

        return new SAAlertMessageResource($alertMessage);
    }

    /**
     * Delete alert message
     * 
     * @param $id
     * @return JsonResponse
     */
    public function delete($id)
    {
        app(DeleteAlertMessage::class)->execute(['id' => $id]);

        return $this->respondObjectDeleted($id);
    }

    /**
     * Get alert message list for SA
     *
     * @param Request $request
     * @return AnonymousResourceCollection
     */
    public function getSAAlertMessages(Request $request)
    {
        $saAlertMessages = app(GetSAAlertMessage::class)->execute();

        return SAAlertMessageResource::collection($saAlertMessages);
    }

    /**
     * Get alert message list for admin
     * 
     * @param Request $request
     * @return AnonymousResourceCollection
     */
    public function getAlertMessages(Request $request)
    {
        $alertMessages = app(GetAlertMessage::class)->execute();
        
        return AdminAlertMessageResource::collection($alertMessages);
    }

    /**
     * Mark alert message as read
     * 
     * @param $id
     * @return JsonResponse
     */
    public function markAsRead($id)
    {
        app(MarkAsRead::class)->execute(['id' => $id]);
        
        return $this->responseWithSuccessMessage('Marked as read successfully');
    }
}
