<?php
namespace App\Http\Controllers\Api\v1\AppRating;

use App\Services\AppRating\DownloadRating;
use App\Services\AppRating\GetRating;
use App\Services\AppRating\GetRatingByPoint;
use App\Services\AppRating\GetRatingOverTimeByPlatform;
use Illuminate\Http\Request;
use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\AppRating\AppRating as AppRatingResource;
use App\Http\Resources\AppRating\Review as ReviewResource;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;
use Illuminate\Http\Resources\Json\JsonResource;

class AppRatingController extends ApiController
{
    /**
     * Get rating by point
     * 
     * @param Request $request
     * @return AnonymousResourceCollection
     */
    public function getAppRating(Request $request)
    {
        $ratings = app(GetRatingByPoint::class)->execute();
        
        return AppRatingResource::collection($ratings);
    }

    /**
     * Get rating over time by platform
     *
     * @return AnonymousResourceCollection
     */
    public function getRatingOverTimeByPlatform()
    {
        $ratingOverTimeByPlatform = app(GetRatingOverTimeByPlatform::class)->execute();

        return JsonResource::collection($ratingOverTimeByPlatform);
    }

    /**
     * Get reviews
     * 
     * @return AnonymousResourceCollection
     */
    public function getReviews()
    {
        $reviews = app(GetRating::class)->execute();
        
        return ReviewResource::collection($reviews);
    }

    /**
     * Get reviews
     *
     * @return AnonymousResourceCollection
     */
    public function downloadReviews()
    {
        return app(DownloadRating::class)->execute();
    }
}
