<?php

namespace App\Http\Controllers\Api\v1;

use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\Asset as AssetResource;
use App\Services\Asset\CreateAsset;
use App\Services\Asset\DeleteAsset;
use App\Services\Asset\GetAssets;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;

class AssetController extends ApiController
{
    /**
     * List all assets
     *
     * @return mixed
     */
    public function getAll()
    {
        $assets =  app(GetAssets::class)->execute($this->options);
        return AssetResource::collection($assets);
    }

    /**
     * Add Asset
     *
     * @param Request $request
     * @return mixed
     * @throws \Exception
     */
    public function create(Request $request): AssetResource
    {
        try {
            $data =  $request->all();
            $asset = app(CreateAsset::class)->execute($data);
        } catch (\Exception $e) {
            throw $e;
        }
        return new AssetResource($asset);
    }

    /**
     * Delete asset
     *
     * @param $id
     * @return JsonResponse
     * @throws \Exception
     */
    public function delete(int $id): JsonResponse
    {
        app(DeleteAsset::class)->execute(['id' => $id]);
        return $this->respondObjectDeleted($id);
    }
}
