<?php
namespace App\Http\Controllers\Api\v1\Client;

use Illuminate\Http\Request;
use App\Http\Controllers\Api\ApiController;
use Auth;

use App\Http\Resources\Client\ClientValue as ClientValueResource;
use App\Services\Client\ClientValue\GetClientValue;
use App\Services\Client\ClientValue\CreateClientValue;
use App\Services\Client\ClientValue\EditClientValue;
use App\Services\Client\ClientValue\DeleteClientValue;

class ClientValueController extends ApiController
{
    /**
     * Get value list
     *
     * @param Request $request
     * @return void
     */
    public function index(Request $request)
    {
        $values = app(GetClientValue::class)->execute($this->options);

        return ClientValueResource::collection($values);
    }

    /**
     * Store new value
     *
     * @param Request $request
     * @return void
     */
    public function store(Request $request)
    {
        $user = \Auth::user();
        $client = $user->getClient();

        $data = $request->all();
        $data['client_id'] = $client->id;

        $result = app(CreateClientValue::class)->execute($data);

        return new ClientValueResource($result);
    }

    /**
     * Update a value
     *
     * @param Request $request
     * @param [type] $value
     * @return void
     */
    public function update(Request $request, $value)
    {
        $user = \Auth::user();
        $client = $user->getClient();

        $data = $request->all();
        $data['client_id'] = $client->id;
        $data['id'] = $value;

        $result = app(EditClientValue::class)->execute($data);

        return new ClientValueResource($result);
    }

    /**
     * Delete a value
     *
     * @param Request $request
     * @param [type] $value
     * @return void
     */
    public function destroy(Request $request, $value)
    {
        app(DeleteClientValue::class)->execute(['id' => $value]);

        return $this->respondObjectDeleted($value);
    }
}