<?php
namespace App\Http\Controllers\Api\v1\Dashboard;

use App\Facades\Context;
use App\Http\Controllers\Api\ApiController;
use App\Services\Dashboard\GetStatistics;
use App\Services\Dashboard\Message\GetWhistleblowingDashboardData;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use App\Traits\JsonRespondController;
use App\Services\Dashboard\Engagement\GetEngagement;
use App\Http\Resources\Client\Client as ClientResource;
use App\Services\Engagement\BaseDriverScore;
use App\Http\Resources\Report\ReportScoring as BaseDriverResource;
use App\Enum\ScheduleEnum;
use App\Models\Driver\Driver;
use Carbon\Carbon;
use App\Services\Report\GetProgressOverTime;
use App\Services\DataControl\GetDataControl;

class DashboardController extends ApiController
{
    use JsonRespondController;

    public function engagement(Request $request)
    {
        $engagement = app(GetEngagement::class)->execute($request->all());

        return $this->respond($engagement);
    }

    public function enpScoring(Request $request)
    {
        $enps_avg = app(BaseDriverScore::class)->execute(array_merge($request->all(), ['enps' => true]));
        if(isset($enps_avg)){
            $questionnaires = Driver::where('parent_id', 0)->limit(4)->get();
            $enpScores = array_merge($enps_avg, ['description' => $questionnaires]);
            return $this->respond($enpScores);
        } else {
            return $this->responseData(null);
        }
    }

    public function getProgressOverTime(Request $request)
    {
        $progress_over_time = app(GetProgressOverTime::class)->execute($request->all());
        if(isset($progress_over_time)){
            return $this->responseData($progress_over_time);
        } else {
            return $this->responseData(null);
        }   
    }
    /**
     * Get dashboard statistics
     * 
     * @return JsonResponse
     */
    public function getStatistics()
    {
        $currentClient = Context::client()->get();
        $statistics = app(GetStatistics::class)->execute(['client_id' => $currentClient->getKey()]);
        return $this->respond(
            array_merge([
                'client' => new ClientResource($currentClient)
            ], $statistics)
        );
    }

    public function getWhistleblowingDashboardData()
    {
        $data = app(GetWhistleblowingDashboardData::class)->execute();
        return $this->responseData($data);
    }
}
