<?php
namespace App\Http\Controllers\Api\v1\Driver;

use App\Http\Controllers\Api\ApiController;
use Illuminate\Http\Request;
use App\Http\Resources\Driver\Driver as DriverResource;
use App\Services\Driver\GetDriver;
use App\Services\Driver\CreateDriver;
use App\Services\Driver\EditDriver;
use App\Services\Driver\DeleteDriver;

class DriverController extends ApiController
{
    /**
     * Get driver list
     *
     * @param Request $request
     * @return void
     */
    public function index(Request $request)
    {
        $drivers = app(GetDriver::class)->execute($request->all());

        return DriverResource::collection($drivers);
    }

    /**
     * Store new driver
     *
     * @param Request $request
     * @return void
     */
    public function store(Request $request)
    {
        $result = app(CreateDriver::class)->execute($request->all());

        return new DriverResource($result);
    }

    /**
     * Update a driver
     *
     * @param Request $request
     * @param [type] $driver
     * @return void
     */
    public function update(Request $request, $driver)
    {
        $data = $request->all();
        $data['id'] = $driver;
        $result = app(EditDriver::class)->execute($data);

        return new DriverResource($result);
    }

    /**
     * Delete a driver
     *
     * @param Request $request
     * @param [type] $driver
     * @return void
     */
    public function destroy(Request $request, $driver)
    {
        app(DeleteDriver::class)->execute(['id' => $driver]);

        return $this->respondObjectDeleted($driver);
    }
}