<?php

namespace App\Http\Controllers\Api\v1\Employee;

use Illuminate\Support\Facades\Storage;
use App\Http\Controllers\Api\ApiController;
use Illuminate\Http\Request;
use App\Helpers\CsvHelper;

class DownloadCsvController extends ApiController
{
    private function getCsvFolder()
    {
        $folderName = "passwords_csv";
        Storage::disk('local')->makeDirectory($folderName);
        return config('filesystems.disks.local.root') . '/' . $folderName;
    }
    private function getCsvFile($id)
    {
        $folderPath = $this->getCsvFolder();
        return $folderPath . '/' . $id . ".csv";
    }

    //
    public function download($id)
    {
        $folderPath = $this->getCsvFolder();
        $filePath = $this->getCsvFile($id);
        // Get the current time minus 10 minutes
        $minutesAgo = time() - (10 * 60);

        // Get the list of files in the folder
        $files = scandir($folderPath);
        foreach ($files as $file) {
            // Exclude current and parent directory
            if ($file === '.' || $file === '..') {
                continue;
            }

            $filePath1 = $folderPath . '/' . $file;
            // Check if the file was created 10 minutes ago or earlier
            if (filectime($filePath1) <= $minutesAgo) {
                unlink($filePath1);
            }
        }

        if (file_exists($filePath)) {
            return response()->download($filePath, "system-generated-passwords.csv"); //->deleteFileAfterSend();
        }
        return response()->json(['error' => 'The file is expired and no longer available'], 404);
    }

    public function save(Request $req, $id)
    {
        $filePath = $this->getCsvFile($id);
        CsvHelper::exportCsv($filePath, $req->rows, $req->header);
        return response()->json(['success' => true]);
    }
}
