<?php

namespace App\Http\Controllers\Api\v1\Engagement;

use App\Http\Controllers\Api\ApiController;
use Illuminate\Http\Request;
use App\Traits\JsonRespondController;
use App\Services\Engagement\EmployeeNetResponse as EmployeeNetResponse;
use App\Models\Driver\Driver;
use Carbon\Carbon;
use App\Services\Engagement\BaseDriverScore;
use App\Http\Resources\Driver\Driver as DriverResource;

class eNPSController extends ApiController
{
    use JsonRespondController;
    /**
     * eNPSController
     *
     * @param Request $request
     * @return mixed
     */
    public function getENPScoring(Request $request)
    {
        // base on the core eNPS formular
        $eNPSDriver = $this->getCoreENPS($request);
        $eNPScores = null;
        // processing total all of driver avg/enps scoring
        foreach ($eNPSDriver as $key => $value) {
            $eNPScores['total_responses'][] = $value['total_responses'];
            $eNPScores['promoters'][] = $value['promoters'];
            $eNPScores['passive'][] = $value['passive'];
            $eNPScores['detractor'][] = $value['detractor'];
            $eNPScores['driver_avg'][] = $value['driver_avg'];
            $eNPScores['driver_enps'][] = $value['driver_enps'];
        }
        $questionnaires = Driver::where('parent_id', 0)->limit(4)->get();
        if(isset($eNPScores)){
            $data = [
                'total_responses' => array_sum($eNPScores['total_responses']),
                'promoters' => array_sum($eNPScores['promoters'])/count($eNPScores['promoters']),
                'passive' => array_sum($eNPScores['passive'])/count($eNPScores['passive']),
                'detractor' => array_sum($eNPScores['detractor'])/count($eNPScores['detractor']),
                'driver_avg' => array_sum($eNPScores['driver_avg'])/count($eNPScores['driver_avg']),
                'driver_enps' => array_sum($eNPScores['driver_enps'])/count($eNPScores['driver_enps']),
                'description' => $questionnaires
            ];
            return $data;
        } else {
            return $this->responseData(null);
        }
    }

    /**
     * get driver score
     *
     * @param Request $request
     * @return mixed
     */
    public function getByDrivers(Request $request)
    {
        // base on the core formular
        $eNPSDriver = $this->getCoreENPS($request);
        return $eNPSDriver;
    }

    /**
     * eNPSController
     *
     * @param Request $request
     * @return mixed
     */
    public function getDriverPerformance(Request $request)
    {
        // base on the core formular
        $eNPSDriver = $this->getCoreENPS($request);
        if(isset($eNPSDriver) && count($eNPSDriver) > 0){
            $eNPScores = [];
            $dataMonth['by_month'] = Carbon::parse($request['by_month']."01")->format('Ym');
            // processing total all of driver avg/enps scoring
            foreach ($eNPSDriver as $key => $value) {
                $eNPScores['driver_avg'][$key] = $value['driver_avg'];
                $eNPScores['driver_enps'][$key] = $value['driver_enps'];
            }
            if(isset($data['enps'])){
                $performanceDriver = $this->getOpportunities($eNPScores['driver_enps'], $dataMonth);
            } else {
                $performanceDriver = $this->getOpportunities($eNPScores['driver_avg'],  $dataMonth);
            }
            return $this->responseData($performanceDriver);
        } else {
            return $this->responseData($eNPSDriver);
        }
    }

    public function getCoreENPS(Request $request){
        $request = $request->all();
        if(isset($request['by_month'])){
            $request['by_month'] = Carbon::parse($request['by_month']."01")->format('Ym');
            $scores = app(BaseDriverScore::class)->execute(array_merge($request, ['performance' => true]));
            // processing for one of each driver
            $eNPSDriver = [];
            if(isset($scores)){
                foreach ($scores as $key => $score) {
                    if(isset($score['driver_avg'])){
                        $eNPSDriver[$key]['promoters'] = $score['promoters'];
                        $eNPSDriver[$key]['passives'] = $score['passives'];
                        $eNPSDriver[$key]['detractors'] = $score['detractors'];
                        $eNPSDriver[$key]['driver_avg'] = $score['driver_avg'];
                        $eNPSDriver[$key]['driver_enps'] = $score['driver_enps'];
                    }
                }
            }
            return $eNPSDriver;
        }
    }

    /**
     * define the drivers performance
     */
    public function getOpportunities($drivers, $by_month = []){
        asort($drivers);
        $opportunities = array_slice($drivers, 0, 3, true);
        asort($opportunities);
        $strengths = array_slice($drivers, -3, 3, true);
        asort($strengths);
        $opportunities_result = [];
        $strengths_result = [];
        // processing for trength drivers
        foreach ($opportunities as $driver_id => $value) {
            $scores = app(BaseDriverScore::class)->execute(array_merge($by_month, ['main_drivers' => $driver_id, 'performance' => true]));
            $trend_month['by_month'] = Carbon::parse($by_month['by_month']."01")->subMonth(1)->format('Ym');
            $trends = app(BaseDriverScore::class)->execute(array_merge($trend_month, ['main_drivers' => $driver_id, 'performance' => true, 'trend' => 'true']));
            if(isset($scores) && isset($trends)){
                $scores_trending = array_combine($scores, $trends);
                $index = 0;
                foreach ($scores_trending as $key => $value) {
                    $trending = (float)$key - (float)$value;
                    if($trending > 0){
                        $trending_value = "1";
                    } elseif($trending < 0) {
                        $trending_value = "-1";
                    } else {
                        $trending_value = "0";
                    }
                    if($index == 0){
                        $trends['driver_avg'] = $trending_value;
                    } else {
                        $trends['driver_enps'] = $trending_value;
                    }
                    $index++;
                }
            }
            $scores = [
                'score' => isset($scores) ? $scores : [], 
                'strength' => isset($trends) ? $trends : []
            ];
            $driver = Driver::find($driver_id);
            $rsDriver = new DriverResource($driver);
            $opportunities_result['opportunities'][] = array_merge([$rsDriver], [$scores]);
        }
        
        // processing for trength drivers
        foreach ($strengths as $driver_id => $value) {
            $scores = app(BaseDriverScore::class)->execute(array_merge($by_month, ['main_drivers' => $driver_id], ['performance' => true]));
            $trend_month['by_month'] = Carbon::parse($by_month['by_month']."01")->subMonth(1)->format('Ym');
            $trends = app(BaseDriverScore::class)->execute(array_merge($trend_month, ['main_drivers' => $driver_id], ['performance' => true, 'trend' => 'true']));
            if(isset($scores) && isset($trends)){
                $scores_trending = array_combine($scores, $trends);
                $index = 0;
                foreach ($scores_trending as $key => $value) {
                    $trending = (float)$key - (float)$value;
                    if($trending > 0){
                        $trending_value = "1";
                    } elseif($trending < 0) {
                        $trending_value = "-1";
                    } else {
                        $trending_value = "0";
                    }
                    if($index == 0){
                        $trends['driver_avg'] = $trending_value;
                    } else {
                        $trends['driver_enps'] = $trending_value;
                    }
                    $index++;
                }
            }
            $scores = [
                'score' => isset($scores) ? $scores : [], 
                'strength' => isset($trends) ? $trends : []
            ];
            $driver = Driver::find($driver_id);
            $rsDriver = new DriverResource($driver);
            $strengths_result['strengths'][] = array_merge([$rsDriver], [$scores]);
        }
        
        return array_merge($opportunities_result, $strengths_result);
    }
    /**
     * eNPSController
     *
     * @param Request $request
     * @return mixed
     */
    public function getParticipate(Request $request)
    {
        $request = $request->all();
        // get participate employees
        $total_participate = app(EmployeeNetResponse::class)->getParticipate($request)->count();
        // get surveyed employees
        $surveyed_employees = app(EmployeeNetResponse::class)->getTotalScheduleSurvey($request);

        if((int)$surveyed_employees > 0){
            $participate_rate = ((int)$total_participate/(int)$surveyed_employees)*100;
            $eNPSParticipate = [
                'surveyed_employees' => $total_participate,
                'total_employees' => $surveyed_employees,
                'participate_rate' => $participate_rate
            ];
            return $this->responseData($eNPSParticipate);
        } else {
            return $this->responseData(null);
        }
    }

    /**
     * eNPSController
     *
     * @param Request $request
     * @return mixed
     */
    public function getProgressOverTime(Request $request)
    {
        // base on the core formular
        $eNPSDriver = $this->getCoreENPSProcessingTime($request);
        if(!empty($eNPSDriver)){
            return $this->responseData($eNPSDriver);
        } else {
            return $this->responseData(null);
        }
    }

    public function getCoreENPSProcessingTime(Request $request){
        // get data result submit questionnaire
        $answers =  app(EmployeeNetResponse::class)->geteNPSProcessing($request->all());

        // define scoring result
        $eNPScoring = [
            'driver_enps' => [],
        ];
        
        $processingTime = [];
        // processing weighting scoring
        foreach ($answers as $key => $value) {
            $row = $value->toArray();
            $row['driver_enps'] = ((float)$row['promoters'] - (float)$row['detractor']) * (float)$row['weight'];
            $processingTime[$row['month']] = $row['month'];
            $eNPScoring['driver_enps'][$row['month']][] = (float)$row['driver_enps'];
        }
        $eNPSDriver = [];
        // processing for one of each driver
        foreach ($processingTime as $key => $value) {
            $month = Carbon::parse($value);
            $eNPSDriver[] = ['date' => $month, 'value' => array_sum($eNPScoring['driver_enps'][$key])];
        }
        return $eNPSDriver;
    }
}
