<?php

namespace App\Http\Controllers\Api\v1\Event;

use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\Event\Event as EventResource;
use App\Http\Resources\Event\NextEvents as NearestEventResource;
use App\Services\Event\GetEvent;
use App\Services\Event\GetDetailEvent;
use App\Services\Event\CreateEvent;
use App\Services\Event\DeleteEvent;
use App\Services\Event\SyncEvent;
use App\Services\Event\UpdateEvent;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;


class EventController extends ApiController
{
    /**
     * List all events
     * 
     * @return mixed
     */
    public function getAll(Request $request)
    {
        $events =  app(GetEvent::class)->execute($this->options);
        return EventResource::collection($events);
    }

    /**
     * List all nearest events
     *
     * @return mixed
     */
    public function getNearestAll(Request $request)
    {
        $events =  app(GetEvent::class)->execute($this->options);
        return NearestEventResource::collection($events);
    }

    /**
     * @param string $code
     * @return EventResource
     */
    public function get(string $code)
    {
        $event = app(GetDetailEvent::class)->execute(['code'=>$code]);
        return new EventResource($event);
    }
    /**
     * Add event
     * 
     * @param Request $request
     * @return mixed
     * @throws \Exception
     */
    public function create(Request $request)
    {
        try {
            $event = app(CreateEvent::class)->execute($request->all());
        } catch (\Exception $e) {
            throw $e;
        }
        return new EventResource($event);
    }

    /**
     * Update event
     *
     * @param Request $request
     * @param $code
     * @return EventResource
     * @throws \Exception
     */
    public function update(Request $request, $code)
    {
        try {
            $input = array_merge($request->all(), ['code' => $code]);
            $event = app(UpdateEvent::class)->execute($input);
        } catch (\Exception $e) {
            throw $e;
        }
        return new EventResource($event);
    }

    /**
     * Delete event
     * 
     * @param $code
     * @return JsonResponse
     * @throws \Exception
     */
    public function delete(string $code)
    {
        try {
            app(DeleteEvent::class)->execute(['code' => $code]);
        } catch (\Exception $e) {
            throw $e;
        }
        return $this->respondObjectDeleted($code);
    }

    /**
     * Sync events
     *
     * @param Request $request
     * @return AnonymousResourceCollection
     */
    public function sync(Request $request)
    {
        $events = app(SyncEvent::class)->execute($request->all());

        return EventResource::collection($events);
    }
}
