<?php

namespace App\Http\Controllers\Api\v1\Form;

use App\Enum\PlanConfigurations;
use App\Facades\Context;
use App\Helpers\PandaDocHelper;
use App\Http\Controllers\Api\ApiController;
use App\Services\Subscription\CheckRemainPlanAction;
use App\Services\Tool\Form\GetTemplates;
use App\Http\Resources\Tool\Form\Form as FormResource;
use App\Services\Tool\Form\IntegrateForm;
use App\Services\Tool\Form\RemoveIntegration;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;

class FormController extends ApiController
{
    
    /**
     * Get form templates
     *
     * @return mixed
     */
    public function getTemplates()
    {
        $templates = app(GetTemplates::class)->execute($this->options);
        
        return FormResource::collection($templates);
    }

    /**
     * Check current client integrated with PandaDoc form
     * 
     * @return JsonResponse
     */
    public function checkIntegration()
    {
        app(CheckRemainPlanAction::class)->execute(PlanConfigurations::PACKAGE_FORM);
        
        $client = Context::client()->get();
        $formAuthenticate = $client->formAuthenticate;
        $authorizationLink = (new PandaDocHelper())->getAuthorizationUrl();
        
        return $this->respond([
            'status' => !empty($formAuthenticate) ? PandaDocHelper::AUTH_LINKED_STATUS : PandaDocHelper::AUTH_OPEN_STATUS,
            'authorization_url' => empty($formAuthenticate) ? $authorizationLink : null
        ]);
    }

    /**
     * Integrate form
     * 
     * @param Request $request
     * @return JsonResponse
     */
    public function integrate(Request $request)
    {
        app(IntegrateForm::class)->execute($request->all());
        
        return $this->responseWithSuccessMessage('Integrated form successfully');
    }

    /**
     * Remove form integration
     * 
     * @return JsonResponse
     */
    public function removeIntegration()
    {
        app(RemoveIntegration::class)->execute();

        return $this->responseWithSuccessMessage('Removed form integration successfully');
    }
}
