<?php
namespace App\Http\Controllers\Api\v1\Initiative;

use App\Http\Controllers\Api\ApiController;
use App\Services\Initiative\UpdateCompletedInitiative;
use Illuminate\Http\Request;
use App\Http\Resources\Initiative\InitiativeDriver as InitiativeDriverResource;
use App\Http\Resources\Initiative\Initiative as InitiativeResource;
use App\Services\Initiative\GetInitiative;
use App\Services\Initiative\CreateInitiative;
use App\Services\Initiative\EditInitiative;
use App\Services\Initiative\DeleteInitiative;

class InitiativeController extends ApiController
{
    /**
     * Get initiative list
     *
     * @param Request $request
     * @return void
     */
    public function index(Request $request)
    {
        $initiatives = app(GetInitiative::class)->execute();

        return InitiativeDriverResource::collection($initiatives);
    }

    /**
     * Store new initiative
     *
     * @param Request $request
     * @return void
     */
    public function store(Request $request)
    {
        $result = app(CreateInitiative::class)->execute($request->all());

        return new InitiativeResource($result);
    }

    /**
     * Update a initiative
     *
     * @param Request $request
     * @param [type] $initiative
     * @return void
     */
    public function update(Request $request, $initiative)
    {
        $data = $request->all();
        $data['id'] = $initiative;

        $result = app(EditInitiative::class)->execute($data);

        return new InitiativeResource($result);
    }

    /**
     * Delete a initiative
     *
     * @param Request $request
     * @param [type] $initiative
     * @return void
     */
    public function destroy(Request $request, $initiative)
    {
        app(DeleteInitiative::class)->execute(['id' => $initiative]);

        return $this->respondObjectDeleted($initiative);
    }

    public function updateCompleted($initiative)
    {
        $result = app(UpdateCompletedInitiative::class)->execute(['id' => $initiative]);

        return new InitiativeResource($result);
    }
}