<?php


namespace App\Http\Controllers\Api\v1\Integration;


use App\Exceptions\InvalidRequestException;
use App\Helpers\StringHelper;
use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\Integration\Integration;
use App\Services\Integration\DisconnectIntegration;
use App\Services\Integration\GetIntegration;
use App\Services\Integration\GetLinkToken;
use App\Services\Integration\SyncIntegrationEmployee;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use App\Traits\JsonRespondController;
use App\Http\Resources\Integration\LinkToken;
use App\Http\Resources\Integration\AccountToken;
use App\Services\Integration\AuthorizeIntegration;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Log;

class IntegrationController extends ApiController
{
    use JsonRespondController;

    /**
     * Get integration link token
     *
     * @param Request $request
     * @return LinkToken
     */
    public function getLinkToken(Request $request)
    {
        $linkToken = app(GetLinkToken::class)->execute();

        return new LinkToken($linkToken);
    }

    /**
     * Get integration
     *
     * @param Request $request
     * @return JsonResource
     */
    public function get(Request $request)
    {
        $integrations = app(GetIntegration::class)->execute();

        return Integration::collection($integrations);
    }

    /**
     * Authorize integration
     *
     * @param Request $request
     * @return AccountToken
     */
    public function authorizeIntegration(Request $request)
    {
        $accountToken = app(AuthorizeIntegration::class)->execute($request->all());

        return new AccountToken($accountToken);
    }

    /**
     * Disconnect integration
     *
     * @param $slug
     * @return JsonResponse
     */
    public function disconnect($slug, $isHris, $isAts, $isCrm)
    {
        app(DisconnectIntegration::class)->execute(['slug' => $slug, 'isHris' => $isHris, 'isAts' => $isAts, 'isCrm' => $isCrm]);
        return $this->responseWithSuccessMessage('Disconnected integration successfully');
    }

    /**
     * Sync integration employee
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function syncIntegration(Request $request)
    {
        $signature = StringHelper::encodePayloadSignature($request->getContent(), config('integration.merge.webhook_signature'));
        if ($signature != $request->header('X-Merge-Webhook-Signature')) {
            Log::debug('Invalid webhook signature', [
                'signature' => $signature,
                'header-webhook-signature' => $request->header('X-Merge-Webhook-Signature'),
            ]);

            throw new InvalidRequestException('Invalid webhook signature');
        }

        app(SyncIntegrationEmployee::class)->execute($request->all());

        return $this->responseWithSuccessMessage('Completed integration synchronization');
    }
}
