<?php

namespace App\Http\Controllers\Api\v1\MasterData;

use App\Http\Controllers\Api\ApiController;
use App\Services\MasterData\Industry\CreateIndustry;
use App\Services\MasterData\Industry\DeleteIndustry;
use App\Services\MasterData\Industry\UpdateIndustry;
use Illuminate\Http\Request;
use App\Http\Resources\MasterData\City as CityResource;
use App\Http\Resources\MasterData\Industry as IndustryResource;
use App\Services\MasterData\Industry\GetIndustries;
use App\Services\MasterData\GetCities;

class MasterDataController extends ApiController
{
    /**
     * Get cities
     *
     * @param Request $request
     * @return void
     */
    public function getCities(Request $request)
    {
        $cities = app(GetCities::class)->execute();
        return CityResource::collection($cities);
    }

    /**
     * Get industries
     *
     * @param Request $request
     * @return void
     */
    public function getIndustries(Request $request)
    {
        $industries = app(GetIndustries::class)->execute();
        return IndustryResource::collection($industries);
    }

    /**
     * Get industries
     *
     * @param Request $request
     * @return void
     */
    public function createIndustry(Request $request)
    {
        $industries = app(CreateIndustry::class)->execute($request->all());
        return new IndustryResource($industries);
    }

    /**
     * Get industries
     *
     * @param Request $request
     * @return void
     */
    public function updateIndustry(int $id, Request $request)
    {
        $data = array_merge(['id' => $id], $request->all());
        $industries = app(UpdateIndustry::class)->execute($data);
        return new IndustryResource($industries);
    }

    /**
     * Get industries
     *
     * @param Request $request
     * @return void
     */
    public function deleteIndustry(int $id, Request $request)
    {
        $id = app(DeleteIndustry::class)->execute(['id' => $id]);
        return $this->respondObjectDeleted($id);
    }

}