<?php

namespace App\Http\Controllers\Api\v1\Message;

use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\Message\AnonymousConversationCategory as AnonymousConversationCategoryResource;
use App\Services\AnonymousConversationCategory\CreateAnonymousConversationCategory;
use App\Services\AnonymousConversationCategory\DeleteAnonymousConversationCategory;
use App\Services\AnonymousConversationCategory\GetAnonymousConversationCategory;
use App\Services\AnonymousConversationCategory\UpdateAnonymousConversationCategory;
use Illuminate\Http\Request;

class AnonymousConversationCategoryController extends ApiController
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $categories = app(GetAnonymousConversationCategory::class)->execute();
        return AnonymousConversationCategoryResource::collection($categories);
    }

    /**
     * Create a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        $category = app(CreateAnonymousConversationCategory::class)->execute($request->all());
        return new AnonymousConversationCategoryResource($category);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $input = array_merge($request->all(), ['id' => $id]);
        $category = app(UpdateAnonymousConversationCategory::class)->execute($input);
        return new AnonymousConversationCategoryResource($category);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete($id)
    {
        app(DeleteAnonymousConversationCategory::class)->execute(['id'=>$id]);
        return $this->respondObjectDeleted($id);
    }
}
