<?php

namespace App\Http\Controllers\Api\v1\QR;

use App\Facades\Context;
use App\Helpers\ActionRequestHelper;
use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\QR\UnassignedToken;
use App\Http\Resources\Tool\Journey\JourneyQR;
use App\Mail\JourneyStepNotification;
use App\Services\QR\CreateNewToken;
use App\Services\Tool\Journey\QR\GetJourneyDetailByQRToken;
use App\Services\Tool\Journey\QR\GetJourneyStepByQRToken;
use App\Services\Tool\Journey\QR\GetVerifaiOTPToken;
use App\Services\Tool\Journey\QR\GetVerifaiResult;
use App\Services\Tool\Journey\QR\DeleteSessionData;
use App\Services\Tool\Journey\QR\SubmitJourneyStepByQRToken;
use App\Services\User\GetUserDetailByQRToken;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;

/**
 * Class QRController
 * @package App\Http\Controllers\Api\v1\QR
 */
class QRController extends ApiController
{
    /**
     * @return UnassignedToken
     */
    public function createNewToken()
    {
        $token = app(CreateNewToken::class)->execute();
        return new UnassignedToken($token);
    }

    /**
     * @param  Request  $request
     * @return JourneyQR
     */
    public function getJourneyDetail(Request $request)
    {
        $journey = app(GetJourneyDetailByQRToken::class)->execute($request->all());
        return new JourneyQR($journey);
    }

    /**
     * @param  Request $request
     * @return User Detail
     */
    public function getUserDetailByQRToken(Request $request)
    {
        $user = app(GetUserDetailByQRToken::class)->execute($request->all());
        return $this->respond($user);
    }

    /**
     * @param  int  $id
     * @param  Request  $request
     * @return mixed
     */
    public function getJourneyStepDetail(int $id, Request $request)
    {
        $param = array_merge(['id' => $id], $request->all());
        $result = app(GetJourneyStepByQRToken::class)->execute($param);

        return ActionRequestHelper::getContentableMobileResource($result);
    }

    /**
     * @param  int  $id
     * @param  Request  $request
     * @return mixed
     */
    public function submitJourneyStepDetail(int $id, Request $request)
    {
        $param = array_merge(['id' => $id], $request->all());
        $result = app(SubmitJourneyStepByQRToken::class)->execute($param);

        $journey_step_result = app(GetJourneyStepByQRToken::class)->execute($param);
        $step = ActionRequestHelper::getContentableMobileResource($journey_step_result)->jsonSerialize();
        if ($step['is_notify']) {
            $journey = app(GetJourneyDetailByQRToken::class)->execute($request->all());
            $emails = explode(";", $step['emails_notify']);
            $user = Context::user()->get();
            foreach ($emails as $email) {
                $name = explode("@", $email);
                Mail::to($email)->send(new JourneyStepNotification($user, $step['step_name'], $journey->name, $name[0]));
            }
        }
        return $this->responseWithSuccessMessage(__('Submit data successfully.'), $result);
    }

    /**
     * @param  int  $id
     * @param  Request  $request
     * @return mixed
     */
    public function getJourneyStepResult(int $id, Request $request)
    {
        $param = array_merge(['id' => $id], $request->all());
        $result = app(GetJourneyStepByQRToken::class)->execute($param);
        return ActionRequestHelper::getResultMobileResource($result);
    }

    public function getOtpToken(Request $request) {
        return app(GetVerifaiOTPToken::class)->execute($request->all());
    }

    public function verifaiResult(string $sessionId, Request $request) {
        $param = array_merge(['sessionId' => $sessionId], $request->all());
        return app(GetVerifaiResult::class)->execute($param);
    }

    public function deleteSessionData(string $sessionId, Request $request) {
        $param = array_merge(['sessionId' => $sessionId], $request->all());
        return app(DeleteSessionData::class)->execute($param);
    }
}
