<?php
namespace App\Http\Controllers\Api\v1\Questionnaire;

use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\Client\ClientValue as ClientValueResource;
use App\Services\Client\ClientValue\GetClientValue;
use App\Services\Questionnaire\PublishQuestionnaire;
use App\Services\Questionnaire\UpdateIllustration;
use Illuminate\Http\Request;
use App\Http\Resources\Questionnaire\Questionnaire as QuestionnaireResource;
use App\Http\Resources\Questionnaire\QuestionnaireClientSetting as QuestionnaireClientSettingResource;
use App\Http\Resources\Driver\Driver as DriverResource;
use App\Http\Resources\Driver\DriverClientValue as DriverClientValueResource;
use App\Services\Questionnaire\GetQuestionnaire;
use App\Services\Questionnaire\CreateQuestionnaire;
use App\Services\Questionnaire\EditQuestionnaire;
use App\Services\Questionnaire\DeleteQuestionnaire;
use Illuminate\Http\Resources\Json\JsonResource;

class QuestionnaireController extends ApiController
{
    /**
     * Get questionnaire list
     *
     * @param Request $request
     * @return void
     */
    public function index(Request $request)
    {
        $questionnaires = app(GetQuestionnaire::class)->execute($request->all());
        $values = app(GetClientValue::class)->execute($this->options);
        return JsonResource::collection(array_merge(DriverResource::collection($questionnaires)->jsonSerialize(), DriverClientValueResource::collection($values)->jsonSerialize()));
    }

    /**
     * Store new questionnaire
     *
     * @param Request $request
     * @return void
     */
    public function store(Request $request)
    {
        $result = app(CreateQuestionnaire::class)->execute($request->all());

        return new QuestionnaireResource($result);
    }

    /**
     * Update a questionnaire
     *
     * @param Request $request
     * @param [type] $questionnaire
     * @return void
     */
    public function update(Request $request, $questionnaire)
    {
        $data = $request->all();
        $data['id'] = $questionnaire;
        $result = app(EditQuestionnaire::class)->execute($data);

        return new QuestionnaireResource($result);
    }

    /**
     * Delete a questionnaire
     *
     * @param Integer $questionnaire
     *
     * @return object
     */
    public function destroy($questionnaire)
    {
        app(DeleteQuestionnaire::class)->execute(['id' => $questionnaire]);

        return $this->respondObjectDeleted($questionnaire);
    }

    public function publishQuestion(Request $request, $questionnaire)
    {
        $data = array_merge([$request->all(), "questionnaire" => $questionnaire]);
        $result = app(PublishQuestionnaire::class)->execute($data);

        return new QuestionnaireClientSettingResource($result);
    }

    /**
     * update Illustration
     *
     * @param Request $request
     */
    public function updateIllustration(Request $request)
    {
        $data = $request->all();
        $result = app(UpdateIllustration::class)->execute($data);

        return QuestionnaireResource::collection($result);
    }
}