<?php

namespace App\Http\Controllers\Api\v1\Quiz;

use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\Tool\Quiz\Quiz as QuizResource;
use App\Http\Resources\Tool\Quiz\QuizDetail as QuizDetailResource;
use App\Services\Tool\Quiz\DeleteQuiz;
use App\Services\Tool\Quiz\DownloadQuiz;
use App\Services\Tool\Quiz\DuplicateQuiz;
use App\Services\Tool\Quiz\GetQuiz;
use App\Services\Tool\Quiz\GetQuizDetail;
use App\Services\Tool\Quiz\PublishQuiz;
use App\Services\Tool\Quiz\SaveQuizQuestion;
use App\Services\Tool\Quiz\CreateQuiz;
use App\Services\Tool\Quiz\UnpublishQuiz;
use App\Services\Tool\Quiz\UpdateQuiz;
use Illuminate\Http\Request;

class QuizController extends ApiController
{
    /**
     * List all event
     *
     * @return mixed
     */
    public function getAll()
    {
        $quizzes = app(GetQuiz::class)->execute($this->options);
        
        return QuizResource::collection($quizzes);
    }

    /**
     * Get quiz detail
     *
     * @param $code
     * @return mixed
     */
    public function detail($code)
    {
        $quiz = app(GetQuizDetail::class)->execute(['code' => $code]);

        return new QuizDetailResource($quiz);
    }

    /**
     *
     */
    public function download($code)
    {
        return app(DownloadQuiz::class)->execute(['code' => $code]);
    }

    /**
     * Create quiz
     * 
     * @param Request $request
     * @return QuizDetailResource
     */
    public function create(Request $request)
    {
        $quiz = app(CreateQuiz::class)->execute($request->all());
        
        return new QuizDetailResource($quiz);
    }

    /**
     * Update quiz
     *
     * @param Request $request
     * @param $code
     * @return QuizDetailResource
     */
    public function update(Request $request, $code)
    {
        $input = array_merge($request->all(), ['code' => $code]);
        $quiz = app(UpdateQuiz::class)->execute($input);
        
        return new QuizDetailResource($quiz);
    }

    /**
     * Delete quiz
     *
     * @param $code
     * @return \Illuminate\Http\JsonResponse
     */
    public function delete($code)
    {
        app(DeleteQuiz::class)->execute(['code' => $code]);
        
        return $this->respondObjectDeleted($code);
    }

    /**
     * Publish quiz
     *
     * @param $code
     * @return QuizDetailResource
     */
    public function publish($code)
    {
        $quiz = $this->transaction(function() use($code) {
            return app(PublishQuiz::class)->execute(['code' => $code]);
        });

        return new QuizDetailResource($quiz);
    }

    /**
     * Unpublish quiz
     *
     * @param $code
     * @return QuizDetailResource
     */
    public function unpublish($code)
    {
        $quiz = app(UnpublishQuiz::class)->execute(['code' => $code]);
        
        return new QuizDetailResource($quiz);
    }

    /**
     * Save quiz question
     *
     * @param Request $request
     * @param $code
     * @return QuizDetailResource
     */
    public function saveQuizQuestion(Request $request, $code)
    {
        $input = array_merge($request->all(), ['code' => $code]);
        $quiz = app(SaveQuizQuestion::class)->execute($input);
        
        return new QuizDetailResource($quiz);
    }

    /**
     * Duplicate quiz
     *
     * @param $code
     * @return QuizDetailResource
     */
    public function duplicate($code)
    {
        $quiz = app(DuplicateQuiz::class)->execute(['code' => $code]);
        
        return new QuizDetailResource($quiz);
    }
    
}
