<?php

namespace App\Http\Controllers\Api\v1\Report;

use App\Enum\CommentTypes;
use App\Facades\Context;
use App\Helpers\AwsQuickSightHelper;
use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\Report\ParticipateResource;
use App\Http\Resources\Report\ReportComment as ReportCommentResource;
use App\Http\Resources\Report\ReportScoring as ReportScoringResource;
use App\Http\Resources\Report\ValuesScoring as ValuesScoringResource;
use App\Http\Resources\Report\SubDriverScore as SubDriverScoreResource;
use App\Http\Resources\Report\ReportTopicDriver as ReportTopicDriverResource;
use App\Http\Resources\Report\ReportTopicCommentAnalyze as ReportTopicCommentAnalyzeResource;
use App\Http\Resources\Report\ReportHeatMapSegment as ReportHeatMapSegmentResource;
use App\Http\Resources\Report\ReportBoard as ReportBoardResource;
use App\Http\Resources\Report\ReportBoardSegmentProgressOverTime as ReportBoardSegmentProgressOverTimeResource;
use App\Services\Report\GetBoardParticipateScore;
use App\Services\Report\GetParticipateScore;
use App\Services\Report\ReactComment;
use App\Services\Report\AcknowledgeSensitiveComment;
use App\Services\Report\DownloadBoardDrivers;
use App\Services\Report\DownloadHeatmapSegment;
use App\Services\Report\GetBoardDrivers;
use App\Services\Report\GetValuesDrivers;
use App\Services\Report\GetBoardSegmentProgressOverTime;
use App\Services\Report\GetDriverScoring;
use App\Services\Report\GetHeatmapSegment;
use App\Services\Report\GetReportComment;
use App\Services\Report\GetSubDriverScoring;
use App\Services\Report\GetTopicCommentAnalyze;
use App\Services\Report\GetTopicDriver;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class ReportController extends ApiController
{
    public function comment(Request $request, $comment_type = 'all')
    {
        $data = $request->all();
        $data['comment_type'] = $comment_type;
        $comments = app(GetReportComment::class)->execute(array_merge($data, $this->options));

        return $comments === null ? $this->responseData(null) : ReportCommentResource::collection($comments);
    }

    /**
     * Get quizzes and surveys report embed url
     *
     * @return JsonResponse
     */
    public function getQuizzesAndSurveysReportEmbedUrl()
    {
        $currentUser = Context::user()->get();
        $embedUrl = (new AwsQuickSightHelper())->getDashboardEmbedUrl($currentUser->email);

        return $this->respond([
            'embed_url' => $embedUrl
        ]);
    }

    public function boards(Request $request)
    {
        $boards = app(GetBoardDrivers::class)->execute(array_merge($request->all(), $this->options));
        return isset($boards) ? ReportBoardResource::collection($boards) : $this->responseData(null);
    }

    public function boardSegmentProgressOverTime(Request $request, $segmentCode)
    {
        $segmentScoresOverTime = app(GetBoardSegmentProgressOverTime::class)->execute(
            array_merge($request->all(), ['segment_code' => $segmentCode])
        );

        return ReportBoardSegmentProgressOverTimeResource::collection($segmentScoresOverTime);
    }

    public function downloadBoards(Request $request)
    {
        return app(DownloadBoardDrivers::class)->execute($request->all());
    }

    public function getParticipateScoreForBoardReport(Request $request)
    {
        $boards = app(GetBoardParticipateScore::class)->execute(array_merge($request->all(), $this->options));
        return isset($boards) ? ParticipateResource::collection($boards) : $this->responseData(null);
    }

    public function heatmap(Request $request)
    {
        $heatMapSegments = app(GetHeatmapSegment::class)->execute(array_merge($request->all(), $this->options));
        return isset($heatMapSegments) ? ReportHeatMapSegmentResource::collection($heatMapSegments) :
            $this->responseData(null);
    }

    public function getParticipateScoreForHeatmapReport(Request $request)
    {
        $heatMapSegments = app(GetParticipateScore::class)->execute(array_merge($request->all(), $this->options));
        return isset($heatMapSegments) ? ParticipateResource::collection($heatMapSegments) :
            $this->responseData(null);
    }

    public function downloadHeatmap(Request $request)
    {
        return app(DownloadHeatmapSegment::class)->execute($request->all());
    }

    public function topics(Request $request)
    {
        $topicDrivers = app(GetTopicDriver::class)->execute(array_merge($request->all(), $this->options));
        return empty($topicDrivers) ? $this->responseData(null) : ReportTopicDriverResource::collection($topicDrivers);
    }

    public function getTopicCommentAnalyze(Request $request, $driverId)
    {
        $topics = app(GetTopicCommentAnalyze::class)->execute(
            array_merge($request->all(), $this->options, ['driver_id' => $driverId])
        );
        return ReportTopicCommentAnalyzeResource::collection($topics);
    }

    public function drivers(Request $request)
    {
        $drivers = app(GetDriverScoring::class)->execute(array_merge($request->all(), $this->options));
        $values = app(GetValuesDrivers::class)->execute(array_merge($request->all(), $this->options));
        $responseValues = isset($values) ? ValuesScoringResource::collection($values) : $this->responseData([]);
        $responseQuestionares = empty($drivers) ? $this->responseData([]) : ReportScoringResource::collection($drivers);

        return JsonResource::collection(array_merge($responseQuestionares->jsonSerialize(), $responseValues->jsonSerialize()));
    }

    public function getSubDrivers(Request $request, $id)
    {
        $subDrivers = app(GetSubDriverScoring::class)->execute(array_merge(['driver_id' => $id], $this->options));
        return SubDriverScoreResource::collection($subDrivers);
    }

    public function acknowledgeSensitiveComment(Request $request, $id)
    {
        $comment = app(AcknowledgeSensitiveComment::class)->execute(['id' => $id]);
        return new ReportCommentResource($comment);
    }

    /**
     * react to the comments
     */
    public function reactComment(Request $request, $id)
    {
        $data = $request->all();
        $data['id'] = $id;
        $data['comment_type'] = CommentTypes::QUESTIONNAIRE_COMMENT;

        $result = app(ReactComment::class)->execute($data);

        return new ReportCommentResource($result);
    }
}