<?php

namespace App\Http\Controllers\Api\v1\Schedule;

use App\Http\Controllers\Api\ApiController;
use App\Services\Employee\DownloadEmployees;
use App\Services\Schedule\CreateScheduleRoundsAndDistributes;
use App\Services\Schedule\GetScheduleFrequency;
use App\Services\Schedule\ReconfigScheduleSurvey;
use Illuminate\Http\Request;
use Exception;
use Illuminate\Http\JsonResponse;
use App\Http\Resources\Schedule\ScheduleSurvey as ScheduleSurveyResource;
use App\Http\Resources\Schedule\ScheduleSegments as ScheduleSegmentsResource;
use App\Http\Resources\Schedule\ScheduleFrequency as ScheduleFrequencyResource;

use App\Services\Schedule\GetSchedule;
use App\Services\Schedule\GetDetailSchedule;
use App\Services\Schedule\DeleteSchedule;
use App\Services\Schedule\PublishSchedule;
use App\Services\Schedule\UnpublishSchedule;
use App\Http\Resources\Driver\Driver as DriverResource;
use App\Services\Driver\GetDriverByScheduleId;
use App\Http\Resources\User\Employee as EmployeeResource;
use App\Services\Employee\GetEmployeeByScheduleId;

class ScheduleController extends ApiController
{
    /**
     * List all schedule survey
     *
     * @param Request $request
     * @return mixed
     */
    public function getAll(Request $request)
    {
        $surveys = app(GetSchedule::class)->execute($this->options);
        return ScheduleSurveyResource::collection($surveys);
    }

    /**
     * @param string $id
     * @return ScheduleSegmentsResource
     */
    public function get(string $id)
    {
        $survey = app(GetDetailSchedule::class)->execute(['id' => $id]);
        return ScheduleSurveyResource::collection($survey);
    }

    /**
     * @param string $id
     * @return ScheduleSegmentsResource
     */
    public function getDriversByScheduleId(string $id)
    {
        $drivers = app(GetDriverByScheduleId::class)->execute(['id' => $id]);

        return DriverResource::collection($drivers);
    }

    /**
     * @param string $id
     * @return ScheduleSegmentsResource
     */
    public function getEmployeesByScheduleId(string $id)
    {
        $employees = app(GetEmployeeByScheduleId::class)->execute(['id' => $id]);

        return EmployeeResource::collection($employees);
    }

    /**
     * @param string $id
     * @return ScheduleSegmentsResource
     */
    public function getEmployeesReportDownload(string $id)
    {
        $employees = app(GetEmployeeByScheduleId::class)->execute(['id' => $id]);

        return app(DownloadEmployees::class)->execute(['employees' => $employees]);
    }

    /**
     * Add survey
     *
     * @param Request $request
     * @return mixed
     * @throws Exception
     */
    public function create(Request $request)
    {
        $survey = app(CreateScheduleRoundsAndDistributes::class)->execute($request->all());
        return new ScheduleSurveyResource($survey);
    }

    /**
     * Publish Survey
     *
     * @param int $id
     * @return SurveyResource
     * @throws Exception
     */
    public function publish(string $id)
    {
        return app(PublishSchedule::class)->execute(['id' => $id]);
    }

    /**
     * Unpublish survey
     *
     * @param string $id
     * @return SurveyResource
     * @throws Exception
     */
    public function unpublish(string $id)
    {
        return app(UnpublishSchedule::class)->execute(['id' => $id]);
    }

    /**
     * Unpublish survey
     *
     * @param string $id
     * @return SurveyResource
     * @throws Exception
     */
    public function reconfig(string $id, Request $request)
    {
        $surveys = app(ReconfigScheduleSurvey::class)->execute(['data' => $request->all(), 'survey_id' => $id]);

        return new ScheduleSurveyResource($surveys);
    }

    /**
     * Delete schedule
     *
     * @param $id
     * @return JsonResponse
     * @throws Exception
     */
    public function delete(string $id)
    {
        app(DeleteSchedule::class)->execute(['id' => $id]);
        return $this->respondObjectDeleted($id);
    }

    public function getScheduleFrequency()
    {
        $frequencies = app(GetScheduleFrequency::class)->execute();
        return ScheduleFrequencyResource::collection($frequencies);
    }
}