<?php

namespace App\Http\Controllers\Api\v1\Segment;

use App\Helpers\SegmentHelper;
use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\User\Employee as EmployeeResource;
use App\Services\Segment\CreateSegment;
use App\Services\Segment\DeleteSegment;
use App\Services\Segment\Employee\AddSegmentEmployee;
use App\Services\Segment\Employee\RemoveSegmentEmployee;
use App\Services\Segment\GetSegmentGroup;
use App\Services\Segment\SegmentType\GetSegmentTypeDetail;
use App\Services\Segment\GetSegmentTypes;
use App\Services\Segment\UpdateSegment;
use Illuminate\Http\Request;
use App\Http\Resources\Segment\SegmentDetail as SegmentDetailResource;
use App\Http\Resources\Segment\SegmentType as SegmentTypeResource;
use App\Http\Resources\Segment\SegmentGroup as SegmentGroupResource;
use App\Services\Segment\GetSegment;
use App\Services\Segment\SegmentType\GetSegmentEmployee;

/**
 * Class SegmentController
 * @package App\Http\Controllers\Api\v1\Segment
 */
class SegmentController extends ApiController
{
    /**
     * TODO: Get segment list
     *
     * @param Request $request
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public function index(Request $request)
    {
        $segments = app(GetSegment::class)->execute();
        return SegmentDetailResource::collection($segments);
    }


    /**
     * @param Request $request
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public function getSegmentTypes(Request $request)
    {
        $segmentTypes = app(GetSegmentTypes::class)->execute();

        return SegmentTypeResource::collection($segmentTypes);
    }


    /**
     * @param string $code
     * @param Request $request
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public function getSegmentTypeDetail(string $code, Request $request)
    {
        $data = array_merge($this->options, ['code' => $code]);
        $segments = app(GetSegmentTypeDetail::class)->execute($data);
        return SegmentHelper::getSegmentTypeResource($code, $segments);
    }


    /**
     * @param string $code
     * @param string $segmentCode
     * @param Request $request
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public function getSegmentDetail(string $code, string $segmentCode, Request $request)
    {
        $data = array_merge($this->options, ['code' => $code, 'segment_code' => $segmentCode]);
        $segments = app(GetSegmentTypeDetail::class)->execute($data);
        return SegmentHelper::getSegmentTypeResource($code, $segments);
    }


    /**
     * @param string $code
     * @param string $segmentCode
     * @param Request $request
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public function getSegmentEmployee(string $code, string $segmentCode, Request $request)
    {
        $data = array_merge($this->options, ['code' => $code, 'segment_code' => $segmentCode]);
        $users = app(GetSegmentEmployee::class)->execute($data);
        $users->loadMissing(['employee.manager', 'employee.client', 'employee.location', 'employee.department', 'employee.gender', 'employee.documentProfiles', 'employee.team']);
        return EmployeeResource::collection($users);
    }


    /**
     * @param string $code
     * @param Request $request
     * @return SegmentDetailResource
     */
    public function addSegment(string $code, Request $request)
    {
        $data = array_merge($request->all(), ['segment_type_id' => $code]);
        $segment = app(CreateSegment::class)->execute($data);
        return new SegmentDetailResource($segment);
    }


    /**
     * @param string $code
     * @param string $segmentCode
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function deleteSegment(string $code, string $segmentCode, Request $request)
    {
        app(DeleteSegment::class)->execute(['segment_type_id' => $code, 'segment_code' => $segmentCode]);
        return $this->respondObjectDeleted($code);
    }


    /**
     * @param string $code
     * @param string $segmentCode
     * @param Request $request
     * @return SegmentDetailResource
     */
    public function updateSegment(string $code, string $segmentCode, Request $request)
    {
        $data = array_merge(['segment_type_id' => $code, 'segment_code' => $segmentCode], $request->all());
        $segment = app(UpdateSegment::class)->execute($data);
        return new SegmentDetailResource($segment);
    }


    /**
     * @param string $code
     * @param string $segmentCode
     * @param Request $request
     * @return SegmentDetailResource
     */
    public function addSegmentEmployee(string $code, string $segmentCode, Request $request)
    {
        $data = array_merge(['segment_code' => $segmentCode, 'segment_type_code' => $code], $request->all());
        $segment = app(AddSegmentEmployee::class)->execute($data);
        return new SegmentDetailResource($segment);
    }


    /**
     * @param string $code
     * @param string $segmentCode
     * @param Request $request
     * @return SegmentDetailResource
     */
    public function deleteSegmentEmployee(string $code, string $segmentCode, Request $request)
    {
        $data = array_merge(['segment_code' => $segmentCode, 'segment_type_code' => $code], $request->all());
        $segment = app(RemoveSegmentEmployee::class)->execute($data);
        return new SegmentDetailResource($segment);
    }

    /**
     * @return \Illuminate\Http\Resources\Json\AnonymousResourceCollection
     */
    public function getSegmentGroup()
    {
        $segments = app(GetSegmentGroup::class)->execute();

        return SegmentGroupResource::collection($segments);
    }
}