<?php
namespace App\Http\Controllers\Api\v1\SensitiveWord;

use App\Http\Controllers\Api\ApiController;
use Illuminate\Http\Request;
use App\Http\Resources\SensitiveWord\SensitiveWord as SensitiveWordResource;
use App\Services\SensitiveWord\GetSensitiveWord;
use App\Services\SensitiveWord\CreateSensitiveWord;
use App\Services\SensitiveWord\EditSensitiveWord;
use App\Services\SensitiveWord\DeleteSensitiveWord;

class SensitiveWordController extends ApiController
{
    /**
     * Get sensitive word list
     *
     * @param Request $request
     * @return void
     */
    public function index(Request $request)
    {
        $sensitiveWords = app(GetSensitiveWord::class)->execute($request->all());

        return SensitiveWordResource::collection($sensitiveWords);
    }

    /**
     * Store new sensitive word
     *
     * @param Request $request
     * @return void
     */
    public function store(Request $request)
    {
        $result = app(CreateSensitiveWord::class)->execute($request->all());

        return new SensitiveWordResource($result);
    }

    /**
     * Update a sensitive word
     *
     * @param Request $request
     * @param [type] $sensitiveWord
     * @return void
     */
    public function update(Request $request, $sensitiveWord)
    {
        $data = $request->all();
        $data['id'] = $sensitiveWord;
        $result = app(EditSensitiveWord::class)->execute($data);

        return new SensitiveWordResource($result);
    }

    /**
     * Delete a sensitive word
     *
     * @param Request $request
     * @param [type] $sensitiveWord
     * @return void
     */
    public function destroy(Request $request, $sensitiveWord)
    {
        app(DeleteSensitiveWord::class)->execute(['id' => $sensitiveWord]);

        return $this->respondObjectDeleted($sensitiveWord);
    }
}