<?php


namespace App\Http\Controllers\Api\v1\User;


use App\Helpers\CookieHelper;
use App\Http\Controllers\Api\ApiController;
use App\Http\Resources\User\User as UserResource;
use App\Http\Resources\User\AuthUser as AuthUserResource;
use App\Http\Resources\User\UserSegment as UserSegmentResource;
use App\Services\User\GetSegmentAndUser;
use App\Services\User\GetAdminOrManagerUsers;
use App\Services\User\UpdatePassword;
use App\Services\User\UpdateProfile;
use Illuminate\Http\Request;
use App\Traits\JsonRespondController;
use Illuminate\Support\Facades\Auth as Auth;

class UserController extends ApiController
{
    use JsonRespondController;

    /**
     * @param Request $request
     */
    public function getSegmentAndUser(Request $request)
    {
        $data = array_merge($this->options, $request->all());
        $usersSegments =  app(GetSegmentAndUser::class)->execute($data);
        return UserSegmentResource::collection($usersSegments);
    }

    public function getAdminAndManager(Request $request)
    {
        $data = array_merge($this->options, $request->all());
        $usersSegments =  app(GetAdminOrManagerUsers::class)->execute($data);
        return UserSegmentResource::collection($usersSegments);
    }

    public function getCurrentUser() {
        $user = new AuthUserResource(Auth::user());
        return $this->respond($user);
    }

    /**
     * Update current user's password
     * 
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function updatePassword(Request $request)
    {
        $user = app(UpdatePassword::class)->execute($request->all());

        $accessToken = $user->createToken(config('auth.access_token_name'))->accessToken;
        $cookie = CookieHelper::generateJWTToken($accessToken);
        
        return $this->respond(['user' => new UserResource($user)])->cookie($cookie);
    }

    /**
     * Update current user's password
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function updateProfile(Request $request)
    {
        $user = app(UpdateProfile::class)->execute($request->all());
        return new UserResource($user);
    }
}
