<?php


namespace App\Http\Controllers\Api\v1\UserAccess;


use App\Enum\Roles;
use App\Http\Controllers\Api\ApiController;
use App\Services\UserAccess\GetAccessByRole;
use App\Services\UserAccess\GetManagerAccess;
use App\Services\UserAccess\GetAllAccessPermissions;
use App\Services\UserAccess\UpdateRoleAccess;
use App\Services\UserAccess\UpdateUserAccess;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use App\Traits\JsonRespondController;
use Illuminate\Http\Resources\Json\AnonymousResourceCollection;
use Illuminate\Http\Resources\Json\JsonResource;

class UserAccessController extends ApiController
{
    use JsonRespondController;


    /**
     * Get manager access permissions
     *
     * @param Request $request
     * @return AnonymousResourceCollection
     */
    public function getAdminAccess(Request $request)
    {
        $adminAccess = app(GetAccessByRole::class)->execute(['role' => Roles::ADMIN]);

        return JsonResource::collection($adminAccess);
    }

     /**
     * Update admin access
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function updateAdminAccess(Request $request)
    {
        $input = array_merge($request->all(), ['role' => Roles::ADMIN]);
        app(UpdateRoleAccess::class)->execute($input);

        return $this->responseWithSuccessMessage('Updated permission successfully');
    }

    /**
     * Get manager access permissions
     *
     * @param Request $request
     * @return AnonymousResourceCollection
     */
    public function getManagerAccess(Request $request)
    {
        $managerAccess = app(GetAccessByRole::class)->execute(['role' => Roles::MANAGER]);

        return JsonResource::collection($managerAccess);
    }

     /**
     * Get employee access permissions
     *
     * @param Request $request
     * @return AnonymousResourceCollection
     */
    public function getEmployeeAccess(Request $request)
    {
        $employeeAccess = app(GetAccessByRole::class)->execute(['role' => Roles::FRONT_USER]);

        return JsonResource::collection($employeeAccess);
    }

    /**
     * Get manager access permissions
     *
     * @param Request $request
     * @return AnonymousResourceCollection
     */
    public function getWhistleblowerAccess(Request $request)
    {
        $whistleblowerAccess = app(GetAccessByRole::class)->execute(['role' => Roles::WHISTLEBLOWER_ADMIN]);

        return JsonResource::collection($whistleblowerAccess);
    }

    /**
     * Update manager access
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function updateManagerAccess(Request $request)
    {
        $input = array_merge($request->all(), ['role' => Roles::MANAGER]);
        app(UpdateRoleAccess::class)->execute($input);

        return $this->responseWithSuccessMessage('Updated permission successfully');
    }

     /**
     * Update employee access
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function updateEmployeeAccess(Request $request)
    {
        $input = array_merge($request->all(), ['role' => Roles::FRONT_USER]);
        app(UpdateRoleAccess::class)->execute($input);

        return $this->responseWithSuccessMessage('Updated permission successfully');
    }

    /**
     * Update manager access
     *
     * @param Request $request
     * @return JsonResponse
     */
    public function updateWhistleblowerAccess(Request $request)
    {
        $input = array_merge($request->all(), ['role' => Roles::WHISTLEBLOWER_ADMIN]);
        app(UpdateRoleAccess::class)->execute($input);

        return $this->responseWithSuccessMessage('Updated permission successfully');
    }

    public function updateOneUserAccess(Request $request)
    {
        return app(UpdateUserAccess::class)->execute($request->all());
//        return $this->responseWithSuccessMessage('Updated permission successfully');
    }

    /**
     * @param  Request  $request
     * @return AnonymousResourceCollection
     */
    public function getAllPermissions(Request $request)
    {
        $permissions = app(GetAllAccessPermissions::class)->execute();
        return JsonResource::collection($permissions);
    }
}
