<?php

namespace App\Http\Middleware;

use App\Exceptions\UnauthenticatedHttpException;
use Illuminate\Auth\Middleware\Authenticate as Middleware;
use Closure;
use Log;
use Auth;
use Sentry\State\Scope;

class Authenticate extends Middleware
{
    /**
     * Get the path the user should be redirected to when they are not authenticated.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return string|null
     */
    protected function redirectTo($request)
    {
        if (! $request->expectsJson()) {
            return route('login');
        }
    }

    public function handle($request, Closure $next, ...$guards)
    {
        if ($request->cookie('qualee_token')) {
            $request->headers->set('Authorization', 'Bearer ' . $request->cookie('qualee_token'));
        }

        $this->authenticate($request, $guards);

        if (Auth::check()) {
            \Sentry\configureScope(function (Scope $scope): void {
                $scope->setUser(['email' => Auth::user()->email, 'id' => Auth::user()->id]);
              });
        }

        return $next($request);
    }

    protected function unauthenticated($request, array $guards)
    {
        throw new UnauthenticatedHttpException("Failed to login");
    }
}
