<?php


namespace App\Http\Middleware;

use App\AppContext\ClientScope;
use App\AppContext\UserScope;
use App\Enum\Roles;
use App\Facades\Context;
use App\Guards\GuardNames;
use App\Resolvers\ClientResolver;
use App\Resolvers\UserResolver;
use Closure;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Auth;

class AuthenticateClientAdminContext
{
    /**
     * Handle an incoming request
     *
     * @param Request $request
     * @param Closure $next
     */
    public function handle(Request $request, Closure $next)
    {
        $currentUser = Auth::user();

        $userContext = Context::user();
        $userScope = new UserScope();
        $userScope->resolver(new UserResolver());

        $clientContext = Context::client();
        $clientScope = new ClientScope();
        $clientScope->resolver(new ClientResolver($request));

        $userScope->guards([GuardNames::AuthenticatedConsole]);
        $clientScope->guards([]);
        if ($currentUser->hasRole(Roles::CLIENT_CONSOLE_ROLES)) {
            $clientScope->guards([GuardNames::ClientIsActive, GuardNames::UserIsBelongToClient]);
            $userScope->guards([GuardNames::UserEmailVerified, GuardNames::UserIsActive]);
        }

        $userContext->set($userScope->check()->get());
        if ($clientScope->check()->get()) {
            $clientContext->set($clientScope->check()->get());
        }
        $request->route()->forgetParameter('clientCode');
        return $next($request);
    }
}