<?php


namespace App\Http\Middleware;

use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Exceptions\UnauthenticatedHttpException;
use App\Facades\Context;
use App\Models\QR\ActionToken;
use Closure;

/**
 * Class CheckQRToken
 * @package App\Http\Middleware
 */
class CheckQRToken
{
    /**
     *
     */
    public function handle($request, Closure $next)
    {
        $tokenCode = $request->token;

        $token = ActionToken::where('token', $tokenCode)->first();
        if (Context::user()->check()) {
            throw new InvalidRequestException('Invalid request', ErrorCode::INVALID_REQUEST);
        }
        if (!$token || $token->expires_at->lessThanOrEqualTo(now()) || !isset($token->user)) {
            throw new UnauthenticatedHttpException("Token expired", ErrorCode::TOKEN_EXPIRED);
        }

        $currentUser = $token->user;
        Context::user()->set($currentUser);
        Context::client()->set($currentUser->employee->client);

        return $next($request);
    }
}