<?php

namespace App\Http\Resources\Action;

use App\Helpers\ActionRequestHelper;
use App\Helpers\DateHelper;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class Action extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  Request $request
     * @return array
     */
    public function toArray($request)
    {
        $actionRequest = $this->actionRequest;
        $type = ActionRequestHelper::getActionRequestTypeByContent($actionRequest->contentable_type);
        $contentId = ActionRequestHelper::getContentableId(
            $actionRequest->contentable_type,
            $actionRequest->contentable
        );

        $description = "";
        switch ($type) {
            case "id-verification":
                if ($contentId == "national-id") {
                    $description = "National ID";
                } else if ($contentId == "driver-license") {
                    $description = "Drivers License";
                } else {
                    $description = "Passport";
                }
                break;
            case "survey":
            case "quiz":
            case "form":
                $description = $actionRequest->contentable->name;
                break;
            case "upload-content":
                $description = $this->message;
                break;
            default:
                break;

        }
        
        return [
            'code' => $this->getBusinessKey(),
            'name' => $this->name,
            'type' => $type,
            'content_id' => $contentId,
            'is_send_immediately' => boolval($this->is_send_immediately),
            'send_on' => $this->send_on ? DateHelper::format($this->send_on) : null,
            'due_by' => DateHelper::format($this->due_by),
            'header_image_id' => $this->header_image_id,
            'message' => $this->message,
            'description' => $description,
        ];
    }
}
