<?php

namespace App\Http\Resources\Event;

use App\Helpers\DateHelper;
use App\Http\Resources\Client\ClientLite;
use App\Http\Resources\Segment\Segment;
use App\Http\Resources\User\UserLite;
use Illuminate\Http\Resources\Json\JsonResource;

/**
 * @extends JsonResource<\App\Models\Contact\Address>
 */
class Event extends JsonResource
{
    /**
     * Transform the resource into an array.
     * 
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        return [
            'name' => $this->name,
            'location' => $this->location,
            'users' => UserLite::collection($this->users),
            'segments' => Segment::collection($this->segments),
            'total_invited_user_count' => $this->getCountInvitedUsers(),
            'description' => $this->description,
            'start_date' => DateHelper::format($this->start_date),
            'end_date' => DateHelper::format($this->end_date),
            'status' => $this->status,
            'code' => $this->code,
            'is_published' => (bool)$this->is_published,
            'is_full_day' => (bool)$this->is_full_day,
            'is_all_employees_invited' => $this->hasAllEmployeeSegment(),
            'client' => new ClientLite($this->client),
            'creator' => new UserLite($this->creator),
            'recurrence' => $this->recurrence,
            'alert' => $this->alert
        ];
    }
    
    public function hasAllEmployeeSegment()
    {
        foreach ($this->segments as $segment) {
            if ($segment->isAllSegmentType()) {
                return true;
            }
        }
        
        return false;
    }
}
