<?php

namespace App\Http\Resources\Library;

use App\Helpers\FileHelper;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\File;
use App\Enum\LibraryItemType;

/**
 * @extends JsonResource<\App\Models\Attachment>
 */
class Attachment extends JsonResource
{
    public $is_signed_url = false;

    public function __construct($resource, $is_signed_url = false)
    {
        $this->resource = $resource;
        $this->is_signed_url = $is_signed_url;
    }

    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array|void
     */
    public function toArray($request)
    {
        $CAN_VIEW_LIST = array("pdf", "png", "jpg", "jpeg", "gif", "svg");

        return [
            "id" => $this->id,
            "name" => $this->name,
            "original_name" => $this->original_name,
            "path" => $this->is_signed_url ? FileHelper::getSignedUrl($this->path) : FileHelper::getPublicUrl($this->path),
            "size" => $this->size,
            "mime_type" => $this->mime_type,
            'extension' => File::extension($this->original_name),
            "created_at" => $this->created_at,
            "deleted_at" => $this->deleted_at,
            "updated_at" => $this->updated_at,
            "can_view" => array_search(File::extension($this->original_name), $CAN_VIEW_LIST) > -1 ? true : false,
        ];
    }
}
