<?php

namespace App\Http\Resources\Library;

use App\Enum\ActionRequestTypes;
use App\Enum\ErrorCode;
use App\Enum\LibraryItemType;
use App\Helpers\ActionRequestHelper;
use App\Http\Resources\Client\ClientLite;
use App\Http\Resources\Message\Message;
use App\Http\Resources\User\User;
use Illuminate\Http\Resources\Json\JsonResource;
use App\Helpers\LibraryItemHelper;
use Illuminate\Support\Facades\Http;

/**
 * @extends JsonResource<\App\Models\LibraryItem>
 */
class LibraryItem extends JsonResource
{
    /**
     *  Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array|void
     */
    public function toArray($request)
    {
        return [
            'id' => $this->id,
            'name' => $this->name,
            'type' => $this->type,
            'document_profile' => new DocumentProfile($this->documentProfile),
            'attachment' => $this->type == LibraryItemType::FILE ? new Attachment($this->linkable) : null,
            'link' => $this->type == LibraryItemType::LINK ? new Link($this->linkable) : null,
            'favicon' => $this->type == LibraryItemType::LINK ? $this->getFavicon($this->linkable->url) : null,
            "creator" => new User($this->creator),
            "created_at" => $this->created_at,
            'client'=> new ClientLite($this->client),
            'usedItems' => $this->getJourneyByLibraryItem($this->actionRequests)
        ];
    }

    private function getFavicon($url) {
        try {
            $response = Http::get("https://www.google.com/s2/favicons?domain_url=" . $url . "&&sz=64");
            if ($response->status() != 200) {
                return "";
            }
            return "https://www.google.com/s2/favicons?domain_url=" . $url . "&&sz=64";
        }
        catch (Exception $exception) {
            return "";
        }

    }

    private function getJourneyByLibraryItem($actionRequests) {
        $journeys = array();
        $action = array();
        $actionSequence = array();
        foreach ($actionRequests as $actionRequest) {
            $actionName = ActionRequestHelper::getActionableName(
                $actionRequest->actionable_type, $actionRequest->actionable
            );
            $actionType = ActionRequestHelper::getActionableType($actionRequest->actionable_type);
            switch ($actionType) {
                case ActionRequestTypes::ACTION_SEQUENCE:
                    array_push($actionSequence, $actionName);
                    break;
                case ActionRequestTypes::ACTION:
                    array_push($action, $actionName);
                    break;
                case ActionRequestTypes::JOURNEY:
                    array_push($journeys, $actionName);
                    break;
                default:
                    break;
            }
        }
        return array(
            "journeys" => $journeys,
            "action" => $action,
            "actionSequence" => $actionSequence
        );
    }
}
