<?php

namespace App\Http\Resources\Message;

use App\Enum\ConversationTypes;
use App\Facades\Context;
use App\Helpers\DateHelper;
use App\Helpers\SegmentHelper;
use App\Http\Resources\Tool\Journey\JourneyConversation;
use App\Http\Resources\User\UserLite as UserResource;
use App\Http\Resources\User\UserConversation as UserConversationResource;
use Illuminate\Http\Resources\Json\JsonResource;

/**
 * @extends JsonResource<\App\Models\Message\Conversation>
 */
class Conversation extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $userConversation = $this->users->where('id',Context::user()->get()->getKey())->first();
        $lastMessage = $this->messages(true)->latest()->first();
        if($lastMessage) {
            $lastMessage->conversation = $this;
        }
        $lastMessageSeen = $userConversation ? $this->getLastMessageSeen($userConversation) : null;

        $result = [
            'id'           => $this->id,
            'type'         => $this->type,
            'order'        => $this->order,
            'anonymous_id' => $this->anonymous_id ?? $this->order,
            'status'       => $this->status,
            'last_read'    => $lastMessageSeen,
            'last_message' => new Message($lastMessage),
            'owner'        => null,
            'receiver'     => null,
            'comment_id'   => $this->comment_id,
            'created_at'   => $this->created_at,
        ];
        if ($this->isDisplayOwner) {
            $result['owner'] = new UserResource($this->owner);
        }
        if ($this->type === ConversationTypes::DIRECT_MESSAGE ||
            $this->type === ConversationTypes::NOTIFY_MESSAGE_EMPLOYEE) {
            $result['journeys'] = $this->receivers->first() !== null ? JourneyConversation::collection($this->receivers->first()->journeys) : JourneyConversation::collection([]);
            $result['receiver'] = UserConversationResource::collection($this->receivers);
        } else if ($this->type === ConversationTypes::NOTIFY_MESSAGE) {
            foreach ($this->segments as $segment) {
                $result['receiver'][] = SegmentHelper::getSegmentResource($segment);
            }
        } else if($this->type === ConversationTypes::ANONYMOUS_MESSAGE){
            $result['whistleblowing_category'] = AnonymousConversationCategory::collection($this->anonymousConversationCategories);
        }

        return $result;
    }

    public function getLastMessageSeen($userConversation)
    {
        $lastMessageSeenTime = $userConversation->pivot->last_read > $userConversation->pivot->last_available
            ? $userConversation->pivot->last_read
            : $userConversation->pivot->last_available;
        return DateHelper::formatWithMilisecond($lastMessageSeenTime);
    }
}
