<?php

namespace App\Http\Resources\Mobile\ActionRequestSubmission\Library;

use App\Enum\LibraryItemType;
use App\Http\Resources\Library\Link;
use App\Http\Resources\Mobile\Assets\Asset;
use App\Http\Resources\Mobile\Attachment\Attachment;
use App\Http\Resources\User\User;
use Illuminate\Http\Resources\Json\JsonResource;
use App\Helpers\ModelHelper;

/**
 * Class LibraryItem
 * @package App\Http\Resources\Mobile\Library
 */
class LibraryItem extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $contentable = $this->contentable;
        $actionable = $this->actionable;
        $message = ModelHelper::convertTokenKeyToValueInJouneySteps($actionable->message);
        $data = [
            'id' => $this->id,
            'type' => $contentable->type,
            'name' => $contentable->name,
            'message' => $message,
            'header_image' => new Asset($actionable->headerImage),
            "creator" => new User($contentable->creator),
            "created_at" => $contentable->created_at,
            "updated_at" => $contentable->updated_at,
            'is_notify'    => $actionable->is_notify,
            'emails_notify'=> $actionable->emails_notify,
            'journey_id' => $actionable->journey_id,
            'step_name' => $actionable->name,
        ];

        if($contentable->type != LibraryItemType::LINK) {
            $libraryItem = $contentable->linkable->libraryItem;
            if(!is_null($libraryItem))
            {
                $data['title'] = $libraryItem->title;
                $data['attachment'] = new Attachment($contentable->linkable);
                if ($data['attachment']['is_image']) {
                    $data['file_type'] = "Image";
                } else {
                    $data['file_type'] = $libraryItem->type;
                }


            } else {
                $data['title'] = null;
                $data['file_type'] = null;
                $data['attachment'] = null;
            }
        } else {
            $data['link'] = new Link($contentable->linkable);
            $data['file_type'] = LibraryItemType::LINK;
        }

        return $data;
    }
}
