<?php

namespace App\Http\Resources\Mobile\Auth;

use App\Enum\AccessPermissions;
use App\Enum\ClientConfigurations;
use App\Enum\PlanConfigurations;
use App\Enum\Roles;
use App\Helpers\ConfigurationHelper;
use App\Helpers\UserHelper;
use App\Http\Resources\Language\Language;
use App\Http\Resources\Mobile\Attachment\Attachment;
use App\Http\Resources\Segment\Segment;
use App\Models\Attachment as AttachmentModel;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use App\Services\UserAccess\GetAccessByRole;
use App\Facades\Context;

class Login extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array
     */
    public function toArray($request)
    {
        $client = $this->client->first();

        $clientConfiguration = $client->clientConfigurations->mapWithKeys(function ($item, $key) {
            return [$item->name => ConfigurationHelper::convertDataByType($item->pivot->value, $item->type)];
        })->toArray();

        $subscriptionPlanConfiguration = $client->subscriptionPlan->planConfigurations->mapWithKeys(function ($item, $key) {
            return [$item->name => ConfigurationHelper::convertDataByType($item->pivot->value, $item->type)];
        })->toArray();

        $type = "employee";
        $show_enps_chart = isset($clientConfiguration[ClientConfigurations::SHOW_ENPS_CHART_FOR_EMPLOYEES]) && $clientConfiguration[ClientConfigurations::SHOW_ENPS_CHART_FOR_EMPLOYEES];
        if ($this->hasRole(Roles::WHISTLEBLOWER_ADMIN)) {
            $type = "wb_admin";
        } else if ($this->hasRole(Roles::MANAGER)) {
            $show_enps_chart = isset($clientConfiguration[ClientConfigurations::SHOW_ENPS_CHART_FOR_MANAGERS]) && $clientConfiguration[ClientConfigurations::SHOW_ENPS_CHART_FOR_MANAGERS];
        } else if ($this->hasRole(Roles::ADMIN)) {
            $type = "admin";
            $show_enps_chart = true;
        }

        Context::client()->set($client);
        $employeeAccess = app(GetAccessByRole::class)->execute(['role' => Roles::FRONT_USER]);
        $gender = $this->when($this->employee->gender_id && $this->employee->gender, new Segment($this->employee->gender), null);
        return [
            "profile" => [
                "code" => $this->getBusinessKey(),
                "email" => $this->email,
                "status" => (string) is_null($this->status) ? null : $this->status,
                "last_login" => is_null($this->employee->last_login) ? null : $this->employee->last_login,
                "first_name" => $this->first_name,
                "surname" => $this->surname,
                "start_date" => is_null($this->employee->start_date) ? null : $this->employee->start_date,
                "job_title" => $this->employee->job_title,
                "end_date" => is_null($this->employee->end_date) ? null : $this->employee->end_date,
                "is_photoid_req" => is_null($this->employee->is_photoid_req) ? null : $this->employee->is_photoid_req,
                "tnc_accepted" => is_null($this->employee->tnc_accepted) ? null : $this->employee->tnc_accepted,
                "avatar" => new Attachment($this->avatar),
                "linkedin_url" => is_null($this->employee->linkedin_url) ? null : $this->employee->linkedin_url,
                "is_demo" => $this->is_demo,
                "location_id" => is_null($this->employee->location_id) ? null : $this->employee->location_id,
                "team_id" => is_null($this->employee->team_id) ? null : $this->employee->team_id,
                "department_id" => is_null($this->employee->department_id) ? null : $this->employee->department_id,
                "type" => $type,
                "gender" => $gender && $gender->name == "Female" ? 0 : 1,
            ],
            "language" => new Language($this->language),
            "client" => [
                "code" => $client->code,
                "name" => $client->name,
                "status" => $client->status,
                "logo" => AttachmentModel::find($client->logo_id),
                ClientConfigurations::CONFIG_PRIMARY_COLOUR => $clientConfiguration[ClientConfigurations::CONFIG_PRIMARY_COLOUR],
                ClientConfigurations::CONFIG_SECONDARY_COLOUR => $clientConfiguration[ClientConfigurations::CONFIG_SECONDARY_COLOUR],
                ClientConfigurations::IS_DEFAULT_COLOUR => isset($clientConfiguration[ClientConfigurations::IS_DEFAULT_COLOUR]) && $clientConfiguration[ClientConfigurations::IS_DEFAULT_COLOUR],
                'show_enps_chart' => $show_enps_chart,
            ],
            "city" => [
                "name" => null
            ],
            "doc_profile" => [
                "name" => $client->name,
                "package_type" => 1,
                "logo" => null,
                "background_image" => null,
                "background_color" => "060E41",
                "menu_font_color" => "FFFFFF",
                "message_image" => null,
                "document_image" => null,
                "action_image" => null
            ],
            "company" => [
                "name" => null
            ],
            "message_feature" => true,
            "feedback" => 0,
            "is_default_password" => $this->employee->is_default_password,
            "rating" => [
                "is_first_time" => UserHelper::isFirstRating($this),
                "is_available" => UserHelper::isRatingAvailable($this)
            ],
            "plan_configurations" => [
                PlanConfigurations::PACKAGE_CUSTOM_COLOUR => $subscriptionPlanConfiguration[PlanConfigurations::PACKAGE_CUSTOM_COLOUR],
                PlanConfigurations::PACKAGE_MESSAGE => $subscriptionPlanConfiguration[PlanConfigurations::PACKAGE_MESSAGE],
                PlanConfigurations::PACKAGE_ENGAGEMENT_MODULE => $subscriptionPlanConfiguration[PlanConfigurations::PACKAGE_ENGAGEMENT_MODULE],
                PlanConfigurations::PACKAGE_ID_VERIFICATION => $subscriptionPlanConfiguration[PlanConfigurations::PACKAGE_ID_VERIFICATION],
                PlanConfigurations::PACKAGE_AI_DOCUMENT_SEARCH => $subscriptionPlanConfiguration[PlanConfigurations::PACKAGE_AI_DOCUMENT_SEARCH],
                PlanConfigurations::PACKAGE_WHISTLEBLOWING_CAPABILITIES => $this->is_demo ? true : $subscriptionPlanConfiguration[PlanConfigurations::PACKAGE_WHISTLEBLOWING_CAPABILITIES],
            ],
            "restrict_employee" => [
                "employee_messages" => $employeeAccess[AccessPermissions::ACCESS_GROUP_EMPLOYEE_MESSAGES],
                "employee_directory" => $employeeAccess[AccessPermissions::ACCESS_GROUP_EMPLOYEE_DIRECTORY],
            ],
        ];
    }
}