<?php

namespace App\Http\Resources\Mobile\ContentFile;

use App\Facades\Context;
use App\Http\Resources\Mobile\Assets\Asset;
use App\Http\Resources\Mobile\Attachment\Attachment as MobileAttachment;
use App\Services\ActionRequest\GetUserSubmission;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Auth;

class ContentFileResult extends JsonResource
{
    /**
     * Transform the resource into an array.
     * 
     * @param Request $request
     * @return array
     */
    public function toArray($request)
    {
        $contentable = $this->contentable;
        $userSubmission = app(GetUserSubmission::class)->execute($this->resource, Context::user()->get()->id);
        if (!$userSubmission) {
            return [];
        }
        $contentFileResult = $userSubmission->contentFileResults()->first();

        return [
            'id' => $contentable->id,
            'name' => $contentable->name,
            'type' => $contentable->getBusinessKey(),
            'header_image' => new Asset($this->actionable->headerImage),
            'message' => $this->actionable->message,
            'reason' => $userSubmission->reason,
            'status' => $userSubmission->status,
            'attachment' => $contentFileResult ? new MobileAttachment($contentFileResult->attachment) : null,
            'created_at' => $userSubmission->created_at,
            'updated_at' => $userSubmission->updated_at
        ];
    }
}
