<?php

namespace App\Http\Resources\Mobile\Journey;

use App\Enum\ActionRequestTypes;
use App\Facades\Context;
use App\Helpers\ActionRequestHelper;
use App\Http\Resources\Mobile\Assets\Asset;
use App\Models\Library\LibraryItem;
use App\Models\Library\Link;
use App\Services\ActionRequest\GetUserSubmission;
use App\Services\Mobile\Journey\IsStepAvailable;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class JourneyStep extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  Request  $request
     * @return array
     */
    public function toArray($request)
    {
        $currentUser = Context::user()->get();
        $fileType = null;
        //Only get file type when action request is library item
        if (is_a($this->actionRequest->contentable, LibraryItem::class)) {
            if (is_a($this->actionRequest->contentable->linkable, Link::class)) {
                $fileType = 'Link';
            } else {
                $fileType = isset($this->actionRequest->contentable->linkable->original_name) ?
                    ucfirst(pathinfo($this->actionRequest->contentable->linkable->original_name, PATHINFO_EXTENSION)) :
                    null;
            }
        }
        $actionRequestType = ActionRequestHelper::getActionRequestTypeByContent($this->actionRequest->contentable_type);
        $actionRequestSubTitle = ActionRequestHelper::getActionRequestSubTitleByContent($this->actionRequest->contentable_type);
        $contentId = ActionRequestHelper::getContentableId(
            $this->actionRequest->contentable_type,
            $this->actionRequest->contentable
        );
        $isAvailable = app(IsStepAvailable::class)->execute(['step' => $this->resource]);
        $userSubmission = app(GetUserSubmission::class)->execute($this->actionRequest, $currentUser->id);
        $actionable = $this->actionRequest->actionable;
        $result = [
            'id'           => $this->actionRequest->id,
            'content_id'   => $contentId,
            'content_type' => $actionRequestType,
            'sub_title'    => $actionRequestSubTitle,
            'message'      => $actionable->message,
            'name'         => $this->name,
            'is_available' => $isAvailable,
            'is_completed' => boolval($this->is_completed),
            'status'       => $userSubmission ? $userSubmission->status : null,
            'file_type'    => $fileType,
            'step_order'   => $this->step_order,
            'header_image' => is_null($actionable->headerImage) || !in_array($actionRequestType,
                ActionRequestTypes::HAVE_HEADER_TYPES) ? null : new Asset($actionable->headerImage),
            'is_notify'    => $this->is_notify,
            'emails_notify'=> $this->emails_notify,
            'step_is_optional' => (bool) $this->step_is_optional,
        ];
        if ($actionRequestType == ActionRequestTypes::HEADSHOT_PHOTO) {
            $result["reason"] = $userSubmission ? $userSubmission->reason : null;
        }

        return $result;
    }
}
