<?php

namespace App\Http\Resources\Mobile\Message;

use App\Enum\ConversationTypes;
use App\Facades\Context;
use App\Http\Resources\Message\AnonymousConversationCategory;
use App\Http\Resources\Mobile\User\UserConversation as UserConversationAliasResource;
use App\Http\Resources\Mobile\User\UserLite as UserResource;
use Illuminate\Http\Resources\Json\JsonResource;

/**
 * @extends JsonResource<\App\Models\Message\Conversation>
 */
class Conversation extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function toArray($request)
    {
        $userConversation = $this->users()->find(Context::user()->get()->getKey());
        $lastMessage = $this->messages()->latest()->first();
        if ($lastMessage) {
            $lastMessage->conversation = $this;
        }
        $unreadMessageCount = $this->messages()
            ->where('created_at', '>', $userConversation->pivot->last_read)
            ->where('sender_id', '!=', Context::user()->get()->getKey())->count();


        $lastMessageSeen = $this->getLastMessageSeen($userConversation);

        $result = [
            'id'                   => $this->id,
            'type'                 => $this->type,
            'last_read'            => $lastMessageSeen,
            'order'                => $this->order,
            'anonymous_id'         => $this->anonymous_id ?? $this->order,
            'status'               => $this->status,
            'unread_message_count' => $unreadMessageCount,
            'last_message'         => new Message($lastMessage),
            'owner'                => null,
            'receiver'             => $this->when(count($this->receivers),
                UserConversationAliasResource::collection($this->receivers), null)
        ];
        if ($this->isDisplayOwner) {
            $result['owner'] = new UserResource($this->owner);
        }
        if ($this->type === ConversationTypes::ANONYMOUS_MESSAGE) {
            $result['whistleblowing_category'] = AnonymousConversationCategory::collection($this->anonymousConversationCategories);
        }
        return $result;
    }

    public function getLastMessageSeen($userConversation)
    {
        $lastMessageSeenTime = $userConversation->pivot->last_read > $userConversation->pivot->last_available ?
            $userConversation->pivot->last_read
            : $userConversation->pivot->last_available;
        return $lastMessageSeenTime;
    }
}
