<?php

namespace App\Http\Resources\Mobile\Message;

use App\Helpers\DateHelper;
use App\Http\Resources\Message\MessageTranslation;
use App\Http\Resources\Mobile\Attachment\Attachment as Attachment;
use App\Http\Resources\Mobile\User\UserLite;
use Illuminate\Http\Resources\Json\JsonResource;

/**
 * @extends JsonResource<\App\Models\Message\Message>
 */
class Message extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $result = [
            'id' => $this->id,
            'content' => $this->content,
            'conversation_id' => $this->conversation_id,
            'attachment' => null,
            'content_type' => $this->content_type,
            'created_at' => $this->created_at,
            'user' => null
        ];
        if ($this->messageTranslations->count() > 0) {
            $result['message_translations'] = MessageTranslation::collection($this->messageTranslations);
        }
        if ($this->attachment_id) {
            //If this broadcast message, use signed url
            $result['attachment'] =   new Attachment($this->attachment);
        }
        if ($this->isDisplayUser()) {
            $result['user'] = $this->sender->getBusinessKey();
            if ($this->is_first_message) {
                $result['user_obj'] = new UserLite($this->sender);
            }
        }

        return $result;
    }
}
