<?php

namespace App\Http\Resources\Mobile\Segment;

use App\Http\Resources\Mobile\User\SegmentUser;
use App\Models\Segment\Segment;
use Illuminate\Http\Resources\Json\JsonResource;
use App\Enum\AccessPermissions;
use App\Helpers\ModelHelper;
use App\Models\User\User;

/**
 * @extends JsonResource<\App\Models\Contact\Address>
 */
class SegmentTypeDetailBasic extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $segment = Segment::where('code', $this->code)->first();
        $userIds = $segment->users->pluck('id')->toArray();
        $query = User::with('employee.client');
        $query->join('employees', 'users.id', 'employees.user_id');
        $query->whereIn('users.id', $userIds);
        $query->select('users.*');

        ModelHelper::setConditionFindByEmployee($query, AccessPermissions::ACCESS_GROUP_EMPLOYEE_DIRECTORY);
        $users = $query->get();

        return [
            'code' => $this->code,
            'name' => $this->name,
            'employee' => SegmentUser::collection($users)->take(3),
            'active_employee' => $this->active_employee,
            'total_employee' => $this->total_employee,
        ];
    }
}
