<?php

namespace App\Http\Resources\Mobile\Tool\Form;

use App\Enum\ActionRequestTypes;
use App\Facades\Context;
use App\Helpers\PandaDocHelper;
use App\Http\Resources\Mobile\Assets\Asset;
use App\Services\Tool\Form\GetUserDocument;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Auth;
use App\Helpers\ModelHelper;

class Form extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array
     */
    public function toArray($request)
    {
        $currentUser = Context::user()->get();
        $formTemplate = $this->contentable;
        $actionable = $this->actionable;
        $message = ModelHelper::convertTokenKeyToValueInJouneySteps($actionable->message);
        $document = app(GetUserDocument::class)->execute([
            'form_template_id' => $formTemplate->getKey(),
            'user_id' => $currentUser->getKey(),
            'action_request_id' => $this->resource->getKey()
        ]);

        if (!empty($document)) {
            return [
                'id' => $document->id,
                'form_template_id' => $document->form_template_id,
                'user_id' => $document->user_id,
                'document_id' => $document->document_id,
                'name' => $document->name,
                'is_sent' => $document->is_sent,
                'type' => ActionRequestTypes::FORM,
                'document' => $this->getDocumentLink($document),
                'message' => $message,
                'header_image' => new Asset($actionable->headerImage),
                'created_at' => $this->created_at,
                'updated_at' => $this->updated_at,
                'is_notify'    => $actionable->is_notify,
                'emails_notify'=> $actionable->emails_notify,
                'journey_id' => $actionable->journey_id,
                'step_name' => $actionable->name,
                'step_is_optional' => (bool) $actionable->step_is_optional,
            ];
        }

        return null;
    }

    /**
     * @param $document
     * @return string|null
     */
    private function getDocumentLink($document): ?string
    {
        $currentClient = Context::user()->get()->getClient();
        $documentLink = null;

        $formAuthenticate = $currentClient->formAuthenticate;
        if ($formAuthenticate) {
            $pandaDocHelper = new PandaDocHelper();
            $pandaDocHelper->setToken($formAuthenticate->access_token);
            $documentLink = $pandaDocHelper->getDocumentLink($document->document_id, $document->user->email);
        }

        return $documentLink;
    }
}
