<?php

namespace App\Http\Resources\Mobile\Tool\Quiz;

use App\Facades\Context;
use App\Helpers\ActionRequestHelper;
use App\Http\Resources\Mobile\Assets\Asset;
use App\Services\ActionRequest\GetUserSubmission;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class QuizResult extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array
     */
    public function toArray($request)
    {
        $contentable = $this->contentable;
        $actionable = $this->actionable;
        $submission = app(GetUserSubmission::class)->execute($this->resource, Context::user()->get()->getKey());
        if (!$submission) {
            return [];
        }
        $contentable_type = $this->contentable_type;

        return [
            'id' => $actionable->id,
            'name' => $actionable->name,
            'type' => ActionRequestHelper::getActionRequestTypeByContent($this->contentable_type),
            'message' => $actionable->message,
            'header_image' => new Asset($actionable->headerImage),
            'is_completed' => boolval(isset($submission)),
            'is_published' => boolval($contentable->is_published),
            'questions' => ActionRequestHelper::getContentableResource(
                $contentable_type,
                $contentable
            ),
            'user_results' => $submission ?
                ActionRequestHelper::getSubmissionResource(
                    $contentable_type,
                    $submission
                ) : null,
            'created_at' => $submission->created_at,
            'updated_at' => $submission->updated_at
        ];
    }
}
