<?php

namespace App\Http\Resources\Mobile\Tool\Survey;

use App\Enum\ActionRequestTypes;
use App\Facades\Context;
use App\Helpers\ActionRequestHelper;
use App\Http\Resources\Mobile\Assets\Asset;
use App\Http\Resources\Tool\Survey\SurveyQuestion;
use App\Services\ActionRequest\GetUserSubmission;
use App\Services\Mobile\Survey\GetSurveyResults;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Auth;

class SurveyResult extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $contentable = $this->contentable;
        $actionable = $this->actionable;
        $userSubmission = app(GetUserSubmission::class)->execute($this->resource, Context::user()->get()->id);
        if (!$userSubmission) {
            return [];
        }

        return [
            'id' => $contentable->id,
            'name' => $contentable->name,
            'code' => $contentable->code,
            'type' => ActionRequestTypes::SURVEY,
            'message' => $actionable->message,
            'header_image' => new Asset($actionable->headerImage),
            'is_published' => boolval($contentable->is_published),
            'questions' => SurveyQuestion::collection($contentable->surveyQuestions),
            'user_results' => app(GetSurveyResults::class)->execute(['submission' => $userSubmission]),
            'created_at' => $userSubmission->created_at,
            'updated_at' => $userSubmission->updated_at
        ];
    }
}
