<?php

namespace App\Http\Resources\Report;

use App\Http\Resources\Report\ReportCommentDriver as ReportCommentDriverResource;
use App\Http\Resources\User\UserLite;
use App\Models\Driver\Driver;
use App\Models\SensitiveWord\SensitiveWord;
use App\Services\SensitiveWord\DetectSensitiveWord_Solution2;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Str;

/**
 * @extends JsonResource
 */
class ReportComment extends JsonResource
{
    public function toArray($request)
    {
        $driver = $this->driver;
        $mainDriver = empty($driver->parent_id) ? $driver : Driver::find($driver->parent_id);
        $sensitiveWordsList = SensitiveWord::all();
        $sensitiveWords = !empty($this->comment) ? app(DetectSensitiveWord_Solution2::class)->execute(['comment' => $this->comment, 'sensitiveWords' => $sensitiveWordsList]) : null;
        return [
            'id' => $this->id,
            'comment' => $this->comment,
            'point' => $this->point,
            'commented_at' => $this->created_at,
            'driver' => new ReportCommentDriverResource($this->driver),
            'client_value' => $this->client_value,
            'main_driver' => new ReportCommentDriverResource($mainDriver),
            'responsible' => $this->questionnaireDiscussionAnswer ? new UserLite($this->questionnaireDiscussionAnswer->user) : null,
            'reaction' => $this->reaction,
            'reacted_by' => $this->reacted_by,
            'user_code' => $this->user->code,
            'conversations' => $this->conversations && $this->conversations->count() > 0 ? $this->conversations->first()->messages()->count() : null,
            'sensitiveWords' => $sensitiveWords,
        ];
    }
}
