<?php


namespace App\Http\Resources\Schedule;

use App\Models\User\User;
use App\Models\Schedule\ScheduleRoundQuestionnaire;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use App\Models\Schedule\ScheduleSegments;

class ScheduleSurvey extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array
     */
    public function toArray($request)
    {
        // get participate rate
        $total_participate = $this->getParticipateRate();

        $userIds = ScheduleRoundQuestionnaire::select('user_id')
            ->where('schedule_survey_id', $this->id)
            ->get();

        $query = User::with('employee.client');
        $query->join('employees', 'users.id', 'employees.user_id');
        $query->whereIn('users.id', $userIds);
        $surveyed_employees = $query->count('users.id');

        if ($surveyed_employees > 0 && $total_participate > 0) {
            $response_rate = (float) ($total_participate / $surveyed_employees) * 100;
        } else {
            $response_rate = 0;
        }

        return [
            'id' => $this->id,
            'name' => $this->name,
            'description' => $this->description,
            'start_date' => $this->start_date,
            'renewal_date' => $this->renewal_date,
            'status' => $this->status,
            'schedule_frequency_id' => $this->schedule_frequency_id,
            'schedule_frequency' => new ScheduleFrequencyLite($this->frequency),
            'duration' => $this->frequency->frequencySetting->week_complete * 7,
            'employees' => $surveyed_employees,
            'participate' => $total_participate,
            'total_questionnaires' => $this->total_questionnaire,
            'segments' => ScheduleSegments::getSegmentBySchedule($this->id),
            'response_rate' => $response_rate,
            'rounds' => ScheduleRound::collection($this->frequencyRounds)
        ];
    }
}