<?php

namespace App\Http\Resources\Segment;

use App\Facades\Context;
use App\Helpers\ModelHelper;
use App\Http\Resources\Schedule\ScheduleSurveyGroup;
use App\Models\Schedule\ScheduleSurvey;
use App\Models\Segment\EmploymentPhaseSegment;
use App\Models\User\Employee;
use App\Models\User\User;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\DB;

/**
 * @extends JsonResource<\App\Models\Contact\Address>
 */
class SegmentGroup extends JsonResource
{
    private function getQueryTotalEmployee(string $status = "")
    {
        $query = Employee::query()->has('user')
            ->groupBy('employees.manager_id')
            ->select(DB::raw('count(employees.id) as count, employees.manager_id as user_id'));
        if ($status) {
            $query->where('employees.status', $status);
        }
        ModelHelper::setConditionFindByClient($query);
        return $query;
    }

    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $client = Context::client()->get();

        if ($this->name == "eNPS survey") {
            $segments = ScheduleSurvey::query()->where('client_id', $client->id)->get();

            return [
                'code' => $this->code,
                'name' => $this->name,
                'options' => ScheduleSurveyGroup::collection($segments)
            ];
        } else if ($this->name == "Employment phase") {
            $segments = EmploymentPhaseSegment::query()->get();
            $options = [];
            foreach ($segments as $segment) {
                $options[] = ['code' => $segment->code, 'name' => $segment->name, 'description' => $segment->description];
            }

            return [
                'code' => $this->code,
                'name' => $this->name,
                'options' => $options,
            ];
        } else if ($this->name == "Manager") {
            $options = [];
            $query = User::manager()
                ->select('users.id', 'users.first_name', 'users.surname', 'users.profile_pic', 'users.' . User::getBusinessKeyName())
                ->leftJoin('employees', 'users.id', 'employees.user_id');

            //count for total user
            $queryTotalEmployee = $this->getQueryTotalEmployee();

            $query->leftjoin(
                DB::raw("(" . $queryTotalEmployee->toSql() . ") as total_employee"),
                function ($join) use ($queryTotalEmployee) {
                    $join->on('users.id', '=', 'total_employee.user_id')
                        ->addBinding($queryTotalEmployee->getBindings());
                    // bindings for sub-query WHERE added
                }
            );
            $query->addSelect('total_employee.count as total_employee')->whereNotNull('total_employee.count');

            $managers = $query->get();
            foreach ($managers as $manager) {
                $name = $manager->surname . ", " . $manager->first_name;
                $options[] = ['code' => $manager->id, 'name' => $name, 'description' => $name];
            }

            return [
                'code' => $this->code,
                'name' => $this->name,
                'options' => $options,
            ];
        } else {
            $segments = $this->segments()->byClient($client->id)->get();
            $options = null;
            if ($this->name == "Age") {
                $options = [];
                for ($i = 1; $i <= 6; $i++) {
                    $options[] = ['code' => $i, 'name' => $i == 6 ? 'Over 65' : ($i * 10 + ($i == 1 ? 6 : 5)) . "-" . (($i + 1) * 10 + 4)];
                }
            }

            return [
                'code' => $this->code,
                'name' => $this->name,
                'options' => $options ? $options : Segment::collection($segments)
            ];
        }
    }
}
