<?php

namespace App\Http\Resources\Subscription;

use App\Helpers\ConfigurationHelper;
use App\Helpers\DateHelper;
use Illuminate\Http\Resources\Json\JsonResource;

/**
 * @extends JsonResource<\App\Models\Subscription\SubscriptionPlan>
 */
class SubscriptionPlanDetail extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        return [
            'code' => $this->getBusinessKey(),
            'name' => $this->name,
            'description' => $this->description,
            'status' => $this->status,
            'stripe_price' => $this->stripe_price,
            'stripe_prod' => $this->stripe_prod,
            'cost' => $this->cost,
            'price_per_employee' => $this->price_per_employee,
            'is_public' => boolval($this->is_public),
            'created_at' => $this->created_at ? DateHelper::format($this->created_at) : null,
            'updated_at' => $this->updated_at ? DateHelper::format($this->updated_at) : null,
            'config' => (object)$this->planConfigurations->mapWithKeys(function($item, $key) {
                $value = ConfigurationHelper::convertDataByType($item->pivot->value, $item->type);
                return [$item->name => $value];
            })->toArray()
        ];
    }
}
