<?php

namespace App\Http\Resources\Tool\Survey;

use App\Enum\QuestionTypes as QuestionTypesEnum;
use App\Enum\SegmentTypes;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class SurveyQuestionDownload extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array
     */
    public function toArray($request)
    {
        $fromDate = $request->input('from_date');
        $toDate = $request->input('to_date');
        $filters = [];

        if (isset($filter)) {
            $filters['journeys'] = SurveyQuestionReport::getFilterByColumn($filter, 'journeys');
            $filters['isUsed'] = SurveyQuestionReport::getFilterByColumn($filter, 'isUsed');
            $filters['sentiment'] = SurveyQuestionReport::getFilterByColumn($filter, 'sentiment');
            $filters['score'] = SurveyQuestionReport::getFilterByColumn($filter, 'score');
            $filters['department'] = SurveyQuestionReport::getFilterByColumn($filter, 'department');
            $filters['location'] = SurveyQuestionReport::getFilterByColumn($filter, 'location');
            $filters['gender'] = SurveyQuestionReport::getFilterByColumn($filter, 'gender');
            $filters['employmentPhrase'] = SurveyQuestionReport::getFilterByColumn($filter, 'employmentPhrase');
            $filters['race'] = SurveyQuestionReport::getFilterByColumn($filter, 'race');
            $filters['team'] = SurveyQuestionReport::getFilterByColumn($filter, 'team');
        }
        $data = [
            'title' => $this->title,
            'type' => $this->type,
            'order' => $this->order,
            'id' => $this->id,
            'options' => $this->surveyOptions(),
        ];

        switch ($this->type) {
            case QuestionTypesEnum::TYPE_TEXT:
                $textResultByUser = $this->textResultByUser($fromDate, $toDate, $filters)->get()->toArray();
                $data['results'] = $textResultByUser;
                break;
            case QuestionTypesEnum::TYPE_RATING:
                $ratingResultByUser = $this->ratingResultByUser($fromDate, $toDate, $filters)->get()->toArray();
                $data['results'] = $ratingResultByUser;
                break;
            case QuestionTypesEnum::TYPE_MULTI:
                $choiceResultByUser = $this->choiceResultByUser($fromDate, $toDate, $filters)->get()->toArray();
                $data['results'] = $choiceResultByUser;
                break;
            default:
                break;
        }

        return $data;
    }
}