<?php


namespace App\Http\Resources\Tool\Survey;
use App\Enum\QuestionTypes as QuestionTypesEnum;
use App\Enum\SegmentTypes;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class SurveyQuestionReport extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array
     */
    public function toArray($request)
    {
        /**
         * Filters Report
         */
        $fromDate = $request->input('from_date');
        $toDate = $request->input('to_date');
        $filter = $request->input('filter');

        $filters = [];

        if (isset($filter)) {
            $filters['journeys'] = $this->getFilterByColumn($filter, 'journeys');
            $filters['isUsed'] = $this->getFilterByColumn($filter, 'isUsed');
            $filters['sentiment'] = $this->getFilterByColumn($filter, 'sentiment');
            $filters['score'] = $this->getFilterByColumn($filter, 'score');
            $filters['department'] = $this->getFilterByColumn($filter, 'department');
            $filters['location'] = $this->getFilterByColumn($filter, 'location');
            $filters['gender'] = $this->getFilterByColumn($filter, 'gender');
            $filters['employmentPhrase'] = $this->getFilterByColumn($filter, 'employmentPhrase');
            $filters['race'] = $this->getFilterByColumn($filter, 'race');
            $filters['team'] = $this->getFilterByColumn($filter, 'team');
        }



        /**
         * ENDED
         * ============================================================================
         */

        $data = [
            'title' => $this->title,
            'type' => $this->type,
            'order' => $this->order,
            'id' => $this->id,
            'options' => $this->surveyOptions(),
        ];
        switch ($this->type) {
            case QuestionTypesEnum::TYPE_TEXT:
                $textResult = $this->textResultCount($fromDate, $toDate, $filters)->get()->toArray();
                $textResultByUser = $this->textResultByUser($fromDate, $toDate, $filters)->get()->toArray();
                $data['report'] = [
                    'average' => '',
                    'distribution' => $textResult,
                    'textUsers' => $textResultByUser,
                ];
                break;
            case QuestionTypesEnum::TYPE_RATING:
                $ratingResult = $this->ratingResultCount($fromDate, $toDate, $filters)->get()->toArray();
                $totalRating = array_reduce($ratingResult, function ($accumulator, $item) {
                    return $accumulator + ($item['rating'] * $item['total']);
                }, 0);
                $totalRate = array_reduce($ratingResult, function ($accumulator, $item) {
                    return $accumulator + $item['total'];
                }, 0);

                $gendersResult = $this->ratingResultSegmentsTypeCount($fromDate, $toDate, $filters)
                    ->where('segments.segment_type_id', SegmentTypes::GENDER)->get();
                $genders = [];
                $gendersResult->map(function ($result) use (&$genders) {
                    if (!isset($genders[$result['name']])) {
                        $genders[$result['name']] = [];
                    }
                    $genders[$result['name']][$result['rating']] = $result['total'];
                });
                $locations = [];
                $locationsResult = $this->ratingResultSegmentsTypeCount($fromDate, $toDate, $filters)
                    ->where('segments.segment_type_id', SegmentTypes::LOCATION)->get();
                $locationsResult->map(function ($result) use (&$locations) {
                    if (!isset($locations[$result['name']])) {
                        $locations[$result['name']] = [];
                    }
                    $locations[$result['name']][$result['rating']] = $result['total'];
                });
                $data['report'] = [
                    'average' => $totalRate > 0 ? round($totalRating / $totalRate, 1) : 0,
                    'distribution' => $ratingResult,
                    'gender_distribution' => (object) $genders,
                    'location_distribution' => (object) $locations,
                ];
                break;
            case QuestionTypesEnum::TYPE_MULTI:
                $data['options'] = SurveyOption::collection($this->surveyOptions);
                $result = $this->choiceResultCount($fromDate, $toDate, $filters)->get()->toArray();
                $gendersResult = $this->choiceResultSegmentsTypeCount($fromDate, $toDate, $filters)
                    ->where('segments.segment_type_id', SegmentTypes::GENDER)->get();
                $genders = [];
                $totalRate = array_reduce($result, function ($accumulator, $item) {
                    return $accumulator + $item['total'];
                }, 0);
                $average = 0;
                if ($totalRate > 0) {
                    foreach ($result as $item) {
                        $average += $item['total'] / $totalRate;
                    }
                }
                $gendersResult->map(function ($result) use (&$genders) {
                    if (!isset($genders[$result['name']])) {
                        $genders[$result['name']] = [];
                    }
                    $genders[$result['name']][$result['option_id']] = $result['total'];
                });
                $locations = [];
                $locationsResult = $this->choiceResultSegmentsTypeCount($fromDate, $toDate, $filters)
                    ->where('segments.segment_type_id', SegmentTypes::LOCATION)->get();
                $locationsResult->map(function ($result) use (&$locations) {
                    if (!isset($locations[$result['name']])) {
                        $locations[$result['name']] = [];
                    }
                    $locations[$result['name']][$result['option_id']] = $result['total'];
                });
                $data['report'] = [
                    'average' => count($result) > 0 ? $average / count($result) : 0,
                    'distribution' => $result,
                    'gender_distribution' => (object) $genders,
                    'location_distribution' => (object) $locations,
                ];
                break;
            default:
                break;
        }
        return $data;
    }

    public static function getFilterByColumn($filter, $column_name)
    {
        return array_filter($filter, function ($item) use ($column_name) {
            return $item['column'] === $column_name;
        });
    }
}
