<?php

namespace App\Http\Resources\Tool\Survey;

use App\Enum\QuestionTypes as QuestionTypesEnum;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class SurveyResult extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param Request $request
     * @return array
     */
    public function toArray($request)
    {
        $questionType = $this->question->type;
        switch ($questionType) {
            case QuestionTypesEnum::TYPE_MULTI:
                // If type is multi-choice, the answer is an array of option ids
                $answer = $this->surveyChoiceResults ?
                    $this->surveyChoiceResults()->pluck('option_id')->toArray() : null;
                break;
            case QuestionTypesEnum::TYPE_RATING:
                $answer = $this->surveyRatingResult ? $this->surveyRatingResult->rating : null;
                break;
            case QuestionTypesEnum::TYPE_TEXT:
                $answer = $this->surveyTextResult ? $this->surveyTextResult->text : null;
                break;
            default:
                $answer = null;
        }
        
        return [
            'id' => $this->id,
            'question_id' => $this->question_id,
            'type' => $questionType,
            'answer' => $answer
        ];
    }
}
