<?php

namespace App\Http\Resources\User;

use App\Http\Resources\Language\Language;
use App\Http\Resources\Library\DocumentProfile;
use App\Http\Resources\Segment\Segment;
use Illuminate\Http\Resources\Json\JsonResource;

/**
 * @extends JsonResource<\App\Models\User\User>
 */
class AuthUser extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $client = $this->getClient();
        $employee = $this->employee;

        return [
            'code' => $this->code,
            'email' => $this->email,
            'email_change' => $this->email_change,
            'name' => $this->first_name,
            'first_name' => $this->first_name,
            'surname' => $this->surname,
            'avatar' => $this->avatarUrl,
            'roles' => $this->getRoleNames(),
            'language' => new Language($this->language),
            'google2fa_enable' => (bool)$this->google2fa_enable,
            'client_code' => isset($client) ? $client->code : null,
            'is_client_demo' => isset($client) ? $client->is_demo : null,
            'document_profiles' => $employee ? DocumentProfile::collection($employee->documentProfiles) : null,
            'status' => $employee ? $employee->status : null,
            'timezone' => $employee ? $employee->timezone : null,
        ];
    }
}
