<?php

namespace App\Http\Resources\User;

use App\Helpers\DateHelper;
use App\Http\Resources\Library\DocumentProfile;
use Illuminate\Http\Resources\Json\JsonResource;

class EmployeeInList extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $employee = $this->employee;


        return [
            'code'              => $this->code,
            'first_name'        => $this->first_name,
            'surname'           => $this->surname,
            'email'             => $this->email,
            'email_change'      => $this->email_change,
            'email_verified_at' => $this->email_verified_at,
            'last_login'        => $this->last_login,
            'job_title'         => $employee->job_title,
            'avatar'            => $this->avatarUrl,
            'start_date'        => $employee->start_date ? DateHelper::format($employee->start_date) : null,
            'created_at'        => $employee->created_at ? DateHelper::format($this->created_at) : null,
            'date_of_birth'     => $employee->date_of_birth ? DateHelper::format($employee->date_of_birth) : null,
            'employment_type'   => $employee->employment_type,
            'location'          => $this->location_code ? [
                'code' => $this->location_code,
                'name' => $this->location_name,
            ] : null,
            'department'        => $this->department_code ? [
                'code' => $this->department_code,
                'name' => $this->department_name,
            ] : null,
            'gender'            => $this->gender_code ? [
                'code' => $this->gender_code,
                'name' => $this->gender_name,
            ] : null,
            'team'              => $this->team_code ? [
                'code' => $this->team_code,
                'name' => $this->team_name,
            ] : null,
            'status'            => $employee->status,
            'document_profiles' => DocumentProfile::collection($employee->documentProfiles),
            'timezone'          => $employee->timezone,
            "location_id" => is_null($employee->location_id) ? null : $employee->location_id,
            "team_id" => is_null($employee->team_id) ? null : $employee->team_id,
            "department_id" => is_null($employee->department_id) ? null : $employee->department_id,
            "social_security_number" => $employee->social_security_number,
            "employee_client_id" => $employee->employee_client_id,
            "phone_number" => $employee->phone_number,
            "race" => $employee->race,
        ];
    }
}