<?php

namespace App\Http\Resources\User;

use App\Helpers\DateHelper;
use App\Http\Resources\ActionRequestSubmission\Submission;
use Illuminate\Http\Resources\Json\JsonResource;
use App\Http\Resources\User\UserLite;

/**
 * @extends JsonResource<\App\Models\Contact\Address>
 */
class JourneyEmployee extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $journey = [
            'code' => $this->code,
            'name' => $this->name,
        ];

        if (!empty($this->employee->stepSubmissions)) {
            $isInprogress = false;
            foreach ($this->employee->stepSubmissions as $stepSubmission) {
                $step = $stepSubmission['step'];
                $submission = $stepSubmission['submission'];

                $journey['employee']['progress']['steps'][] = [
                    'id' => $step->getKey(),
                    'name' => $step->name,
                    'submission' => !empty($submission) ? new Submission($submission) : null
                ];

                if (!empty($submission)) {
                    $isInprogress = true;
                }
            }
            $laststep = end($journey['employee']['progress']['steps']);
            $submission = $laststep['submission'];
            $journey['employee']['isInprogress'] = $isInprogress;
            $journey['employee']['isCompleted'] = $submission != null;
        }

        return $journey;
    }
}