<?php

namespace App\Http\Resources\User;

use App\Enum\ActionTypes;
use App\Helpers\DateHelper;
use App\Http\Resources\Action\Action as ActionResource;
use App\Http\Resources\Action\ActionSequence as ActionSequenceResource;
use App\Http\Resources\ActionRequestSubmission\Submission;
use App\Http\Resources\Client\ClientLite;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class UserActionProgress extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  Request $request
     * @return array
     */
    public function toArray($request)
    {
        $employee =  [
            'code' => $this->code,
            'email' => $this->email,
            'first_name' => $this->first_name,
            'surname' => $this->surname,
            'avatar' => $this->avatarUrl,
            'job_title' => $this->employee->job_title,
            'start_date' => $this->employee->start_date ? DateHelper::format($this->employee->start_date) : null,
            'type' => $this->action_type,
            'client' => new ClientLite($this->employee->client)
        ];

        switch ($this->action_type) {
            case ActionTypes::SINGLE_ACTION:
                $employee['single_action_progress']['action'] = new ActionResource($this->action);
                
                $submission = $this->single_action_submission;
                $employee['single_action_progress']['submission'] = !empty($submission) ? new Submission($submission) : null;
                break;
            case ActionTypes::ACTION_SEQUENCE:
                $employee['action_sequence_progress']['action_sequence'] =  new ActionSequenceResource($this->action);

                $submissions = $this->action_sequence_submission;
                if (!empty($submissions)) {
                    foreach ($submissions as $stepSubmission) {
                        $step = $stepSubmission['step'];
                        $submission = $stepSubmission['submission'];

                        $employee['action_sequence_progress']['steps'][] = [
                            'id' => $step->getKey(),
                            'name' => $step->name,
                            'submission' => !empty($submission) ? new Submission($submission) : null
                        ];
                    }
                }
        }
        
        return $employee;
    }
}
