<?php

namespace App\Http\Resources\User;

use App\Helpers\DateHelper;
use App\Http\Resources\ActionRequestSubmission\Submission;
use Illuminate\Http\Resources\Json\JsonResource;

/**
 * @extends JsonResource<\App\Models\Contact\Address>
 */
class UserJourney extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $employee = [
            'code' => $this->code,
            'email' => $this->email,
            'name' => $this->name,
            'first_name' => $this->first_name,
            'surname' => $this->surname,
            'avatar' => $this->avatarUrl,
            'job_title' => $this->employee->job_title,
            'start_date' => $this->employee->start_date ? DateHelper::format($this->employee->start_date) : null,
        ];

        if (!empty($this->stepSubmissions)) {

            foreach ($this->stepSubmissions as $stepSubmission) {
                $step = $stepSubmission['step'];
                $submission = $stepSubmission['submission'];

                $employee['progress']['steps'][] = [
                    'id' => $step->getKey(),
                    'name' => $step->name,
                    'submission' => !empty($submission) ? new Submission($submission) : null
                ];
            }
            $laststep = end($employee['progress']['steps']);
            $submission = $laststep['submission'];
            $employee['isCompleted'] = $submission != null;
        }

        return $employee;
    }
}