<?php

namespace App\Jobs;

use App\Facades\Context;
use App\Helpers\PandaDocHelper;
use App\Models\Action\ActionSequence;
use App\Services\Tool\Form\CheckValidTemplate;
use App\Services\Tool\Form\CreatePandaDocument;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;

class CreateActionSequenceDocument extends QualeeJob
{
    protected $actionSequence;

    /**
     * Create a new job instance.
     *
     * @param ActionSequence $actionSequence
     */
    public function __construct(ActionSequence $actionSequence)
    {
        $this->actionSequence = $actionSequence;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $actionSequence = $this->actionSequence;
        $formTypeSteps = $actionSequence->getFormTypeSteps();
        if (count($formTypeSteps) === 0) {
            return;
        }

        $actionSequenceClient = $actionSequence->client;
        Context::client()->set($actionSequenceClient);
        // Check client integrated PandaDoc form
        if (empty($actionSequenceClient->formAuthenticate)) {
            return;
        }

        $pandaDocHelper = (new PandaDocHelper())->setToken($actionSequenceClient->formAuthenticate->access_token);

        foreach ($formTypeSteps as $step) {
            $actionRequest = $step->actionRequest;
            $formTemplate = $actionRequest->contentable;
            if (!app(CheckValidTemplate::class)->execute(['template_id' => $formTemplate->template_id, 'is_throw' => 0])) {
                continue;
            }

            $existedUserIds = $formTemplate->documents()
                ->where('action_request_id', $actionRequest->id)
                ->pluck('user_id')->toArray();

            foreach ($actionSequence->users as $user) {
                // Only create document for employees who did not created document yet
                if (in_array($user->id, $existedUserIds)) {
                    continue;
                }
                app(CreatePandaDocument::class)->execute($formTemplate, $user, $actionRequest, $pandaDocHelper);
            }
        }
    }
}
