<?php

namespace App\Jobs;

use App\Enum\PlanConfigurations;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\IntegrationHelper;
use App\Models\Client\Client;
use App\Models\User\User;
use App\Services\Integration\CreateIntegrationEmployee;
use App\Services\Subscription\CheckRemainPlanAction;
use Illuminate\Validation\ValidationException;

class CreateIntegrationEmployees extends QualeeJob
{

    protected $client;
    protected $user;

    /**
     * Create a new job instance.
     *
     * @param Client $client
     * @param User $user
     */
    public function __construct(Client $client, User $user)
    {
        $this->client = $client;
        $this->user = $user;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        Context::client()->set($this->client);
        Context::user()->set($this->user);

        if (!app(CheckRemainPlanAction::class)->execute(PlanConfigurations::PACKAGE_INTEGRATION, false)) {
            return;
        }

        $integration = $this->client->integration;
        if (!$integration) {
            return;
        }

        $integrationHelper = new IntegrationHelper();
        $integrationEmployees = $integrationHelper->getEmployees($integration->account_token);
        foreach ($integrationEmployees as $employee) {
            try {
                app(CreateIntegrationEmployee::class)->execute([
                    'employee' => $employee, 'client' => $this->client
                ]);
            } catch (ValidationException | InvalidRequestException $e) {
                report($e);

                continue;
            }
        }
    }
}
