<?php

namespace App\Jobs;

use App\Facades\Context;
use App\Helpers\PandaDocHelper;
use App\Models\Journey\Journey;
use App\Services\Tool\Form\CheckValidTemplate;
use App\Services\Tool\Form\CreatePandaDocument;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;

class CreateJourneyEmployeeDocument extends QualeeJob
{
    protected $journey;

    /**
     * Create a new job instance.
     *
     * @param Journey $journey
     */
    public function __construct(Journey $journey)
    {
        $this->journey = $journey;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $journey = $this->journey;
        $formTypeSteps = $journey->getFormTypeSteps();

        // Only create document when journey is published and have more than one Form type step
        if ($journey->is_published && count($formTypeSteps) > 0) {
            $ownerClient = $journey->client;
            Context::client()->set($ownerClient);

            // Check client integrated PandaDoc form
            if (!empty($ownerClient->formAuthenticate)) {
                $pandaDocHelper = (new PandaDocHelper())->setToken($ownerClient->formAuthenticate->access_token);

                foreach ($formTypeSteps as $step) {
                    $actionRequest = $step->actionRequest;
                    $formTemplate = $actionRequest->contentable;
                    if (!app(CheckValidTemplate::class)->execute(['template_id' => $formTemplate->template_id, 'is_throw' => 0])) {
                        continue;
                    }

                    $existedUserIds = $formTemplate->documents()
                        ->where('action_request_id', $actionRequest->id)
                        ->pluck('user_id')->toArray();

                    foreach ($journey->users as $user) {
                        // Only create document for employees who did not created document yet
                        if (in_array($user->id, $existedUserIds)) {
                            continue;
                        }
                        app(CreatePandaDocument::class)->execute($formTemplate, $user, $actionRequest, $pandaDocHelper);
                    }
                }
            }
        }
    }
}
