<?php

namespace App\Jobs;

use App\Enum\ActionRequestTypes;
use App\Facades\Context;
use App\Helpers\ActionRequestHelper;
use App\Helpers\PandaDocHelper;
use App\Models\Action\Action;
use App\Services\Tool\Form\CheckValidTemplate;
use App\Services\Tool\Form\CreatePandaDocument;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;

class CreateSingleActionDocument extends QualeeJob
{
    protected $action;

    /**
     * Create a new job instance.
     *
     * @param Action $action
     */
    public function __construct(Action $action)
    {
        $this->action = $action;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $action = $this->action;
        $actionRequest = $action->actionRequest;
        $actionType = ActionRequestHelper::getActionRequestTypeByContent($actionRequest->contentable_type);
        if ($actionType !== ActionRequestTypes::FORM) {
            return;
        }

        $actionClient = $action->client;
        Context::client()->set($actionClient);
        // Check client integrated PandaDoc form
        if (empty($actionClient->formAuthenticate)) {
            return;
        }

        $pandaDocHelper = (new PandaDocHelper())->setToken($actionClient->formAuthenticate->access_token);

        $formTemplate = $actionRequest->contentable;
        if (!app(CheckValidTemplate::class)->execute(['template_id' => $formTemplate->template_id, 'is_throw' => 0])) {
            return;
        }

        $existedUserIds = $formTemplate->documents()
            ->where('action_request_id', $actionRequest->id)
            ->pluck('user_id')->toArray();

        foreach ($action->users as $user) {
            // Only create document for employees who did not created document yet
            if (in_array($user->id, $existedUserIds, true)) {
                continue;
            }
            app(CreatePandaDocument::class)->execute($formTemplate, $user, $actionRequest, $pandaDocHelper);
        }
    }
}
