<?php

namespace App\Jobs;

use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Models\Questionnaire\QuestionnaireSensitiveComment;
use App\Services\Client\GetClientAdminsByClientId;

class DistributeSensitiveCommentToAdmin extends QualeeJob
{
    protected $answer;
    protected $sensitiveWords;

    /**
     * Create a new job instance.
     *
     * @param QuestionnaireAnswer $answer
     * @param array $sensitiveWords
     */
    public function __construct(QuestionnaireAnswer $answer, array $sensitiveWords)
    {
        $this->answer = $answer;
        $this->sensitiveWords = $sensitiveWords;
    }

    /**
     * Execute the job.
     *
     * @return bool
     */
    public function handle()
    {
        $clientAdmins = app(GetClientAdminsByClientId::class)->execute(['client_id' => $this->answer->client_id]);

        // Reject all old data (apply for case employee update comment and it's not sensitive comment)
        QuestionnaireSensitiveComment::where('questionnaire_answer_id', $this->answer->questionnaire_id)->delete();

        //Insert new data
        $insertData = [];
        if (!empty($this->sensitiveWords)) {
            foreach ($clientAdmins as $admin) {
                $insertData[] = [
                    'client_id' => $this->answer->client_id,
                    'questionnaire_answer_id' => $this->answer->id,
                    'user_id' => $admin->id,
                    'is_read' => 0
                ];
            }
            QuestionnaireSensitiveComment::insert($insertData);
        }

        return true;
    }
}
