<?php

namespace App\Jobs;

use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Models\Journey\Journey;
use App\Models\Message\Conversation;
use App\Models\Quiz\Quiz;
use App\Models\Survey\Survey;
use App\Models\User\Employee;
use App\Models\User\User;
use App\Models\Event\Event;
use App\Models\Library\LibraryItem;
use App\Models\PowerSearch\SearchableObject;
use Illuminate\Support\Facades\Log;

/**
 * Class IndexPowerSearch
 * @package App\Jobs
 */
class IndexPowerSearch extends QualeeJob
{
    protected $id;
    protected $type;
    protected $action;
    protected $clientId;
    /**
     * IndexPowerSearch constructor.
     * @param string $id : ID/Code of object
     * @param string $type : 'employee', 'event'...
     * @param action $type : 'add', 'delete'
     */
    public function __construct($id, $type, $action, $clientId)
    {
        $this->id = $id;
        $this->type = $type;
        $this->action = $action;
        $this->clientId = $clientId;
    }

    public function handle()
    {
        if ($this->action == PowerSearchActions::ADD) {
            $newText = null;
            switch ($this->type) {
                case PowerSearchTypes::EMPLOYEE:
                    $user = User::where('code', $this->id)->first();
                    if ($user) {
                        $names = [$user->surname, $user->first_name];
                        $newText = implode(", ", array_filter($names, function($k) {
                            return !empty($k);
                        }));
                    }
                    break;
                case PowerSearchTypes::EVENT:
                    $event = Event::where('code', $this->id)->first();
                    if ($event) {
                        $newText = $event->name;
                    }
                    break;
                case PowerSearchTypes::LIBRARY:
                    $libraryItem = LibraryItem::find($this->id);
                    if ($libraryItem) {
                        $newText = $libraryItem->name;
                    }
                    break;
                case PowerSearchTypes::JOURNEY:
                    $journey = Journey::where('code', $this->id)->first();
                    if ($journey) {
                        $newText = $journey->name;
                    }
                    break;
                case PowerSearchTypes::QUIZ:
                    $quiz = Quiz::where('code', $this->id)->first();
                    if ($quiz) {
                        $newText = $quiz->name;
                    }
                    break;
                case PowerSearchTypes::SURVEY:
                    $survey = Survey::where('code', $this->id)->first();
                    if ($survey) {
                        $newText = $survey->name;
                    }
                    break;
                case PowerSearchTypes::CASE_ID:
                    $conversation = Conversation::query()->where('id', $this->id)->first();
                    if ($conversation) {
                        $newText = $conversation->anonymous_id;
                    }
            }

            if ($newText && !empty($this->clientId)) {
                $searchableObj = SearchableObject::where('client_id', $this->clientId)
                    ->where('object_type', $this->type)
                    ->where('object_id', $this->id)->first();

                if ($searchableObj) {
                    $searchableObj->object_content = $newText;
                } else {
                    $searchableObj = new SearchableObject();
                    $searchableObj->object_content = $newText;
                    $searchableObj->client_id = $this->clientId;
                    $searchableObj->object_type = $this->type;
                    $searchableObj->object_id = $this->id;
                }
                $searchableObj->save();
            }
        } elseif ($this->action == PowerSearchActions::DELETE) {
            SearchableObject::where('client_id', $this->clientId)
                ->where('object_type', $this->type)
                ->where('object_id', $this->id)->delete();
        }
        return true;
    }
}
