<?php


namespace App\Jobs;


use App\Events\MessageWatched;
use App\Helpers\DateHelper;
use App\Models\Message\Conversation;
use Carbon\Carbon;

class MarkConversationAsRead extends QualeeJob
{

    protected $conversationId;
    protected $userId;

    /**
     * Mark conversation as read constructor.
     * @param $conversationId
     * @param $userId
     */
    public function __construct($conversationId, $userId)
    {
        $this->conversationId = $conversationId;
        $this->userId = $userId;
    }

    public function handle()
    {
        $conversation = Conversation::active()->findOrFail($this->conversationId);
        $conversation->users()->sync([$this->userId => ['last_read' => Carbon::now()]], false);
        $receiverCodes = $conversation->users()->where('id', '!=', $this->userId)->pluck('code')->toArray();
        foreach ($receiverCodes as $receiverCode) {
            $watchedTime = DateHelper::formatWithMilisecond(Carbon::now());
            broadcast(new MessageWatched($conversation->id, $receiverCode, $watchedTime))->toOthers();
        }
    }
}

