<?php

namespace App\Jobs;

use App\DataTransferObject\StreamedFile;
use App\Facades\Context;
use App\Helpers\PandaDocHelper;
use App\Helpers\ResourceLocationBuilder;
use App\Models\Form\FormDocument;
use App\Models\Form\FormSignedDocument;
use App\Services\Attachment\CreateAttachment;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;

class SaveFormDocument extends QualeeJob
{
    protected $document;

    /**
     * Create a new job instance.
     *
     * @param FormDocument $document
     */
    public function __construct(FormDocument $document)
    {
        $this->document = $document;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $user = $this->document->user;
        $client = $user->getClient();
        $formAuthenticate = $client->formAuthenticate;
        if (!empty($formAuthenticate)) {
            $pandaDocHelper = new PandaDocHelper();
            $pandaDocHelper->setToken($formAuthenticate->access_token);
            $fileContent = $pandaDocHelper->downloadDocument($this->document->document_id);
            
            if ($fileContent) {
                $documentTemplate = $this->document->template;
                
                $document = new StreamedFile(
                    $fileContent,
                    $documentTemplate->name . '.pdf',
                    'pdf',
                    strlen($fileContent),
                    'application/pdf'
                );

                $fileDir = (new ResourceLocationBuilder())
                    ->setClient($client->getBusinessKey())
                    ->setUser($user->getBusinessKey())
                    ->getSignedDocumentPath();

                $attachment = app(CreateAttachment::class)->execute($document, $fileDir, $user->getKey());

                FormSignedDocument::create([
                    'document_id' => $this->document->getKey(),
                    'attachment_id' => $attachment->getKey()
                ]);
            }
        }
    }
}
