<?php

namespace App\Jobs;


use App\Helpers\DateHelper;
use App\Helpers\ObjectHelper;
// use App\Models\Message\Notification;
use App\Models\User\User;
use Carbon\Carbon;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\ValidationException;

/**
 * Class SendNotification
 * @package App\Jobs
 */
class SendNotification extends QualeeJob
{

    /**
     * @var
     */
    protected $appId;
    /**
     * @var
     */
    protected $apiKey;

    /**
     *
     */
    protected $url;

    /**
     *
     */
    protected $options;

    /**
     * SendNotification constructor.
     * @param array $arguments
     * @param array $options
     */
    public function __construct(array $arguments = [], array $options = [])
    {
        $this->arguments = $arguments;
        $this->options = $options;
        $this->getConfigurationKey();
    }

    /**
     * Execute the job.
     *
     * @return mixed
     * @throws ValidationException
     */
    public function handle()
    {
        $this->validateData();

        $signalId = $this->getSignalId($this->arguments['userIds']);

        $sendAfterDate = !empty($this->arguments['send_after']) ? Carbon::parse($this->arguments['send_after']) : null;

        $fields = array(
            'app_id' => $this->appId,
            'include_player_ids' => $signalId,
            'data' => ObjectHelper::nullOrValue($this->arguments, 'data'),
            'send_after' => !empty($sendAfterDate) ? DateHelper::format($sendAfterDate) : null
        );

        $fields = array_merge($fields, $this->getDataNotification());
        $fields = array_merge($fields, $this->options);

        $url = $this->url;

        $header = array(
            'Content-Type: application/json; charset=utf-8',
            'Authorization: Basic ' . $this->apiKey
        );

        $response = Http::withHeaders($header)->post($url, $fields);
        if (isset($response['errors']) && count($response['errors']) > 0) {
            $this->reportSentry($response['errors'], 'signal_id: ' . count($signalId));
        }
        /*
        if (isset($response['id']) && $response['id']) {
            $notification = new Notification(['sender_id' => $this->arguments['sender'], 'onesignal_id' => $response['id']]);
            $notification->save();
            $notification->receivers()->sync(User::whereIn('code', $this->arguments['userIds'])->get()->pluck('id'));
        }
        */
        return $response->json();
    }

    /**
     *
     */
    public function reportSentry($errors, $detail = '')
    {
        logger()->error('Something when wrong when send notification' . $detail, $errors);
    }

    /**
     * Get configuration for send notification
     */
    protected function getConfigurationKey()
    {
        $this->appId = config('services.onesignal.app_id');
        $this->apiKey = config('services.onesignal.rest_api_key');
        $this->url = config('services.onesignal.url');
    }

    /**
     * @return array
     */
    protected function getDataNotification()
    {
        $dataKeys = ["headings", "subtitle", "contents"];
        $result = [];
        foreach ($dataKeys as $key) {
            $value = ObjectHelper::nullOrValue($this->arguments, $key);
            if ($value) {
                $result[$key] = array("en" => $value);
            }
        }
        return $result;
    }

    /**
     * @param string|array $userCodes
     * @return mixed
     */
    protected function getSignalId($userCodes)
    {
        $userCodes = ObjectHelper::toArray($userCodes);
        $result = User::query()
            ->join('employees', 'users.id', 'employees.user_id')
            ->whereIn('users.code', $userCodes)
            ->whereNotNull('employees.signal_id')
            ->whereNull('employees.deleted_at')
            ->select('employees.signal_id')
            ->get()
            ->pluck('signal_id')
            ->toArray();
        return array_filter($result, function ($id) {
            return !empty($id) && $id != '0';
        });
    }

    /**
     * @throws ValidationException
     */
    protected function validateData()
    {
        Validator::make($this->arguments, [
            'contents' => 'string',
            'headings' => 'required|string',
            'subtitle' => 'string',
            'userIds' => 'required',
            'data' => 'array'
        ])->validate();
    }
}
