<?php

namespace App\Jobs;

use App\Events\NotificationCreated;
use App\Models\Message\Notification;
use App\Models\User\User;
use Illuminate\Validation\ValidationException;

/**
 * Class SendNotification
 * @package App\Jobs
 */
class SendNotificationConsole extends QualeeJob
{
    protected $sender;
    protected $receiver;
    protected $content = '';
    protected $params = [];

    /**
     * SendNotification constructor.
     * @param array $arguments
     * @param array $options
     */
    public function __construct(User $sender, User $receiver, string $content = '', $params = [])
    {
        $this->sender = $sender;
        $this->receiver = $receiver;
        $this->content = $content;
        $this->params = $params;
    }

    /**
     * Execute the job.
     *
     * @return mixed
     * @throws ValidationException
     */
    public function handle()
    {
        $notification = new Notification([
            'sender_id' => $this->sender->id,
            'receiver_id' => $this->receiver->id,
            'content' => $this->content,
        ]);
        $notification->save();

        broadcast(
            new NotificationCreated($notification)
        )->toOthers();
    }

    /**
     *
     */
    public function reportSentry($errors, $detail = '')
    {
        logger()->error('Something when wrong when send notification via console' . $detail, $errors);
    }
}
