<?php

namespace App\Jobs;

use App\Enum\QuestionnaireEnum;
use App\Mail\SensitiveAlert;
use App\Models\Client\Client;
use App\Models\Questionnaire\Questionnaire;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Models\User\User;
use App\Services\Client\GetClientAdminsByClientId;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Mail;

class SendSensitiveAlert extends QualeeJob
{
    protected $answer;
    protected $sensitiveWords;

    /**
     * Create a new job instance.
     *
     * @param QuestionnaireAnswer $answer
     * @param array $sensitiveWords
     */
    public function __construct(QuestionnaireAnswer $answer, array $sensitiveWords)
    {
        $this->answer = $answer;
        $this->sensitiveWords = $sensitiveWords;
    }

    /**
     * Execute the job.
     *
     * @return bool
     */
    public function handle()
    {
        $clientAdmins = app(GetClientAdminsByClientId::class)->execute(['client_id' => $this->answer->client_id]);
        $questionnaire = Questionnaire::find($this->answer->questionnaire_id);

        $client = Client::find($this->answer->client_id);
        if (!empty($client) && strpos($questionnaire->question, QuestionnaireEnum::QUESTION_PREFIX) !== false) {
            $questionnaire->question = str_replace(QuestionnaireEnum::QUESTION_PREFIX, $client->name, $questionnaire->question);
        }
        foreach($clientAdmins as $admin) {
            Mail::to($admin->email)->send(new SensitiveAlert($this->answer, $questionnaire, $admin, $this->sensitiveWords));
        }
        return true;
    }
}
