<?php

namespace App\Jobs;

use App\Mail\EmailChangeVerification;
use App\Models\User\User;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Mail;

class SendVerifyEmailChange extends QualeeJob
{

    protected $newEmail;
    protected $user;

    /**
     * Create a new job instance.
     *
     * @param User $user
     * @param string $newEmail
     */
    public function __construct(User $user, string $newEmail)
    {
        $this->user = $user;
        $this->newEmail = $newEmail;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $verificationUrl = $this->verificationUrl($this->user, $this->newEmail);
        Mail::to($this->newEmail)->send(new EmailChangeVerification($verificationUrl));
    }

    protected function verificationUrl(User $user, string $email)
    {
        $path = app('api.url')->version('v1')->temporarySignedRoute(
            'verification.verify',
            Carbon::now()->addMinutes(Config::get('auth.verification.expire', 60)),
            [
                'id' => $user->getKey(),
                'hash' => sha1($email),
            ],
            false
        );

        $frontEndPath = preg_replace('/^(.*?)api\//', '/', $path);

        return url(config('app.front_end_url') . $frontEndPath);
    }
}
