<?php

namespace App\Jobs;

use App\Enum\OCRAllowedMimeTypes;
use App\Enum\OCRJobStatus;
use App\Models\Attachment;
use App\Models\Attachment\AttachmentOCR;
use Exception;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class StartDocumentOCR extends QualeeJob
{
    protected $attachment;

    /**
     * Create a new job instance.
     *
     * @param Attachment $attachment
     */
    public function __construct(Attachment $attachment)
    {
        $this->attachment = $attachment;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $attachment = $this->attachment;

        // OCR only support JPEG, PNG OR PDF format
        if (!in_array($attachment->mime_type, OCRAllowedMimeTypes::AllowedMimeTypes, true)) {
            return;
        }

        $documentPath = $attachment->path;
        $ocrEnv = config('ocr.ocr_env');
        $outputPrefix = $ocrEnv . '/' . dirname($documentPath);

        try {
            $attachmentOCR = AttachmentOCR::create([
                'attachment_id' => $attachment->getKey(),
                'ocr_job_id' => '',
                'ocr_job_status' => OCRJobStatus::IN_PROGRESS
            ]);

            $params = [
                'bucket_name' => config('filesystems.disks.s3.bucket'),
                'document_name' => $documentPath,
                'output_bucket_name' => config('filesystems.disks.s3OCR.bucket'),
                'output_prefix' => $outputPrefix,
            ];

            $startDocumentOCRUrl = config('qualee-ai-doc-search.ads_lambda_search_domain') . '/start_document_ocr';
            $response = Http::withHeaders(['Accept' => 'application/json'])
                ->asJson()
                ->post($startDocumentOCRUrl, $params);

            $responseJob = $response->json();
            if (!$response->successful()) {
                Log::error('Error occurred when starting document OCR', $responseJob);
                return;
            }

            $attachmentOCR->ocr_job_id = $responseJob['JobId'];
            $attachmentOCR->save();
        } catch (Exception $e) {
            Log::error($e);
        }
    }
}
