<?php

namespace App\Listeners;

use App\Events\QuestionnaireAnswerSubmitted;
use App\Jobs\SendSensitiveAlert as SendSensitiveAlertJobs;
use App\Jobs\DistributeSensitiveCommentToAdmin as DistributeSensitiveCommentToAdminJobs;
use App\Jobs\SendAlertMessageToAdmin as SendAlertMessageToAdminJobs;
use App\Services\SensitiveWord\DetectSensitiveWord;

class CheckSensitiveComment
{
    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param QuestionnaireAnswerSubmitted $event
     * @return void
     */
    public function handle(QuestionnaireAnswerSubmitted $event)
    {
        $answer = $event->answer;

        //check if the comment content have sensitive word
        $sensitiveWords = !empty($answer->comment) ? app(DetectSensitiveWord::class)->execute(['comment' => $answer['comment']]) : null;

        // Display sensitive comment for admin
        DistributeSensitiveCommentToAdminJobs::dispatch($answer, $sensitiveWords);

        if (!empty($sensitiveWords)) {
            // Send Alert message to client admin
            SendAlertMessageToAdminJobs::dispatch($answer);

            // Send email to client admin
            SendSensitiveAlertJobs::dispatch($answer, $sensitiveWords);
        }
    }
}
