<?php

namespace App\Listeners;

use App\Enum\ConversationTypes;
use App\Enum\SegmentTypes;
use App\Events\MessageCreated;
use App\Facades\Context;
use App\Helpers\ModelHelper;
use App\Models\Segment\AgeSegment;
use App\Models\Segment\EmploymentPhaseSegment;
use App\Models\Segment\Segment;
use App\Models\Segment\SegmentType;
use App\Models\User\User;
use App\Services\Message\CreateConversation;
use App\Services\Segment\SegmentType\GetSegmentEmployee;
use Illuminate\Contracts\Queue\ShouldQueue;

/**
 * Class CreateMessageNotifyType
 * @package App\Listeners
 */
class CreateMessageNotifyType implements ShouldQueue
{
    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param object $event
     * @return void
     */
    public function handle(MessageCreated $event)
    {
        $message = $event->message;
        $conversation = $message->conversation;
        if ($conversation->type === ConversationTypes::NOTIFY_MESSAGE) {
            Context::user()->set($conversation->owner);
            Context::client()->set($conversation->owner->client->first());
            $segments = $conversation->segments;
            foreach ($segments as $segment) {
                $users = $this->getUserBySegment($segment)->filter(function($item) use ($conversation) {
                    return $item->id !== $conversation->owner_id;
                });
                foreach ($users as $user) {
                    $conversation = app(CreateConversation::class)
                        ->execute(['type'          => ConversationTypes::NOTIFY_MESSAGE_EMPLOYEE,
                                   'receiver_code' => $user->code,
                                   'force_create'  => false]);
                    $newMessage = $message->replicate();
                    $newMessage->conversation()->associate($conversation);
                    $newMessage->save();
                }

            }
        }
    }

    /**
     * @param Segment $segment
     * @return mixed
     */
    public function getUserBySegment($segment)
    {
        if ($segment instanceof Segment) {
            $data = ['code' => $segment->segmentType->code, 'segment_code' => $segment->code];
        } else if ($segment instanceof User) {
            $code = ModelHelper::convertIdToBusinessKey(SegmentType::class, SegmentTypes::MANAGER);
            $data = ['code' => $code, 'segment_code' => $segment->code];
        } else if ($segment instanceof AgeSegment) {
            $code = ModelHelper::convertIdToBusinessKey(SegmentType::class, SegmentTypes::AGE);
            $data = ['code' => $code, 'segment_code' => $segment->code];
        } else if ($segment instanceof EmploymentPhaseSegment) {
            $code = ModelHelper::convertIdToBusinessKey(SegmentType::class, SegmentTypes::EMPLOYMENT);
            $data = ['code' => $code, 'segment_code' => $segment->code];
        }
        return app(GetSegmentEmployee::class)->execute($data);
    }
}
