<?php

namespace App\Listeners;

use App\Events\SubmissionUpdated;
use App\Http\Resources\User\Manager;
use App\Mail\JourneyNotification;
use App\Models\Action\Action;
use App\Models\Action\ActionSequenceStep;
use App\Models\Action\ActionSequenceUser;
use App\Models\Action\ActionUser;
use App\Models\Journey\JourneyStep;
use App\Models\Journey\JourneyUser;
use App\Models\User\Employee;
use App\Models\User\User;
use App\Services\ActionRequest\CheckUserCompletedRequest;
use Illuminate\Support\Facades\Mail;

class HandleMarkRequestAsCompleted
{
    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param SubmissionUpdated $event
     * @return void
     */
    public function handle(SubmissionUpdated $event)
    {
        $actionRequest = $event->submission->actionRequest;
        $user = $event->submission->user;
        $userId = $user->getKey();
        
        $isUserCompletedRequest = app(CheckUserCompletedRequest::class)->execute($actionRequest, $user);
        
        switch ($actionRequest->actionable_type) {
            case JourneyStep::class:
                $journey = $actionRequest->actionable->journey;

                JourneyUser::where('journey_id', $journey->getKey())
                    ->where('user_id', $userId)
                    ->update(['is_completed' => $isUserCompletedRequest]);

                if ($isUserCompletedRequest) {
                    $employee = Employee::where('user_id', '=', $userId)->firstOrFail();
                    if ($employee) {
                        if ($employee->manager_notification_id) {
                            $managerIds = explode(';', $employee->manager_notification_id);
                            if (isset($managerIds)) {
                                $managers = User::whereIn('id', $managerIds)->get();
                                foreach ($managers as $manager) {
                                    $email = $manager->email;
                                    Mail::to($email)->send(new JourneyNotification($user, $journey->name, $manager));
                                }
                            }
                        }
                    }
                }
                break;

            case ActionSequenceStep::class:
                $actionSequence = $actionRequest->actionable->actionSequence;

                ActionSequenceUser::where('action_sequence_id', $actionSequence->getKey())
                    ->where('user_id', $userId)
                    ->update(['is_completed' => $isUserCompletedRequest]);
                break;

            case Action::class:
                ActionUser::where('action_id', $actionRequest->actionable->getKey())
                    ->where('user_id', $userId)
                    ->update(['is_completed' => $isUserCompletedRequest]);
                break;
        }
        
    }
}
