<?php

namespace App\Listeners;

use App\Events\RoleAccessUpdated;
use App\Services\UserAccess\GetClientRoleAccessNames;

class SyncRoleAccess
{
    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param RoleAccessUpdated $event
     * @return void
     */
    public function handle(RoleAccessUpdated $event)
    {
        $client = $event->client;
        $previousPermissions = $event->previousPermissions;
        $role = $event->role;
        $clientRoleAccessPermissions = app(GetClientRoleAccessNames::class)->execute([
            'client' => $client,
            'role'   => $role
        ]);
        $permissionsToRevoke = array_diff($previousPermissions, $clientRoleAccessPermissions);
        $permissionsToGive = array_diff($clientRoleAccessPermissions, $previousPermissions);
        if (empty($permissionsToRevoke) && empty($permissionsToGive)) {
            return;
        }
        $clientEmployeeByRole = $client->employees()->whereHas('user', function ($uq) use ($role) {
            $uq->whereHas("roles", function ($rq) use ($role) {
                $rq->where('name', $role);
            });
        })->get()->pluck('user');
        foreach ($clientEmployeeByRole as $employee) {
            $employee->revokePermissionTo($permissionsToRevoke);
            $employee->givePermissionTo($permissionsToGive);
        }
    }
}
