<?php

namespace App\Mail;

use App\Models\User\User;
use Illuminate\Bus\Queueable;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;

class JourneyNotification extends Mailable
{
    use Queueable, SerializesModels;

    protected $user;
    private $journey_name;
    private $manager;

    /**
     * Create a new message instance.
     *
     * @param User $user
     * @param string $journey_name
     * @param User $manager
     */
    public function __construct(User $user, string $journey_name, User $manager)
    {
        $this->user = $user;
        $this->journey_name = $journey_name;
        $this->manager = $manager;
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        return $this->markdown('emails.journey-notification')
            ->subject('Journey Notification')
            ->with([
                'name' => $this->manager->first_name . " " . $this->manager->surname,
                'first_name' => $this->user->first_name,
                'last_name' => $this->user->surname,
                'journey_name' => $this->journey_name,
            ]);
    }
}