<?php

namespace App\Mail;

use App\Models\User\User;
use Illuminate\Bus\Queueable;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;

class JourneyStepNotification extends Mailable
{
    use Queueable, SerializesModels;

    protected $user;
    private $journey_name;
    private $journey_step_name;
    private $email;

    /**
     * Create a new message instance.
     *
     * @param User $user
     * @param string $journey_step_name
     * @param string $journey_name
     * @param string $email
     */
    public function __construct(User $user, string $journey_step_name, string $journey_name, string $email)
    {
        $this->user = $user;
        $this->journey_name = $journey_name;
        $this->journey_step_name = $journey_step_name;
        $this->email = $email;
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        return $this->markdown('emails.journey-step-notification')
            ->subject('Journey Step Notification')
            ->with([
                'name' => $this->email,
                'first_name' => $this->user->first_name,
                'last_name' => $this->user->surname,
                'step_name' => $this->journey_step_name,
                'journey_name' => $this->journey_name,
            ]);
    }
}