<?php

namespace App\Mail;

use App\Enum\EmailNotifications;
use App\Models\User\User;
use Illuminate\Bus\Queueable;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;

class Notification extends Mailable
{
    use Queueable, SerializesModels;

    private $user;
    private $type = '';
    private $params = [];

    /**
     * Create a new message instance.
     *
     * @return void
     */
    public function __construct(User $user, $type = 'journey', $params = [])
    {
        //
        $this->user = $user;
        $this->type = $type;
        $this->params = $params ?? [];
    }

    private function setParam($field, $value, $forceUpdate = false)
    {
        if ($forceUpdate) {
            $this->params[$field] = $value;
            return;
        }
        if (!isset($this->params[$field]) || !$this->params[$field]) {
            $this->params[$field] = $value;
        }
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        switch ($this->type) {
            case EmailNotifications::JOURNEY_INVITATION:
                $this->setParam('journey', 'New Journey');
                break;
        }
        return $this->markdown('notifications.' . $this->type)
            ->subject('You have a new Qualee notification')
            ->with(array_merge([
                'name' => $this->user->first_name,
                'company_name' => $this->user->employee->client->name
            ], $this->params));
    }
}
