<?php

namespace App\Mail;

use App\Models\Questionnaire\Questionnaire;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Models\User\User;
use Illuminate\Bus\Queueable;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Log;

class SensitiveAlert extends Mailable
{
    use Queueable, SerializesModels;

    protected $admin;
    protected $answer;
    protected $sensitiveWords;
    protected $questionnaire;

    /**
     * Create a new message instance.
     *
     * @param QuestionnaireAnswer $answer
     * @param Questionnaire $questionnaire
     * @param User $admin
     * @param array $sensitiveWords
     */
    public function __construct(QuestionnaireAnswer $answer, Questionnaire $questionnaire, User $admin, array $sensitiveWords)
    {
        $this->admin = $admin;
        $this->answer = $answer;
        $this->sensitiveWords = $sensitiveWords;
        $this->questionnaire = $questionnaire;
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        return $this->markdown('emails.sensitive-word')
            ->subject('ALERT: Employee comment')
            ->with([
                'admin' => $this->admin,
                'sensitiveWords' => $this->sensitiveWords,
                'questionnaire' => $this->questionnaire,
                'answer' => $this->answer
            ]);
    }
}
