<?php

namespace App\Mail;

use Illuminate\Mail\Mailable;
use App\Models\User\User;
use Illuminate\Bus\Queueable;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Carbon;

class WorkAnniversaryNotification extends Mailable
{
    use Queueable, SerializesModels;

    protected $user;
    protected $employeeUser;

    /**
     * Create a new message instance.
     *
     * @param User $user
     */
    public function __construct(User $user, User $employee)
    {
        $this->user = $user;
        $this->employeeUser = $employee;
    }

    /**
     * Build the message.
     *
     * @return $this
     */
    public function build()
    {
        return $this->markdown('emails.work-anniversary-notification')
            ->subject('Work Anniversary Notification')
            ->with([
                'name' => $this->user->first_name . " " . $this->user->surname,
                'first_name' => $this->employeeUser->first_name,
                'last_name' => $this->employeeUser->surname,
                'start_date'=> Carbon::parse($this->employeeUser->employee->start_date)->format('d M Y'),
            ]);
    }
}