<?php

namespace App\Models\Action;

use App\Contracts\ClientProperty;
use App\Helpers\ActionRequestHelper;
use App\Models\ActionRequest\ActionRequest;
use App\Models\Asset;
use App\Models\Client\Client;
use App\Models\User\User;
use App\Traits\HasBusinessKey;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\MorphOne;

class Action extends Model implements ClientProperty
{
    
    use HasBusinessKey;
    
    protected $table = 'actions';
    
    protected $fillable = ['client_id', 'is_send_immediately', 'send_on', 'due_by', 'created_by', 'message', 'header_image_id'];

    protected $dates = ['send_on', 'due_by'];

    /**
     * @return BelongsToMany
     */
    public function users(): BelongsToMany
    {
        return $this->belongsToMany(User::class);
    }

    /**
     * @return BelongsToMany
     */
    public function approvers(): BelongsToMany
    {
        return $this->belongsToMany(User::class, 'action_approver');
    }

    /**
     * @return MorphOne
     */
    public function actionRequest() : MorphOne
    {
        return $this->morphOne(ActionRequest::class, 'actionable');
    }

    /**
     * Get action name
     * 
     * @return string|null
     */
    public function getNameAttribute()
    {
        return ActionRequestHelper::getTypeNameByContentType($this->actionRequest->contentable_type);
    }

    public function getClientId()
    {
        return $this->client_id;
    }

    /**
     * @return BelongsTo
     */
    public function headerImage(): BelongsTo
    {
        return $this->belongsTo(Asset::class, 'header_image_id', 'id');
    }

    /**
     * @return BelongsTo
     */
    public function client()
    {
        return $this->belongsTo(Client::class);
    }
}
