<?php

namespace App\Models\Action;

use App\Enum\SubmissionStatus;
use App\Facades\Context;
use App\Models\ActionRequest\ActionRequest;
use App\Models\Asset;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\MorphOne;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class ActionSequenceStep extends Model
{

    protected $table = 'action_sequence_steps';

    protected $fillable = ['message', 'order', 'name', 'header_image_id'];
    
    /**
     * @return BelongsTo
     */
    public function actionSequence(): BelongsTo
    {
        return $this->belongsTo(ActionSequence::class);
    }
    
    /**
     * @return MorphOne
     */
    public function actionRequest() : MorphOne
    {
        return $this->morphOne(ActionRequest::class, 'actionable');
    }

    /**
     * Get is_completed status
     *
     * @return mixed
     */
    public function getIsCompletedAttribute()
    {
        return $this->actionRequest->submissions()
            ->select(DB::raw('count(DISTINCT user_id) as count'))
            ->where('user_id', Context::user()->get()->id)
            ->where('action_request_id', $this->actionRequest->id)
            ->whereIn('status', SubmissionStatus::COMPLETED_STATUS)
            ->first()
            ->count;
    }

    /**
     * @return BelongsTo
     */
    public function headerImage(): BelongsTo
    {
        return $this->belongsTo(Asset::class, 'header_image_id', 'id');
    }

    /**
     * @return bool
     */
    public function hasSubmission()
    {
        if ($this->actionRequest->submissions()->count() > 0) {
            return true;
        }
        
        return false;
    }
}
