<?php

namespace App\Models\ActionRequest;

use App\Contracts\ClientProperty;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\MorphTo;

/**
 * Class ActionRequest
 * @package App\Models\ActionRequest
 */
class ActionRequest extends Model implements ClientProperty
{
    protected $table = 'action_requests';
    
    protected $fillable = ['status'];

    /**
     * @return MorphTo
     */
    public function actionable() : MorphTo
    {
        return $this->morphTo();
    }

    /**
     * @return MorphTo
     */
    public function contentable() : MorphTo
    {
        return $this->morphTo();
    }

    /**
     * @return HasMany
     */
    public function submissions() : HasMany
    {
        return $this->hasMany(ActionRequestSubmission::class);
    }

    public function countNewSubmission(): int
    {
        $yesterday = Carbon::yesterday();
        return $this->submissions()->where('action_request_submissions.created_at', '>=', $yesterday)->count();
    }

    public function getClientId()
    {
        return $this->client_id;
    }
}
