<?php

namespace App\Models\ActionRequest;

use App\Enum\SubmissionStatus;
use App\Models\ContentFile\ContentFileResult;
use App\Models\ContentPhoto\ContentPhotoResult;
use App\Models\Form\FormDocument;
use App\Models\Form\FormResult;
use App\Models\IDVerification\IDVerificationResult;
use App\Models\Quiz\QuizResult;
use App\Models\User\User;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use App\Models\Survey\SurveyResult;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasManyThrough;

class ActionRequestSubmission extends Model
{
    protected $fillable = ['user_id', 'action_request_id', 'status', 'reason'];

    /**
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'action_request_submissions';

    /**
     * @return HasMany
     */
    public function quizResults(): HasMany
    {
        return $this->hasMany(QuizResult::class,'submission_id');
    }

    /**
     * @return HasMany
     */
    public function surveyResults(): HasMany
    {
        return $this->hasMany(SurveyResult::class,'submission_id');
    }

    /**
     * @return HasMany
     */
    public function contentPhotoResults(): HasMany
    {
        return $this->hasMany(ContentPhotoResult::class,'submission_id');
    }

    /**
     * @return HasMany
     */
    public function contentFileResults(): HasMany
    {
        return $this->hasMany(ContentFileResult::class, 'submission_id');
    }

    /**
     * @return HasMany
     */
    public function idVerificationResults(): HasMany
    {
        return $this->hasMany(IDVerificationResult::class,'submission_id');
    }

    /**
     * @return HasMany
     */
    public function formResults() : HasMany
    {
        return $this->hasMany(FormResult::class,'submission_id');
    }

    /**
     * @return hasManyThrough
     */
    public function formDocuments() : hasManyThrough
    {
        return $this->hasManyThrough(
            FormDocument::class,FormResult::class,
            'submission_id');
    }

    /**
     * @return BelongsTo
     */ 
    public function actionRequest() : BelongsTo
    {
        return $this->belongsTo(ActionRequest::class);
    }

    /**
     * @return BelongsTo
     */
    public function user() : BelongsTo
    {
        return $this->belongsTo(User::class);
    }

    /**
     * @return bool
     */
    public function isPending()
    {
        return $this->status == SubmissionStatus::PENDING;
    }

    /**
     * @return bool
     */
    public function isCompleted()
    {
        return in_array($this->status, SubmissionStatus::COMPLETED_STATUS);
    }
}
