<?php

namespace App\Models\AlertMessage;

use App\Models\User\User;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use App\Enum\AlertMessage as AlertMessageEnum;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;

/**
 * Class AdminAlertMessage
 * @package App\Models\ActionRequest
 */
class AlertMessage extends Model
{
    protected $table = 'alert_messages';
    
    protected $fillable = ['message', 'display_on', 'expire_on', 'type', 'payload'];
    
    protected $dates = ['display_on', 'expire_on'];
    
    public function scopeManual($query)
    {
        return $query->where('type', AlertMessageEnum::MANUAL_TYPE);
    }

    /**
     * @return BelongsToMany
     */
    public function readUsers(): BelongsToMany
    {
        return $this->belongsToMany(User::class, 'alert_message_read_user');
    }

    /**
     * @return bool
     */
    public function isScheduled()
    {
        if (!empty($this->display_on) && $this->display_on->greaterThan(Carbon::now())) {
            return true;
        }
        
        return false;
    }

    /**
     * @return bool
     */
    public function isActive()
    {
        if (!empty($this->display_on) && !empty($this->expire_on) &&
            $this->display_on->lessThanOrEqualTo(Carbon::now()) &&
            $this->expire_on->greaterThanOrEqualTo(Carbon::now())) {
            return true;
        }

        return false;
    }

    /**
     * @return bool
     */
    public function isExpired()
    {
        if (!empty($this->expire_on) && $this->expire_on->lessThan(Carbon::now())) {
            return true;
        }

        return false;
    }

    /**
     * Get status
     * 
     * @return string|null
     */
    public function getStatusAttribute()
    {
        if ($this->isActive()) {
            return AlertMessageEnum::ACTIVE_STATUS;
        }
        
        if ($this->isScheduled()) {
            return AlertMessageEnum::SCHEDULED_STATUS;
        }
        
        if ($this->isExpired()) {
            return AlertMessageEnum::EXPIRED_STATUS;
        }
        
        return null;
    }
}
