<?php

namespace App\Models;

use App\Contracts\ClientProperty;
use App\Models\Client\Client;
use App\Models\User\User;
use App\Models\Attachment;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;

class Asset extends Model implements ClientProperty
{
    protected $table = 'assets';

    protected $with = ['attachment', 'creator'];

    protected $fillable = ['title', 'client_id', 'type', 'created_by'];

    /**
     * @return BelongsTo
     */
    public function client(): BelongsTo
    {
        return $this->belongsTo(Client::class);
    }

     /**
     * @return BelongsTo
     */
    public function attachment(): BelongsTo
    {
        return $this->belongsTo(Attachment::class);
    }

    /**
     * @return BelongsTo
     */
    public function creator()
    {
        return $this->belongsTo(User::class, 'created_by');
    }

    public function getClientId()
    {
        return $this->client_id;
    }
}
