<?php

namespace App\Models\Driver;

use App\Facades\Context;
use App\Models\Attachment;
use App\Models\Initiative\Initiative;
use Illuminate\Database\Eloquent\Model;
use App\Models\Questionnaire\Questionnaire;
use App\Enum\DriverStatus;

class Driver extends Model
{
    protected $table = 'drivers';

    protected $fillable = ['parent_id', 'name', 'description', 'weight', 'priority','icon', 'status'];

    public function scopeActive($query)
    {
        return  $query->where('status', DriverStatus::ACTIVE);
    }

    public function scopePrimary($query)
    {
        return $query->where('parent_id', 0);
    }

    public function subDrivers()
    {
        return $this->hasMany(Driver::class, 'parent_id', 'id');
    }

    public function subDriverInfo()
    {
        return $this->hasMany(Driver::class, 'parent_id', 'id')->with('questionnaire');
    }

    public function questionnaire()
    {
         return $this->hasOne(Questionnaire::class, 'driver_id', 'id');
    }

    public function initiative()
    {
        return $this->hasOne(Initiative::class, 'driver_id', 'id');
    }

    public function initiatives()
    {
        $client = Context::client()->get();
        return $this->hasMany(Initiative::class, 'driver_id', 'id')->where('client_id', $client->id);
    }
}
