<?php

namespace App\Models\Initiative;

use App\Contracts\ClientProperty;
use App\Models\Segment\Segment;
use Illuminate\Database\Eloquent\Model;
use App\Models\Client\Client;
use App\Models\Driver\Driver;
use App\Models\User\User;
use App\Enum\InitiativeEnum;

class Initiative extends Model implements ClientProperty
{
    protected $table = 'initiatives';

    protected $fillable = ['client_id', 'driver_id', 'responsible_id', 'title', 'description', 'due_by', 'created_by', 'status'];

    protected $dates = ['due_by'];

    public function client()
    {
        return $this->belongsTo(Client::class, 'client_id', 'id');
    }

    public function driver()
    {
        return $this->belongsTo(Driver::class, 'driver_id', 'id');
    }

    public function responsible()
    {
        return $this->belongsTo(User::class, 'responsible_id', 'id');
    }

    public function creator()
    {
        return $this->belongsTo(User::class, 'created_by', 'id');
    }

    public function segments()
    {
        return $this->belongsToMany(Segment::class, 'initiative_segment', 'initiative_id', 'segment_id');
    }

    public function scopeActive($query)
    {
        return $query->where('status', InitiativeEnum::COMPLETED);
    }

    public function getClientId()
    {
        return $this->client_id;
    }
}
