<?php

namespace App\Models\Journey;

use App\Enum\SubmissionStatus;
use App\Facades\Context;
use App\Models\ActionRequest\ActionRequest;
use App\Models\Asset;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\MorphOne;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

/**
 * Class JourneyStep
 * @package App\Models\Journey
 */
class JourneyStep extends Model
{
    protected $table = 'journey_steps';

    protected $fillable = [
        'name',
        'is_available_immediately',
        'available_days',
        'available_term',
        'header_image_id',
        'message',
        'step_order',
        'is_notify',
        'emails_notify',
        'step_is_optional',
        'type',
    ];

    protected $touches = ['journey'];

    /**
     * @return BelongsTo
     */
    public function journey(): BelongsTo
    {
        return $this->belongsTo(Journey::class);
    }

    /**
     * @return BelongsTo
     */
    public function headerImage(): BelongsTo
    {
        return $this->belongsTo(Asset::class);
    }

    /**
     * @return MorphOne
     */
    public function actionRequest(): MorphOne
    {
        return $this->morphOne(ActionRequest::class, 'actionable');
    }

    /**
     * Count employee has submitted for current step
     * 
     * @return mixed
     */
    public function countSubmittedEmployee()
    {
        return $this->actionRequest->submissions()
            ->select(DB::raw('count(DISTINCT user_id) as count'))
            ->first()
            ->count;
    }

    /**
     * Get is_completed status
     *
     * @return mixed
     */
    public function getIsCompletedAttribute()
    {
        return $this->actionRequest->submissions()
            ->select(DB::raw('count(DISTINCT user_id) as count'))
            ->where('user_id', Context::user()->get()->id)
            ->where('action_request_id', $this->actionRequest->id)
            ->whereIn('status', SubmissionStatus::COMPLETED_STATUS)
            ->first()
            ->count;
    }

    /**
     * @return bool
     */
    public function hasSubmission()
    {
        if ($this->actionRequest->submissions()->count() > 0) {
            return true;
        }

        return false;
    }
}