<?php

namespace App\Models\Library;

use App\Contracts\ClientProperty;
use App\Models\ActionRequest\ActionRequest;
use App\Models\Client\Client;
use App\Models\Link;
use App\Models\User\User;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\MorphMany;

/**
 * @property mixed id
 * @property mixed client_id
 */
class LibraryItem extends Model implements ClientProperty
{
    protected $table = 'library_items';

    protected $with = ['documentProfile', 'linkable', 'client', 'creator'];

    protected $fillable = ['name', 'client_id', 'document_profile_id', 'type', 'created_by', 'uid'];

    /**
     * @return BelongsTo
     */
    public function client(): BelongsTo
    {
        return $this->belongsTo(Client::class);
    }

    /**
     * @return BelongsTo
     */
    public function documentProfile(): BelongsTo
    {
        return $this->belongsTo(DocumentProfile::class, 'document_profile_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\MorphTo
     */
    public function linkable()
    {
        return $this->morphTo();
    }

    /**
     * @return BelongsTo
     */
    public function creator()
    {
        return $this->belongsTo(User::class, 'created_by');
    }

    /**
     * @return MorphMany
     */
    public function actionRequests() : MorphMany
    {
        return $this->morphMany(ActionRequest::class, 'contentable');
    }

    public function getClientId()
    {
        return $this->client_id;
    }

    /**
     * @param $query
     * @param $clientId
     * @return mixed
     */
    public function scopeOfClient($query, $clientId)
    {
        return $query->where('client_id', $clientId);
    }
}
