<?php

namespace App\Models\Message;

use App\Enum\ConversationTypes;
use App\Facades\Context;
use App\Models\Attachment;
use App\Models\User\User;
use GoldSpecDigital\LaravelEloquentUUID\Database\Eloquent\Uuid;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;

/**
 * Class Message
 * @package App\Models\Message
 */
class Message extends Model
{
    use Uuid;

    /**
     * @var bool
     */
    public $incrementing = false;
    /**
     * @var string
     */
    protected $keyType = 'string';
    /**
     * @var string[]
     */
    protected $with = ['sender'];

    /**
     * @var string
     */
    protected $dateFormat = 'Y-m-d H:i:s.u';

    /**
     * @var string[]
     */
    protected $touches = ['conversation'];
    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function sender()
    {
        return $this->belongsTo(User::class, 'sender_id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function conversation()
    {
        return $this->belongsTo(Conversation::class, 'conversation_id');
    }

    /**
     * Check userId have right to see message sender
     * @param $userId
     * @return bool
     */
    public function isDisplayUser($userId = -1)
    {
        if ($userId === -1) {
            $userId = Context::user()->get()->getKey();
        }
        return !($this->conversation->type === ConversationTypes::ANONYMOUS_MESSAGE) ||
            ($this->sender_id === $userId) ||
            ($this->conversation->users->filter(function($item){
                return $item->pivot->is_anonymous == false;
            })->pluck('id')->contains($this->sender_id));
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function attachment()
    {
        return $this->belongsTo(Attachment::class, 'attachment_id');
    }

    /**
     * @return HasMany
     */
    public function messageTranslations(): HasMany
    {
        return $this->hasMany(MessageTranslation::class);
    }
}
