<?php

namespace App\Models\Questionnaire;

use App\Facades\Context;
use App\Models\Attachment;
use Illuminate\Database\Eloquent\Model;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Models\Driver\Driver;
use App\Enum\QuestionnaireEnum;
use App\Models\Questionnaire\QuestionnaireOption;

/**
 * @method static active()
 */
class Questionnaire extends Model
{
    protected $table = 'questionnaires';

    protected $fillable = [
        'driver_id',
        'question',
        'status',
        'created_by',
        'is_question_value',
        'score_rating_type',
        'illustration_id'
    ];

    public function getQuestionAttribute($question)
    {
        $user = Context::user()->get();
        $client = !empty($user) ? $user->getClient() : null;

        if (!empty($client)) {
            if (strpos($question, QuestionnaireEnum::QUESTION_PREFIX) !== false) {
                $question = str_replace(QuestionnaireEnum::QUESTION_PREFIX, $client->name, $question);
            }
        }
        return $question;
    }

    public function scopeActive($query)
    {
        return $query->where('questionnaires.status', QuestionnaireEnum::ACTIVE);
    }

    public function answers()
    {
        return $this->hasMany(QuestionnaireAnswer::class, 'questionnaire_id', 'id');
    }

    public function answer($roundId, $userId, $clientValueId = null)
    {
        return $this->hasOne(QuestionnaireAnswer::class, 'questionnaire_id', 'id')->where([
            'round_id' => $roundId,
            'user_id' => $userId,
            'client_value_id' => $clientValueId,
        ]);
    }

    public function driver()
    {
        return $this->belongsTo(Driver::class, 'driver_id', 'id');
    }
    public function options()
    {
        return $this->hasMany(QuestionnaireOption::class, 'questionnaire_id', 'id');
    }

    public function illustration()
    {
        return $this->belongsTo(Attachment::class, 'illustration_id', 'id');
    }

    public function translate()
    {
        return $this->hasOne(QuestionnaireTranslate::class, 'questionnaire_id', 'id');
    }

    public function clientSetting()
    {
        $client = Context::client()->get();

        return $this->hasOne(QuestionnaireClientSetting::class, 'questionnaire_id', 'id')
            ->where('client_id', $client != null ? $client->getKey() : null);
    }

    public function scopeTranslateQuestion($query, $languageId)
    {
        return $query->with(['translate' => function($q) use ($languageId) {
            return $q->where('language_id', $languageId);
        }]);
    }

    public function scopeQuestionValue()
    {
        return $this->whereNull('driver_id');
    }
}
