<?php

namespace App\Models\Questionnaire;

use App\Enum\QuestionnaireEnum;
use App\Facades\Context;
use App\Models\Driver\Driver;
use App\Models\Questionnaire\Questionnaire;
use App\Models\Schedule\ScheduleSegments;
use Illuminate\Database\Eloquent\Model;

class QuestionnaireAnswerTopics extends Model
{
    protected $table = 'questionnaire_answers';

    protected $fillable = [
        'client_id','user_id', 'driver_id',
        'client_id', 'questionnaire_id', 'point',
        'comment', 'round_id', 'skip_question_id',
        'client_value_id', 'survey_id'
    ];

    public function scopeUser($query, $id)
    {
        return $query->where('user_id', $id);
    }

    public function scopeRound($query, $id)
    {
        return $query->where('round_id', $id);
    }

    public function scopeQuestionnaire($query, $id)
    {
        if (is_array($id)) {
            return $query->whereIn('questionnaire_id', $id);
        }
        return $query->where('questionnaire_id', $id);
    }

    public function filterDate($year, $month, $day)
    {
        if (!empty($day)) {
            $this->whereDay('created_at', $day);
        }
        if (!empty($month)) {
            $this->whereMonth('created_at', $month);
        }
        if (!empty($year)) {
            $this->whereYear('created_at', $year);
        }
        return $this;
    }

    public function question()
    {
        return $this->belongsTo(Questionnaire::class, 'questionnaire_id', 'id');
    }

    public function driver()
    {
        return $this->belongsTo(Driver::class, 'driver_id', 'id');
    }

    public function surveySegment()
    {
        return $this->belongsTo(ScheduleSegments::class, 'survey_id', 'schedule_survey_id');
    }

    public function scopeReport($query, $data)
    {
        $client = $data['client'];
        $questionValue = $data['questionValue'];
        $scoreType = !empty($data['scoreType']) ? $data['scoreType'] : '';

        $query = $query->where('questionnaire_answers.client_id', $client->id)
            ->where('questionnaire_answers.questionnaire_id', '!=', $questionValue->id);
        $query->whereNotNull('questionnaire_answers.comment');

        if (!empty($data['fromDate']) && !empty($data['toDate'])) {
            $fromDate = $data['fromDate'];
            $toDate = $data['toDate'];
            $query->where(function($q) use ($fromDate, $toDate) {
                return $q->whereDate('questionnaire_answers.created_at', '>=', $fromDate)
                    ->whereDate('questionnaire_answers.created_at', '<=', $toDate);
            });
        }

        if (!empty($scoreType)) {
            $minPoint = $scoreType == 'promoters'
                ? QuestionnaireEnum::PROMOTER['min']
                : ($scoreType == 'passives'
                    ? QuestionnaireEnum::PASSIVE['min']
                    : ($scoreType == 'detractors' ? QuestionnaireEnum::DETRACTOR['min'] : null));
            $maxPoint = $scoreType == 'promoters'
                ? QuestionnaireEnum::PROMOTER['max']
                : ($scoreType == 'passives'
                    ? QuestionnaireEnum::PASSIVE['max']
                    : ($scoreType == 'detractors' ? QuestionnaireEnum::DETRACTOR['max'] : null));
            if ($minPoint !== null && $maxPoint !== null) {
                $query = $query->where('questionnaire_answers.point', '>=', $minPoint)
                    ->where('questionnaire_answers.point', '<=', $maxPoint);
            }
        }
        return $query;
    }
}
