<?php

namespace App\Models\Quiz;

use App\Contracts\ClientProperty;
use App\Contracts\CreatorProperty;
use App\Models\ActionRequest\ActionRequest;
use App\Models\Client\Client;
use App\Traits\HasBusinessKey;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\MorphMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use App\Models\User\User;

class Quiz extends Model implements ClientProperty, CreatorProperty
{
    use HasBusinessKey, SoftDeletes;
    
    protected $table = 'quizzes';
    
    protected $fillable = ['client_id', 'name', 'created_by'];

    protected $dates = ['published_at'];

    /**
     * @return HasMany
     */
    public function questions(): HasMany
    {
        return $this->hasMany(QuizQuestion::class);
    }

    /**
     * @return BelongsTo
     */
    public function client() : BelongsTo
    {
        return $this->belongsTo(Client::class);
    }

    /**
     * @return MorphMany
     */
    public function actionRequests() : MorphMany
    {
        return $this->morphMany(ActionRequest::class, 'contentable');
    }

    public function creator()
    {
        return $this->belongsTo(User::class, 'created_by');
    }

    public function getCreatorId()
    {
        return $this->created_by;
    }

    public function getClientId()
    {
        return $this->client_id;
    }

    /**
     * @param $query
     * @param $clientId
     * @return mixed
     */
    public function scopeOfClient($query, $clientId)
    {
        return $query->where('client_id', $clientId);
    }
}
