<?php

namespace App\Models\Quiz;

use App\Models\Action\Action;
use App\Models\Action\ActionSequenceStep;
use App\Models\Journey\Journey;
use App\Models\Journey\JourneyStep;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Support\Facades\DB;

class QuizOption extends Model
{
    protected $table = 'quiz_options';

    protected $fillable = ['content', 'is_correct'];

    /**
     * @return BelongsTo
     */
    public function question(): BelongsTo
    {
        return $this->belongsTo(QuizQuestion::class, 'quiz_question_id');
    }

    public function results(): HasMany
    {
        return $this->hasMany(QuizResult::class, 'option_id', 'id');
    }

    public function resultsByUser($from = '', $to = '', $journeys = []) {
        $query = $this->results()
            ->join('action_request_submissions', 'action_request_submissions.id', 'quiz_results.submission_id')
            ->join('action_requests', 'action_requests.id', 'action_request_submissions.action_request_id')
            ->join('users', 'users.id', 'action_request_submissions.user_id')
            ->join('employees', 'employees.user_id', 'users.id');
        if (!empty($from)) {
            $query->whereDate('action_request_submissions.created_at', '>=', $from);
        }
        if (!empty($to)) {
            $query->whereDate('action_request_submissions.created_at', '<=', $to);
        }
        $query = $query->leftJoin('journey_steps', function ($join) {
            $join->on('journey_steps.id', '=', 'action_requests.actionable_id')
                ->where('action_requests.actionable_type', JourneyStep::class);
        })->leftJoin('journeys', 'journeys.id', 'journey_steps.journey_id');

        $query = $query->leftJoin('actions', function ($join) {
            $join->on('actions.id', '=', 'action_requests.actionable_id')
                ->where('action_requests.actionable_type', Action::class);
        });

        $query = $query->leftJoin('action_sequence_steps', function ($join) {
            $join->on('action_sequence_steps.id', '=', 'action_requests.actionable_id')
                ->where('action_requests.actionable_type', ActionSequenceStep::class);
        })->leftJoin('action_sequences', 'action_sequences.id', 'action_sequence_steps.action_sequence_id');
        if (!empty($journeys)) {
            $query->whereIn('journeys.code', $journeys);
        }
        return $query->select(DB::raw("users.first_name, users.surname, quiz_results.option_id, journeys.name as journey_name, action_sequences.name as action_sequence_name, 
        action_requests.actionable_type, action_requests.contentable_type, action_request_submissions.created_at"))
            ->orderBy('action_request_submissions.created_at');
    }

    public function reportCount($from = '', $to = '', $journeys = [])
    {
        $query = $this->results()
            ->join('action_request_submissions', 'action_request_submissions.id', 'quiz_results.submission_id')
            ->join('action_requests', 'action_requests.id', 'action_request_submissions.action_request_id');
        if (!empty($from)) {
            $query->whereDate('action_request_submissions.created_at', '>=', $from);
        }
        if (!empty($to)) {
            $query->whereDate('action_request_submissions.created_at', '<=', $to);
        }

        $query = $query->leftJoin('journey_steps', function ($join) {
            $join->on('journey_steps.id', '=', 'action_requests.actionable_id')
                ->where('action_requests.actionable_type', JourneyStep::class);
        })->leftJoin('journeys', 'journeys.id', 'journey_steps.journey_id');

        $query = $query->leftJoin('actions', function ($join) {
            $join->on('actions.id', '=', 'action_requests.actionable_id')
                ->where('action_requests.actionable_type', Action::class);
        });

        $query = $query->leftJoin('action_sequence_steps', function ($join) {
            $join->on('action_sequence_steps.id', '=', 'action_requests.actionable_id')
                ->where('action_requests.actionable_type', ActionSequenceStep::class);
        })->leftJoin('action_sequences', 'action_sequences.id', 'action_sequence_steps.action_sequence_id');

        if (!empty($journeys)) {
            $query->whereIn('journeys.code', $journeys);
        }
        return $query;
    }
}
