<?php

namespace App\Models\Quiz;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;

class QuizQuestion extends Model
{
    protected $table = 'quiz_questions';

    protected $fillable = ['title', 'order'];

    protected $touches = ['quiz'];

    /**
     * @return BelongsTo
     */
    public function quiz(): BelongsTo
    {
        return $this->belongsTo(Quiz::class);
    }

    /**
     * @return HasMany
     */
    public function options(): HasMany
    {
        return $this->hasMany(QuizOption::class);
    }

    /**
     * get correct option
     * 
     * @return Mixed|null
     */
    public function getCorrectOption()
    {
        foreach ($this->options as $option) {
            if ($option->is_correct) {
                return $option;
            }
        }

        return null;
    }

    /**
     * Ordered question
     * @param $query
     * @return mixed
     */
    public function scopeOrdered($query)
    {
        return $query->orderBy('order', 'asc');
    }
}
