<?php

namespace App\Models\Schedule;

use App\Models\Client\ClientValue;
use App\Models\Questionnaire\Questionnaire;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Models\Questionnaire\QuestionnaireAnswerValue;
use Illuminate\Database\Eloquent\Model;
use App\Models\Schedule\ScheduleFrequencyRound;

class ScheduleRoundQuestionnaire extends Model
{
    protected $table = 'schedule_round_questionnaires';

    protected $fillable = ['schedule_survey_id', 'questionnaire_id', 'user_id', 'status', 'client_value', 'created_at', 'updated_at'];

    public function getQuestionnaireIdAttribute($value)
    {
        return json_decode($value, true);
    }

    public function getClientValueAttribute($value)
    {
        return json_decode($value, true);
    }

    /**
     * 
     */
    public function frequencyRounds()
    {
        return $this->belongsTo(ScheduleFrequencyRound::class, 'frequency_round_id', 'id');
    }

    public function scopeActive($query, $active = 1)
    {
        return $query->where('status', $active);
    }

    public function scopeAnswer($query, $roundId, $userId)
    {
        return $query->with([
            'question',
            'questionValue',
            'answer' => function($q) use ($roundId, $userId){
                return $q->where(['round_id' => $roundId, 'user_id' => $userId]);
            }
        ]);
    }

    public function answer()
    {
        return $this->hasOne(QuestionnaireAnswer::class, 'questionnaire_id', 'questionnaire_id');
    }

    public function answerValue()
    {
        return $this->hasOne(QuestionnaireAnswerValue::class, 'questionnaire_id', 'questionnaire_id');
    }

    public function question()
    {
        return $this->belongsTo(Questionnaire::class, 'questionnaire_id', 'id');
    }

    public function questionValue()
    {
        return $this->belongsTo(ClientValue::class, 'client_value_id', 'id');
    }

    public function getFrequencyRoundInfo($surveyId, $userId)
    {
        $info = $this->where([
            'schedule_survey_id' => $surveyId,
            'user_id' => $userId
        ])->first();

        return $info;
    }
}
