<?php

namespace App\Models\Schedule;

use Illuminate\Database\Eloquent\Model;
use App\Models\Schedule\ScheduleSurvey;
use App\Models\Segment\SegmentUser;
use App\Models\Segment\Segment;
use App\Models\Questionnaire\QuestionnaireAnswer;
use Illuminate\Support\Facades\DB;
use App\Facades\Context;
use App\Enum\ScheduleEnum;
use App\Enum\ClientStatus;

class ScheduleSegments extends Model
{
    protected $table = 'schedule_survey_segments';

    protected $fillable = ['schedule_survey_id', 'send_to', 'exclude_id', 'status', 'created_at', 'updated_at'];

    /**
     * relationship for send to segments
     */
    public function scheduleSurvey()
    {
        return $this->belongsTo(ScheduleSurvey::class, 'schedule_survey_id');
    }

    public static function getUserBySegment($id){
        $segments = ScheduleSegments::where('schedule_survey_id', $id);
        $send_to = $segments->pluck('send_to')->toArray();
        $send_to = !empty($send_to) ? explode(",", $send_to[0]) : [];
        $exclude_id = $segments->pluck('exclude_id')->toArray();
        $exclude_id = !empty($exclude_id) ? explode(",", $exclude_id[0]) : [];

        $sendUsers = SegmentUser::whereIn('segment_id', $send_to)->distinct()->pluck('user_id');
        $excludeUsers = SegmentUser::whereIn('segment_id', $exclude_id)->distinct()->pluck('user_id');
        $users = array_diff($sendUsers->toArray(), $excludeUsers->toArray());
        return $users;
    }

    public static function getSegmentBySchedule($id){
        $segments = ScheduleSegments::where('schedule_survey_id', $id);
        $send_to = $segments->pluck('send_to')->toArray();
        $send_to = !empty($send_to) ? explode(",", $send_to[0]) : [];
        $exclude_id = $segments->pluck('exclude_id')->toArray();
        $exclude_id = !empty($exclude_id) ? explode(",", $exclude_id[0]) : [];

        $sendUsers = Segment::whereIn('id', $send_to)->distinct()->get();
        $excludeUsers = Segment::whereIn('id', $exclude_id)->distinct()->get();
        $segments = ["send_to" => $sendUsers->toArray(), "exclude" => $excludeUsers->toArray()];
        return $segments;
    }

    public static function getSegmentIdsBySchedule($id){
        $segments = ScheduleSegments::where('schedule_survey_id', $id);
        $send_to = $segments->pluck('send_to')->toArray();
        $send_to = !empty($send_to) ? explode(",", $send_to[0]) : [];
        $exclude_id = $segments->pluck('exclude_id')->toArray();
        $exclude_id = !empty($exclude_id) ? explode(",", $exclude_id[0]) : [];
        return ["send_to" => $send_to, "exclude" => $exclude_id];
    }

}
