<?php

namespace App\Models\Schedule;

use App\Enum\EmployeeStatus;
use App\Enum\ScheduleEnum;
use App\Facades\Context;
use App\Helpers\DebugHelper;
use App\Models\Questionnaire\Questionnaire;
use App\Models\Questionnaire\QuestionnaireAnswer;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\DB;

class ScheduleSurvey extends Model
{
    use SoftDeletes;

    protected $table = 'schedule_survey';

    protected $fillable = [
        'id', 'name', 'description', 'schedule_frequency_id', 'client_id', 'created_by', 'start_date', 'renewal_date',
        'status', 'created_at', 'updated_at'
    ];
    protected $dates = ['start_date', 'renewal_date'];

    /**
     * relationship for send to segments
     */
    public function scheduleSegments()
    {
        return $this->hasMany(ScheduleSegments::class, 'schedule_survey_id', 'id');
    }

    /**
     * relationship with rounds of frequency
     */
    public function frequencyRounds()
    {
        return $this->hasMany(ScheduleFrequencyRound::class, 'schedule_survey_id', 'id');
    }

    public function frequency()
    {
        return $this->belongsTo(ScheduleFrequency::class, 'schedule_frequency_id', 'id');
    }

    public function scopeActive($query)
    {
        return $query->where('status', ScheduleEnum::ACTIVE);
    }

    public function scopeClient($query, $id)
    {
        return $query->where('client_id', $id);
    }

    public function scopeGetPendingFrequencyRound($query)
    {
        return $query->with([
            'frequencyRounds' => function ($q) {
                $q = $q->where('status', ScheduleEnum::ACTIVE);
                $user = Context::user()->get();
                if (!config('app.demo') && !$user->is_demo) {
                    $now = Carbon::now();
                    $q = $q->whereDate('start_date', '<=', $now);
                }
                return $q;
            }
        ]);
    }


    public function getParticipateRate()
    {
        $client = Context::client()->get();
        $rounds = $this->frequencyRounds->pluck('id')->toArray();
        $result = QuestionnaireAnswer::query()
            ->select(DB::raw('count(questionnaire_answers.user_id) as `countResponse`'))
            ->join('employees', 'employees.user_id', 'questionnaire_answers.user_id')
            ->where('questionnaire_answers.client_id', $client->id)
            ->whereNull('questionnaire_answers.skip_question_id')
            ->where('employees.status', EmployeeStatus::ACTIVE)
            ->whereIn('questionnaire_answers.round_id', $rounds)
            ->groupBy('questionnaire_answers.user_id')
//            ->having('countResponse', '>=', $this->total_questionnaire)
            ->get();

        return $result->count();
    }

    /**
     * relationship with schedule round questionnaire
     */
    public function scheduleRoundQuestionnaire()
    {
        return $this->hasMany(ScheduleRoundQuestionnaire::class, 'schedule_survey_id', 'id');
    }
}
