<?php

namespace App\Models\Subscription;

use App\Enum\QualeeStatus;
use App\Models\Client\Client;
use App\Traits\HasBusinessKey;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class SubscriptionPlan extends Model
{
    use SoftDeletes, HasBusinessKey;

    /**
     * @var string
     */
    protected $table = 'plans';

    /**
     * @var string[]
     */
    protected $guarded = ['id'];


    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsToMany
     */
    public function planConfigurations()
    {
        return $this->belongsToMany(PlanConfiguration::class, 'plan_configuration_detail', 'plan_id', 'configuration_id')
            ->withPivot('value');
    }

    /**
     * @return HasMany
     */
    public function clients(): HasMany
    {
        return $this->hasMany(Client::class, 'plan_id');
    }

    /**
     * @param $query
     * @return mixed
     */
    public function scopePublic($query)
    {
        return $query->where('is_public', true);
    }
}

