<?php

namespace App\Models\Survey;

use App\Enum\QuestionTypes;
use Illuminate\Database\Eloquent\Model;
use App\Models\ActionRequest\ActionRequestSubmission;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;

class SurveyResult extends Model
{
    protected $fillable = ['submission_id', 'question_id'];

    /**
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'survey_results';

    /**
     * @return BelongsTo
     */
    public function actionRequestSubmissions(): BelongsTo
    {
        return $this->belongsTo(ActionRequestSubmission::class, 'submission_id');
    }

    /**
     * @return HasMany
     */
    public function surveyChoiceResults() : HasMany
    {
        return $this->hasMany(SurveyChoiceResult::class,'survey_result_id');
    }

    /**
     * @return HasOne
     */
    public function surveyRatingResult() : HasOne
    {
        return $this->hasOne(SurveyRatingResult::class,'survey_result_id');
    }

    /**
     * @return HasOne
     */
    public function surveyTextResult() : HasOne
    {
        return $this->hasOne(SurveyTextResult::class,'survey_result_id');
    }

    /**
     * @return BelongsTo
     */
    public function question() : BelongsTo
    {
        return $this->belongsTo(SurveyQuestion::class);
    }

    /**
     * Get corresponding survey answer
     * 
     * @return array
     */
    public function getAnswer()
    {
        $answer = [];
        switch ($this->question->type) {
            case QuestionTypes::TYPE_RATING:
                $answer[] = $this->surveyRatingResult->rating;
                break;
            case QuestionTypes::TYPE_TEXT:
                $answer[] = $this->surveyTextResult->text;
                break;
            case QuestionTypes::TYPE_MULTI:
                foreach ($this->surveyChoiceResults as $choiceResult) {
                    $answer[] = $choiceResult->option->content;
                }
                break;
        }
        
        return $answer;
    }
}
