<?php


namespace App\Models\User;


use App\Contracts\ClientProperty;
use App\Enum\EmployeeStatus;
use App\Models\Client\Client;
use App\Models\Library\DocumentProfile;
use App\Models\Library\LibraryItem;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use App\Models\Segment\Segment;

class Employee extends Model implements ClientProperty
{
    use SoftDeletes;

    protected $table = 'employees';

    protected $guarded = ['id'];

    protected $dates = ['start_date', 'end_date', 'date_of_birth'];

    /**
     * @return BelongsTo
     */
    public function client(): BelongsTo
    {
        return $this->belongsTo(Client::class, 'client_id');
    }

    /**
     * @return BelongsTo
     */
    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    /**
     * @return BelongsTo
     */
    public function manager(): BelongsTo
    {
        return $this->belongsTo(User::class, 'manager_id');
    }

      /**
     * @return BelongsTo
     */
    public function secondaryManager(): BelongsTo
    {
        return $this->belongsTo(User::class, 'secondary_manager_id');
    }

    /**
     * @return BelongsTo
     */
    public function location(): BelongsTo
    {
        return $this->belongsTo(Segment::class, 'location_id');
    }

    /**
     * @return BelongsTo
     */
    public function team(): BelongsTo
    {
        return $this->belongsTo(Segment::class, 'team_id');
    }

    /**
     * @return BelongsTo
     */
    public function department(): BelongsTo
    {
        return $this->belongsTo(Segment::class, 'department_id');
    }

    /**
     * @return BelongsTo
     */
    public function gender(): BelongsTo
    {
        return $this->belongsTo(Segment::class, 'gender_id');
    }

    /**
     * @return BelongsToMany
     */
    public function documentProfiles(): BelongsToMany
    {
        return $this->belongsToMany(DocumentProfile::class);
    }

    /**
     * @return array
     */
    public function getDocumentProfileIds(): array
    {
        return $this->documentProfiles->pluck('id')->toArray();
    }

    public function scopeActive($query)
    {
        return $query->where('status', EmployeeStatus::ACTIVE);
    }

    public function getClientId()
    {
        return $this->client_id;
    }

    /**
     * User's library items
     *
     * @return HasMany
     */
    public function libraryItems(): HasMany
    {
        return $this->hasMany(LibraryItem::class, 'client_id', 'client_id');
    }

    /**
     * @param $query
     * @param $clientId
     * @return mixed
     */
    public function scopeOfClient($query, $clientId)
    {
        return $query->where('client_id', $clientId);
    }
}