<?php

namespace App\Notifications;

use App\Helpers\UserHelper;
use App\Models\User\User;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Illuminate\Support\Facades\Auth;

class UserReportBug extends Notification implements ShouldQueue
{
    use Queueable;

    protected $request;
    protected $user;

    /**
     * Create a new notification instance.
     *
     * @param $request
     * @param $user
     */
    public function __construct($request, $user)
    {
        $this->request = $request;
        $this->user = $user;
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function via($notifiable)
    {
        return ['mail'];
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        $client = UserHelper::getClientByUserId($this->user->getKey());
        return (new MailMessage)
            ->line('Below is a bug reported from a user:')
            ->line('User: ' . $this->user->name)
            ->line('Email: ' . $this->user->email)
            ->line('Client: ' . $client->name)
            ->line('Device Name: ' . $this->request['device_name'])
            ->line('Device OS: ' . $this->request['device_os'])
            ->line('App_version: ' . $this->request['app_version'])
            ->line('User Text: ' . $this->request['user_text']);
    }

    /**
     * Get the array representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function toArray($notifiable)
    {
        return [
            //
        ];
    }
}
