<?php

namespace App\Providers;

use App\Events\CardChanged;
use App\Events\JourneyUpdated;
use App\Events\MessageCreated;
use App\Events\OCRDocumentUploaded;
use App\Events\PasswordUpdated;
use App\Events\QuestionnaireAnswerSubmitted;
use App\Events\RoleAccessUpdated;
use App\Events\SubmissionUpdated;
use App\Events\TwoFactorEnabled;
use App\Events\ActionSequenceUpdated;
use App\Events\UserAccessDenied;
use App\Events\UserAccessGranted;
use App\Listeners\BroadcastMessage;
use App\Listeners\CheckSensitiveComment;
use App\Listeners\CreateFormDocument;
use App\Listeners\CreateMessageNotifyType;
use App\Listeners\HandleMarkRequestAsCompleted;
use App\Listeners\LogDeniedUserAccess;
use App\Listeners\LogPasswordUpdated;
use App\Listeners\RemoveDeniedUserAccessLog;
use App\Listeners\RemoveDisabling2FAAlert;
use App\Listeners\RemoveExpiringCardAlert;
use App\Listeners\RemoveExpiringPasswordAlert;
use App\Listeners\RevokeUserToken;
use App\Listeners\SendPasswordUpdatedEmail;
use App\Listeners\CreateActionSequenceFormDocument;
use App\Listeners\SyncRoleAccess;
use App\Listeners\StartDocumentOCR;
use Illuminate\Auth\Events\PasswordReset;
use Illuminate\Auth\Events\Registered;
use Illuminate\Auth\Listeners\SendEmailVerificationNotification;
use Illuminate\Foundation\Support\Providers\EventServiceProvider as ServiceProvider;

class EventServiceProvider extends ServiceProvider
{
    /**
     * The event listener mappings for the application.
     *
     * @var array
     */
    protected $listen = [
        Registered::class => [
            SendEmailVerificationNotification::class,
        ],
        JourneyUpdated::class => [
            CreateFormDocument::class
        ],
        SubmissionUpdated::class => [
            HandleMarkRequestAsCompleted::class
        ],
        QuestionnaireAnswerSubmitted::class => [
            CheckSensitiveComment::class,
        ],
        MessageCreated::class => [
            BroadcastMessage::class,
            CreateMessageNotifyType::class,
        ],
        PasswordUpdated::class => [
            LogPasswordUpdated::class,
            RemoveExpiringPasswordAlert::class,
            SendPasswordUpdatedEmail::class
        ],
        PasswordReset::class => [
            LogPasswordUpdated::class,
            RemoveExpiringPasswordAlert::class
        ],
        TwoFactorEnabled::class => [
            RemoveDisabling2FAAlert::class
        ],
        CardChanged::class => [
            RemoveExpiringCardAlert::class
        ],
        ActionSequenceUpdated::class => [
            CreateActionSequenceFormDocument::class
        ],
        RoleAccessUpdated::class => [
            SyncRoleAccess::class
        ],
        UserAccessDenied::class => [
            LogDeniedUserAccess::class,
            RevokeUserToken::class
        ],
        UserAccessGranted::class => [
            RemoveDeniedUserAccessLog::class
        ],
        OCRDocumentUploaded::class => [
            StartDocumentOCR::class
        ]
    ];

    /**
     * Register any events for your application.
     *
     * @return void
     */
    public function boot()
    {
        parent::boot();

        //
    }
}
