<?php

namespace App\Rules;

use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use Illuminate\Contracts\Validation\Rule;
use Illuminate\Support\Facades\DB;

class ThrowableUniqueRule implements Rule
{
    protected $table;
    protected $column;
    protected $exceptId;
    protected $errorCode;

    /**
     * Create a new rule instance.
     *
     * @param string $errorCode
     * @param string $table
     * @param string $column
     * @param string $exceptId
     */
    public function __construct(string $errorCode, string $table, string $column, string $exceptId = null)
    {
        $this->errorCode = $errorCode;
        $this->table = $table;
        $this->column = $column;
        $this->exceptId = $exceptId;
    }

    /**
     * Determine if the validation rule passes.
     *
     * @param  string  $attribute
     * @param  mixed  $value
     * @return bool
     */
    public function passes($attribute, $value)
    {
        $query = DB::table($this->table)->where($this->column, $value);
        if (!empty($this->exceptId)) {
            $query->where('id', '<>', $this->exceptId);
        }
        
        if ($query->count() > 0) {
            throw new InvalidRequestException(
                "The $attribute has already been taken", $this->errorCode
            );
        }
        
        return true;
    }

    /**
     * Get the validation error message.
     *
     * @return string
     */
    public function message()
    {
        return __('validation.unique');
    }
}
