<?php


namespace App\Services\Action\ActionSequence;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\ModelHelper;
use App\Helpers\PermissionHelper;
use App\Models\Action\ActionSequence;
use App\Models\User\User;
use App\Services\ActionRequest\ClearActionRequestSubmission;
use App\Services\BaseService;

class CancelUserActionSequence extends BaseService implements Validatable, Performable
{
    public function getRules($args)
    {
        return [
            'code' => 'required',
            'employee_code' => 'required'
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Send user action sequence reminder
     * 
     * @param array $data
     * @return bool
     */
    public function performAction(array $data)
    {

        $actionSequence = ActionSequence::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($actionSequence);

        $userId = ModelHelper::convertBusinessKeyToId(User::class, $data['employee_code']);
        foreach ($actionSequence->steps as $step) {
            if (!empty($step->actionRequest)) {
                app(ClearActionRequestSubmission::class)->execute(
                    ['action_request' => $step->actionRequest, 'user_id' => $userId]
                );
            }
        }

        $actionSequence->users()->detach($userId);
        
        return true;
    }
}