<?php

namespace App\Services\Action\ActionSequence;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\AccessPermissions;
use App\Enum\Roles;
use App\Facades\Context;
use App\Jobs\SendNotificationConsole;
use App\Models\Action\ActionSequence;
use App\Models\User\User;
use App\Services\BaseService;
use App\Services\UserAccess\GetAccessByRole;

class CreateActionSequence extends BaseService implements Validatable, Performable
{

    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($data)
    {
        return [
            'name' => 'required|string|max:255'
        ];
    }


    /**
     * Create action sequence
     *
     * @param array $data
     * @return ActionSequence
     */
    public function performAction(array $data): ActionSequence
    {

        $clientId = Context::client()->get()->getKey();
        $data['client_id'] = $clientId;
        $data['created_by'] = Context::user()->get()->getKey();

        $result = ActionSequence::create($data);


        /*
        // Send Invite Notifications to employees
        $employeeAccess = app(GetAccessByRole::class)->execute(['role' => Roles::FRONT_USER]);
        $accessEmployeePermissions = $employeeAccess[AccessPermissions::ACCESS_GROUP_NOTIFICATIONS];

        $user = Context::user()->get();
        if ($accessEmployeePermissions[AccessPermissions::NOTIFICATION_CONSOLE_EMPLOYEE_ACTION]) {
            SendNotificationConsole::dispatch($user, $user, 'Action Sequence Created');
        }
        */

        return $result;
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }
}
