<?php

namespace App\Services\Action\ActionSequence;

use App\Contracts\Performable;
use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Models\Action\ActionSequence;
use App\Services\ActionRequest\ClearActionRequestSubmission;
use App\Services\BaseService;

class DeleteActionSequence extends BaseService implements Validatable, Transactionable, Performable
{
    
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required',
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }
    /**
     * Delete action sequence
     * 
     * @param array $data
     * @return bool
     */
    public function performAction(array $data)
    {
        $actionSequence = ActionSequence::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($actionSequence);

        foreach ($actionSequence->steps as $step) {
            if ($step->actionRequest) {
                app(ClearActionRequestSubmission::class)->execute(['action_request' => $step->actionRequest]);
            }
            $step->actionRequest()->delete();
            $step->delete();
        }

        $actionSequence->users()->detach();
        $actionSequence->forceDelete();

        return true;
    }
}
