<?php

namespace App\Services\Action\ActionSequence;

use App\Contracts\Validatable;
use App\Helpers\ModelHelper;
use App\Helpers\PermissionHelper;
use App\Models\Action\ActionSequence;
use App\Models\User\User;
use App\Services\ActionRequest\GetUserSubmission;
use App\Services\BaseService;

class GetEmployeeSubmission extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param $args
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required', 
            'employee_code' => 'required'
        ];
    }

    /**
     * Get employee submission
     *
     * @param array $args
     * @return array
     */
    public function performAction(array $args)
    {
        $actionSequence = ActionSequence::findByBusinessKey($args['code']);
        PermissionHelper::hasAccessOn($actionSequence);
        
        $userId = ModelHelper::convertBusinessKeyToId(User::class, $args['employee_code']);
        
        $stepSubmission = [];
        
        $actionSequenceSteps = $actionSequence->steps()->with('actionRequest')->get();
        foreach ($actionSequenceSteps as $step) {
            $stepSubmission[] = [
                'step' => $step,
                'submission' => app(GetUserSubmission::class)->execute($step->actionRequest, $userId)
            ];
        }
        
        return $stepSubmission;
    }
}
