<?php


namespace App\Services\Action\ActionSequence;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Jobs\SendNotification;
use App\Models\Action\ActionSequence;
use App\Models\User\User;
use App\Services\BaseService;
use Illuminate\Support\Facades\Auth;

class SendUserActionSequenceReminder extends BaseService implements Validatable, Performable
{
    public function getRules($args)
    {
        return [
            'code' => 'required',
            'employee_code' => 'required'
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Send user action sequence reminder
     * 
     * @param array $data
     * @return bool
     */
    public function performAction(array $data)
    {
        $actionSequence = ActionSequence::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($actionSequence);

        $user = User::findByBusinessKey($data['employee_code']);
        // Check user belong to action sequence
        if (!$actionSequence->users->contains($user->id)) {
            throw new InvalidRequestException(__("User does not belong to Action sequence"));
        }
        
        $arguments = array(
            'sender' => Auth::user()->id,
            "userIds" => $user->getBusinessKey(),
            "headings" => __("A action sequence is pending"),
            "contents" => __("You need to complete your :name action sequence", ["name" => $actionSequence->name]),
        );
        SendNotification::dispatch($arguments);
        
        return true;
    }
}