<?php

namespace App\Services\Action\ActionSequence;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\NotificationTypes;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Jobs\SendNotification;
use App\Models\Action\ActionSequence;
use App\Services\BaseService;
use Illuminate\Support\Facades\Auth;

class UpdateActionSequence extends BaseService implements Validatable, Performable
{
    
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required',
            'name' => 'required|string|max:255'
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Update action sequence
     * 
     * @param array $data
     * @return ActionSequence
     */
    public function performAction(array $data) : ActionSequence
    {

        $actionSequence = ActionSequence::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($actionSequence);
        
        $actionSequence->update($data);
        $userIds = $actionSequence->users->pluck('code')->toArray();
        if(!empty($userIds)){
            $arguments = array(
                'sender' => Auth::user()->id,
                "userIds" => $userIds,
                "headings" => __("An action has been updated"),
                "contents" => __("Tap to open action"),
                "data"=>[
                    "type" => NotificationTypes::ACTION_UPDATED,
                    "code" => $actionSequence->code,
                ],
                'send_after' => null
            );
            SendNotification::dispatch($arguments);
        }

        return $actionSequence->refresh();
    }
}
