<?php


namespace App\Services\Action;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\ModelHelper;
use App\Helpers\PermissionHelper;
use App\Models\Action\Action;
use App\Models\User\User;
use App\Services\ActionRequest\ClearActionRequestSubmission;
use App\Services\BaseService;

class CancelUserAction extends BaseService implements Validatable, Performable
{
    public function getRules($args)
    {
        return [
            'code' => 'required',
            'employee_code' => 'required'
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Send user action reminder
     * 
     * @param array $data
     * @return bool
     */
    public function performAction(array $data)
    {
        $action = Action::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($action);
        $userId = ModelHelper::convertBusinessKeyToId(User::class, $data['employee_code']);
        
        app(ClearActionRequestSubmission::class)->execute(
            ['action_request' => $action->actionRequest, 'user_id' => $userId]
        );

        $action->users()->detach($userId);
        app(DeleteActionIfNoUser::class)->execute(['action' => $action]);
        return true;
    }
}