<?php

namespace App\Services\Action;

use App\Contracts\Validatable;
use App\Helpers\ModelHelper;
use App\Helpers\PermissionHelper;
use App\Models\Action\Action;
use App\Models\User\User;
use App\Services\ActionRequest\GetUserSubmission;
use App\Services\BaseService;

class GetEmployeeActionSubmission extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required', 
            'employee_code' => 'required'
        ];
    }

    /**
     * Get employee action submission
     * 
     * @param array $args
     * @return mixed
     */
    public function performAction(array $args)
    {
        $action = Action::findByBusinessKey($args['code']);
        PermissionHelper::hasAccessOn($action);
        
        $userId = ModelHelper::convertBusinessKeyToId(User::class, $args['employee_code']);

        return app(GetUserSubmission::class)->execute($action->actionRequest, $userId);
    }
}
