<?php


namespace App\Services\Action;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\NotificationTypes;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\ActionRequestHelper;
use App\Helpers\PermissionHelper;
use App\Jobs\SendNotification;
use App\Models\Action\Action;
use App\Models\User\User;
use App\Services\BaseService;
use Illuminate\Support\Facades\Auth;

class SendUserActionReminder extends BaseService implements Validatable, Performable
{
    public function getRules($args)
    {
        return [
            'code' => 'required',
            'employee_code' => 'required'
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Send user action  reminder
     *
     * @param array $data
     * @return bool
     */
    public function performAction(array $data)
    {
        $action = Action::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($action);

        $user = User::findByBusinessKey($data['employee_code']);
        // Check user belong to action sequence
        if (!$action->users->contains($user->id)) {
            throw new InvalidRequestException(__("User does not belong to Action sequence"));
        }

        $arguments = array(
            'sender' => Auth::user()->id,
            "userIds" => $user->getBusinessKey(),
            "headings" => __("A new action is pending"),
            "contents" => __("Tap to open action"),
            "data"=>[
                "type" => NotificationTypes::ACTION_IS_PENDING,
                "code" => $action->code,
                'id' => $action->id,
                'action_type' => ActionRequestHelper::getActionTypeForNotification($action->actionRequest)
            ],
            'send_after' => null
        );
        SendNotification::dispatch($arguments);

        return true;
    }
}