<?php

namespace App\Services\ActionRequest;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Enum\SubmissionStatus;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Models\ActionRequest\ActionRequestSubmission;
use App\Services\BaseService;

class ApproveSubmission extends BaseService implements Validatable, Performable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'submission_id' => 'required|integer'
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     *  Approve submission
     * 
     * @param array $data
     * @return ActionRequestSubmission
     */
    public function performAction(array $data) : ActionRequestSubmission
    {
        $submission = ActionRequestSubmission::findOrFail($data['submission_id']);
        if (!$submission->isPending()) {
            throw new InvalidRequestException('Invalid request', ErrorCode::INVALID_REQUEST);
        }
        
        $actionRequest = $submission->actionRequest;
        app(CheckUserAuthorizedActionRequest::class)->execute(Context::user()->get(), $actionRequest);

        $submission->status = SubmissionStatus::APPROVED;
        $submission->save();
        
        return $submission;
    }
}
