<?php

namespace App\Services\ActionRequest;

use App\Enum\Roles;
use App\Exceptions\UnauthorizedHttpException;
use App\Models\Action\Action;
use App\Models\ActionRequest\ActionRequest;
use App\Models\User\User;
use App\Services\InternalBaseService;

class CheckUserAuthorizedActionRequest extends InternalBaseService
{

    /**
     * Check user authorized action request
     *
     * @param User $user
     * @param ActionRequest $actionRequest
     * @return void
     */
    public function execute(User $user, ActionRequest $actionRequest)
    {
        switch ($actionRequest->actionable_type) {
            case Action::class:
                $action = $actionRequest->actionable;
                if (!$user->hasRole(Roles::CLIENT_CONSOLE_ROLES) || !$action->approvers->contains($user->id)) {
                    throw new UnauthorizedHttpException();
                }
                break;
        }
    }
}
