<?php

namespace App\Services\ActionRequest;

use App\Enum\SubmissionStatus;
use App\Models\Action\Action;
use App\Models\Action\ActionSequenceStep;
use App\Models\ActionRequest\ActionRequest;
use App\Models\ActionRequest\ActionRequestSubmission;
use App\Models\Journey\JourneyStep;
use App\Models\User\User;
use App\Services\InternalBaseService;

class CheckUserCompletedRequest extends InternalBaseService
{

    /**
     * Check if user completed all requests of journey, action sequence, action
     * 
     * @param ActionRequest $actionRequest
     * @param User $user
     * @return bool
     */
    public function execute(ActionRequest $actionRequest, User $user)
    {

        $actionable = $actionRequest->actionable;
        $userId = $user->getKey();

        switch ($actionRequest->actionable_type) {
            case JourneyStep::class:
                $journey = $actionable->journey;
                $steps = $journey->steps()->with('actionRequest')->get();

                $actionRequestIds = [];
                foreach ($steps as $step) {
                    if (!empty($step->actionRequest)) {
                        $actionRequestIds[] = $step->actionRequest->getKey();
                    }
                }

                $completedSubmissionCount = $this->getCompletedSubmissionCount($actionRequestIds, $userId);
                break;

            case ActionSequenceStep::class:
                $actionSequence = $actionable->actionSequence;
                $steps = $actionSequence->steps()->with('actionRequest')->get();

                $actionRequestIds = [];
                foreach ($steps as $step) {
                    if (!empty($step->actionRequest)) {
                        $actionRequestIds[] = $step->actionRequest->getKey();
                    }
                }
                
                $completedSubmissionCount = $this->getCompletedSubmissionCount($actionRequestIds, $userId);
                break;
                
            case Action::class:
                $actionRequestIds = [];
                $actionRequestIds[] = $actionRequest->getKey();

                $completedSubmissionCount = $this->getCompletedSubmissionCount($actionRequestIds, $userId);
                break;
                
            default:
                return false;
        }

        return $completedSubmissionCount == count($actionRequestIds);
    }
    
    public function getCompletedSubmissionCount(array $actionRequestIds, $userId)
    {
        return ActionRequestSubmission::whereIn('action_request_id', $actionRequestIds)
            ->whereIn('status', SubmissionStatus::COMPLETED_STATUS)
            ->where('user_id', $userId)
            ->select('action_request_id')
            ->groupBy('action_request_id')
            ->get()
            ->count();
    }
}
