<?php

namespace App\Services\ActionRequest\Submission\Export;

use App\DataTransferObject\StreamedFile;
use App\Helpers\FileHelper;
use App\Helpers\PandaDocHelper;
use App\Helpers\ResourceLocationBuilder;
use App\Models\Client\Client;
use App\Services\InternalBaseService;
use Illuminate\Support\Facades\Storage;
use Illuminate\Database\Eloquent\Collection;
use Str;

class SaveFormDocument extends InternalBaseService
{
    const FORM_DOCUMENT_EXTENSION = '.pdf';

    /**
     * Download and save form document
     *
     * @param Collection $formResults
     * @param Client $client
     * @param string $folderName
     * @return void
     */
    public function execute(Collection $formResults, Client $client, string $folderName)
    {
        $formAuthenticate = $client->formAuthenticate;
        if ($formAuthenticate) {
            $pandaDocHelper = new PandaDocHelper();
            $pandaDocHelper->setToken($formAuthenticate->access_token);

            foreach ($formResults as $result) {
                $document = $result->document;
                $fileContent = $pandaDocHelper->downloadDocument($document->document_id);
                $fileName = $document->name . self::FORM_DOCUMENT_EXTENSION;

                $documentTemplate = $document->template;

                $file = new StreamedFile(
                    $fileContent,
                    $documentTemplate->name . '.pdf',
                    'pdf',
                    strlen($fileContent),
                    'application/pdf'
                );

                $path = FileHelper::storeFile($file, $folderName, $fileName);
                Storage::disk('local')->put($path, Storage::disk('s3')->get($path));
            }
        }
    }
}