<?php

namespace App\Services\ActionRequest\Submission\Export;

use App\Models\IDVerification\IDVerificationResult;
use App\Services\InternalBaseService;
use Illuminate\Contracts\Filesystem\FileNotFoundException;
use Illuminate\Support\Facades\Storage;

class SaveIDVerificationImage extends InternalBaseService
{

    /**
     * Approve submission
     *
     * @param IDVerificationResult $result
     * @param string $folderName
     * @param string $frontImageName
     * @param string $backImageName
     * @return void
     * @throws FileNotFoundException
     */
    public function execute(IDVerificationResult $result, string $folderName, string $frontImageName,
                            string $backImageName)
    {

        $frontAttachment = $result->frontAttachment;
        $frontImagePath = $folderName . '/' . $frontImageName;
        // Save front-image from S3 to local
        Storage::disk('local')->put($frontImagePath, Storage::disk('s3')->get($frontAttachment->path));

        $backAttachment = $result->backAttachment;
        if (!empty($backAttachment)) {
            $backImagePath = $folderName . '/' . $backImageName;
            // Save back-image from S3 to local
            Storage::disk('local')->put($backImagePath, Storage::disk('s3')->get($backAttachment->path));
        }
    }
}