<?php

namespace App\Services\ActionRequest\Submission\Export;

use App\Helpers\ObjectHelper;
use App\Models\Quiz\Quiz;
use App\Services\InternalBaseService;
use Illuminate\Database\Eloquent\Collection;

class SaveQuizResultCSV extends InternalBaseService
{
    const FILE_NAME = 'response.csv';
    // TODO Check if validation needed since all inputs taken from db.
//    /**
//     * Get the validation rules that apply to the service.
//     *
//     * @return array
//     */
//    public function getRules()
//    {
//        return [
//            'date' => 'required|date',
//            'client_name' => 'required|string',
//            'action_name' => 'required|string',
//            'employee_name' => 'required|string',
//            'employee_city' => 'nullable|string',
//            'employee_job_title' => 'nullable|string',
//        ];
//    }

    /**
     *  Approve submission
     *
     * @param Quiz $quiz
     * @param Collection $quizResults
     * @param array $data
     * @param array $header
     * @param string $filePath
     * @param string $fileName
     * @return void
     */
    public function execute(Quiz $quiz, Collection $quizResults, array $data, array $header, string $filePath,
                            string $fileName = self::FILE_NAME)
    {

        $file = fopen($filePath . '/'. $fileName, 'w');
        
        if (count($header) > 0) {
            fputcsv($file, array_merge($header, ['Question', 'Answer', 'Correct answer']));
        }
        
        foreach ($quiz->questions as $question) {
            $answer = null;

            foreach ($quizResults as $result) {
                if ($result->question_id == $question->id) {
                    $answer = $result->option->content;
                }
            }
            
            $rows = [
                'date' => ObjectHelper::nullOrValue($data, 'date'),
                'client_name' => ObjectHelper::nullOrValue($data, 'client_name'),
                'action_name' => ObjectHelper::nullOrValue($data, 'action_name'),
                'employee_name' => ObjectHelper::nullOrValue($data, 'employee_name'),
                'employee_city' => ObjectHelper::nullOrValue($data, 'employee_city'),
                'employee_job_title' => ObjectHelper::nullOrValue($data, 'employee_job_title'),
                'question' => $question->title,
                'answer' => $answer,
                'correct_answer' => !empty($question->getCorrectOption()) ?
                    $question->getCorrectOption()->content : null,
            ];

            fputcsv($file, $rows);
        }

        fclose($file);
    }
}
