<?php

namespace App\Services\ActionRequest\Submission\Export;

use App\Helpers\ObjectHelper;
use App\Models\Survey\Survey;
use App\Services\InternalBaseService;
use Illuminate\Database\Eloquent\Collection;

class SaveSurveyResultCSV extends InternalBaseService
{
    const FILE_NAME = 'response.csv';

    // TODO Check if validation needed since all inputs taken from db.
//    /**
//     * Get the validation rules that apply to the service.
//     *
//     * @return array
//     */
//    public function getRules()
//    {
//        return [
//            'date' => 'required|date',
//            'client_name' => 'required|string',
//            'action_name' => 'required|string',
//            'employee_name' => 'required|string',
//            'employee_city' => 'nullable|string',
//            'employee_job_title' => 'nullable|string',
//        ];
//    }

    /**
     *  Approve submission
     *
     * @param Survey $survey
     * @param Collection $surveyResults
     * @param array $data
     * @param array $header
     * @param string $filePath
     * @param string $fileName
     * @return void
     */
    public function execute(Survey $survey, Collection $surveyResults, array $data, array $header, string $filePath,
                            string $fileName = self::FILE_NAME)
    {

        $file = fopen($filePath . '/'. $fileName, 'w');
        fputcsv($file, array_merge($header, ['Question', 'Type', 'Answer']));

        foreach ($survey->surveyQuestions as $question) {
            $answer = [];

            foreach ($surveyResults as $result) {
                if ($result->question_id == $question->id) {
                    $answer = $result->getAnswer();
                }
            }

            $rows = [
                'date' => ObjectHelper::nullOrValue($data, 'date'),
                'client_name' => ObjectHelper::nullOrValue($data, 'client_name'),
                'action_name' => ObjectHelper::nullOrValue($data, 'action_name'),
                'employee_name' => ObjectHelper::nullOrValue($data, 'employee_name'),
                'employee_city' => ObjectHelper::nullOrValue($data, 'employee_city'),
                'employee_job_title' => ObjectHelper::nullOrValue($data, 'employee_job_title'),
                'question' => $question->title,
                'type' => $question->type,
            ];

            fputcsv($file, array_merge($rows, $answer));
        }

        fclose($file);
    }
}
