<?php

namespace App\Services\AlertMessage;

use App\Contracts\Validatable;
use App\Exceptions\InvalidRequestException;
use App\Models\AlertMessage\AlertMessage;
use App\Services\BaseService;
use App\Enum\AlertMessage as AlertMessageEnum;

class UpdateAlertMessage extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'id' => 'required',
            'message' => 'required|max:1023',
            'display_on' => 'required|date_utc',
            'expire_on' => 'required|date_utc|after:display_on',
        ];
    }

    /**
     * Update alert message
     * 
     * @param array $args
     * @return AlertMessage
     */
    public function performAction(array $args) : AlertMessage
    {
        $alertMessage = AlertMessage::findOrFail($args['id']);
        if ($alertMessage->type === AlertMessageEnum::AUTOMATIC_TYPE) {
            throw new InvalidRequestException();
        }
        $args['type'] = AlertMessageEnum::MANUAL_TYPE;
        $alertMessage->update($args);
        
        return $alertMessage;
    }
}
