<?php

namespace App\Services\AppRating;

use App\Helpers\CsvHelper;
use App\Helpers\DateHelper;
use App\Services\BaseService;
use App\Traits\Pageable;

class DownloadRating extends BaseService
{
    use Pageable;

    /**
     * Get rating
     * 
     * @param array $args
     * @return mixed
     */
    public function performAction(array $args)
    {
        $ratings = app(GetRating::class)->execute();

        $rows = [];
        foreach ($ratings as $rating) {
            $user = $rating->user;
            $rows[] = [
                'point' => str_repeat("* ", $rating->point),
                'comment' => $rating->comment,
                'user_name' => isset($user) ? $user->full_name : null,
                'platform' => $rating->platform,
                'location' => isset($user->employee->location) ? $user->employee->location->name : null,
                'date' => DateHelper::formatDateTime($rating->created_at),
            ];
        }

        $header = ['Star', 'Comment', 'User name', 'Platform', 'Location', 'Date'];
        
        $path = config('filesystems.disks.local.root');
        $fileName = 'ratings' . '_' . time() . '.csv';
        $filePath = $path . '/' . $fileName;
        
        CsvHelper::exportCsv($filePath, $rows, $header);
        
        return response()->download($filePath)->deleteFileAfterSend();
    }
}
