<?php


namespace App\Services\AppRating;

use App\Facades\Context;
use App\Helpers\FilterFluent;
use App\Models\AppRating\AppRating;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;
use Illuminate\Validation\ValidationException;
use App\Enum\SegmentTypes;
use App\Models\Segment\Segment;

class GetRatingByPoint extends BaseService
{

    /**
     * Get rating over time by platform
     * 
     * @param array $args
     * @return array
     * @throws ValidationException
     */
    public function performAction(array $args)
    {
        $LOCATION_SEGMENT_IDS = [];
        $DEPARTMENT_SEGMENT_IDS = [];
        $TEAM_SEGMENT_IDS = [];
        $MANAGER_SEGMENT_IDS = [];
        $GENDER_SEGMENT_IDS = [];
        $E_NPS_SEGMENT_IDS = [];

        $options = Context::request()->getOptions();
        $client = Context::client()->get();

        $query = AppRating::query();
        $query->select('point', DB::raw('COUNT(user_id) as total'));
        $query->groupBy('point');

        if (!empty($client)) {
            $query->where('client_id', $client->getKey());
        }

        if (isset($args['segments_filter']) && is_array($args['segments_filter'])) {
            $query->leftJoin('employees', 'employees.user_id', 'app_ratings.user_id');

            foreach ($args['segments_filter'] as $key => $segment) {
                $segmentItem = Segment::where('code', $segment['value'])->first();

                switch ($segmentItem['segment_type_id']) {
                    case SegmentTypes::LOCATION:
                        array_push($LOCATION_SEGMENT_IDS, $segmentItem['id']);
                        break;
                    case SegmentTypes::DEPARTMENT:
                        array_push($DEPARTMENT_SEGMENT_IDS, $segmentItem['id']);
                        break;
                    case SegmentTypes::TEAM:
                        array_push($TEAM_SEGMENT_IDS, $segmentItem['id']);
                        break;
                    case SegmentTypes::MANAGER:
                        array_push($MANAGER_SEGMENT_IDS, $segmentItem['id']);
                        break;
                    case SegmentTypes::GENDER:
                        array_push($GENDER_SEGMENT_IDS, $segmentItem['id']);
                        break;
                    case SegmentTypes::E_NPS_SERVEY:
                        array_push($E_NPS_SEGMENT_IDS, $segmentItem['id']);
                        break;

                    default:
                        break;
                }
            }

            switch (true) {
                case count($LOCATION_SEGMENT_IDS) > 0:
                    $query->whereIn('employees.location_id', $LOCATION_SEGMENT_IDS);
                    break;
                case count($DEPARTMENT_SEGMENT_IDS) > 0:
                    $query->whereIn('employees.department_id', $DEPARTMENT_SEGMENT_IDS);
                    break;
                case count($TEAM_SEGMENT_IDS) > 0:
                    $query->whereIn('employees.team_id', $TEAM_SEGMENT_IDS);
                    break;
                case count($MANAGER_SEGMENT_IDS) > 0:
                    $query->whereIn('employees.manager_id', $MANAGER_SEGMENT_IDS);
                    break;
                case count($GENDER_SEGMENT_IDS) > 0:
                    $query->whereIn('employees.gender_id', $GENDER_SEGMENT_IDS);
                    break;

                default:
                    break;
            }
        }

        FilterFluent::init()
            ->setQuery($query)
            ->setTable('app_ratings')
            ->setFilterOptions($options)
            ->setAllowedFilters(['platform'])
            ->validate()
            ->removeFilter('platform')
            ->setCustomFilter('platform', function ($query, $type, $col, $value) {
                FilterFluent::applyBasicFilter($query, $type, 'platform', $value);
            })->applyFilter();

        return $query->get();
    }
}