<?php


namespace App\Services\AppRating;

use App\Enum\Platforms;
use App\Facades\Context;
use App\Helpers\FilterFluent;
use App\Models\AppRating\AppRating;
use App\Services\BaseService;
use Illuminate\Support\Facades\DB;
use Illuminate\Validation\ValidationException;

class GetRatingOverTimeByPlatform extends BaseService
{

    /**
     * Get rating over time by platform
     * 
     * @param array $args
     * @return array
     * @throws ValidationException
     */
    public function performAction(array $args)
    {
        $options = Context::request()->getOptions();
        $client = Context::client()->get();

        $query = AppRating::query();
        $query->select(
            'platform',
            DB::raw('DATE(created_at) AS date'),
            DB::raw('AVG(point) as avg_point')
        );
        $query->groupBy('platform', 'date');

        if (!empty($client)) {
            $query->where('client_id', $client->getKey());
        }
        
        FilterFluent::init()
            ->setQuery($query)
            ->setTable('app_ratings')
            ->setFilterOptions($options)
            ->setAllowedFilters(['date', 'platform'])
            ->validate()
            ->removeFilter('date')
            ->removeFilter('platform')
            ->setCustomFilter('date', function ($query, $type, $col, $value) {
                FilterFluent::applyBasicFilter($query, $type, 'created_at', $value);
            })
            ->setCustomFilter('platform', function ($query, $type, $col, $value) {
                FilterFluent::applyBasicFilter($query, $type, 'platform', $value);
            })->applyFilter();

        $ratingOverTime = $query->get();

        $ratingOverTimeByPlatform = [];
        foreach (Platforms::ALL as $platform) {
            $ratingOverTimeByPlatform[$platform] = $ratingOverTime->filter(function ($item) use ($platform) {
                return $item->platform == $platform;
            })->toArray();
        }

        return $ratingOverTimeByPlatform;
    }
}
