<?php

namespace App\Services\Attachment;

use App\Helpers\FileHelper;
use App\Models\Attachment;
use App\Services\InternalBaseService;
use Illuminate\Http\UploadedFile;
use Str;
use App\DataTransferObject\StreamedFile;

class CreateAttachment extends InternalBaseService
{
    /**
     * Create a attachment
     *
     * @param StreamedFile|UploadedFile $file
     * @param string $path
     * @param int $uploadedBy
     * @return Attachment
     */
    public function execute($file, string $path, int $uploadedBy): Attachment
    {
        $attachment = $this->create($file, $path, $uploadedBy);
        return $attachment;
    }

    /**
     * Create the attachment
     * 
     * @param StreamedFile|UploadedFile $file
     * @param string $path
     * @param $uploadedBy
     * @return Attachment
     */
    private function create($file, string $path, $uploadedBy): Attachment
    {
        $fileName = Str::uuid() . '.' . $file->extension();

        $path = FileHelper::storeFile($file, $path, $fileName);
        $originalName = FileHelper::getOriginalName($file);

        $attachment = Attachment::create([
            'name' => $originalName,
            'path' => $path,
            'original_name' => $originalName,
            'size' => $file->getSize(),
            'mime_type' => $file->getMimeType(),
            'created_by' => $uploadedBy
        ]);

        return $attachment;
    }
}
