<?php

namespace App\Services\Attachment;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Services\BaseService;
use Symfony\Component\HttpFoundation\StreamedResponse;

class DownloadDocumentOCR extends BaseService implements Validatable, Performable
{

    public function getRules(array $args)
    {
        return [
            'attachment_id' => 'required'
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Download document OCR
     *
     * @param array $args
     * @return StreamedResponse
     */
    public function performAction(array $args)
    {
        $documentOCR = app(GetDocumentOCR::class)->execute(['attachment_id' => $args['attachment_id']]);

        $fileName = $documentOCR->attachment->original_name . '_OCR.txt';

        $headers = [
            'Content-Encoding: UTF-8',
            'Content-Type' => 'text/plain',
        ];

        return response()->streamDownload(function () use ($documentOCR) {
            $contents = '';
            foreach ($documentOCR->lines as $line) {
                $contents .= $line['text'] . PHP_EOL;
            }

            echo $contents;
        }, $fileName, $headers);
    }
}
