<?php

namespace App\Services\Attachment;

use App\Services\BaseService;
use Illuminate\Support\Facades\Storage;
use Carbon\Carbon;
use Symfony\Component\HttpFoundation\Response as SymfonyResponse;

class ResponseAttachment extends BaseService
{

    /**
     * Response with attachment.
     *
     * @param array $attachment
     */
    public function performAction(array $data)
    {
        $url = $data['url'];
        $fileExisted = Storage::disk('s3')->has($url);
        if ($fileExisted) {
            $time = Storage::disk('s3')->lastModified($url);

            $updatedAt = Carbon::createFromTimestamp($time);

            $headerEtag = md5($time);
            $headerExpires = $updatedAt->addMonth()->toRfc2822String();
            $headerLastModified = $updatedAt->toRfc2822String();

            $headers = [
                'Cache-Control' => 'max-age=0, must-revalidate',
                'Etag' => $headerEtag,
                'Expires' => $headerExpires,
                'Last-Modified' => $headerLastModified,
                'Pragma' => 'public',
            ];

            $server = request()->server;

            $requestModifiedSince =
            $server->has('HTTP_IF_MODIFIED_SINCE') &&
            $server->get('HTTP_IF_MODIFIED_SINCE') === $headerLastModified;

            $requestNoneMatch =
            $server->has('HTTP_IF_NONE_MATCH') &&
            $server->get('HTTP_IF_NONE_MATCH') === $headerEtag;

            if ($requestModifiedSince || $requestNoneMatch) {
                return response('', SymfonyResponse::HTTP_NOT_MODIFIED, $headers);
            }

            return Storage::disk('s3')->response($url, null, $headers);
        } else {
            return response('', 404);
        }
    }
}
