<?php

namespace App\Services\Attachment;

use App\DataTransferObject\StreamedFile;
use App\Helpers\FileHelper;
use App\Models\Attachment;
use App\Services\InternalBaseService;
use Illuminate\Http\UploadedFile;
use Illuminate\Support\Facades\Storage;
use Str;

class UpdateAttachment extends InternalBaseService
{
    /**
     * Update a attachment
     *
     * @param Attachment $attachment
     * @param StreamedFile|UploadedFile $file
     * @param string $path
     * @param int $uploadedBy
     * @return Attachment
     */
    public function execute(Attachment $attachment, $file, string $path, int $uploadedBy): Attachment
    {
        Storage::disk('s3')->delete($attachment->path);

        $fileName = Str::uuid() . '.' . $file->extension();

        $path = FileHelper::storeFile($file, $path, $fileName);
        $originalName = FileHelper::getOriginalName($file);

        $attachment->update([
            'name' => $originalName,
            'path' => $path,
            'original_name' => $originalName,
            'size' => $file->getSize(),
            'mime_type' => $file->getMimeType(),
            'created_by' => $uploadedBy
        ]);

        return $attachment;
    }
}
