<?php


namespace App\Services\Auth;


use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Enum\Roles;
use App\Exceptions\UnauthorizedHttpException;
use App\Guards\GuardNames;
use App\Helpers\CookieHelper;
use App\Services\BaseService;
use App\Traits\Guard;
use Illuminate\Support\Facades\Auth as Auth;

/**
 * Class SSOLogin
 * @package App\Services\Auth
 */
class SSOLogin extends BaseService implements Validatable
{
    use Guard;

    /**
     * @param  array  $args
     * @return string[]
     */
    public function getRules(array $args)
    {
        return [
            "user" => "required"
        ];
    }

    /**
     * @param  array  $args
     * @return array
     */
    public function performAction(array $args)
    {
        $user = $args['user'];
        Auth::login($user);
        $currentUser = Auth::user();
        if (!$currentUser->hasRole(Roles::CLIENT_CONSOLE_ROLES)) {
            throw new UnauthorizedHttpException(
                'User is not configured for sso',
                ErrorCode::USER_IS_NOT_ENABLE_SSO
            );
        }else{
            $this->guard([GuardNames::UserIsActive, GuardNames::ClientIsActive, GuardNames::UserEmailVerified],
                ['user' => $currentUser, 'client' => $currentUser->getClient()]);
        }

        app(UserLogin::class)->execute();
        $accessToken = $currentUser->createToken(config('auth.access_token_name'))->accessToken;
        $cookie = CookieHelper::generateJWTToken($accessToken);
        return ['user' => $currentUser, 'cookie' => $cookie];

    }
}