<?php


namespace App\Services\Auth;


use App\Contracts\Validatable;
use App\Enum\Roles;
use App\Guards\GuardNames;
use App\Services\BaseService;
use App\Services\Token\CheckMagicLinkTokenValid;
use App\Traits\Guard;
use Illuminate\Support\Facades\Auth as Auth;

class UserMagicLinkLogin extends BaseService implements Validatable
{
    use Guard;

    public function getRules(array $args)
    {
        return [
            "token" => "required|string"
        ];
    }

    public function performAction(array $args)
    {
        $magicToken = app(CheckMagicLinkTokenValid::class)->execute();

        $userDemo = $magicToken->user;
        Auth::login($userDemo);

        $currentUser = Auth::user();
        if ($currentUser->hasRole(Roles::CLIENT_CONSOLE_ROLES)) {
            $this->guard([GuardNames::UserIsActive, GuardNames::UserEmailVerified, GuardNames::ClientIsActive],
                ['user' => $currentUser, 'client' => $currentUser->getClient()]);
        }

        app(UserLogin::class)->execute();

        return $currentUser;

    }
}