<?php

namespace App\Services\Auth;

use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Helpers\ObjectHelper;
use App\Services\BaseService;
use Illuminate\Support\Facades\Http;

class VerifyReCaptcha extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'recaptcha_token' => 'required',
            'remote_ip' => 'nullable'
        ];
    }

    /**
     * @param array $args
     * @return bool
     */
    public function performAction(array $args)
    {
        $token = $args['recaptcha_token'];

        if ($token === config('recaptcha.bypass_token') || !config('recaptcha.enable_recaptcha')) {
            return true;
        }
        
        $params = [
            'secret' => config('recaptcha.secret_key'),
            'response' => $token,
            'remoteip' => ObjectHelper::nullOrValue($args, 'remote_ip')
        ];
        
        $response = Http::asForm()->post(config('recaptcha.url'), $params);
        
        $response = $response->object();
        
        if (!$response->success) {
            throw new InvalidRequestException('Invalid captcha', ErrorCode::INVALID_CAPTCHA);
        }

        return $response->success;
    }
}
