<?php


namespace App\Services\Client;


use App\Contracts\Validatable;
use App\Enum\ConversationTypes;
use App\Enum\QualeeStatus;
use App\Enum\Roles;
use App\Facades\Context;
use App\Models\Message\Conversation;
use App\Models\User\User;
use App\Services\BaseService;
use App\Services\Message\TransferWhistleblowerData;

class AssignWBConversationToAnotherAdmin extends BaseService implements Validatable
{
    /**
     * @param  array  $args
     * @return string[]
     */
    public function getRules(array $args)
    {
        return [
            'user' => 'required'
        ];
    }

    /**
     * Transfer conversation which user responsible to another admin
     * @param  array  $args
     */
    public function performAction(array $args)
    {
        $user = $args['user'];
        $currentClient = Context::client()->get();
        $conversations = Conversation::query()->where('type', ConversationTypes::ANONYMOUS_MESSAGE)
            ->whereHas(
                'users',
                function ($query) use ($user) {
                    $query->where('messageables.messageable_id', $user->id)
                        ->where('messageables.status', QualeeStatus::ACTIVE)
                        ->where('messageables.is_anonymous', 0);
                }
            )->get();
        $wbAdminCount = User::query()->active()->role(Roles::WHISTLEBLOWER_ADMIN)->whereHas(
            'employee',
            function ($query) use ($currentClient) {
                $query->where('client_id', $currentClient->getKey());
            }
        )->get();
        foreach ($conversations as $conversation) {
            $transferTo = $wbAdminCount->random();
            app(TransferWhistleblowerData::class)->execute(
                [
                    'id'            => $conversation->id,
                    'transfer_from' => $user->id,
                    'transfer_to'   => $transferTo->id,
                    'is_throw'      => false
                ]
            );
        }
    }
}