<?php


namespace App\Services\Client;

use App\Contracts\Validatable;
use App\Enum\ClientStatus;
use App\Models\Client\Client;
use App\Services\BaseService;
use App\Services\User\RevokeUserToken;


class ChangeClientStatus extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required|string|exists:clients,code',
            'status' => 'required|string',
        ];
    }

    /**
     * Suspend client
     *
     * @param array $data
     * @param string $status
     * @return Client
     */
    public function performAction(array $data): Client
    {
        $status = $data['status'];
        $client = Client::where('code', $data['code'])->firstOrFail();
        $client->status = $status;
        $client->save();

        // Prevent all admin and employee login if suspended
        if ($status == ClientStatus::SUSPENDED) {
            $users = $client->users()->with('tokens')->get();
            foreach ($users as $user) {
                app(RevokeUserToken::class)->execute($user);
            }
        }

        return $client->refresh();
    }
}
