<?php


namespace App\Services\Client;

use App\Contracts\Validatable;
use App\Contracts\Transactionable;
use App\Enum\AllowedFileSizes;
use App\Enum\AllowedFileTypes;
use App\Facades\Context;
use App\Helpers\ModelHelper;
use App\Helpers\ResourceLocationBuilder;
use App\Models\Client\Client;
use App\Models\Client\ClientConfiguration;
use App\Models\Phone;
use App\Models\Subscription\SubscriptionPlan;
use App\Services\Attachment\CreateAttachment;
use App\Services\BaseService;
use Carbon\Carbon;
use Illuminate\Support\Arr;
use App\Services\Client\Traits\CheckStripe;

class CreateClientDemo extends BaseService implements Validatable, Transactionable
{
    use CheckStripe;

    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'name' => 'required|string',
            'logo' => 'required|mimes:' . AllowedFileTypes::IMAGE . '|max:' . AllowedFileSizes::IMAGE_SIZE,
            'plan_id' => 'required',
            'industry_id' => 'required',
            'phone_number' => 'required|string',
            'phone_country' => 'required|string',
        ];
    }

    /**
     * Create Client
     *
     * @param array $args
     * @return Client
     */
    public function performAction(array $args): Client
    {

        $logoFile =  $args['logo'];
        $phone =  Phone::create(['country_code' => $args['phone_country'], 'phone_number' => $args['phone_number']]);
        $args = Arr::except($args, ['phone_number','phone_country']);
        $args['plan_id'] = ModelHelper::convertBusinessKeyToId(SubscriptionPlan::class, $args['plan_id']);
        $client = new Client($args);
        $client->phone()->associate($phone);
        $client->save();
        $client->refresh();

        $fileDir = (new ResourceLocationBuilder())->setClient($client->code)->getLogoPath();
        $user = Context::user()->get();
        $logo = app(CreateAttachment::class)->execute($logoFile, $fileDir, $user->id);
        $client->logo()->associate($logo);
        $client->save();

        $clientConfigurations = ClientConfiguration::all();

        foreach ($clientConfigurations as $clientConfiguration) {
            $client->clientConfigurations()->attach($clientConfiguration->getKey(), [
                'value' => $clientConfiguration->default_value,
                'applied_date' => Carbon::now()
            ]);
        }

        $client->refresh();

        return $client;
    }

}
