<?php


namespace App\Services\Client;

use App\Facades\Context;
use App\Helpers\FilterFluent;
use App\Models\Client\Client;
use App\Services\BaseService;
use App\Traits\Pageable;
use App\Traits\Sortable;
use Illuminate\Validation\ValidationException;

class GetClientWithAdmins extends BaseService
{
    use Sortable, Pageable;

    /**
     * Get list client with admins
     * 
     * @param array $args
     * @return mixed
     * @throws ValidationException
     */
    public function performAction(array $args)
    {
        $options = Context::request()->getOptions();
        
        $query = Client::query();

        FilterFluent::init()
        ->setQuery($query)
        ->setTable('clients')
        ->setFilterOptions($options)
        ->setAllowedFilters(['name', 'admin_name', 'admin_email'])
        ->validate()
        ->removeFilter('admin_name')
        ->removeFilter('admin_email')
        ->setCustomFilter('admin_name', function ($query, $type, $col, $value) {
            $query->whereHas('admins', function ($q) use ($type, $col, $value) {
                $q->whereHas('user', function ($uq) use ($type, $col, $value) {
                    FilterFluent::applyBasicFilter($uq, $type, 'first_name', $value, 'users');
                    $uq->orWhere(function ($subQuery) use ($type, $col, $value) {
                        FilterFluent::applyBasicFilter($subQuery, $type, 'surname', $value, 'users');
                    });
                });
            });
        })->setCustomFilter('admin_email', function ($query, $type, $col, $value) {
            $query->whereHas('admins', function ($q) use ($type, $col, $value) {
                $q->whereHas('user', function ($uq) use ($type, $col, $value) {
                    FilterFluent::applyBasicFilter($uq, $type, 'email', $value, 'users');
                });
            });
        })->applyFilter();

        $this->applySorting($options, $query);
        return $this->applyPaging($options, $query);
    }
}
