<?php


namespace App\Services\Client;

use App\Facades\Context;
use App\Helpers\FilterFluent;
use App\Helpers\SortFluent;
use App\Helpers\StripeHelper;
use App\Models\Client\Client;
use App\Services\BaseService;
use App\Traits\Pageable;
use App\Traits\Sortable;
use Illuminate\Validation\ValidationException;

class GetClientWithSubscriptions extends BaseService
{
    use Sortable, Pageable;


    /**
     * Get list client with Subscription
     * 
     * @param array $args
     * @return mixed
     * @throws ValidationException
     * @throws \Stripe\Exception\ApiErrorException
     */
    public function performAction(array $args)
    {
        $options = Context::request()->get()['options'];
        
        $stripeSubscriptions = collect((new StripeHelper())->getAllSubscriptions());
        
        $stripeCustomerId = $stripeSubscriptions->pluck('customer');
        
        $query = Client::query()->select("clients.*")
            ->whereNotNull('stripe_cus_id')
            ->where("stripe_cus_id", '!=', "")
            ->whereIn("stripe_cus_id", $stripeCustomerId)
            ->with('subscriptionPlan');
        FilterFluent::init()
            ->setQuery($query)
            ->setTable('clients')
            ->setFilterOptions($options)
            ->setAllowedFilters(['name'])
            ->validate()
            ->applyFilter();
        SortFluent::init()
            ->setQuery($query)
            ->setTable('clients')
            ->setSortOptions($options)
            ->setAllowedSorts(['name', 'plan', 'monthly_cost'])
            ->validate()
            ->removeSort(['plan', 'monthly_cost'])
            ->setCustomSort('plan', function($query, $col, $direction) {
                $query->leftJoin('plans as p1', 'clients.plan_id', '=', 'p1.id');
                SortFluent::applyBasicSort($query, 'p1.name', $direction);
            })
            ->setCustomSort('monthly_cost', function($query, $col, $direction) {
                $query->leftJoin('plans as p2', 'clients.plan_id', '=', 'p2.id');
                SortFluent::applyBasicSort($query, 'p2.cost', $direction);
            })
            ->applySort();

        $clients = $this->applyPaging($options, $query);
        $clients->map(function($item) use($stripeSubscriptions){
            $item->subscription = $stripeSubscriptions->where('customer', $item->stripe_cus_id)->first();
            return $item;
        });
        
        return $clients;
    }
}
