<?php


namespace App\Services\Client;


use App\Contracts\Validatable;
use App\Enum\EmployeeStatus;
use App\Enum\Roles;
use App\Facades\Context;
use App\Helpers\FilterFluent;
use App\Models\User\User;
use App\Models\UserAccess\ClientDeniedUserAccess;
use App\Services\BaseService;
use App\Traits\Pageable;
use Illuminate\Validation\Rule;
use Spatie\Permission\Models\Role;

/**
 * Class GetDeniedUserAccess
 * @package App\Services\Client
 */
class GetDeniedUserAccess extends BaseService implements Validatable
{
    use Pageable;


    public function getRules(array $args)
    {
        return [
            'role' => ['required', Rule::in(Roles::CLIENT_CONSOLE_ROLES)]
        ];
    }


    public function performAction(array $data)
    {
        $client = Context::client()->get();

        $query = User::query()
            ->active()
            ->join('client_denied_user_access', 'client_denied_user_access.user_id', '=', 'users.id')
            ->join('roles', 'roles.id', '=', 'client_denied_user_access.role_id')
            ->where('roles.name', $data['role'])
            ->where('client_denied_user_access.client_id', $client->getKey())
            ->with('avatar');

        $options = Context::request()->getOptions();

        return $this->applyPaging($options, $query);
    }
}