<?php


namespace App\Services\Client;


use App\Enum\EmployeeStatus;
use App\Enum\Roles;
use App\Helpers\DebugHelper;
use App\Helpers\FilterFluent;
use App\Models\User\User;
use App\Services\BaseService;
use App\Traits\Pageable;

/**
 * Class GetAdminCurrentCompany
 * @package App\Services\Client
 */
class GetUserCurrentCompany extends BaseService
{
    use Pageable;
    /**
     * @return mixed
     */
    public function performAction(array $options)
    {
        $typeOption = $options['type'];
        $company = $this->getCurrentCompany();
        // Overwrite
        $query = User::whereHas('employee', function($query) use ($company) {
            $query->where('client_id', $company->getKey());
            $query->where('status', EmployeeStatus::ACTIVE);
        })->with('employee');

        $types = explode("|", $typeOption);
        $query->where(function($subQuery) use ($types) {
            foreach ($types as $type) {
                switch ($type)
                {
                    case Roles::ADMIN:
                        $subQuery->orWhere(function($sub) {
                            $sub->role(Roles::ADMIN);
                        });
                        break;
                    case 'employee':
                        $subQuery->orWhere(function($sub) {
                            $sub->role(Roles::FRONT_USER);
                            $sub->has('roles', '=', 1);
                        });
                        break;
                    case 'journey_notification':
                        $subQuery->orWhere(function($sub) {
                            $sub->role(Roles::AVAILABLE_ROLES);
                        });
                        break;
                    case Roles::MANAGER:
                        $subQuery->orWhere(function($sub) {
                            $sub->role(Roles::MANAGER);
                        });
                        break;
                    case Roles::WHISTLEBLOWER_ADMIN:
                        $subQuery->orWhere(function($sub) {
                            $sub->role(Roles::WHISTLEBLOWER_ADMIN);
                        });
                        break;
                }
            }
        });

        FilterFluent::init()
            ->setQuery($query)
            ->setFilterOptions($options)
            ->setAllowedFilters(['name'])
            ->removeFilter('name')
            ->validate()
            ->setCustomFilter('name', function ($query, $type, $col, $value) {
                FilterFluent::applyCombinedColumnFilter($query, $type, 'surname','first_name', $value, 'users');
            })
            ->applyFilter();
        return $this->applyPaging($options, $query);
    }

    /**
     * @return mixed
     */
    public function getCurrentCompany()
    {
        return app(GetCompany::class)->execute();
    }
}