<?php


namespace App\Services\Client;


use App\Contracts\Validatable;
use App\Enum\Roles;
use App\Events\UserAccessDenied;
use App\Exceptions\UnauthorizedHttpException;
use App\Facades\Context;
use App\Models\User\User;
use App\Services\Action\ReassignApprover;
use App\Services\BaseService;

class RemoveAdminAccess extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'users' => 'array|required'
        ];
    }

    public function performAction(array $data)
    {
        $company = $this->getCurrentCompany();
        $users = array();
        foreach ($data['users'] as $userCode) {
            $user = User::findByBusinessKey($userCode);
            if($user->getKey() === Context::user()->get()->getKey())
                continue;
            if ($user->employee->client_id !== $company->getKey()) {
                throw new UnauthorizedHttpException();
            }
            app(ReassignApprover::class)->execute(['id'=>$user->getKey()]);
            $user->removeRole(Roles::ADMIN);
            $user->assignRole(Roles::FRONT_USER);

            event(new UserAccessDenied($user, Roles::ADMIN));

            $users[] = $user;
        }
        return $users;
    }


    /**
     * @return mixed
     */
    public function getCurrentCompany()
    {
        return app(GetCompany::class)->execute();
    }
}