<?php


namespace App\Services\Client;


use App\Contracts\Validatable;
use App\Enum\RoleEditablePermissions;
use App\Enum\Roles;
use App\Events\UserAccessDenied;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Helpers\UserAccessHelper;
use App\Models\User\User;
use App\Services\BaseService;

class RemoveManagerAccess extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'users' => 'array|required',
            'users.*' => 'required',
        ];
    }

    public function performAction(array $data)
    {
        $users = array();
        foreach ($data['users'] as $userCode) {
            $user = User::findByBusinessKey($userCode);
            if($user->getKey() === Context::user()->get()->getKey() || !$user->hasRole(Roles::MANAGER)) {
                continue;
            }
            PermissionHelper::hasAccessOn($user->employee);
            $user->removeRole(Roles::MANAGER);
            $user->assignRole(Roles::FRONT_USER);
            $user->revokePermissionTo(RoleEditablePermissions::MANAGER_PERMISSIONS);

            event(new UserAccessDenied($user, Roles::MANAGER));

            $users[] = $user;
        }

        return $users;
    }
}