<?php


namespace App\Services\Client;


use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Enum\RoleEditablePermissions;
use App\Enum\Roles;
use App\Events\UserAccessDenied;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Models\User\User;
use App\Services\BaseService;

class RemoveWhistleblowerAccess extends BaseService implements Validatable, Transactionable
{
    public function getRules(array $args)
    {
        return [
            'users'   => 'array|required',
            'users.*' => 'required',
        ];
    }

    public function performAction(array $data)
    {
        $users = array();
        $client = Context::client()->get();
        foreach ($data['users'] as $userCode) {
            $user = User::findByBusinessKey($userCode);
            $wbAdminCount = User::query()->active()->role(Roles::WHISTLEBLOWER_ADMIN)->whereHas(
                'employee',
                function ($query) use ($client) {
                    $query->where('client_id', $client->getKey());
                }
            )->count();
            if ($wbAdminCount <= 1) {
                throw new InvalidRequestException(
                    'Only have 1 whistleblower admin left',
                    ErrorCode::WHISTLEBLOWER_REMAIN
                );
            }
            if ($user->getKey() === Context::user()->get()->getKey() || !$user->hasRole(Roles::WHISTLEBLOWER_ADMIN)) {
                continue;
            }
            PermissionHelper::hasAccessOn($user->employee);
            $user->removeRole(Roles::WHISTLEBLOWER_ADMIN);
            $user->assignRole(Roles::FRONT_USER);
            $user->revokePermissionTo(RoleEditablePermissions::WHISTLEBLOWER_PERMISSIONS);

            app(AssignWBConversationToAnotherAdmin::class)->execute(['user'=>$user]);

            event(new UserAccessDenied($user, Roles::WHISTLEBLOWER_ADMIN));

            $users[] = $user;
        }
        return $users;
    }

}