<?php

namespace App\Services\Dashboard\Engagement;

use App\Services\BaseService;
use App\Models\User\User;
use Carbon\Carbon;
use App\Models\Questionnaire\Questionnaire;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Enum\QuestionnaireEnum;

class GetEngagement extends BaseService
{
    /**
     * TODO: combine with other member
     * Get list quiz
     *
     * @param array $options
     * @return mixed
     */
    public function performAction(array $options)
    {

        $eNPS = $this->eNPS($options);

        $result = [
            "eNPS" => [
                "total_response" => count($eNPS['employeesResponse']),
                "total_employees" => count($eNPS['employees']),
                "promoters" => count($eNPS['promoters']),
                "passives" => count($eNPS['passives']),
                "detractors" => count($eNPS['detractors']),
                "answer" => $eNPS['totalAnwsers']
            ]
        ];

        return $result;
    }

    public function eNPS($options=[])
    {
        $questionnaires = Questionnaire::active()->get()->toArray();
        $answers = QuestionnaireAnswer::questionnaire($questionnaires);

        if (!empty($options['date'])) {
            $filterDate = Carbon::createFromFormat('Y-m', $options['date']);
            $answers->filterDate($filterDate->format('Y'), $filterDate->format('m'));
        }
        $answers = $answers->get();

        $promoters = $this->eNPSfilterPointRange($answers, QuestionnaireEnum::PROMOTER['min'], QuestionnaireEnum::PROMOTER['max']);
        $passives = $this->eNPSfilterPointRange($answers, QuestionnaireEnum::PASSIVE['min'], QuestionnaireEnum::PASSIVE['max']);
        $detractors = $this->eNPSfilterPointRange($answers, QuestionnaireEnum::DETRACTOR['min'], QuestionnaireEnum::DETRACTOR['max']);

        $employeesResponse = $answers->unique('user_id');
        $employees = User::active()->get();

        $totalAnwsers = count($promoters) + count($passives) + count($detractors);

        return [
            'employeesResponse' => $employeesResponse,
            'employees' => $employees,
            'promoters' => $promoters,
            'passives' => $passives,
            'detractors' => $detractors,
            'totalAnwsers' => $totalAnwsers
        ];
    }

    public function eNPSfilterPointRange($model, $min, $max)
    {
        return $model->filter(function ($model, $key) use($min, $max) {
            return $model->point >= $min && $model->point <= $max;
        });
    }
}
