<?php
namespace App\Services\Driver;

use App\Contracts\Transactionable;
use App\Models\Driver\Driver;
use App\Models\Schedule\ScheduleSurvey;
use App\Models\Questionnaire\Questionnaire;
use App\Services\BaseService;
use App\Traits\Pageable;
use App\Traits\Sortable;
use App\Facades\Context;
use App\Helpers\ModelHelper;
use App\Models\Client\ClientValue;

class GetDriverByScheduleId extends BaseService implements Transactionable
{
    use Sortable, Pageable;


    /**
     * Get list driver
     *
     * @param array $data
     * @return mixed
     */
    public function performAction(array $data)
    {
        $options = Context::request()->getOptions();

        $clientValueQuery = ClientValue::select('id', 'name', 'description')
        ->selectRaw('0 as parent_id')
        ->selectRaw('name as icon')
        ->selectRaw('0 as weight')
        ->selectRaw('0 as priority');
        ModelHelper::setConditionFindByClient($clientValueQuery);

        $questionIds = [];
        $client = Context::client()->get();
        $query = ScheduleSurvey::query();
        $query->find($data['id']);
        $query->where('client_id', $client->id);
        $query->leftJoin('schedule_round_questionnaires as s', 's.schedule_survey_id', 'schedule_survey.id');
        $schedules = $query->first();

        $questionnaireId = json_decode($schedules->questionnaire_id);

        foreach ($questionnaireId as $key => $question) {
            $questionIds = array_merge($questionIds, $question);
        }

        $questionIds = array_unique($questionIds);

        $driverIds = Questionnaire::select('driver_id')
        ->whereIn('id', $questionIds)
        ->get()->toArray();
        
        $query = Driver::select('id', 'name', 'description', 'parent_id', 'icon', 'weight', 'priority')
        ->whereIn('id', $driverIds)
        ->active()->primary()
        ->union($clientValueQuery);

        return $this->applyPaging($options, $query);
    }
}
