<?php


namespace App\Services\Employee;

use App\Contracts\Validatable;
use App\Helpers\PermissionHelper;
use App\Models\User\User;
use App\Services\BaseService;
use Str;
use Storage;
use Spatie\Activitylog\Models\Activity;

class DownloadActivity extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'code' => 'required|string',
        ];
    }

    /**
     * Download employee's activities
     * 
     * @param array $data
     * @return string
     */
    public function performAction(array $data)
    {
        $user = User::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($user->employee);

        $activities = Activity::where('causer_id', $user->id)->get();
        
        // TODO Make it common
        $folderName = Str::uuid();
        Storage::disk('local')->makeDirectory($folderName);
        $folderPath = config('filesystems.disks.local.root') . '/' . $folderName;
        $fileName = $folderPath . '/activities.csv';
        $file = fopen($fileName, 'w');
        $columns = ['date', 'action'];
        fputcsv($file, $columns);
        foreach ($activities as $activity) {
            $row = [$activity->created_at, $activity->description];
            fputcsv($file, $row);
        }
        fclose($file);
        return $fileName;
    }
}
