<?php

namespace App\Services\Employee;

use Carbon\Carbon;
use App\Services\BaseService;
use Symfony\Component\HttpFoundation\StreamedResponse;
use League\Csv\Writer;

class DownloadEmployees extends BaseService
{
    private $employee;
    private $client;

    public function performAction(array $param)
    {
        $employees = $param['employees'];

        $now = Carbon::now()->format('Y-m-d');
        $fileName = 'employee-report' . '_' . $now . '.csv';

        $response = new StreamedResponse(function () use ($employees) {
            $output = fopen('php://output', 'w');
            $csv = Writer::createFromStream($output);

            $topHeader = ['First name', 'Surname', 'Email', 'Location', 'Team', 'Department', 'Gender', 'Status'];
            $csv->insertOne($topHeader);

            foreach ($employees as $employee) {
                $rowData = [
                    $employee->first_name,
                    $employee->surname,
                    $employee->email,
                    isset($employee->employee->location) ? $employee->employee->location->name : null,
                    isset($employee->employee->team) ? $employee->employee->team->name : null,
                    isset($employee->employee->department) ? $employee->employee->department->name : null,
                    isset($employee->employee->gender) ? $employee->employee->gender->name : null,
                    $employee->employee->status,
                ];
                $csv->insertOne($rowData);
                $rows[] = $rowData;
            }

            fclose($output);
        });

        $response->headers->set('Content-Disposition', 'attachment; filename="' . $fileName . '"');
        $response->headers->set('Content-Type', 'text/csv');

        return $response;
    }
}