<?php


namespace App\Services\Employee;

use App\Contracts\Transactionable;
use App\Jobs\SendSaveCsvRequest;
use App\Services\BaseService;
use App\Http\Resources\Library\DocumentProfile;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\DB;

/**
 * Class GeneratePasswordsCsv
 * @package App\Services\Employee
 */
class GeneratePasswordsCsv extends BaseService implements Transactionable
{

    private function generateCSV($users = [])
    {
        $header = ['First Name', 'Surname', 'Email', 'Date Of Birth', 'Department', 'Location', 'National ID', 'Employee ID', 'Job Title', 'Start Date', 'Manager', 'Content Profile/s', 'Password'];
        $passwords = [];

        foreach ($users as $user) {
            if ($user->last_login) {
                continue;
            }
            $password = Str::random(8);
            $passwords[$user->id] = $password;
        }
        $userIds = array_keys($passwords);
        if (count($userIds) > 0) {
            $cases = [];
            foreach ($passwords as $userId => $password) {
                $passwordHash = Hash::make($password);
                $cases[] = "WHEN {$userId} THEN '{$passwordHash}'";
            }
            $cases = implode(' ', $cases);
            $sql = "UPDATE users SET password = CASE id {$cases} END WHERE id IN (".implode(',', $userIds).")";
            DB::update(DB::raw($sql));
        }

        $rows = [];
        foreach ($users as $user) {
            $password = isset($passwords[$user->id]) ? $passwords[$user->id] : '';
            $department = $user->employee->department ? $user->employee->department->name : '';
            $location = $user->employee->location ? $user->employee->location->name : '';
            $manager = $user->employee->manager ? $user->employee->manager->email : '';
            $documentProfiles = '';
            if ($user->employee->documentProfiles) {
                $documentProfiles = join(', ', array_map(function ($documentProfile) { return $documentProfile['name']; }, DocumentProfile::collection($user->employee->documentProfiles)->jsonSerialize()));
            }
            $row = [$user->first_name, $user->surname, $user->email, date('y-n-j', strtotime($user->employee->date_of_birth)), $department, $location, $user->employee->social_security_number ?? ""
                , $user->employee->employee_client_id ?? "", $user->employee->job_title ?? "", date('y-n-j', strtotime($user->employee->start_date)), $manager, $documentProfiles, $password];
            $rows[] = $row;
        }
        $fileId = uniqid();
        SendSaveCsvRequest::dispatch($fileId, $rows, $header);

        return url(config('app.back_end_url') . '/api/download-csv/' . $fileId);
    }

    /**
     * @param array $args
     * @return bool
     */
    public function performAction(array $args)
    {
        ini_set('max_execution_time', 1800);
        return $this->generateCSV($args['users']);
    }
}
