<?php

namespace App\Services\Employee;

use App\Contracts\Validatable;
use App\Enum\SubmissionStatus;
use App\Facades\Context;
use App\Models\ActionRequest\ActionRequestSubmission;
use App\Models\Journey\Journey;
use App\Models\Journey\JourneyUser;
use App\Services\BaseService;
use App\Traits\Pageable;
use Illuminate\Validation\ValidationException;
use App\Models\User\User;
use App\Helpers\ModelHelper;
use App\Helpers\UserAccessHelper;
use App\Services\Tool\Journey\GetJourneyEmployees;

class GetEmployeeJourneys extends BaseService implements Validatable
{
    use Pageable;

    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'code' => 'required',
        ];
    }



    /**
     * Get journey employees
     * 
     * @param array $data
     * @return mixed
     * @throws ValidationException
     */
    public function performAction(array $data)
    {   
        $options = Context::request()->getOptions();
        $user = Context::user()->get();
        $employeeUser = User::findByBusinessKey($data['code']);
        
        $query = Journey::query()->with(['steps.actionRequest', 'users', 'creator.avatar'])
        ->leftJoin('journey_user', 'journey_user.journey_id', 'journeys.id')
        ->where('journey_user.user_id', $employeeUser->id);

        if (UserAccessHelper::isManager($user)) {
            $query->where('created_by', $user->getKey())
                ->orWhereIntegerInRaw('id', $this->getManagerJourneyIds($user));
        }

        ModelHelper::setConditionFindByClient($query);
        
        $journeys = $this->applyPaging($options, $query);

        foreach ($journeys as $journey) {
            $employees = app(GetJourneyEmployees::class)->execute(['code' => $journey->code]);
            $employee = $employees->filter(function($item) use($journey) {
                if ($item->id === $journey->user_id) {
                    return $item;
                }
            })->first();
            $journey->employee = !empty($employee) ? $employee : null;
        }
        return $journeys;
    }

    public function getCompletedSubmissionCount(array $actionRequestIds, $userId)
    {
        return ActionRequestSubmission::whereIn('action_request_id', $actionRequestIds)
            ->whereIn('status', SubmissionStatus::COMPLETED_STATUS)
            ->where('user_id', $userId)
            ->select('action_request_id')
            ->groupBy('action_request_id')
            ->get()
            ->count();
    }

    public function getManagerJourneyIds(User $manager): array
    {
        $staffUsers = UserAccessHelper::getManagerStaffUsers($manager);
        $journeyIds = JourneyUser::whereIntegerInRaw('user_id', $staffUsers->pluck('id')->toArray())
            ->pluck('journey_id')->toArray();

        return array_unique($journeyIds);
    }
}
 