<?php

namespace App\Services\Employee;

use App\Facades\Context;
use App\Services\BaseService;
use Illuminate\Support\Facades\Cache;

class ImportEmployee extends BaseService
{
    public function performAction($args)
    {
        ini_set('max_execution_time', 900);
        $import = new EmployeeImport();
        $id = now()->unix();
        $headers = [
            'Access-Control-Allow-Origin' => config('app.front_end_url'),
            'Access-Control-Allow-Credentials' => 'true'
        ];
        response()->json(["data" => [
            'id' => $id,
            'totalRow'   => 0,
            'successRow' => 0,
            'failedRow'  => 0,
            'skipRow' => 0,
            'failedLogs' => [],
            'skipErrors' => [],
        ]], 200, $headers)->send();
        $import->importWithClientId(Context::client()->get()->id, $args['file'], null, null, $id);

        $failureRes = $this->transformFailure($import->failures());

        return [
            'totalRow'   => $import->getRowCount(),
            'successRow' => $import->getSuccessCount(),
            'skipRow' => $import->getSkipCount(),
            'failedRow'  => count($failureRes),
            'skipErrors' => [],
            'failedLogs' => $failureRes,

        ];
    }

    public function getImportStatus($code)
    {
        $clientId = Context::client()->get()->id;
        $key = "import_" . $clientId . "_" . $code;
        $failures = Cache::get($key . "_failures");
        $failureRes = $this->transformFailure($failures);
        return [
            'totalRow'   => Cache::get($key . "_total") ?? 0,
            'successRow' => Cache::get($key . "_success") ?? 0,
            'skipRow' => Cache::get($key . "_skip") ?? 0,
            'skipErrors' => Cache::get($key . "_skipErrors") ?? [],
            'failedRow'  => count($failureRes),
            'failedLogs' => $failureRes,
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    private function transformFailure($failures): array
    {
        $items = collect($failures);
        $byRowKeys = $items->mapToGroups(function ($item) {
            return [$item->row() => $this->transformFailureEntry($item)];
        })->all();

        ksort($byRowKeys);

        return $this->convertToObject($byRowKeys);
    }

    private function transformFailureEntry($attr): array
    {
        return [
            'field'     => $attr->attribute(),
            'fieldName' => ucwords(str_replace('-', ' ', $attr->attribute())),
            'errorCode' => $attr->errors(),
        ];
    }

    private function convertToObject($byRowKeys): array
    {
        $res = [];
        foreach ($byRowKeys as $key => $value) {
            $res[] = [
                'rowNum' => $key,
                'fields' => $value
            ];
        }
        return $res;
    }
}
