<?php


namespace App\Services\Employee;


use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Enum\Roles;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Jobs\SendNewFrontUserEmail;
use App\Jobs\SendVerifyEmail;
use App\Models\User\User;
use App\Services\BaseService;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

/**
 * Class ResendVerifyEmail
 * @package App\Services\Employee
 */
class ResendVerifyEmail extends BaseService implements Validatable, Performable
{
    public function canPerform(): bool
    {
        return Context::client()->check() && !Context::client()->get()->is_demo;
    }

    /**
     * @param array $args
     * @return string[]
     */
    public function getRules(array $args)
    {
        return [
            'code' => 'required'
        ];
    }

    /**
     * @param array $args
     * @return bool
     */
    public function performAction(array $args)
    {
        $user = User::findByBusinessKey($args['code']);
        if ($user->hasRole(Roles::CLIENT_CONSOLE_ROLES)) {
            if ($user->hasVerifiedEmail()) {
                if (isset($args['is_multiple']) && $args['is_multiple']) {
                    return false;
                }
                throw new InvalidRequestException('Your email address has already been verified.', ErrorCode::EMAIL_ALREADY_VERIFIED);
            }
            SendVerifyEmail::dispatch($user);
        } else if ($user->hasRole(Roles::FRONT_USER)) {
            if ($user->last_login) {
                return false;
            }
            $password = Str::random(8);
            $user->password = Hash::make($password);
            $user->save();
            SendNewFrontUserEmail::dispatch($user, $password, true);
        }
        return true;
    }
}