<?php


namespace App\Services\Employee;


use App\DataTransferObject\StreamedFile;
use App\Enum\ErrorCode;
use App\Enum\ImageDimensions;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\ImageHelper;
use App\Helpers\ResourceLocationBuilder;
use App\Models\User\User;
use App\Services\Attachment\CreateAttachment;
use App\Services\Attachment\UpdateAttachment;
use App\Services\BaseService;

class UpdateAvatar extends BaseService
{
    public function performAction(array $args)
    {
        $avatar = $args['avatar'];
        $user = User::findOrFail($args['user_id']);
        if ($avatar) {
            if (!ImageHelper::checkImageDimension($avatar->path(), ImageDimensions::AVATAR_WIDTH, ImageDimensions::AVATAR_HEIGHT)) {
                throw new InvalidRequestException('The avatar is too small.',
                    ErrorCode::AVATAR_TOO_SMALL,
                    ['min_width' => ImageDimensions::AVATAR_WIDTH, 'min_height' => ImageDimensions::AVATAR_HEIGHT]);
            }

            $content = ImageHelper::resizeFitAvatar($avatar->path());
            $resizedAvatar = new StreamedFile($content, $avatar->getClientOriginalName(), $avatar->extension(), $avatar->getSize(), $avatar->getMimeType());

            $fileDir = (new ResourceLocationBuilder())
                ->setClient(Context::client()->get()->getBusinessKey())
                ->setUser($user->getBusinessKey())
                ->getContentPhotoPath();

            if ($user->avatar) {
                app(UpdateAttachment::class)->execute($user->avatar, $resizedAvatar, $fileDir, $user->profile_pic);
            } else {
                $attachment = app(CreateAttachment::class)->execute($resizedAvatar, $fileDir, $user->id);
                $user->profile_pic = $attachment->id;
                $user->save();
            }
        }
    }
}