<?php

namespace App\Services\Engagement;

use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Enum\EmployeeStatus;
use App\Enum\QuestionnaireEnum;
use App\Facades\Context;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Services\BaseService;
use App\Services\DataControl\GetDataControl;
use App\Services\Segment\SegmentType\GetSegmentEmployee;
use App\Traits\Filterable;
use App\Traits\Pageable;
use App\Traits\Sortable;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use App\Enum\SegmentTypes;
use App\Models\Segment\Segment;

class BaseDriverScore extends BaseService implements Validatable, Transactionable
{
    use Sortable, Pageable, Filterable;

    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $data
     * @return array
     */
    public function getRules(array $data): array
    {
        return [];
    }

    /**
     * get report comments
     *
     * @param  array  $data
     * @return mixed
     */
    public function performAction(array $data)
    {
        $LOCATION_SEGMENT_IDS = [];
        $DEPARTMENT_SEGMENT_IDS = [];
        $TEAM_SEGMENT_IDS = [];
        $MANAGER_SEGMENT_IDS = [];
        $GENDER_SEGMENT_IDS = [];
        $PARTNER_SEGMENT_IDS = [];
        $VENDOR_SEGMENT_IDS = [];

        $client = Context::client()->get();
        $manager = Context::user()->get();

        $dataControl = $data['data_control'] ?? app(GetDataControl::class)->execute();

        // Get start date based on data referencing
        $now = Carbon::now();
        $availableDate = Carbon::now()->subMonths($dataControl->data_referencing);

        ////////////// Data referencing //////////////
        if (empty($data['trend'])) {
            $data['from_date'] = isset($data['from_date']) ? Carbon::parse($data['from_date'])->toDateString() : $availableDate;
            $data['to_date'] = isset($data['to_date']) ? Carbon::parse($data['to_date'])->toDateString() : $now;
        } else {
            $data['from_date'] = isset($data['from_date']) ? Carbon::parse($data['from_date'])->subMonth()->toDateString() : $availableDate;
            $data['to_date'] = isset($data['to_date']) ? Carbon::parse($data['to_date'])->subMonth()->subDay()->toDateString() : Carbon::now()->subMonth()->subDay()->toDateString();
        }

        // If request start date less than available date then start date is available date
        $data['from_date'] = Carbon::parse($data['from_date'])->lessThan($availableDate) ? $availableDate : $data['from_date'];
        $data['to_date'] = Carbon::parse($data['to_date'])->greaterThan($now) ? $now : $data['to_date'];

        if ((isset($data['by_month']) && isset($data['progress_time']))
            || (isset($data['by_month']) && isset($data['performance']))) {
            $data['from_date'] = Carbon::parse($data['by_month']."01")->toDateString();
            $data['to_date'] = Carbon::parse($data['from_date'])->addMonth()->subDay()->toDateString();
        }

        $data['your_team_ids'] = collect([]);
        if (isset($data['your_team']) && $data['your_team'] == 'true') {
            $data['your_team_ids'] = app(GetSegmentEmployee::class)->getEmployeeSegmentManager($manager->code);
        }

        $query = QuestionnaireAnswer::query();
        $queryGetDetractor = $this->getSubQueryForScoreType(QuestionnaireEnum::DETRACTOR, $data);
        $queryGetPassive = $this->getSubQueryForScoreType(QuestionnaireEnum::PASSIVE, $data);
        $queryGetPromoter = $this->getSubQueryForScoreType(QuestionnaireEnum::PROMOTER, $data);

        $query->select([
            "pro.questionnaire_id",
            DB::raw("IF(drv.parent_id != 0, drv.parent_id, drv.id) driver"),
            DB::raw("IF(drv.parent_id = 0, drv.id, null) main_driver"),
            DB::raw("IF(drv.parent_id != 0, drv.id, null) sub_driver"),
            "drv.weight",
        ]);

        $query->selectRaw("SUM(pro.point) AS weight_score")
            ->selectRaw("COUNT(pro.questionnaire_id) AS total_responsed")
            ->from('questionnaire_answers AS pro')
            ->join('drivers AS drv', 'drv.id', 'pro.questionnaire_id');
        $query->join('employees', 'employees.user_id', 'pro.user_id');

        if (isset($data['segment'])) {
            $query->leftJoin('segment_user', 'employees.user_id', 'segment_user.user_id');
            $query->where('segment_user.segment_id', $data['segment']);
        }

        if (isset($data['segments_filter']) && is_array($data['segments_filter'])) {
            foreach ($data['segments_filter'] as $key => $segment) {
                $segmentItem = Segment::where('code', $segment['value'])->first();

                switch ($segmentItem['segment_type_id']) {
                    case SegmentTypes::LOCATION:
                        array_push($LOCATION_SEGMENT_IDS, $segmentItem['id']);
                        break;
                    case SegmentTypes::DEPARTMENT:
                        array_push($DEPARTMENT_SEGMENT_IDS, $segmentItem['id']);
                        break;
                    case SegmentTypes::TEAM:
                        array_push($TEAM_SEGMENT_IDS, $segmentItem['id']);
                        break;
                    case SegmentTypes::MANAGER:
                        array_push($MANAGER_SEGMENT_IDS, $segmentItem['id']);
                        break;
                    case SegmentTypes::GENDER:
                        array_push($GENDER_SEGMENT_IDS, $segmentItem['id']);
                        break;

                    default:
                        break;
                }
            }

            switch (true) {
                case count($LOCATION_SEGMENT_IDS) > 0:
                    $query->whereIn('employees.location_id', $LOCATION_SEGMENT_IDS);
                    break;
                case count($DEPARTMENT_SEGMENT_IDS) > 0:
                    $query->whereIn('employees.department_id', $DEPARTMENT_SEGMENT_IDS);
                    break;
                case count($TEAM_SEGMENT_IDS) > 0:
                    $query->whereIn('employees.team_id', $TEAM_SEGMENT_IDS);
                    break;
                case count($MANAGER_SEGMENT_IDS) > 0:
                    $query->whereIn('employees.manager_id', $MANAGER_SEGMENT_IDS);
                    break;
                case count($GENDER_SEGMENT_IDS) > 0:
                    $query->whereIn('employees.gender_id', $GENDER_SEGMENT_IDS);
                    break;
                case count($PARTNER_SEGMENT_IDS) > 0:
                    $query->whereIn('employees.partner_id', $PARTNER_SEGMENT_IDS);
                    break;
                case count($VENDOR_SEGMENT_IDS) > 0:
                    $query->whereIn('employees.vendor_id', $VENDOR_SEGMENT_IDS);
                    break;

                default:
                    break;
            }
        }

        $query->where('employees.status', EmployeeStatus::ACTIVE);

        $query->where('pro.client_id', $client->id);

        $isEmpty = $query->count();
        if ($isEmpty == 0) {
            return null;
        }

        $query->selectSub($queryGetDetractor, 'detractors')
            ->selectSub($queryGetPassive, 'passives')
            ->selectSub($queryGetPromoter, 'promoters');

        $query->whereNull('pro.skip_question_id');
        $query->whereNotNull('pro.point');

        if (isset($data['from_date']) && isset($data['to_date'])) {
            $query->where(function ($q) use ($data) {
                return $q->whereDate('pro.created_at', '>=', $data['from_date'])
                    ->whereDate('pro.created_at', '<=', $data['to_date']);
            });
        }

        $query->groupBy('pro.questionnaire_id', 'drv.weight', 'drv.parent_id', 'drv.id');

        if (!empty($data['main_drivers'])) {
            if (is_array($data['main_drivers'])) {
                $bindingString = substr(str_repeat('?,', count($data['main_drivers'])), 0, -1);
                $bindingValues = $data['main_drivers'];
            } else {
                $bindingString = '?';
                $bindingValues = [$data['main_drivers']];
            }
            $query->havingRaw("driver IN($bindingString)", $bindingValues);
        } else {
            if (!empty($data['sub_drivers'])) {
                if (is_array($data['sub_drivers'])) {
                    $bindingString = substr(str_repeat('?,', count($data['sub_drivers'])), 0, -1);
                    $bindingValues = $data['sub_drivers'];
                } else {
                    $bindingString = '?';
                    $bindingValues = [$data['sub_drivers']];
                }
                $query->havingRaw("sub_driver IN($bindingString)", $bindingValues);
            } else {
                if (isset($data['topics'])) {
                    $query->whereIn('pro.driver_id', $data['topics'] ?? []);
                    $query->whereIn('pro.id', $data['comment_ids'] ?? []);
                }
            }
        }

        $query->orderBy('pro.questionnaire_id');
        $query->orderBy('drv.parent_id');
        $answers = $query->get();

        $drivers = $answers->toArray();
        if (count($drivers) === 0) {
            $driverScores = [];
            $driverIds = ($data['main_drivers'] ?? ($data['sub_drivers'] ?? null));
            if (is_array($driverIds)) {
                foreach ($driverIds as $driverId) {
                    $driverScores[$driverId] = ['driver_avg' => null, 'driver_enps' => null];
                }
            }

            return count($driverScores) ? $driverScores : ['driver_avg' => null, 'driver_enps' => null];
        }

        $enps_avg = null;
        foreach ($drivers as $id => $item) {
            $promoters = (float) $item['promoters'] / (float) $item['total_responsed'] * 100;
            $detractors = (float) $item['detractors'] / (float) $item['total_responsed'] * 100;
            $passives = (float) $item['passives'] / (float) $item['total_responsed'] * 100;
            $total_responses = (float) $item['total_responsed'];
            $driver_avg = (float) $item['weight_score'] / $total_responses * (float) $item['weight'];
            $driver_enps = ((float) $promoters - (float) $detractors) * (float) $item['weight'];
            $enps_avg[$item['driver']]['detractors'][] = $detractors;
            $enps_avg[$item['driver']]['passives'][] = $passives;
            $enps_avg[$item['driver']]['promoters'][] = $promoters;
            $enps_avg[$item['driver']]['total_responses'][] = $total_responses;
            $enps_avg[$item['driver']]['driver_avg'][] = $driver_avg;
            $enps_avg[$item['driver']]['driver_enps'][] = $driver_enps;
            $enps_avg[$item['driver']]['total_scores'][] = (float) $item['weight_score'];
            if (!empty($item['sub_driver'])) {
                $enps_avg[$item['driver']]['sub_drivers'][$item['sub_driver']]['detractors'] = $detractors;
                $enps_avg[$item['driver']]['sub_drivers'][$item['sub_driver']]['passives'] = $passives;
                $enps_avg[$item['driver']]['sub_drivers'][$item['sub_driver']]['promoters'] = $promoters;
                $enps_avg[$item['driver']]['sub_drivers'][$item['sub_driver']]['total_responses'] = $total_responses;
                $enps_avg[$item['driver']]['sub_drivers'][$item['sub_driver']]['driver_avg'] = $driver_avg;
                $enps_avg[$item['driver']]['sub_drivers'][$item['sub_driver']]['driver_enps'] = $driver_enps;
                $enps_avg[$item['driver']]['sub_drivers'][$item['sub_driver']]['total_scores'] = (float) $item['weight_score'];
            }
        }

        $enpsAvg = null;
        if (isset($enps_avg)) {
            foreach ($enps_avg as $id => $value) {
                $totalResponses = array_sum($enps_avg[$id]['total_responses']);
                $totalScores = array_sum($enps_avg[$id]['total_scores']);
                $enpsAvg[$id]['detractors'] = array_sum($enps_avg[$id]['detractors']) / count($enps_avg[$id]['detractors']);
                $enpsAvg[$id]['passives'] = array_sum($enps_avg[$id]['passives']) / count($enps_avg[$id]['passives']);
                $enpsAvg[$id]['promoters'] = array_sum($enps_avg[$id]['promoters']) / count($enps_avg[$id]['promoters']);
                $enpsAvg[$id]['total_responses'] = $totalResponses;
                $driverAvg = array_sum($enps_avg[$id]['driver_avg']);
                $driverEnps = array_sum($enps_avg[$id]['driver_enps']);
                $enpsAvg[$id]['driver_avg'] = $this->limitScoreResult(0, 10, $driverAvg);
                $enpsAvg[$id]['driver_enps'] = $this->limitScoreResult(-100, 100, $driverEnps);
                $enpsAvg[$id]['total_scores'] = $totalScores;
                $enpsAvg[$id]['avg_score'] = array_sum($enps_avg[$id]['total_scores']) / $totalResponses;
                if (!empty($value['sub_drivers'])) {
                    $enpsAvg[$id]['sub_drivers'] = $value['sub_drivers'];
                    foreach ($value['sub_drivers'] as $subDriverId => $subDriver) {
                        $enpsAvg[$id]['sub_drivers'][$subDriverId]['driver_avg'] = $this->limitScoreResult(0, 10, $subDriver['driver_avg']);
                        $enpsAvg[$id]['sub_drivers'][$subDriverId]['driver_enps'] = $this->limitScoreResult(-100, 100, $subDriver['driver_enps']);
                        $enpsAvg[$id]['sub_drivers'][$subDriverId]['avg_score'] = $subDriver['total_scores'] / $subDriver['total_responses'];
                    }
                }
            }
        }

        $scores = null;
        $board = null;
        if ((isset($enpsAvg) && isset($data['enps']))
            || (isset($enpsAvg) && isset($data['by_month']) && isset($data['progress_time']))
            || (isset($enpsAvg) && isset($data['topics']))) {
            foreach ($enpsAvg as $id => $value) {
                $board['detractors'][] = $enpsAvg[$id]['detractors'];
                $board['passives'][] = $enpsAvg[$id]['passives'];
                $board['promoters'][] = $enpsAvg[$id]['promoters'];
                $board['total_responses'][] = $enpsAvg[$id]['total_responses'];
                $board['driver_avg'][] = $enpsAvg[$id]['driver_avg'];
                $board['driver_enps'][] = $enpsAvg[$id]['driver_enps'];
                $board['avg_score'][] = $enpsAvg[$id]['avg_score'];
            }
            $scores['detractors'] = array_sum($board['detractors']) / count($board['detractors']);
            $scores['passives'] = array_sum($board['passives']) / count($board['passives']);
            $scores['promoters'] = array_sum($board['promoters']) / count($board['promoters']);
            $scores['total_responses'] = array_sum($board['total_responses']);
            $scores['driver_avg'] = array_sum($board['driver_avg']) / count($board['driver_avg']);
            $scores['driver_enps'] = array_sum($board['driver_enps']) / count($board['driver_enps']);
            $scores['avg_score'] = array_sum($board['avg_score']) / count($board['avg_score']);
        } elseif (isset($enpsAvg) && isset($data['main_drivers'])) {
            if (is_array($data['main_drivers'])) {
                foreach ($data['main_drivers'] as $mainDriverId) {
                    $scores[$mainDriverId]['driver_avg'] = $enpsAvg[$mainDriverId]['driver_avg'] ?? null;
                    $scores[$mainDriverId]['driver_enps'] = $enpsAvg[$mainDriverId]['driver_enps'] ?? null;
                }
            } else {
                $parent_id = (int) $data['main_drivers'];
                $scores['driver_avg'] = $enpsAvg[$parent_id]['driver_avg'];
                $scores['driver_enps'] = $enpsAvg[$parent_id]['driver_enps'];
            }
        } elseif (isset($enpsAvg) && isset($data['sub_drivers'])) {
            $parent_id = (int) $data['parent_id'];
            if (is_array($data['sub_drivers'])) {
                foreach ($data['sub_drivers'] as $subDriverId) {
                    $scores[$subDriverId]['driver_avg'] = $enpsAvg[$parent_id]['sub_drivers'][$subDriverId]['driver_avg'] ?? null;
                    $scores[$subDriverId]['driver_enps'] = $enpsAvg[$parent_id]['sub_drivers'][$subDriverId]['driver_enps'] ?? null;
                }
            } else {
                $scores['driver_avg'] = $enpsAvg[$parent_id]['driver_avg'];
                $scores['driver_enps'] = $enpsAvg[$parent_id]['driver_enps'];
            }
        } elseif (isset($enpsAvg) && (isset($data['by_month']) && isset($data['performance']))) {
            return $enpsAvg;
        }
        return $scores;
    }

    protected function getSubQueryForScoreType($scoreRange, $data)
    {
        $currentClient = Context::client()->get();
        $query = QuestionnaireAnswer::query()
            ->select(DB::raw('count(questionnaire_answers.id)'))
            ->join('employees', 'employees.user_id', 'questionnaire_answers.user_id')
            ->where('questionnaire_answers.created_at', '>=', $data['from_date'])
            ->where('questionnaire_answers.created_at', '<=', $data['to_date'])
            ->where('questionnaire_answers.client_id', '=', $currentClient->id)
            ->where('questionnaire_answers.point', '>=', $scoreRange['min'])
            ->where('questionnaire_answers.point', '<=', $scoreRange['max'])
            ->where('employees.status', EmployeeStatus::ACTIVE)
            ->whereColumn('questionnaire_answers.questionnaire_id', '=', 'pro.questionnaire_id');

        if (isset($data['your_team_ids']) && $data['your_team_ids']->count() > 0) {
            $query->whereIn('questionnaire_answers.user_id', $data['your_team_ids']);
        }

        if (isset($data['segment'])) {
            $query->leftJoin('segment_user', 'employees.user_id', 'segment_user.user_id');
            $query->where('segment_user.segment_id', $data['segment']);
        }

        if (isset($data['topics'])) {
            $query->whereIn('questionnaire_answers.driver_id', $data['topics'] ?? []);
            $query->whereIn('questionnaire_answers.id', $data['comment_ids'] ?? []);
        }

        return $query;
    }

    public function limitScoreResult($min, $max, $number)
    {
        if ($number < $min) {
            return $min;
        }

        if ($number > $max) {
            return $max;
        }

        return $number;
    }
}
