<?php


namespace App\Services\Engagement;


use App\Enum\EmployeeStatus;
use App\Enum\QuestionnaireEnum;
use App\Facades\Context;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Services\BaseService;
use App\Services\DataControl\GetDataControl;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;

class GetScoreValues extends BaseService
{
    /**
     * get participate employees answered
     * @param array $data
     * @return null | array
     */
    public function performAction($data = [])
    {
        $client = Context::client()->get();
        $dataControl = $data['data_control'] ?? app(GetDataControl::class)->execute();
        $mainDrivers = null;
        if (isset($data['main_drivers'])) {
            $mainDrivers = is_array($data['main_drivers']) ? $data['main_drivers'] : [$data['main_drivers']];
        }

        // Get start date based on data referencing
        $now = Carbon::now();
        $availableDate = Carbon::now()->subMonths($dataControl->data_referencing);

        ////////////// Data referencing //////////////
        if (empty($data['trend'])) {
            $data['from_date'] = isset($data['from_date']) ? Carbon::parse($data['from_date'])->toDateString() : $availableDate;
            $data['to_date'] = isset($data['to_date']) ? Carbon::parse($data['to_date'])->toDateString() : $now;
        } else {
            $data['from_date'] = isset($data['from_date']) ? Carbon::parse($data['from_date'])->subMonth()->toDateString() : Carbon::now()->subMonth()->toDateString();
            $data['to_date'] = isset($data['to_date']) ? Carbon::parse($data['to_date'])->subMonth()->toDateString() : Carbon::now()->subMonth()->toDateString();
        }

        // If request start date less than available date then start date is available date
        $data['from_date'] = Carbon::parse($data['from_date'])->lessThan($availableDate) ? $availableDate : $data['from_date'];
        $data['to_date'] = Carbon::parse($data['to_date'])->greaterThan($now) ? $now : $data['to_date'];

        if (isset($data['by_month']) && isset($data['progress_time'])) {
            $data['from_date'] = Carbon::parse($data['by_month']."01")->toDateString();
            $data['to_date'] = Carbon::parse($data['from_date'])->addMonth()->subDay()->toDateString();
        }

        $query = QuestionnaireAnswer::query();
        $query->select([
            "pro.client_value_id AS questionnaire_id",
            DB::raw("pro.client_value_id AS driver"),
            DB::raw("1 AS weight")
        ])
            ->selectRaw("SUM(pro.point) AS weight_score")
            ->selectRaw("COUNT(pro.id) AS total_responsed")
            ->from('questionnaire_answers AS pro');

        $query->join('employees', 'employees.user_id', 'pro.user_id')
            ->where('employees.status', EmployeeStatus::ACTIVE);

        $query->where('pro.client_id', $client->id);

        $isEmpty = $query->count();
        if ($isEmpty == 0) {
            return null;
        }

        $queryGetDetractor = $this->getSubQueryForScoreType(QuestionnaireEnum::DETRACTOR, $data);
        $queryGetPassive = $this->getSubQueryForScoreType(QuestionnaireEnum::PASSIVE, $data);
        $queryGetPromoter = $this->getSubQueryForScoreType(QuestionnaireEnum::PROMOTER, $data);
        $query->selectSub($queryGetDetractor, 'detractors')
            ->selectSub($queryGetPassive, 'passives')
            ->selectSub($queryGetPromoter, 'promoters');

        if (isset($mainDrivers)) {
            $query->whereIn('pro.client_value_id', $mainDrivers);
        }

        if (isset($data['segment'])) {
            $query->leftJoin('segment_user', 'segment_user.user_id', 'pro.user_id');
            $query->where('segment_user.segment_id', $data['segment']);
        }

        $query->whereNull('pro.skip_question_id');
        $query->whereNull('pro.driver_id');
        $query->whereNotNull('pro.point');
        $query->whereNotNull('pro.client_value_id');
        $query->groupBy('pro.client_value_id', 'pro.questionnaire_id');

        $answers = $query->get();

        $drivers = $answers->toArray();

        $enps_avg = null;
        foreach ($drivers as $id => $item) {
            $promoters = (float) $item['promoters'] / (float) $item['total_responsed'] * 100;
            $detractors = (float) $item['detractors'] / (float) $item['total_responsed'] * 100;
            $passives = (float) $item['passives'] / (float) $item['total_responsed'] * 100;
            $total_responses = (float) $item['total_responsed'];
            $enps_avg[$item['driver']]['detractors'][] = $detractors;
            $enps_avg[$item['driver']]['passives'][] = $passives;
            $enps_avg[$item['driver']]['promoters'][] = $promoters;
            $enps_avg[$item['driver']]['total_responses'][] = $total_responses;
            $enps_avg[$item['driver']]['driver_avg'][] = (float) $item['weight_score'] / $total_responses * (float) $item['weight'];
            $enps_avg[$item['driver']]['driver_enps'][] = ((float) $promoters - (float) $detractors) * (float) $item['weight'];
        }

        $enpsAvgScores = null;
        if (isset($enps_avg)) {
            foreach ($enps_avg as $id => $value) {
                $enpsAvgScores[$id]['detractors'] = array_sum($enps_avg[$id]['detractors']) / count($enps_avg[$id]['detractors']);
                $enpsAvgScores[$id]['passives'] = array_sum($enps_avg[$id]['passives']) / count($enps_avg[$id]['passives']);
                $enpsAvgScores[$id]['promoters'] = array_sum($enps_avg[$id]['promoters']) / count($enps_avg[$id]['promoters']);
                $enpsAvgScores[$id]['total_responses'] = array_sum($enps_avg[$id]['total_responses']);
                $enpsAvgScores[$id]['driver_avg'] = array_sum($enps_avg[$id]['driver_avg']);
                $enpsAvgScores[$id]['driver_enps'] = array_sum($enps_avg[$id]['driver_enps']);
            }
        }

        $scores = null;
        if (isset($mainDrivers)) {
            foreach ($mainDrivers as $driver) {
                $scores[$driver]['driver_avg'] = $enpsAvgScores[$driver]['driver_avg'] ?? null;
                $scores[$driver]['driver_enps'] = $enpsAvgScores[$driver]['driver_enps'] ?? null;
            }
        }

        return $scores;
    }

    protected function getSubQueryForScoreType($scoreRange, $data)
    {
        $currentClient = Context::client()->get();
        $query = QuestionnaireAnswer::query()
            ->select(DB::raw('count(questionnaire_answers.id)'))
            ->join('employees', 'employees.user_id', 'questionnaire_answers.user_id')
            ->whereColumn('questionnaire_answers.client_value_id', '=', 'pro.client_value_id')
            ->where('questionnaire_answers.created_at', '>=', $data['from_date'])
            ->where('questionnaire_answers.created_at', '<=', $data['to_date'])
            ->where('questionnaire_answers.client_id', '=', $currentClient->id)
            ->where('questionnaire_answers.point', '>=', $scoreRange['min'])
            ->where('questionnaire_answers.point', '<=', $scoreRange['max'])
            ->where('employees.status', EmployeeStatus::ACTIVE);

        if (isset($data['segment'])) {
            $query->leftJoin('segment_user', 'segment_user.user_id', 'questionnaire_answers.user_id');
            $query->where('segment_user.segment_id', $data['segment']);
        }

        return $query;
    }
}