<?php


namespace App\Services\Event;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Facades\Context;
use App\Helpers\ModelHelper;
use App\Helpers\PermissionHelper;
use App\Helpers\UserAccessHelper;
use App\Jobs\IndexPowerSearch;
use App\Models\Event\Event;
use App\Services\BaseService;

class DeleteEvent extends BaseService implements Validatable, Performable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($data)
    {
        return [
            'code' => 'required|string',
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Delete event
     *
     * @param array $data
     * @return bool
     */
    public function performAction(array $data): bool
    {
        $event = Event::findByBusinessKey($data['code']);

        PermissionHelper::hasAccessOn($event);
        UserAccessHelper::hasAccessAsOwner($event);

        $event->users()->detach();
        $event->segments()->detach();
        IndexPowerSearch::dispatch($event->code, PowerSearchTypes::EVENT, PowerSearchActions::DELETE, $event->client_id);
        $event->delete();

        return true;
    }
}
