<?php


namespace App\Services\Event;

use App\Enum\AccessPermissions;
use App\Enum\Roles;
use App\Facades\Context;
use App\Helpers\FilterFluent;
use App\Helpers\ModelHelper;
use App\Helpers\UserAccessHelper;
use App\Models\Event\Event;
use App\Services\BaseService;
use App\Traits\Pageable;
use App\Traits\Sortable;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use App\Services\Mobile\Event\GetEvent as GetInvitedEvent;

class GetEvent extends BaseService
{
    use Sortable, Pageable;


    /**
     * Get list event
     * @param array $options
     * @return mixed
     */
    public function performAction(array $options)
    {
        $query = Event::query()->with('creator.avatar')
            ->select('events.*');

        $user = Context::user()->get();
        if (!UserAccessHelper::hasAccess(AccessPermissions::ACCESS_COMPANY_EVENT) &&
            UserAccessHelper::hasAccess(AccessPermissions::ACCESS_OWNER_EVENT)) {
            // Get events created by current user or events that the current user is guests
            $invitedEvents = app(GetInvitedEvent::class)->execute();
            $query->where('created_by', $user->getKey())
                ->orWhereIntegerInRaw('id', $invitedEvents->pluck('id')->toArray());
        }

        ModelHelper::setConditionFindByClient($query);

        FilterFluent::init()
        ->setQuery($query)
        ->setFilterOptions($options)
        ->setAllowedFilters(['nearest', 'start_date', 'end_date', 'recurrence_end_date'])
        ->removeFilter(['nearest', 'recurrence_end_date'])
        ->validate()
        ->setCustomFilter('nearest', function ($query, $type, $col, $value) {
            $query->where('start_date', '>', Carbon::now());
            $query->orderBy('start_date');
        })
        ->setCustomFilter('recurrence_end_date', function ($query, $type, $col, $value) {
            $query->orWhere(function($subQuery) use ($value) {
                ModelHelper::setConditionFindByClient($subQuery);
                $subQuery->where('start_date', '<=', $value);
                $subQuery->where(function($sub) use($value) {
                    $sub->where('recurrence_end_date', '>=', $value);
                    $sub->orWhere('recurrence_end_date', '0001-01-01'); // Endless event
                });
            });
        })
        ->applyFilter();

        $this->applySorting($options, $query);
        return $this->applyPaging($options, $query);
    }
}
