<?php
namespace App\Services\Initiative;

use App\Facades\Context;
use App\Helpers\ModelHelper;
use App\Models\Driver\Driver;
use App\Models\Initiative\Initiative;
use App\Models\User\User;
use App\Services\BaseService;

class GetInitiative extends BaseService
{

    /**
     * Get list Initiative
     *
     * @param array $options
     * @return mixed
     */
    public function performAction(array $ags)
    {
        $driverAvailableQuery = Initiative::query();
        ModelHelper::setConditionFindByClient($driverAvailableQuery);
        $driverAvailable = $driverAvailableQuery->pluck('driver_id')->unique()->toArray();

        $client = Context::client()->get();

        $initiativeResponder = Initiative::where('client_id', $client->id)->pluck('responsible_id')->unique();
        $initiativeCreator = Initiative::where('client_id', $client->id)->pluck('created_by')->unique();
        $initiativeUser = $initiativeResponder->merge($initiativeCreator)->unique()->toArray();
        $users = User::whereIn('id', $initiativeUser)->get();
        $usersMap = $users->mapWithKeys(function($value) {
            return [$value['id'] => $value];
        });

        $drivers = Driver::whereIn('id', $driverAvailable)->get();
        foreach ($drivers as $driver) {
            $initiatives = $driver->initiatives()->get();
            foreach ($initiatives as $initiative) {
                $initiative->responsible = !empty($usersMap[$initiative->responsible_id]) ? $usersMap[$initiative->responsible_id] : null;
                $initiative->creator = !empty($usersMap[$initiative->created_by]) ? $usersMap[$initiative->created_by] : null;
            }
            $driver->initiatives_list = $initiatives;
        }

        return $drivers;
    }
}
