<?php


namespace App\Services\Initiative;

use App\Contracts\Transactionable;
use App\Enum\NotificationTypes;
use App\Jobs\SendNotification;
use App\Models\Initiative\Initiative;
use App\Models\User\User;
use App\Services\BaseService;
use App\Enum\InitiativeEnum;
use Illuminate\Support\Facades\Auth;

class UpdateCompletedInitiative extends BaseService implements Transactionable
{
    /**
     * UpdateCompletedInitiative
     *
     * @param array $data
     * @return Initiative
     */
    public function performAction(array $data)
    {
        $initiative = Initiative::findOrFail($data['id']);

        $initiative->update([
            'status' => InitiativeEnum::COMPLETED
        ]);
        $user = User::find($initiative->responsible_id);
        if($user){
            $arguments = array(
                'sender' => Auth::user()->id,
                "userIds" => $user->code,
                "headings" => __("An initiative has closed"),
                "contents" => __("Tap to view"),
                "data"=>[
                    "type" => NotificationTypes::INITIATIVE_CLOSED,
                    "id" => $initiative->id,
                ],
                'send_after' => null
            );
            SendNotification::dispatch($arguments);
        }
        return $initiative;
    }
}
