<?php

namespace App\Services\Integration;

use App\Contracts\Validatable;
use App\Enum\PlanConfigurations;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\IntegrationHelper;
use App\Jobs\CreateIntegrationCandidates;
use App\Jobs\CreateIntegrationEmployees;
use App\Jobs\CreateIntegrationContacts;
use App\Models\Integration\Integration;
use App\Services\BaseService;
use App\Services\Subscription\CheckRemainPlanAction;


class AuthorizeIntegration extends BaseService implements Validatable
{

    /**
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'public_token' => 'required'
        ];
    }

    /**
     * Authorize client integration
     *
     * @param array $args
     * @return array
     */
    public function performAction(array $args)
    {
        app(CheckRemainPlanAction::class)->execute(PlanConfigurations::PACKAGE_INTEGRATION);

        $client = Context::client()->get();
        $user = Context::user()->get();
        $integrationHelper = new IntegrationHelper();
        $accountToken = $integrationHelper->retrieveAccountToken($args['public_token']);

        if (!$accountToken) {
            throw new InvalidRequestException('Invalid token');
        }

        Integration::updateOrCreate(
            [
                'client_id' => $client->getKey()
            ],
            [
                'client_id' => $client->getKey(),
                'account_token' => $accountToken['account_token'],
                'name' => $accountToken['integration']['name'],
                'slug' => $accountToken['integration']['slug'],
            ]
        );

        // Automatically create employees from client's integration
        // Delay a minute to Merge complete syncing integration data
        $categories = $accountToken['integration']['categories'];
        if (in_array('hris', $categories)) {
            CreateIntegrationEmployees::dispatch($client, $user)->delay(now()->addMinute());
        }
        if (in_array('ats', $categories)) {
            CreateIntegrationCandidates::dispatch($client, $user)->delay(now()->addMinute());
        }
        if (in_array('crm', $categories)) {
            CreateIntegrationContacts::dispatch($client, $user)->delay(now()->addMinute());
        }

        return $accountToken;
    }
}
