<?php

namespace App\Services\Integration;

use App\Enum\EmployeeStatus;
use App\Enum\EmploymentTypes;
use App\Enum\Roles;
use App\Enum\SegmentTypes;
use App\Helpers\IntegrationHelper;
use App\Helpers\SegmentHelper;
use App\Models\User\User;
use App\Services\BaseService;
use App\Services\Employee\CreateEmployee;

class CreateIntegrationCandidate extends BaseService
{

    /**
     * Create integration employee
     *
     * @param array $args
     * @return bool|User
     */
    function performAction(array $args)
    {
        if (!isset($args['candidate']) || !isset($args['client'])) {
            return false;
        }
        $client = $args['client'];
        $candidate = $args['candidate'];

        $employeeEmail = !isEmpty($candidate['email_addresses']) ? $candidate['email_addresses'][0]['value'] : '';
        if (empty($employeeEmail)) {
            return false;
        }

        $emailCount = User::where('email', $employeeEmail)->count();
        if ($emailCount) {
            return false;
        }

        $employeeData = [
            'first_name' => $candidate['first_name'],
            'surname' => $candidate['last_name'],
            'email' => $employeeEmail,
            'start_date' => $candidate['remote_created_at'],
            'job_title' => $candidate['title'],
            'employment_type' => EmploymentTypes::CANDIDATE,
            'role' => Roles::FRONT_USER,
            'status' => EmployeeStatus::INCOMPLETE,
            'location_id' => $candidate['locations'] ? $this->getSegmentId(
                SegmentTypes::LOCATION, $candidate['locations'][0], $client->getKey()
            ) : '',
            'gender_id' => $this->getSegmentId(
                SegmentTypes::GENDER, IntegrationHelper::convertGenderSegment($candidate['gender']), $client->getKey()
            ),
            'action' => 'invite',
        ];

        $createdEmployee = app(CreateEmployee::class)->execute($employeeData);

        return $createdEmployee;
    }

    function getSegmentId($segmentType, $name, $clientId)
    {
        if (!empty($name)) {
            $segment = SegmentHelper::firstOrCreateSegment($segmentType, $name, $clientId);

            return $segment->getKey();
        }

        return null;
    }
}