<?php

namespace App\Services\Integration;

use App\Enum\EmployeeStatus;
use App\Enum\Roles;
use App\Enum\SegmentTypes;
use App\Enum\DocumentProfiles;
use App\Helpers\IntegrationHelper;
use App\Helpers\SegmentHelper;
use App\Models\Segment\Segment;
use App\Models\User\User;
use App\Services\BaseService;
use App\Services\Employee\CreateEmployee;
use App\Services\Library\GetDocumentProfiles;
use App\Services\Library\CreateDocumentProfile;


class CreateIntegrationEmployee extends BaseService
{
    /**
     * Create integration employee
     *
     * @param array $args
     * @return bool|User
     */
    public function performAction(array $args)
    {
        if (!isset($args['employee']) || !isset($args['client'])) {
            return false;
        }
        $client = $args['client'];
        $employee = $args['employee'];

        $employeeEmail = $employee['work_email'] ?? $employee['personal_email'];
        if (empty($employeeEmail)) {
            return false;
        }

        $emailCount = User::where('email', $employeeEmail)->count();
        if ($emailCount) {
            return false;
        }

        if (in_array($employee['employment_status'], IntegrationHelper::INACTIVE_EMPLOYMENT_STATUS)) {
            return false;
        }

        $employment = reset($employee['employments']);

        $employmentType = IntegrationHelper::convertEmploymentType($employment);

        $locationId = $employee['work_location'];
        $location = null;
        if ($locationId) {
            $integration = $client->integration;
            $integrationHelper = new IntegrationHelper();
            $location = $integrationHelper->getLocations($integration->account_token, $locationId);
        }

        $documentProfiles = app(GetDocumentProfiles::class)->execute();
        if($documentProfiles->count() > 0) {
            $documentProfile = $documentProfiles[0];
        } else {
            $data['name'] = DocumentProfiles::DEFAULT_NAME;
            $documentProfile = app(CreateDocumentProfile::class)->execute($data);
        }

        $documentProfileIds[] = $documentProfile['id'];

        $employeeData = [
            'first_name' => $employee['first_name'],
            'surname' => $employee['last_name'],
            'document_profiles' => $documentProfileIds,
            'email' => $employeeEmail,
            'date_of_birth' => $employee['date_of_birth'],
            'start_date' => $employee['start_date'],
            'job_title' => $employment ? $employment['job_title'] : null,
            'employment_type' => $employmentType,
            'role' => Roles::FRONT_USER,
            'status' => EmployeeStatus::INCOMPLETE,
            'external_avatar_url' => $employee['avatar'],
            'location_id' => $location ? $this->getSegmentId(
                SegmentTypes::LOCATION, $location['name'], $client->getKey()
            ) : '',
            'gender_id' => $this->getSegmentId(
                SegmentTypes::GENDER, IntegrationHelper::convertGenderSegment($employee['gender']), $client->getKey()
            ),
            'department_id' => $this->getSegmentId(
                SegmentTypes::DEPARTMENT, $employee['team']['name'] ?? null, $client->getKey()
            ),
            'action' => 'invite',
        ];

        $createdEmployee = app(CreateEmployee::class)->execute($employeeData);

        return $createdEmployee;
    }

    function getSegmentId($segmentType, $name, $clientId)
    {
        if (!empty($name)) {
            $segment = SegmentHelper::firstOrCreateSegment($segmentType, $name, $clientId);

            return $segment->getKey();
        }

        return null;
    }
}
