<?php

namespace App\Services\Integration;

use App\Contracts\Validatable;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\IntegrationHelper;
use App\Models\Integration\DisconnectedIntegration;
use App\Models\Integration\Integration;
use App\Services\BaseService;


class DisconnectIntegration extends BaseService implements Validatable
{

    public function getRules(array $args)
    {
        return [
            'slug' => 'required'
        ];
    }

    /**
     * Disconnect integration
     *
     * @param array $args
     * @return bool
     */
    public function performAction(array $args)
    {
        $client = Context::client()->get();
        $clientIntegration = $client->integration;
        if (!$clientIntegration || $clientIntegration->slug != $args['slug']) {
            throw new InvalidRequestException();
        }

        if($args['isHris'] == 'true') {
            $isDeleted = (new IntegrationHelper())->deleteLinkedAccount($clientIntegration->account_token);
            if (!$isDeleted) {
                return false;
            }
        }

        if($args['isAts'] == 'true') {
            $isDeletedCandidate = (new IntegrationHelper())->deleteCandidateLinkedAccount($clientIntegration->account_token);
            if (!$isDeletedCandidate) {
                return false;
            }
        }
        
        if($args['isCrm'] == 'true') {
            $isDeletedContact = (new IntegrationHelper())->deleteContactLinkedAccount($clientIntegration->account_token);
            if (!$isDeletedContact) {
                return false;
            }
        }

        DisconnectedIntegration::updateOrCreate(
            [
                'client_id' => $clientIntegration->client_id,
                'slug' => $clientIntegration->slug,
            ],
            [
                'client_id' => $clientIntegration->client_id,
                'enabled_at' => $clientIntegration->created_at,
                'name' => $clientIntegration->name,
                'slug' => $clientIntegration->slug,
            ]
        );

        Integration::where('client_id', $clientIntegration->client_id)->delete();

        return true;
    }
}
