<?php

namespace App\Services\Integration;

use App\Enum\IntegrationStatus;
use App\Enum\PlanConfigurations;
use App\Enum\SortTypes;
use App\Facades\Context;
use App\Helpers\IntegrationHelper;
use App\Helpers\SortFluent;
use App\Services\BaseService;
use App\Services\Subscription\CheckRemainPlanAction;
use Illuminate\Validation\ValidationException;


class GetIntegration extends BaseService
{

    /**
     * Get integrations
     *
     * @param array $args
     * @return array
     * @throws ValidationException
     */
    public function performAction(array $args)
    {
        app(CheckRemainPlanAction::class)->execute(PlanConfigurations::PACKAGE_INTEGRATION);

        $integrations = (new IntegrationHelper())->getIntegrations();
        if (!$integrations) {
            return [];
        }

        $client = Context::client()->get();
        $clientIntegration = $client->integration;
        $disconnectedIntegrations = $client->disconnectedIntegration()->pluck('slug')->toArray();
        foreach ($integrations as &$integration) {
            $integration['date'] = null;
            $integration['status'] = null;

            if (in_array($integration['slug'], $disconnectedIntegrations)) {
                $integration['status'] = IntegrationStatus::INACTIVE;
            }

            if ($clientIntegration && $integration['slug'] === $clientIntegration->slug) {
                $integration['date'] = $clientIntegration->created_at;
                $integration['status'] = IntegrationStatus::ACTIVE;
            }
        }

        $sortedIntegration = [];
        $queryOptions = Context::request()->getOptions();
        SortFluent::init()
            ->setSortOptions($queryOptions)
            ->setAllowedSorts(['name', 'date', 'status'])
            ->validate();
        $sortOption = isset($queryOptions['sort']) ? reset($queryOptions['sort']) : [];
        if ($sortOption) {
            $sortedIntegration = $sortOption['direction'] == SortTypes::DESC ?
                collect($integrations)->sortByDesc(function ($integration) use ($sortOption) {
                    return $integration[$sortOption['column']];
                }) : collect($integrations)->sortBy(function ($integration) use ($sortOption) {
                    return $integration[$sortOption['column']];
                });
        }

        return !empty($sortedIntegration) ? $sortedIntegration : $integrations;
    }
}
