<?php

namespace App\Services\Integration;

use App\Enum\PlanConfigurations;
use App\Facades\Context;
use App\Helpers\IntegrationHelper;
use App\Models\Client\Client;
use App\Models\User\User;
use App\Services\BaseService;
use App\Services\Subscription\CheckRemainPlanAction;
use Illuminate\Support\Facades\Log;


class SyncIntegrationEmployee extends BaseService
{
    const ALLOWED_EVENTS = ['Employee.changed', 'Employee.added'];

    /**
     * Sync integration employee
     *
     * @param array $args
     * @return bool
     */
    public function performAction(array $args)
    {
        Log::debug('Integration webhook request',  $args);
        $event = $args['hook']['event'] ?? null;
        if (!in_array($event, self::ALLOWED_EVENTS)) {
            Log::debug('Invalid event', $args);
            return false;
        }

        if (!isset($args['linked_account']['end_user_origin_id'])) {
            Log::debug('Invalid client id', $args);
            return false;
        }

        $clientKey = $args['linked_account']['end_user_origin_id'];
        $client = Client::findByBusinessKey($clientKey);
        if (!$client) {
            Log::debug('Client not found', $args);
            return false;
        }
        $clientIntegration = $client->integration;
        if (!$clientIntegration) {
            Log::debug('Client is not integrated with Merge', $args);
            return false;
        }

        if (!isset($args['data']['id'])) {
            Log::debug('Invalid employee id', $args);
            return false;
        }

        $integrationEmployeeId = $args['data']['id'];
        $integrationHelper = new IntegrationHelper();
        $employee = $integrationHelper->getEmployeeDetail($clientIntegration->account_token, $integrationEmployeeId);
        if (!$employee) {
            Log::debug('Employee not found', $args);
            return false;
        }

        $employeeEmail = $employee['work_email'] ?? $employee['personal_email'];
        if (!$employeeEmail) {
            return false;
        }

        $clientAdmin = $client->adminUsers()->first();
        Context::client()->set($client);
        Context::user()->set($clientAdmin);

        if (!app(CheckRemainPlanAction::class)->execute(PlanConfigurations::PACKAGE_INTEGRATION, false)) {
            return false;
        }

        $user = User::where('email', $employeeEmail)->first();
        if ($user) {
            try {
                app(UpdateIntegrationEmployee::class)->execute([
                    'user' => $user, 'employee' => $employee, 'client' => $client
                ]);

                return true;
            } catch (\Exception $e) {
                Log::error($e);
            }
        } else {
            try {
                app(CreateIntegrationEmployee::class)->execute([
                    'employee' => $employee, 'client' => $client
                ]);

                return true;
            } catch (\Exception $e) {
                Log::error($e);
            }
        }

        return false;
    }
}
