<?php

namespace App\Services\Integration;

use App\Enum\EmployeeStatus;
use App\Enum\SegmentTypes;
use App\Helpers\IntegrationHelper;
use App\Helpers\SegmentHelper;
use App\Models\Segment\Segment;
use App\Models\User\User;
use App\Services\BaseService;
use App\Services\Employee\ChangeEmployeeStatus;
use App\Services\Employee\UpdateEmployee;


class UpdateIntegrationEmployee extends BaseService
{

    /**
     * Update integration employee
     *
     * @param array $args
     * @return bool|User
     */
    public function performAction(array $args)
    {
        if (!isset($args['user']) || !isset($args['employee']) || !isset($args['client'])) {
            return false;
        }
        $user = $args['user'];
        $client = $args['client'];
        $employee = $args['employee'];

        if ($user->employee->status != EmployeeStatus::INCOMPLETE) {
            $status = in_array($employee['employment_status'], IntegrationHelper::INACTIVE_EMPLOYMENT_STATUS) ?
                EmployeeStatus::INACTIVE : EmployeeStatus::ACTIVE;

            app(ChangeEmployeeStatus::class)->execute([
                'code' => $user->getBusinessKey(),
                'status' => $status
            ]);
        }

        $employment = reset($employee['employments']);
        $employmentType = IntegrationHelper::convertEmploymentType($employment);

        $employeeData = [
            'code' => $user->getBusinessKey(),
            'first_name' => $employee['first_name'],
            'surname' => $employee['last_name'],
            'email' => $user->email,
            'date_of_birth' => $employee['date_of_birth'],
            'start_date' => $employee['start_date'],
            'job_title' => $employment ? $employment['job_title'] : null,
            'employment_type' => $employmentType,
            'external_avatar_url' => $employee['avatar'],
            'gender_id' => $this->getSegmentId(
                SegmentTypes::GENDER, IntegrationHelper::convertGenderSegment($employee['gender']), $client->getKey()
            ),
            'department_id' => $this->getSegmentId(
                SegmentTypes::DEPARTMENT, $employee['team']['name'] ?? null, $client->getKey()
            ),
        ];

        $createdEmployee = app(UpdateEmployee::class)->execute($employeeData);

        return $createdEmployee;
    }

    function getSegmentId($segmentType, $name, $clientId)
    {
        if (!empty($name)) {
            $segment = SegmentHelper::firstOrCreateSegment($segmentType, $name, $clientId);

            return $segment->getKey();
        }

        return null;
    }
}
