<?php

namespace App\Services\Library;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Models\Library\DocumentProfile;
use App\Services\BaseService;

class CreateDocumentProfile extends BaseService implements Validatable, Performable
{
    public function getRules(array $args): array
    {
        return [
            'name' => 'required|string',
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Create document profile
     *
     * @param array $args
     * @return DocumentProfile
     */
    function performAction(array $args): DocumentProfile
    {
        $client = Context::client()->get();
        $user = Context::user()->get();

        $args['client_id'] = $client->id;
        $args['created_by'] = $user->id;
        $documentProfile = new DocumentProfile($args);
        $documentProfile->save();

        return $documentProfile->refresh();
    }
}
