<?php


namespace App\Services\Library;

use App\Contracts\Performable;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Models\Library\DocumentProfile;
use App\Models\Library\LibraryItem;
use App\Services\BaseService;

class DeleteDocumentProfile extends BaseService implements Performable
{
    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Delete document profile
     *
     * @param array $args
     * @return bool
     */
    public function performAction(array $args): bool
    {
        $documentProfile = DocumentProfile::findOrFail($args['id']);
        PermissionHelper::hasAccessOn($documentProfile);
        $li = LibraryItem::where('document_profile_id', $documentProfile->id)->first();
        if ($li != null) {
            throw new InvalidRequestException("Document profile is being used.", ErrorCode::DELETE_NOT_ALLOWED);
        }
        $documentProfile->delete();
        return true;
    }
}
