<?php


namespace App\Services\Library;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Models\Library\DocumentProfile;
use App\Services\BaseService;
use Illuminate\Support\Arr;

class UpdateDocumentProfile extends BaseService implements Validatable, Performable
{
    public function getRules(array $args): array
    {
        return [
            'id' => 'required',
            'name' => 'required|string',
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Update document profile
     * 
     * @param array $args
     * @return DocumentProfile
     */
    public function performAction(array $args): DocumentProfile
    {
        $user = Context::user()->get();

        $documentProfile = DocumentProfile::findOrFail($args['id']);
        PermissionHelper::hasAccessOn($documentProfile);

        //If user don't have permission to create all, exclude client_id
        if (!$user->isSuperAdmin() && isset($args['client_id'])) {
            $args = Arr::except($args, ['client_id']);
        }
      
        $documentProfile->update($args);
        return $documentProfile->refresh();
    }    
}
