<?php


namespace App\Services\Message;

use App\Enum\AccessPermissions;
use App\Enum\ConversationTypes;
use App\Enum\EmailNotifications;
use App\Enum\NotificationTypes;
use App\Enum\QualeeStatus;
use App\Enum\Roles;
use App\Events\MessagePosted;
use App\Http\Resources\Message\MessageBroadcast as MessageResource;
use App\Jobs\SendNotification;
use App\Jobs\SendNotificationEmail;
use App\Services\BaseService;
use App\Services\UserAccess\GetAccessByRole;
use Illuminate\Support\Facades\Auth;

/**
 * Class BroadcastMessage
 * @package App\Services\Message
 */
class BroadcastMessage extends BaseService
{
    /**
     * @param array $data
     */
    public function performAction(array $data)
    {
        $message = $data['message'];
        $conversation = $message->conversation;
        if ($conversation->type !== ConversationTypes::NOTIFY_MESSAGE) {
            $message->is_first_message = $conversation->messages()->where('sender_id', $message->sender_id)->count() === 1;
            $message->is_broadcast_message = true;
            $receivers = $conversation->users()
                ->wherePivot('status', QualeeStatus::ACTIVE)
                ->where('id', '!=', $message->sender_id)->get();
            foreach ($receivers as $receiver) {
                $message->receiverId = $receiver->id;
                $messageResourceWeb = (new MessageResource($message))->resolve();
                $arguments = array(
                    "userIds" => $receiver->code,
                    "headings" => __("You've got a message"),
                    "contents" => __('notify.new_message', ['name' => $message->isDisplayUser($receiver->id) ? $message->sender->fullName : 'Anonymous']),
                    "data" => [
                        "type" => NotificationTypes::MESSAGE_RECEIVED,
                        "conversation_id" => $conversation->id
                    ],
                    'send_after' => null
                );
                SendNotification::dispatch($arguments);
                broadcast(new MessagePosted($messageResourceWeb, $receiver->code))->toOthers();
            }


            // Send Invite Notifications to employees
            $employeeAccess = app(GetAccessByRole::class)->execute(['role' => Roles::FRONT_USER]);
            $accessEmployeePermissions = $employeeAccess[AccessPermissions::ACCESS_GROUP_NOTIFICATIONS];

            $owner = $message->sender;
            if ($accessEmployeePermissions[AccessPermissions::NOTIFICATION_EMAIL_MENTION]) {
                foreach ($receivers as $iuser) {
                    SendNotificationEmail::dispatch($iuser, EmailNotifications::MESSAGE, ['owner' => $owner->surname . ', ' . $owner->first_name]);
                }
            }
        }
    }
}