<?php


namespace App\Services\Message;


use App\Contracts\Validatable;
use App\Enum\AccessPermissions;
use App\Enum\ConversationTypes;
use App\Enum\ErrorCode;
use App\Exceptions\NotFoundHttpException;
use App\Exceptions\UnauthorizedHttpException;
use App\Facades\Context;
use App\Helpers\UserAccessHelper;
use App\Models\Message\Conversation;
use App\Models\User\User;
use App\Models\User\UserPermission;
use App\Services\BaseService;

class CheckPermissionUserOnConversation extends BaseService implements Validatable
{
    public function getRules($data): array
    {
        return [
            'conversation_id' => 'required|string'
        ];
    }

    public function performAction(array $data)
    {
        $conversation = Conversation::query()
            ->find($data['conversation_id']);
        if (!$conversation) {
            throw new NotFoundHttpException('The conversation has been deleted', ErrorCode::CONVERSATION_NOT_FOUND);
        }

        if ($conversation->type === ConversationTypes::NOTIFY_MESSAGE &&
            !UserAccessHelper::hasAccess(AccessPermissions::SEND_SEGMENT_NOTIFICATION)) {
            throw new UnauthorizedHttpException();
        }

        if (!app(IsUserBelongToConversation::class)->execute($conversation)) {
            if (empty($data['isMaster'])) {
                throw new NotFoundHttpException('The conversation not found', ErrorCode::CONVERSATION_NOT_FOUND);
            }
        }

        return $conversation;
    }
}