<?php


namespace App\Services\Message;

use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Models\Message\Message;
use App\Services\Attachment\DeleteAttachment;
use App\Services\BaseService;

class ClearAnonymousMessage extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args): array
    {
        return [
            'id' => 'required|string',
        ];
    }

    /**
     * Mark conversation as read
     *
     * @param array $data
     * @return Message
     */
    public function performAction(array $data)
    {
        $conversation = app(CheckPermissionUserOnConversation::class)->execute(['conversation_id' => $data['id']]);
        if($conversation->is_anonymous === 1){
            $attachments = $conversation->messages->pluck('attachment')->unique()->filter(function ($value, $key){
                return !!$value;
            });
            $attachments->each(function($item, $key){
                app(DeleteAttachment::class)->execute($item);
            });
            $conversation->messages()->delete();
            $conversation->users()->detach();
            $conversation->delete();
        }else{
            throw new InvalidRequestException('Your request is invalid.', ErrorCode::INVALID_VERIFICATION_REQUEST);
        }

    }
}
