<?php


namespace App\Services\Message;


use App\Contracts\Validatable;
use App\Enum\ConversationStatues;
use App\Facades\Context;
use App\Models\Message\AnonymousConversationStatusLog;
use App\Services\BaseService;
use Illuminate\Validation\Rule;

/**
 * Class CreateAnonymousConversationStatusLogs
 * @package App\Services\Message
 */
class CreateAnonymousConversationStatusLogs extends BaseService implements Validatable
{
    /**
     * @param  array  $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'conversation_id' => 'required|string',
            'status'          => ['required', Rule::in([ConversationStatues::ACTIVE, ConversationStatues::CLOSE, ConversationStatues::ESCALATED, ConversationStatues::RESOLVING, ConversationStatues::REVIEWING])]
        ];
    }

    /**
     * Create anonymous conversation status log
     * @param  array  $args
     */
    public function performAction(array $args)
    {
        $currentUser = Context::user()->get();
        return AnonymousConversationStatusLog::create([
            'conversation_id' => $args['conversation_id'],
            'status'          => $args['status'],
            'created_by'      => $currentUser->id
        ]);
    }
}