<?php


namespace App\Services\Message;


use App\Enum\MessageableTypes;
use App\Facades\Context;
use App\Models\Message\Conversation;
use App\Models\User\User;
use App\Services\BaseService;

/**
 * Class CreateBasicConversation
 * @package App\Services\Message
 */
class CreateBasicConversation extends BaseService
{
    /**
     * @param array $data
     * @return mixed
     */
    public function performAction(array $data)
    {
        $currentUser = Context::user()->get();
        $receiver = User::where('code', $data['receiver_code'])->whereHas('employee', function ($query) {
            $query->where('client_id', Context::client()->get()->getKey());
        })->firstOrFail();
        $receiverId = $receiver->getKey();
        $userIds = collect([$currentUser->id, $receiverId])->unique()->toArray();
        $conversation = Conversation::where('type', $data['type'])->whereHas('users', function ($q) use ($userIds) {
            $q->whereIn('messageable_id', $userIds)
                ->groupBy('conversation_id')
                ->havingRaw('COUNT(DISTINCT messageable_id) = ' . count($userIds));
        })->get()->first();

        if (!$conversation) {
            $conversation = app(CreateRawConversation::class)->execute($data);
            $conversation->users()->attach($userIds, ['type' => MessageableTypes::USER]);
        }
        $conversation = app(MapReceiverInfoToJourney::class)->execute(collect([$conversation]))->first();
        return $conversation;
    }
}