<?php


namespace App\Services\Message;

use App\Enum\ConversationTypes;
use App\Facades\Context;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Models\Questionnaire\QuestionnaireDiscussionAnswer;
use App\Services\BaseService;
use App\Enum\MessageableTypes;
use App\Models\Message\Conversation;
use App\Models\User\User;
/**
 * Class CreateCommentDiscussion
 * @package App\Services\Message
 */
class CreateCommentDiscussion extends BaseService
{
    /**
     * @param array $args
     * @return mixed
     */
    public function performAction(array $args)
    {
        $currentUser = Context::user()->get();
        $receiver = User::where('code', $args['receiver_code'])->whereHas('employee', function ($query) {
            $query->where('client_id', Context::client()->get()->getKey());
        })->firstOrFail();
        $receiverId = $receiver->getKey();
        $userIds = collect([$currentUser->id, $receiverId])->unique()->toArray();
        $conversation = Conversation::where(['type' => $args['type'], 'comment_id' => $args['comment_id']])
            ->whereHas('users', function ($q) use ($userIds) {
            $q->whereIn('messageable_id', $userIds)
                ->groupBy('conversation_id')
                ->havingRaw('COUNT(DISTINCT messageable_id) = ' . count($userIds));
        })->get()->first();

        if (!$conversation) {
            $conversation = app(CreateRawConversation::class)->execute($args);
            $conversation->users()->attach($userIds, ['type' => MessageableTypes::USER]);
        }
        $conversation = app(MapReceiverInfoToJourney::class)->execute(collect([$conversation]))->first();

        return $conversation;
    }
}