<?php


namespace App\Services\Message;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\AllowedFileSizes;
use App\Enum\AllowedFileTypes;
use App\Enum\ConversationStatues;
use App\Enum\ConversationTypes;
use App\Enum\ErrorCode;
use App\Enum\PlanConfigurations;
use App\Events\OCRDocumentUploaded;
use App\Exceptions\InvalidRequestException;
use App\Exceptions\NotFoundHttpException;
use App\Facades\Context;
use App\Models\Message\Message;
use App\Services\BaseService;
use App\Services\Attachment\CreateAttachment;
use App\Helpers\ResourceLocationBuilder;
use App\Enum\MessageType;
use App\Models\Message\CommentNote;
use App\Services\Subscription\CheckRemainPlanAction;

class CreateCommentNote extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($data)
    {
        return [
            'content' => 'required|string',
            'comment_id' => 'required',
        ];
    }

    /**
     * Create message
     *
     * @param array $data
     * @return CommentNote
     */
    public function performAction(array $data): CommentNote
    {
        $currentUserId = Context::user()->get()->getKey();

        $note = new CommentNote();
        $note->sender_id = $data['sender_id'] ?? $currentUserId;
        $note->content = $data['content'] ?? '';
        $note->comment_id = $data['comment_id'];
        
        $note->save();

        return $note->refresh();
    }
}
