<?php


namespace App\Services\Message;


use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\AccessPermissions;
use App\Enum\ConversationTypes;
use App\Exceptions\UnauthorizedHttpException;
use App\Facades\Context;
use App\Helpers\UserAccessHelper;
use App\Services\BaseService;
use Illuminate\Support\Arr;
use Illuminate\Validation\Rule;

class CreateConversationAdmin extends BaseService implements Validatable, Performable
{
    /**
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'type' => ['required', Rule::in([ConversationTypes::DIRECT_MESSAGE, ConversationTypes::NOTIFY_MESSAGE])]
        ];
    }

    /**
     * @return bool
     */
    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * @param array $args
     */
    public function performAction(array $args)
    {
        if (!UserAccessHelper::hasAccess(AccessPermissions::SEND_SEGMENT_NOTIFICATION) &&
            $args['type'] === ConversationTypes::NOTIFY_MESSAGE) {
            throw new UnauthorizedHttpException();
        }

        $args['force_create'] = false;
        return app(CreateConversation::class)->execute($args);
    }
}