<?php


namespace App\Services\Message;


use App\Enum\ConversationTypes;
use App\Enum\MessageableTypes;
use App\Enum\SegmentTypes;
use App\Facades\Context;
use App\Helpers\SegmentHelper;
use App\Models\Message\Conversation;
use App\Models\Segment\SegmentType;
use App\Services\BaseService;

/**
 * Class CreateNotifyConversation
 * @package App\Services\Message
 */
class CreateNotifyConversation extends BaseService
{
    /**
     * @param array $data
     * @return \Illuminate\Database\Eloquent\Builder|\Illuminate\Database\Eloquent\Model|object
     */
    public function performAction(array $data)
    {
        $currentUser = Context::user()->get();
        $segmentTypes = SegmentType::findByBusinessKey($data['segment_type_code']);
        $receiver = SegmentHelper::getModelSegmentBySegmentType($segmentTypes, $data['receiver_code']);
        $receiverId = $receiver->getKey();
        $segmentIds = [$receiverId];
        $userIds = [$currentUser->id];
        $relationshipConversationSegment = 'basicSegments';
        switch ($segmentTypes->getKey()) {
            case SegmentTypes::MANAGER:
                $relationshipConversationSegment = 'managerSegments';
                break;
            case SegmentTypes::EMPLOYMENT:
                $relationshipConversationSegment = 'employmentPhaseSegments';
                break;
            case SegmentTypes::AGE:
                $relationshipConversationSegment = 'ageSegments';
                break;
        }
        $conversation = $this->getExistConversationNotifyType($segmentIds, $relationshipConversationSegment);
        if (!$conversation) {
            $conversation = app(CreateRawConversation::class)->execute($data);
            $conversation->{$relationshipConversationSegment}()->attach($segmentIds, ['type' => MessageableTypes::SEGMENT]);
            $conversation->users()->attach($userIds, ['type' => MessageableTypes::USER]);
        }

        return $conversation->refresh();
    }

    /**
     * @param $segmentIds
     * @param $relationshipConversationSegment
     * @return \Illuminate\Database\Eloquent\Builder|\Illuminate\Database\Eloquent\Model|object|null
     */
    public function getExistConversationNotifyType($segmentIds, $relationshipConversationSegment)
    {
        $currentUser = Context::user()->get();
        $userIds = [$currentUser->id];
        $conversationQuery = Conversation::query()
            ->where('type', ConversationTypes::NOTIFY_MESSAGE)
            ->where('owner_id', $currentUser->id)
            ->whereHas('users', function ($q) use ($userIds) {
                $q->whereIn('messageable_id', $userIds)
                    ->groupBy('conversation_id')
                    ->havingRaw('COUNT(DISTINCT messageable_id) = ' . count($userIds));
            });

        $conversationQuery->whereHas($relationshipConversationSegment, function ($q) use ($segmentIds) {
            $q->whereIn('messageable_id', $segmentIds)
                ->groupBy('conversation_id')
                ->havingRaw('COUNT(DISTINCT messageable_id) = ' . count($segmentIds));
        });

        return $conversationQuery->first();
    }

}