<?php


namespace App\Services\Message;


use App\Enum\ConversationTypes;
use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Enum\QualeeStatus;
use App\Facades\Context;
use App\Jobs\IndexPowerSearch;
use App\Models\Message\Conversation;
use App\Services\BaseService;

/**
 * Class CreateRawConversation
 * @package App\Services\Message
 */
class CreateRawConversation extends BaseService
{
    /**
     * @param array $args
     * @return Conversation
     */
    public function performAction(array $args)
    {
        $client = Context::client()->get();
        $conversation = new Conversation();
        $conversation->owner_id = Context::user()->get()->id;
        $conversation->status = QualeeStatus::ACTIVE;
        if ($args['type'] === ConversationTypes::ANONYMOUS_MESSAGE) {
            $conversation->order = Conversation::where('type', ConversationTypes::ANONYMOUS_MESSAGE)
                    ->where('client_id', Context::client()->get()->getKey())->count() + 1;
            $conversation->anonymous_id = $this->generateConversationAnonymousId($client->name);
        }
        if (isset($args['comment_id'])) {
            $conversation->comment_id = $args['comment_id'];
        }
        $conversation->type = $args['type'];
        $conversation->client_id = $client->getKey();
        $conversation->save();
        $conversation->refresh();
        if ($args['type'] === ConversationTypes::ANONYMOUS_MESSAGE) {
            IndexPowerSearch::dispatch($conversation->id,PowerSearchTypes::CASE_ID, PowerSearchActions::ADD, $client->id);
        }

        return $conversation;
    }

    public function generateConversationAnonymousId($prefix)
    {
        $suffix = 'WB';
        $firstThreePrefixLetter = strtoupper(substr($prefix, 0, 3));
        $time = 0;
        do {
            $randomNumbers = sprintf("%05d", random_int(0, 99999));
            $anonymousId = $firstThreePrefixLetter . $randomNumbers . $suffix;
            $isExistAnonymousId = Conversation::firstWhere('anonymous_id', $anonymousId);
            $anonymousId = $isExistAnonymousId ? null : $anonymousId;
            $time++;
        } while ($isExistAnonymousId && $time <= 10);

        return $anonymousId;
    }
}