<?php


namespace App\Services\Message;


use App\Contracts\Validatable;
use App\Enum\ConversationTypes;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Models\Questionnaire\QuestionnaireDiscussionAnswer;
use App\Services\BaseService;

/**
 * Class CreateSensitiveCommentDiscussion
 * @package App\Services\Message
 */
class CreateSensitiveCommentDiscussion extends BaseService implements Validatable
{
    /**
     * @param array $args
     * @return array|string[]
     */
    public function getRules(array $args): array
    {
        return [
            'id' => 'required'
        ];
    }

    /**
     * @param array $args
     * @return mixed
     */
    public function performAction(array $args)
    {
        $questionnaireAnswer = QuestionnaireAnswer::findOrFail($args['id']);
        if (!$questionnaireAnswer->is_sensitive) {
            throw new InvalidRequestException('Comment must be sensitive.');
        }
        if (!$questionnaireAnswer->questionnaireDiscussionAnswer || !$questionnaireAnswer->questionnaireDiscussionAnswer->conversation) {
            $conversation = $this->createConversation($questionnaireAnswer);
        }else{
            $users = $questionnaireAnswer->questionnaireDiscussionAnswer->conversation->users->pluck('code')->toArray();
            if (in_array(Context::user()->get()->getBusinessKey(), $users)) {
                $conversation = $questionnaireAnswer->questionnaireDiscussionAnswer->conversation;
                if (empty($conversation->comment_id)) {
                    $conversation->save();
                }
            } else {
                $conversation = $this->createConversation($questionnaireAnswer);
            }
        }
        return $conversation;
    }

    function createConversation($questionnaireAnswer)
    {
        $conversationData = [
            'type'          => ConversationTypes::ANONYMOUS_MESSAGE,
            'force_create'  => true,
            'users' => [
                'public_user' => Context::user()->get()->getBusinessKey(),
                'anonymous_user' => $questionnaireAnswer->user->code
            ],
            'comment_id'  => $questionnaireAnswer->id
        ];
        $conversation = app(CreateAnonymousConversation::class)->execute($conversationData);
        QuestionnaireDiscussionAnswer::create([
            'user_id'                 => Context::user()->get()->getKey(),
            'questionnaire_answer_id' => $questionnaireAnswer->getKey(),
            'conversation_id'            => $conversation->getKey()
        ]);
        return $conversation;
    }
}