<?php


namespace App\Services\Message;


use App\Contracts\Validatable;
use App\Enum\ConversationTypes;
use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Facades\Context;
use App\Jobs\IndexPowerSearch;
use App\Models\Message\Conversation;
use App\Models\Message\Message;
use App\Services\BaseService;
use Carbon\Carbon;

class DeleteConversation extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args): array
    {
        return [
            'id' => 'required|string',
        ];
    }

    /**
     * Mark conversation as read
     *
     * @param array $data
     * @return Message
     */
    public function performAction(array $data)
    {
        $userId = Context::user()->get()->getKey();
        $conversation = Conversation::query()->findOrFail($data['id']);
        if ($conversation->type === ConversationTypes::ANONYMOUS_MESSAGE) {
            IndexPowerSearch::dispatch($conversation->id, PowerSearchTypes::CASE_ID, PowerSearchActions::DELETE, $conversation->client_id);
        }
        $conversation->users()->sync([$userId => ['last_available' => Carbon::now()]], false);
    }
}