<?php


namespace App\Services\Message;

use App\Enum\ConversationTypes;
use App\Enum\PlanConfigurations;
use App\Models\Message\AnonymousConversationStatusLog;
use App\Models\Message\CommentNote;
use App\Models\Message\WhistleblowingTransferLog;
use App\Services\BaseService;
use App\Services\Subscription\CheckRemainPlanAction;
use Carbon\Carbon;
use stdClass;

/**
 * Class GetCommentNote
 * @package App\Services\Message
 */
class GetCommentNote extends BaseService
{
    /**
     *
     */
    protected const MILISECOND_FORMAT = 'Y-m-d\TH:i:s.u+';
    /**
     *
     */
    protected const MILISECOND_FORMAT_MYSQL = 'Y-m-d H:i:s.u';

    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules(): array
    {
        return [
            'comment_id' => 'required'
        ];
    }

    /**
     * @param  array  $data
     * @return stdClass
     */
    public function performAction(array $data)
    {
        $result = new stdClass();

        $queryNotes = CommentNote::query()
            ->where('comment_id', $data['comment_id']);
        $this->applyCustomPagination($queryNotes, $data);
        $queryNotes->orderBy('created_at', 'asc');
        $notes = $queryNotes->with(['sender'])->get();
        return $notes;
    }

    /**
     * @param $query
     * @param $options
     */
    private function applyCustomPagination($query, $options)
    {
        $size = $options['page']['size'] ?? 15;
        $size = $size < 2 ? 2 : $size;
        if (isset($options['page']) && isset($options['page']['time'])) {
            $time = $options['page']['time'];
            $time = (Carbon::createFromFormat(self::MILISECOND_FORMAT, $time))->format(self::MILISECOND_FORMAT_MYSQL);
            $query->where('created_at', '<', $time);
        }
        $query->limit($size);
    }
}
