<?php


namespace App\Services\Message;


use App\Enum\ConversationTypes;
use App\Enum\QualeeStatus;
use App\Enum\Roles;
use App\Facades\Context;
use App\Helpers\DebugHelper;
use App\Models\Message\Conversation;
use App\Services\InternalBaseService;

class IsUserBelongToConversation extends InternalBaseService
{
    public function execute(Conversation $conversation): bool
    {
        $currentUser = Context::user()->get();
        switch ($conversation->type) {
            case ConversationTypes::DIRECT_MESSAGE:
            case ConversationTypes::ANONYMOUS_MESSAGE:
            case ConversationTypes::NOTIFY_MESSAGE_EMPLOYEE:
                return $conversation
                    ->users()
                    ->where('users.id', $currentUser->id)
                    ->wherePivot('status', QualeeStatus::ACTIVE)->exists();
                break;
            case ConversationTypes::NOTIFY_MESSAGE:
                return $conversation->users()->where('users.id',
                        $currentUser->id)->exists() && $currentUser->hasRole(Roles::CLIENT_CONSOLE_ROLES);
                break;
        }
        return false;
    }
}