<?php


namespace App\Services\Message;


use App\Contracts\Validatable;
use App\Enum\ConversationStatues;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Exceptions\NotFoundHttpException;
use App\Facades\Context;
use App\Models\Message\AnonymousConversationCategory;
use App\Services\BaseService;

/**
 * Class ManageWhistleblowingCategoryConversation
 * @package App\Services\Message
 */
class ManageWhistleblowingCategoryConversation extends BaseService implements Validatable
{
    /**
     * @param  array  $args
     * @return string[]
     */
    public function getRules(array $args): array
    {
        return [
            'id' => 'required'
        ];
    }

    /**
     * @param  array  $args
     * @return mixed
     */
    public function performAction(array $args)
    {
        $conversation = app(CheckPermissionOnManageAnonymousConversation::class)->execute(['id' => $args['id']]);
        if($conversation->status === ConversationStatues::CLOSE){
            throw new InvalidRequestException('Can\'t manage category for this conversation', ErrorCode::MESSAGE_ERROR);
        }
        if (!isset($args['categories'])) {
            $args['categories'] = [];
        }
        $categories = AnonymousConversationCategory::whereIn('id', $args['categories'])->get();
        $conversation->anonymousConversationCategories()->sync($categories->pluck('id'));
        return $conversation->fresh();
    }
}