<?php


namespace App\Services\Message;


use App\Enum\ConversationTypes;
use App\Services\InternalBaseService;

class MapReceiverInfoToJourney extends InternalBaseService
{
    public function execute($conversations)
    {
        $conversations->map(function ($item) {
            if ($item->type === ConversationTypes::DIRECT_MESSAGE) {
                $item = $this->mapJourneyIntoConversation($item);
            }
            return $item;
        });
        return $conversations;
    }

    public function mapJourneyIntoConversation($conversation)
    {

        $receiverKey = $conversation->receivers->keys()->first();
        if (!isset($conversation->receivers[$receiverKey])) {
            return $conversation;
        }
        //Only have  one receiver
        $receiverId = $conversation->receivers[$receiverKey]->getKey();
        $journeys = $conversation->receivers[$receiverKey]->journeys()
            ->whereHas('journeyUsers', function ($q) use($receiverId) {
                $q->where('is_completed', 0);
                $q->where('user_id', $receiverId);
            })->get();
        $journeys->load(['steps.actionRequest.submissions']);
        $journeys->map(function ($item) use ($receiverId) {
            $lastSubmission = $item->steps->pluck('actionRequest.submissions')->flatten()
                ->where('user_id', $receiverId)
                ->sortByDesc('created_at')
                ->first();
            if ($lastSubmission) {
                $item->last_step = $item->steps->filter(function ($value) use ($lastSubmission) {
                    return !!$value->actionRequest->submissions && !!$value->actionRequest->submissions->where('id', $lastSubmission->id);
                })->first();
            }
            return $item;
        });
        $conversation->receivers[$receiverKey]->journeys = $journeys;
        return $conversation;
    }
}