<?php


namespace App\Services\Message;


use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Enum\AccessPermissions;
use App\Enum\ConversationStatues;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Models\User\User;
use App\Services\BaseService;

/**
 * Class TransferWhistleblower
 * @package App\Services\Message
 */
class TransferWhistleblower extends BaseService implements Validatable, Transactionable
{
    /**
     * @param  array  $args
     * @return string[]
     */
    public function getRules(array $args): array
    {
        return [
            'id'          => 'required|string',
            'transfer_to' => 'required|string'
        ];
    }

    /**
     * @param  array  $args
     */
    public function performAction(array $args): void
    {
        $currentUser = Context::user()->get();
        $currentClient = Context::client()->get();
        $userTransferTo = User::active()->select(User::getModel()->getTable() . ".*")->where('code',$args['transfer_to'])->firstOrFail();
        $conversation = app(CheckPermissionOnManageAnonymousConversation::class)->execute(['id' => $args['id']]);
        if ($conversation->status === ConversationStatues::CLOSE) {
            throw new InvalidRequestException('Can\'t transfer this conversation', ErrorCode::MESSAGE_ERROR);
        }
        if (!$userTransferTo->can(AccessPermissions::ACCESS_WB_MESSAGE) || $userTransferTo->getClient(
            )->id !== $currentClient->id) {
            throw new InvalidRequestException(
                "Wrong user role",
                ErrorCode::WRONG_USER_ROLE
            );
        }
        if ($currentUser->getKey() === $userTransferTo->getKey()) {
            throw new InvalidRequestException(
                "Current user and user transfer to  must be different",
                ErrorCode::MESSAGE_ERROR
            );
        }
        app(TransferWhistleblowerData::class)->execute(
            [
                'id'            => $conversation->id,
                'transfer_from' => $currentUser->id,
                'transfer_to'   => $userTransferTo->id
            ]
        );
    }
}