<?php


namespace App\Services\Message;


use App\Contracts\Validatable;
use App\Enum\MessageType;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Models\Language\Language;
use App\Models\Message\Message;
use App\Models\Message\MessageTranslation;
use App\Services\BaseService;

class TranslateMessage extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'id'            => 'required|string',
            'language_code' => 'required|exists:languages,code',
            'content'       => 'required|string'
        ];
    }

    public function performAction(array $args)
    {
        $message = Message::findOrFail($args['id']);
        $currentUser = Context::user()->get();
        app(CheckPermissionOnManageAnonymousConversation::class)->execute(['id' => $message->conversation->getKey()]);
        if ($message->sender_id === $currentUser->getKey() || $message->content_type === MessageType::FILE) {
            throw new InvalidRequestException(
                "Something wrong when create message translation",
                ErrorCode::MESSAGE_ERROR
            );
        }
        $language = Language::where('code', $args['language_code'])->first();
        return MessageTranslation::updateOrCreate(
            [
                'message_id'  => $args['id'],
                'language_id' => $language->id,

            ],
            [
                'content' => $args['content']
            ]
        );
    }
}