<?php

namespace App\Services\Mobile\Action;

use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Models\Action\ActionSequenceUser;
use App\Services\BaseService;
use Auth;
use Illuminate\Support\Collection;

class ActionSequencePendingAction extends BaseService implements Validatable, Transactionable
{
    public function getRules(array $args): array
    {
        return [];
    }

    /**
     * ActionSequencePendingAction
     * @return mixed
     */
    public function performAction(array $data)
    {
        $user = Context::user()->get();

        $actionSequencesUs = ActionSequenceUser::where([
            'user_id' => $user->id,
            'is_completed' => 0,
        ])->get();

        $result = [];

        foreach ($actionSequencesUs as $actionSequenceUsItem) {
            $actionSequence = $actionSequenceUsItem->actionSequence()->first();
            if (empty($actionSequence)) continue;

            $steps = app(ActionSequenceStepDetails::class)->execute(['actionSequence' => $actionSequence]);
            $completedStep = $steps->filter(function($step) {
                return $step->is_completed == 1;
            });
            $remainingStep = count($steps) - count($completedStep);

            $result[] = [
                'id' => $actionSequence->id,
                'title' => 'Complete these actions',
                'description' => $remainingStep. ' step'.($remainingStep > 1 ? 's' : '').' to complete',
                'total_steps' => count($steps),
                'remaining_steps' => $remainingStep,
                'action_type' => 'action_sequence'
            ];
        }

        return new Collection($result);
    }
}
