<?php

namespace App\Services\Mobile\Action;

use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Services\BaseService;
use App\Services\Mobile\Journey\GetActiveJourney;
use App\Services\Mobile\Journey\GetStepDetails;
use Auth;
use Illuminate\Support\Collection;

class JourneyPendingAction extends BaseService implements Validatable, Transactionable
{
    public function getRules(array $args): array
    {
        return [];
    }

    /**
     * JourneyPendingAction
     * @return mixed
     */
    public function performAction(array $data)
    {
        // get Journey have is_completed = 0
        $activeJourneys = app(GetActiveJourney::class)->execute($data);

        $journey = array();
        foreach ($activeJourneys as $activeJourney) {
            if(is_null($activeJourney)) continue;

            $steps = app(GetStepDetails::class)->execute(['journey' => $activeJourney]);
            $completedStep = $steps->filter(function($step) {
                return $step->is_completed == 1;
            });
            $remainingStep = count($steps) - count($completedStep);

            $journey[] = [
                'id' => $activeJourney->id,
                'title' => $activeJourney->name,
                'description' => $remainingStep. ' more step'.($remainingStep>1 ? 's' : '').' to complete',
                'total_steps' => count($steps),
                'remaining_steps' => $remainingStep,
                'action_type' => 'journey'
            ];
        }
        return new Collection($journey);
    }
}
