<?php

namespace App\Services\Mobile\Action;

use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Models\Schedule\ScheduleRoundQuestionnaire;
use App\Models\Schedule\ScheduleSurvey;
use App\Services\BaseService;
use App\Services\Mobile\Questionnaire\CompareAnsweredAndRequestAnswerQuestion;
use Auth;
use Illuminate\Support\Collection;

class QuestionnairePendingAction extends BaseService implements Validatable, Transactionable
{
    public function getRules(array $args): array
    {
        return [];
    }

    /**
     * QuestionnairePendingAction
     * @return mixed
     */
    public function performAction(array $data)
    {
        $scheduleRoundQuestionnaireModel = new ScheduleRoundQuestionnaire();

        $user = Context::user()->get();
        $client = $user->client->first();

        if (empty($client)) {
            return [];
        }
        $scheduleSurvey = ScheduleSurvey::active()
            ->client($client->id)
            ->getPendingFrequencyRound()
            ->get();

        $pendingActions = [];
        $actionType = 'questionnaire';
        $title = 'Complete questionnaire';

        foreach ($scheduleSurvey as $item) {
            if (!empty($item->frequencyRounds)) {
                //pending round question info
                $surveyInfo = $scheduleRoundQuestionnaireModel->getFrequencyRoundInfo($item->id, $user->id);

                foreach ($item->frequencyRounds as $round) {
                    // Questions in round
                    $questionIds = !empty($surveyInfo->questionnaire_id) && !empty($surveyInfo->questionnaire_id[$round->id]) ? $surveyInfo->questionnaire_id[$round->id] : [];
                    $valueIds = !empty($surveyInfo->client_value) && !empty($surveyInfo->client_value[$round->id]) ? $surveyInfo->client_value[$round->id] : [];
                    $getUserAnswered = QuestionnaireAnswer::where(['user_id' => $user->id, 'round_id' => $round->id])->get();

                    // Check is completed answer question
                    $isCompleted = app(CompareAnsweredAndRequestAnswerQuestion::class)->execute([
                        'answered' => $getUserAnswered,
                        'questionsSetting' => $questionIds,
                        'valuesSetting' => $valueIds,
                    ]);

                    // Remaining questions
                    $remainingQuestions = count($questionIds) - count($getUserAnswered);

                    if (!$isCompleted && $remainingQuestions > 0) {
                        $pendingActions[] = [
                            'id' => $round->id,
                            'title' => $title,
                            'description' => ($remainingQuestions > 0 ? $remainingQuestions : 0). ' question'.($remainingQuestions > 1 ? 's' : '').' remaining',
                            'total_questions' => count($questionIds),
                            'remaining_questions' => $remainingQuestions,
                            'expire_date' => $round->expire_date,
                            'action_type' => $actionType
                        ];
                    }
                }
            }
        }

        return new Collection($pendingActions);
    }
}
