<?php

namespace App\Services\Mobile\ActionRequestSubmission;

use App\Models\ContentFile\ContentFile;
use App\Models\ContentPhoto\ContentPhoto;
use App\Models\ContentText\ContentText;
use App\Models\Form\FormTemplate;
use App\Models\IDVerification\IDVerification;
use App\Models\Library\LibraryItem;
use App\Models\Quiz\Quiz;
use App\Models\Survey\Survey;
use App\Services\InternalBaseService;
use App\Services\Mobile\ActionRequestSubmission\Submission\SubmitContentFile;
use App\Services\Mobile\ActionRequestSubmission\Submission\SubmitContentPhoto;
use App\Services\Mobile\ActionRequestSubmission\Submission\SubmitContentText;
use App\Services\Mobile\ActionRequestSubmission\Submission\SubmitForm;
use App\Services\Mobile\ActionRequestSubmission\Submission\SubmitIDVerification;
use App\Services\Mobile\ActionRequestSubmission\Submission\SubmitQuiz;
use App\Services\Mobile\ActionRequestSubmission\Submission\SubmitSurvey;
use App\Services\Mobile\ActionRequestSubmission\Submission\SubmitFile;
use Illuminate\Database\Eloquent\Model;

class CreateActionRequestSubmission extends InternalBaseService
{
    public function execute(array $data, Model $actionRequest)
    {
        $contentableType = $actionRequest->contentable_type;
        $data['status'] = null;
        $data['action_request_id'] = $actionRequest->id;

        //Todo: Need check is update or create submission.
        //Todo: Need transaction
        switch ($contentableType) {
            case ContentText::class:
                $result = app(SubmitContentText::class)->execute($data);
                break;
            case Quiz::class:
                $result = app(SubmitQuiz::class)->execute($data);
                break;
            case Survey::class:
                $result = app(SubmitSurvey::class)->execute($data);
                break;
            case LibraryItem::class:
                $result = app(SubmitFile::class)->execute($data);
                break;
            case IDVerification::class:
                $result = app(SubmitIDVerification::class)->execute($data);
                break;
            case ContentPhoto::class:
                $result = app(SubmitContentPhoto::class)->execute($data);
                break;
            case FormTemplate::class:
                $result = app(SubmitForm::class)->execute($data);
                break;
            case ContentFile::class:
                $result = app(SubmitContentFile::class)->execute($data);
                break;
            default:
                $result = null;
        }

        return $result;
    }
}
