<?php

namespace App\Services\Mobile\ActionRequestSubmission\Submission;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\AllowedFileSizes;
use App\Enum\AllowedFileTypes;
use App\Events\OCRDocumentUploaded;
use App\Facades\Context;
use App\Helpers\ResourceLocationBuilder;
use App\Models\ContentFile\ContentFileResult;
use App\Services\Attachment\CreateAttachment;
use App\Services\BaseService;

class SubmitContentFile extends BaseService implements Validatable, Performable
{
    public function getRules($args)
    {
        if (strstr($args['attachment']->getMimeType(), "video/")) {
            return [
                'id' => 'required',
                'attachment' => 'required|mimes:' . AllowedFileTypes::COMMON_FILE . '|max:' . AllowedFileSizes::VIDEO_SIZE
            ];
        }
        return [
            'id' => 'required',
            'attachment' => 'required|mimes:' . AllowedFileTypes::COMMON_FILE . '|max:' . AllowedFileSizes::IMAGE_SIZE
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check() && !Context::client()->get()->is_demo;
    }

    public function performAction(array $data)
    {
        $user = Context::user()->get();
        $data['user_id'] = $user->getKey();

        // Save Submission
        $submissionModel = app(SubmitSubmission::class)->execute($data);
        $data['submission_id'] = $submissionModel->id;

        // Save attachment
        $currentClient = Context::client()->get();
        $contentFilePath = (new ResourceLocationBuilder())
            ->setClient($currentClient->getBusinessKey())
            ->setUser($user->code)
            ->getContentFilePath();
        $attachment = app(CreateAttachment::class)->execute($data['attachment'], $contentFilePath, $user->id);

        // Save Content File Result
        ContentFileResult::updateOrCreate([
            'submission_id' => $submissionModel->id
        ], [
            'submission_id' => $submissionModel->id,
            'attachment_id' => $attachment->id,
        ]);

        event(new OCRDocumentUploaded($attachment));

        return true;
    }
}