<?php

namespace App\Services\Mobile\ActionRequestSubmission\Submission;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\ActionRequestTypes;
use App\Enum\AllowedFileSizes;
use App\Enum\AllowedFileTypes;
use App\Enum\SubmissionStatus;
use App\Facades\Context;
use App\Helpers\ResourceLocationBuilder;
use App\Models\ContentPhoto\ContentPhotoResult;
use App\Services\Attachment\CreateAttachment;
use App\Services\BaseService;

class SubmitContentPhoto extends BaseService implements Validatable, Performable
{
    public function getRules($args)
    {
        return [
            'id' => 'required',
            'attachment' => 'required|mimes:' . AllowedFileTypes::IMAGE . '|max:' . AllowedFileSizes::IMAGE_SIZE
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check() && !Context::client()->get()->is_demo;
    }

    public function performAction(array $data)
    {

        $data['status'] = SubmissionStatus::PENDING;
        $data['user_id'] = Context::user()->get()->getKey();

        //Save Submission
        $submissionModel = app(SubmitSubmission::class)->execute($data);
        $data['submission_id'] = $submissionModel->id;

        //Save attachment
        $user = Context::user()->get();
        $currentClient = Context::client()->get();
        $fileDir = (new ResourceLocationBuilder())
            ->setClient($currentClient->getBusinessKey())
            ->setUser($user->code)
            ->getContentPhotoPath();
        $attachment = app(CreateAttachment::class)->execute($data['attachment'], $fileDir, $user->id);
        $data['attachment_id'] = $attachment->id;

        //Save Content Result
        ContentPhotoResult::updateOrCreate([
            'submission_id' => $submissionModel->id
        ], [
            'submission_id' => $submissionModel->id,
            'attachment_id' => $attachment->id,
            'verify_data' => null,
            'status' => SubmissionStatus::PENDING
        ]);

        return true;
    }
}