<?php

namespace App\Services\Mobile\ActionRequestSubmission\Submission;

use App\Contracts\Validatable;
use App\Facades\Context;
use App\Models\ActionRequest\ActionRequest;
use App\Models\Form\FormResult;
use App\Models\Form\FormSignedDocument;
use App\Services\BaseService;
use App\Jobs\SaveFormDocument;
use App\Services\Tool\Form\GetUserDocument;

class SubmitForm extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'id' => 'required'
        ];
    }

    public function performAction(array $data)
    {
        $currentUser = Context::user()->get();
        $submission =  app(SubmitSubmission::class)->execute($data);

        $formTemplate = ActionRequest::findOrFail($data['id'])->contentable;
        $document = app(GetUserDocument::class)->execute([
            'form_template_id' => $formTemplate->getKey(),
            'user_id' => $currentUser->getKey(),
            'action_request_id' => $data['action_request_id']
        ]);

        if (!empty($document)) {
            // Save form result
            FormResult::updateOrCreate([
                'submission_id' => $submission->getKey()
            ], [
                'submission_id' => $submission->getKey(),
                'form_document_id' => $document->getKey()
            ]);

            $signedDocumentCount = FormSignedDocument::where('document_id', $document->getKey())->count();

            if ($signedDocumentCount == 0) {
                // Trigger save docs to local storage
                SaveFormDocument::dispatch($document);
            }

            return true;
        }

        return false;
    }
}
