<?php

namespace App\Services\Mobile\ActionRequestSubmission\Submission;

use App\Contracts\Validatable;
use App\Enum\ActionRequestTypes;
use App\Enum\AllowedFileSizes;
use App\Enum\AllowedFileTypes;
use App\Enum\VerifiAITypes;
use App\Facades\Context;
use App\Helpers\ResourceLocationBuilder;
use App\Models\IDVerification\IDVerificationResult;
use App\Services\Attachment\CreateAttachment;
use App\Services\BaseService;

class SubmitIDVerification extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'id' => 'required',
            'front_attachment' => 'required|mimes:' . AllowedFileTypes::IMAGE . '|max:' . AllowedFileSizes::IMAGE_SIZE,
            'back_attachment' => 'nullable|mimes:' . AllowedFileTypes::IMAGE . '|max:' . AllowedFileSizes::IMAGE_SIZE,
            'verify_data' => 'required'
        ];
    }

    public function performAction(array $data)
    {
        $currentUser = Context::user()->get();
        
        $verify_data = json_decode($data['verify_data'], true);
        $data['user_id'] =  $currentUser->getKey();

        //Save Submission
        $data['status'] = VerifiAITypes::APPROVED;
        $submissionModel = app(SubmitSubmission::class)->execute($data);
        $data['submission_id'] = $submissionModel->id;

        //Save attachment
        //Todo: Update instead of create and do trick to last record
        $data = $this->saveAttachment($data);

        //Save Content Result
        $data['status'] = $this->getVerifyStatus($verify_data);
        unset($data['front_attachment'], $data['back_attachment'], $data['action_request_id'], $data['user_id']);

        IDVerificationResult::updateOrCreate($data);

        return true;
    }

    /**
     * Get Status of AI Verification
     *
     * @param $verify_data
     * @return bool
     */
    private function getVerifyStatus($verify_data): bool
    {
        //Todo: Alway return true when user submission the AI Verifai
        $objectType = $this->getObjectType($verify_data);
        if ($objectType === VerifiAITypes::DOCUMENT) {
            return true;
        } else {
            return true;
        }
    }

    /**
     * Get type of uploaded object
     *
     * @param $verify_data
     * @return string
     */
    private function getObjectType($verify_data): string
    {
        if (array_key_exists("document", $verify_data)) {
            return VerifiAITypes::DOCUMENT;
        } else {
            return VerifiAITypes::MRZ_DATA;
        }
    }

    /**
     * Save image attachment into asset
     *
     * @param $data
     * @return mixed
     */
    private function saveAttachment($data) {
        $clientCode = Context::client()->get()->getBusinessKey();
        $userCode = Context::user()->get()->getBusinessKey();
        $fileDir = (new ResourceLocationBuilder())->setClient($clientCode)->setUser($userCode)->getUserSubmissionPath(ActionRequestTypes::ID_VERIFICATION);

        $data['front_attachment_id'] = app(CreateAttachment::class)
            ->execute($data['front_attachment'], $fileDir, $data['user_id'])->id;

        if(isset($data['back_attachment'])) {
            $data['back_attachment_id'] = app(CreateAttachment::class)
                ->execute($data['back_attachment'], $fileDir, $data['user_id'])->id;
        } else {
            $data['back_attachment_id'] = null;
        }

        return $data;
    }
}
