<?php

namespace App\Services\Mobile\ActionRequestSubmission\Submission;

use App\Contracts\Validatable;
use App\Enum\QuestionTypes;
use App\Helpers\AwsComprehendHelper;
use App\Models\Survey\SurveyQuestion;
use App\Models\Survey\SurveyResult;
use App\Services\BaseService;

class SubmitSurvey extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'id' => 'required',
            'results' => 'required'
        ];
    }

    /**
     * Submit survey answers
     *
     * @param array $data
     * @return bool
     */
    public function performAction(array $data)
    {
        $submissionModel = app(SubmitSubmission::class)->execute($data);
        $data['submission_id'] = $submissionModel->id;

        foreach ($data['results'] as $k => $value) {
            $value['action_request_id'] = $data['action_request_id'];
            $value['status'] = $data['status'];
            $value['submission_id'] = $data['submission_id'];

            $this->createSurveyResult($value);
        }

        return true;
    }

    /**
     * Save survey answers to db
     *
     * @param $data
     * @return bool
     */
    private function createSurveyResult($data)
    {
        $surveyResult = SurveyResult::updateOrCreate([
            'submission_id' => $data['submission_id'],
            'question_id' => $data['question_id']
        ], [
            'submission_id' => $data['submission_id'],
            'question_id' => $data['question_id']
        ]);
        $resultId = $surveyResult->id;

        $surveyQuestionModel = SurveyQuestion::find($data['question_id']);
        switch ($surveyQuestionModel->type) {
            case QuestionTypes::TYPE_RATING:
                $surveyResult->surveyRatingResult()->updateOrCreate(['survey_result_id' => $resultId],[
                    'survey_result_id' => $surveyResult->id,
                    'rating' => $data['content']
                ]);
                break;
            case QuestionTypes::TYPE_MULTI:
                $options = $data['options'];
                $surveyResult->surveyChoiceResults()->where('survey_result_id', $surveyResult->id)->delete();
                foreach ($options as $option) {
                    $surveyResult->surveyChoiceResults()->create([
                        'survey_result_id' => $surveyResult->id,
                        'option_id' => $option['id']
                    ]);
                }
                break;
            case QuestionTypes::TYPE_TEXT:
                try {
                    $awsComprehendHelper = new AwsComprehendHelper();
                    $detectEntities = $awsComprehendHelper->detechSentiment($data['text']);
                } catch (\Exception $e) {

                }
                $mixed_score = isset($detectEntities) ? $detectEntities['SentimentScore']['Mixed'] : 0;
                $positive_score = isset($detectEntities) ? $detectEntities['SentimentScore']['Positive'] : 0;
                $neutral_score = isset($detectEntities) ? $detectEntities['SentimentScore']['Neutral'] : 0;
                $negative_score = isset($detectEntities) ? $detectEntities['SentimentScore']['Negative'] : 0;
                $sentiment = isset($detectEntities) ? $detectEntities['Sentiment'] : '';
                $surveyResult->surveyTextResult()->updateOrCreate(['survey_result_id' => $resultId],[
                    'survey_result_id' => $surveyResult->id,
                    'text' => $data['text'],
                    'mixed_score' => $mixed_score,
                    'positive_score' => $positive_score,
                    'neutral_score' => $neutral_score,
                    'negative_score' => $negative_score,
                    'sentiment' => $sentiment,
                ]);
                break;
            default:
                $result = null;
        }

        return true;
    }
}
