<?php


namespace App\Services\Mobile\AppRating;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Services\BaseService;
use App\Enum\Platforms;
use App\Models\AppRating\AppRating;
use Illuminate\Validation\Rule;

class SubmitAppRating extends BaseService implements Performable, Validatable
{
    public function getRules($data)
    {
        return [
            'point' => 'required|string',
            'platform' => ['required', Rule::in(Platforms::ALL)]
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check() && !Context::client()->get()->is_demo;
    }

    /**
     *
     *
     * @param $data
     * @return bool
     * @throws \Illuminate\Validation\ValidationException
     */
    public function performAction($data)
    {
        $this->performValidation($data);

        AppRating::create([
                'point' => $data['point'],
                'user_id' => Context::user()->get()->getKey(),
                'client_id' => Context::client()->get()->getKey(),
                'comment' => $data['comment'],
                'platform' => $data['platform']
            ]
        );

        return true;
    }
}
