<?php

namespace App\Services\Mobile\Archive;

use App\Facades\Context;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Models\Schedule\ScheduleRoundQuestionnaire;
use App\Models\Schedule\ScheduleSurvey;
use App\Services\BaseService;
use App\Services\Mobile\Questionnaire\CompareAnsweredAndRequestAnswerQuestion;
use Illuminate\Support\Collection;

class QuestionnaireArchive extends BaseService
{
    /**
     * QuestionnaireArchive
     * @return mixed
     */
    public function performAction(array $data)
    {
        $user = Context::user()->get();

        $result = [];
        //Get questions answered
        $answeredSurvey = QuestionnaireAnswer::where(['user_id' => $user->id])->get()->groupBy('survey_id');
        foreach($answeredSurvey as $surveyId => $surveyAnswers) {
            $survey = ScheduleSurvey::find($surveyId);
            if (empty($survey)) continue;

            $rounds = $surveyAnswers->groupBy('round_id');
            foreach ($rounds as $roundId => $answered) {
                $latestAnswered = $answered->sortByDesc('created_at')->first();

                $userRoundQuestions = ScheduleRoundQuestionnaire::where([
                    'schedule_survey_id' => $surveyId,
                    'user_id' => $user->id
                ])->first();
                $questionsSetting = !empty($userRoundQuestions->questionnaire_id) && !empty($userRoundQuestions->questionnaire_id[$roundId] ) ? $userRoundQuestions->questionnaire_id[$roundId] : [];
                $valuesSetting = !empty($userRoundQuestions->client_value) && !empty($userRoundQuestions->client_value[$roundId] ) ? $userRoundQuestions->client_value[$roundId] : [];
                $isCompleted = app(CompareAnsweredAndRequestAnswerQuestion::class)->execute([
                    'answered' => $answered,
                    'questionsSetting' => $questionsSetting,
                    'valuesSetting' => $valuesSetting,
                ]);

                if ($isCompleted) {
                    $result[] = [
                        'id' => $roundId,
                        'title' => $survey->name,
                        'completed_date' => !empty($latestAnswered) ? $latestAnswered->created_at : null,
                        'action_type' => 'questionnaire'
                    ];
                }
            }
        }
        return new Collection($result);
    }
}
