<?php

namespace App\Services\Mobile\Archive;

use App\Enum\ActionRequestTypes;
use App\Facades\Context;
use App\Models\Action\ActionUser;
use App\Models\ContentFile\ContentFile;
use App\Models\Form\FormTemplate;
use App\Services\BaseService;
use Auth;
use App\Models\IDVerification\IDVerification;
use App\Models\ContentPhoto\ContentPhoto;
use App\Models\Quiz\Quiz;
use App\Models\Survey\Survey;

class SingleActionArchive extends BaseService
{
    /**
     * SingleActionArchive
     * @return mixed
     */
    public function performAction(array $data)
    {
        $user = Context::user()->get();

        $actionsUs = ActionUser::where([
            'user_id' => $user->id,
            'is_completed' => 1,
        ])->get();

        $result = [];
        foreach ($actionsUs as $actionUsItem) {
            $action = $actionUsItem->action()->first();

            if (empty($action)) continue;

            $actionRequest = $action->actionRequest()->first();
            if (empty($actionRequest)) continue;

            switch ($actionRequest->contentable_type) {
                case IDVerification::class:
                    $actionType = ActionRequestTypes::ID_VERIFICATION;
                    $title = 'Verified your ID';
                    break;
                case ContentPhoto::class:
                    $actionType = ActionRequestTypes::HEADSHOT_PHOTO;
                    $title = 'Submitted headshot photo';
                    break;
                case Quiz::class:
                    $actionType = ActionRequestTypes::QUIZ;
                    $title = 'Completed a quiz';
                    break;
                case Survey::class:
                    $actionType = ActionRequestTypes::SURVEY;
                    $title = 'Completed a survey';
                    break;
                case FormTemplate::class:
                    $actionType = ActionRequestTypes::FORM;
                    $title = 'Completed a form';
                    break;
                case ContentFile::class:
                    $actionType = ActionRequestTypes::UPLOAD_CONTENT;
                    $title = 'Uploaded a file';
                    break;
                default:
                    $actionType = '';
                    $title = '';
                    break;
            }
            if (empty($actionType)) continue;

            $result[] = [
                'id' => $actionRequest->id,
                'title' => $title,
                'completed_date' => $actionUsItem->updated_at,
                'action_type' => $actionType
            ];
        }

        return $result;
    }
}
