<?php

namespace App\Services\Mobile\Auth;

use App\Helpers\DebugHelper;
use App\Models\User\Employee;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth as Auth;

class AuthService
{
    const TOKEN_GENERATE_KEY = 'token_key';

    /**
     * Update new Device Id when another phone login
     *
     * @param $userId
     * @param $deviceId
     * @return bool
     */
    public function updateDeviceId($userId, $deviceId)
    {
        Employee::where('user_id', $userId)
            ->update(['device_id' => $deviceId]);

        return true;
    }

    /**
     * Revoke tokens not used
     *
     * @param $currentTokenId
     * @return bool
     */
    public function revokeOldTokens($currentTokenId)
    {
        //Only revoke token from mobile
        $userTokens = Auth::user()->tokens()
            ->where('revoked',false)
            ->where('name', self::TOKEN_GENERATE_KEY)
            ->get();
        foreach ($userTokens as $token) {
            if ($currentTokenId === $token->id) {
                continue;
            }
            $token->revoke();
        }
        return true;
    }

    /**
     * Revoke all tokens
     *
     * @return bool
     */
    public function revokeAllToken()
    {
        //Only revoke token from mobile
        $userTokens = Auth::user()->tokens()
            ->where('revoked',false)
            ->where('name', self::TOKEN_GENERATE_KEY)
            ->get();
        foreach ($userTokens as $token) {
            $token->revoke();
        }

        return true;
    }

    /**
     * Init user token information
     *
     * @param $data
     * @return \Laravel\Passport\PersonalAccessTokenResult
     */
    public function initToken($data)
    {
        $user = Auth::user();
        $tokenResult = $user->createToken(self::TOKEN_GENERATE_KEY);
        $token = $tokenResult->token;
        if ($data['remember_me']) {
            $token->expires_at = Carbon::now()->addMonths(6);
        }
        $token->save();

        $mobileAuthService = new AuthService();
        $mobileAuthService->revokeOldTokens($token->id);

        return $tokenResult;
    }
}
