<?php

namespace App\Services\Mobile\Auth;

use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Models\Mobile\User\PasswordReset;
use App\Services\BaseService;
use App\Traits\MobileJsonResponseController;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Hash;
use Jenssegers\Agent\Agent;

class RedirectBySchemaUrl extends BaseService implements Validatable
{
    use MobileJsonResponseController;

    public function getRules(array $args)
    {
        return [
            'email' => 'required|email',
            'token' => 'required'
        ];
    }

    public function performAction(array $data)
    {
        $agent = new Agent();
        $url = null;

        //Check is token valid
        $reminder = PasswordReset::firstWhere('email', $data['email']);
        if (! $reminder or ! Hash::check($data['token'], $reminder->token)) {
            throw new \App\Exceptions\UnauthorizedHttpException('Invalid token.', ErrorCode::INVALID_CREDENTIALS);
        }

        if ($agent->isDesktop()) {
            $url = url(config('app.front_end_url') . '/password/reset/' . $data['token'] . '?email=' . $data['email']);
        } else {
            $url = config('app.mobile_schema_url') . '://password/reset?token=' . $data['token'] . '&email=' . $data['email'];
        }
        return $url;
    }
}
