<?php

namespace App\Services\Mobile\Auth;

use App\Contracts\Validatable;
use App\Facades\Context;
use App\Models\User\Employee;
use App\Models\User\User;
use App\Services\BaseService;
use App\Traits\MobileJsonResponseController;

class ResetDefaultPassword extends BaseService implements Validatable
{
    use MobileJsonResponseController;

    public function getRules(array $args)
    {
        return [
            'password' => 'required'
        ];
    }

    /**
     * Reset password service
     *
     * @param array $data
     * @return bool
     * @throws ValidationException
     */
    public function performAction(array $data)
    {
        $currentUser = Context::user()->get();
        $user = User::where('email', $currentUser->email)->first();
        $user->password = bcrypt(base64_decode($data['password']));
        $user->save();

        //Reset password at first time login done.
        Employee::where('user_id', $currentUser->getKey())->update(['is_default_password' => 0]);

        return true;
    }
}
