<?php

namespace App\Services\Mobile\Auth;

use App\Contracts\Validatable;
use App\Services\BaseService;
use Illuminate\Auth\Events\PasswordReset;
use App\Traits\MobileJsonResponseController;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Password;
use Illuminate\Support\Str;

class ResetPassword extends BaseService implements Validatable
{
    use MobileJsonResponseController;

    public function getRules(array $args)
    {
        return [
            'token' => 'required',
            'email' => 'required|email',
            'password' => 'required|confirmed|min:8'
        ];
    }

    /**
     * Reset password service
     *
     * @param array $data
     * @return mixed
     */
    public function performAction(array $data)
    {
        return Password::reset($data, function ($user, $password){
            $user->password = Hash::make(base64_decode($password));
            $user->setRememberToken(Str::random(60));
            $user->save();
            event(new PasswordReset($user));
        });
    }
}
