<?php


namespace App\Services\Mobile\Auth;


use App\Contracts\Validatable;
use App\Enum\FilePaths;
use App\Enum\Roles;
use App\Exceptions\UnauthorizedHttpException;
use App\Http\Resources\Mobile\Auth\Login as LoginResource;
use App\Models\Client\Client;
use App\Services\BaseService;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;

class UserDemoLogin extends BaseService implements Validatable
{
    const TOKEN_GENERATE_KEY = 'token_key';
    public function getRules(array $args)
    {
        return [
            'device_id' => 'required'
        ];
    }

    public function performAction(array $args)
    {
        $clientDemo = Client::where('is_demo', true)->firstOrFail();
        $userDemo = $clientDemo->users()->role(Roles::FRONT_USER)->where('is_demo',true)->firstOrFail();
        Auth::login($userDemo);

        $deviceId = $args['device_id'];

        if (session_id() != Auth::user()->last_session) {
            Auth::logout();
            throw new UnauthorizedHttpException();
        }

        $user = Auth::user();
        $userResource = (new LoginResource($user))->resolve();

        $userResource['resource_urls'] = [];

        // Language Polish
        $polish = [
            'langKey' => 'pl',
        ];
        if (file_exists(public_path(FilePaths::TERM_AND_CONDITIONAL_PATH) . "MobileAppTermsofUse_pl.pdf")) {
            $polish['tnc_url'] = config('app.back_end_url')  . FilePaths::TERM_AND_CONDITIONAL_PATH . "MobileAppTermsofUse_pl.pdf";
        }
        if (file_exists(public_path(FilePaths::PRIVACY_PATH) . "Mobile_Privacy_Policy_pl.pdf")) {
            $polish['privacy_url'] = config('app.back_end_url')  . FilePaths::PRIVACY_PATH . "Mobile_Privacy_Policy_pl.pdf";
        }
        $userResource['resource_urls'][] = $polish;
        // End

        if (file_exists(public_path(FilePaths::TERM_AND_CONDITIONAL_PATH) . "MobileAppTermsofUse.pdf")) {
            $userResource['tnc_url'] = config('app.back_end_url')  . FilePaths::TERM_AND_CONDITIONAL_PATH . "MobileAppTermsofUse.pdf";
        } else {
            $userResource['tnc_url'] = null;
        }

        if (file_exists(public_path(FilePaths::PRIVACY_PATH) . "Mobile_Privacy_Policy.pdf")) {
            $userResource['privacy_url'] = config('app.back_end_url')  . FilePaths::PRIVACY_PATH . "Mobile_Privacy_Policy.pdf";
        } else {
            $userResource['privacy_url'] = null;
        }

        //Add token to response
        $userResource['authorization'] = "Bearer " . $this->getToken($args, $user->id, $deviceId);

        return $userResource;
    }
    private function getToken()
    {
        $user = Auth::user();

        $tokenResult = $user->createToken(self::TOKEN_GENERATE_KEY);

        $token = $tokenResult->token;

        $token->expires_at = Carbon::now()->addMonths(1);

        $token->save();

        return $tokenResult->accessToken;
    }
}