<?php

namespace App\Services\Mobile\Auth;

use App\Contracts\Validatable;
use App\Enum\FilePaths;
use App\Exceptions\UnauthorizedHttpException;
use App\Http\Resources\Mobile\Auth\Login as LoginResource;
use App\Services\BaseService;
use Carbon\Carbon;
use Illuminate\Http\JsonResponse;
use Illuminate\Support\Facades\Auth as Auth;

class UserLogin extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'device_id' => 'required',
            'remember_me' => 'required|boolean'
        ];
    }

    /**
     * User login service
     *
     * @param array $data
     * @return array|JsonResponse
     */
    public function performAction(array $data)
    {
        $deviceId = $data['device_id'];

        if (session_id() != Auth::user()->last_session) {
            Auth::logout();
            throw new UnauthorizedHttpException();
        }

        $user = Auth::user();
        $user->last_login = Carbon::now();
        $user->save();
        $userResource = (new LoginResource($user))->resolve();

        $userResource['resource_urls'] = [];

        // Language Polish
        $polish = [
            'langKey' => 'pl',
        ];
        if (file_exists(public_path(FilePaths::TERM_AND_CONDITIONAL_PATH) . "MobileAppTermsofUse_pl.pdf")) {
            $polish['tnc_url'] = config('app.back_end_url')  . FilePaths::TERM_AND_CONDITIONAL_PATH . "MobileAppTermsofUse_pl.pdf";
        }
        if (file_exists(public_path(FilePaths::PRIVACY_PATH) . "Mobile_Privacy_Policy_pl.pdf")) {
            $polish['privacy_url'] = config('app.back_end_url')  . FilePaths::PRIVACY_PATH . "Mobile_Privacy_Policy_pl.pdf";
        }
        $userResource['resource_urls'][] = $polish;
        // End

        if (file_exists(public_path(FilePaths::TERM_AND_CONDITIONAL_PATH) . "MobileAppTermsofUse.pdf")) {
            $userResource['tnc_url'] = config('app.back_end_url')  . FilePaths::TERM_AND_CONDITIONAL_PATH . "MobileAppTermsofUse.pdf";
        } else {
            $userResource['tnc_url'] = null;
        }

        if (file_exists(public_path(FilePaths::PRIVACY_PATH) . "Mobile_Privacy_Policy.pdf")) {
            $userResource['privacy_url'] = config('app.back_end_url')  . FilePaths::PRIVACY_PATH . "Mobile_Privacy_Policy.pdf";
        } else {
            $userResource['privacy_url'] = null;
        }
        //Add token to response
        $userResource['authorization'] = "Bearer " . $this->getToken($data, $user->id, $deviceId);

        return $userResource;
    }

    private function getToken($data, $userId, $deviceId)
    {
        $authService = new AuthService();
        $authService->updateDeviceId($userId, $deviceId);
        $token = $authService->initToken($data);

        return $token->accessToken;
    }
}
