<?php

namespace App\Services\Mobile\Dashboard;

use App\Facades\Context;
use App\Helpers\DateHelper;
use App\Models\User\User;
use App\Services\BaseService;
use Carbon\Carbon;
use App\Services\Mobile\Setting\GetProfile;

class GetUserInfo  extends BaseService
{

    /**
     * Get list event
     *
     * @param array $args
     * @return mixed
     */
    public function performAction(array $args)
    {
        $user = Context::user()->get();
        
        return [
            'user_info' => app(GetProfile::class)->execute(),
            'company_name' => $user->getClient()->name,
            'days' => $this->getDayDiff($user)
        ];
    }

    /**
     * The notification message that displayed into dashboard
     *
     * @param User $user
     * @return int
     */
    public function getDayDiff(User $user): int
    {
        $currentDate = $employeeStartDate = DateHelper::format(Carbon::now());
        if($user->employee->start_date) {
            $startDateTime = Carbon::instance($user->employee->start_date)->hour(0)->minute(0)->second(0);
            $employeeStartDate = DateHelper::format($startDateTime);
        }

        $diffInDays = Carbon::parse($currentDate)->diffInDays($employeeStartDate, false);
        if($diffInDays == 0) {
            return $currentDate < $employeeStartDate ? 1 : 0;
        }

        return $diffInDays;
    }
}
