<?php

namespace App\Services\Mobile\Dashboard;

use App\Contracts\Validatable;
use App\Services\BaseService;
use Carbon\Carbon;
use App\Models\Questionnaire\Questionnaire;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Enum\QuestionnaireEnum;
use Illuminate\Support\Facades\DB;
use App\Models\Schedule\ScheduleSurvey;
use App\Models\Schedule\ScheduleFrequencyRound;

class ProgressOverTime extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [];
    }

    /**
     *
     * Represents the total percentage of Promoters minus the total percentage of Detractors
     *
     * @param array $args
     * @return mixed
     */
    public function performAction(array $args)
    {
        return $this->getProgressOverTime();
    }

    /**
     * calculation scoring average for eNPS
     * @param array $options
     */
    public function getProgressOverTime()
    {

        $start_date = Carbon::now()->addMonth(-24)->toDateString();
        $end_date = Carbon::now()->toDateString();

        $query = Questionnaire::query();
        $query->select(['questionnaire_id','weight',
            DB::raw("((SELECT 
                COUNT(point)
            FROM
                questionnaire_answers
            WHERE 
                point >= ".QuestionnaireEnum::PROMOTER['min']." AND point <= ".QuestionnaireEnum::PROMOTER['max'].
                " AND questionnaire_answers.driver_id = drivers.id)/count(*))*100 promoters"),

            DB::raw("((SELECT 
                COUNT(point)
            FROM
                questionnaire_answers
            WHERE
                point >= ".QuestionnaireEnum::PASSIVE['min']." AND point <= ".QuestionnaireEnum::PASSIVE['max'].
                " AND questionnaire_answers.driver_id = drivers.id)/count(*))*100 passive"),

            DB::raw("((SELECT 
                COUNT(point)
            FROM
                questionnaire_answers
            WHERE
                point >= ".QuestionnaireEnum::DETRACTOR['min']." AND point <= ".QuestionnaireEnum::DETRACTOR['max'].
                " AND questionnaire_answers.driver_id = drivers.id)/count(*))*100 detractor")])
        ->selectRaw("DATE_FORMAT(questionnaire_answers.created_at, '%Y-%m') month")
        ->selectRaw('sum(point)/count(*) as avg_weight_score')
        ->selectRaw('(sum(point)/count(*)) * drivers.weight as driver_score')
        ->selectRaw('count(questionnaire_id) as total_responses')
        ->selectRaw('sum(point) as weighted_score')
        ->from('questionnaire_answers')
        ->join('drivers','drivers.id','questionnaire_answers.driver_id');

        $query->whereNull('questionnaire_answers.skip_question_id');
        if(isset($start_date) && isset($end_date)){
            $query->where(function($q) use ($start_date, $end_date) {
                return $q->whereDate('questionnaire_answers.created_at', '>=', $start_date)
                    ->whereDate('questionnaire_answers.created_at', '<=', $end_date);
            });
        }
        $query->whereIn('questionnaire_answers.round_id', $this->ensureData());
        $query->groupBy('questionnaire_answers.questionnaire_id','drivers.weight', 'drivers.id', 'questionnaire_answers.created_at');
        $query->orderBy('month');
        
        $enps = $query->get();
        return $enps;
    }

    public function ensureData(array $data = []): array
    {
        $user = \Auth::user();
        $client = $user->client()->first();
        $clientId = !empty($client) ? $client->id : null;
        $data['client_id'] = $clientId;
        //Default publish when create
        $data['status'] = 1;
        $survey = ScheduleSurvey::where($data)->get()->pluck('id')->toArray();
        $rounds = ScheduleFrequencyRound::whereIn('schedule_survey_id', $survey)->get()->pluck('id')->toArray();
        return $rounds;
    }
}
