<?php


namespace App\Services\Mobile\Employee;


use App\Contracts\Validatable;
use App\Enum\Roles;
use App\Facades\Context;
use App\Helpers\FilterFluent;
use App\Helpers\ModelHelper;
use App\Models\User\User;
use App\Services\BaseService;
use App\Traits\Pageable;
use Illuminate\Support\Facades\DB;
use Illuminate\Validation\Rule;
use Illuminate\Validation\ValidationException;
use App\Exceptions\InvalidRequestException;
use App\Enum\ErrorCode;
use App\Enum\AccessPermissions;

class GetEmployees extends BaseService
{
    use Pageable;

    /**
     * @param array $args
     * @return mixed
     * @throws ValidationException
     */
    public function performAction(array $args)
    {
        $options = Context::request()->getOptions();

        $query = User::with('employee')->active();
        $query->select('users.*');

        $client = Context::client()->get();

        $isUsedForStandardMessage = true;

        if (isset($options['filter'])) {
            $filters = array_filter($options['filter'], function ($filter) {
                return $filter['column'] === 'role';
            });
            if (!empty($filters)) {
                if ($filters[0]['value'] === 'whistleblower_admin') {
                    $isUsedForStandardMessage = false;
                }
            }
        }

        $userIds = DB::table(config('permission.table_names.model_has_roles'))
            ->join('roles', 'roles.id', 'role_id')
            ->join('employees', 'employees.user_id', 'model_id')
            ->where('model_type', User::class)
            ->where('employees.client_id', $client->id)
            ->where('roles.name',$isUsedForStandardMessage ? Roles::ADMIN : Roles::WHISTLEBLOWER_ADMIN)
            ->distinct()
            ->pluck('model_id');

        ModelHelper::setConditionFindByEmployee($query, AccessPermissions::ACCESS_GROUP_EMPLOYEE_MESSAGES, $userIds);
        ModelHelper::setConditionFindByClient($query, 'employees');



        FilterFluent::init()
            ->setQuery($query)
            ->setTable('users')
            ->setFilterOptions($options)
            ->setAllowedFilters(['name', 'role'])
            ->validate()
            ->removeFilter(['name', 'role'])
            ->setCustomFilter('name', function($query, $type, $col, $value) {
                FilterFluent::applyCombinedColumnFilter($query, $type, 'users.surname', 'users.first_name', $value);
            })
            ->setCustomFilter('role', function($query, $type, $col, $value) {
                if (!in_array($value, Roles::AVAILABLE_ROLES, true)) {
                    throw new InvalidRequestException('Invalid user role', ErrorCode::WRONG_USER_ROLE);
                }
                $query->role($value);
            })->applyFilter();
        return $this->applyPaging($options, $query);
    }
}