<?php

namespace App\Services\Mobile\Engage;

use App\Facades\Context;
use App\Models\Initiative\Initiative;
use App\Models\Segment\Segment;
use App\Models\Segment\SegmentType;
use App\Enum\SegmentTypes as SegmentTypesEnum;
use App\Services\BaseService;
use App\Http\Resources\Mobile\Engage\Initiative as InitiativeResource;

class GetInitiative extends BaseService
{
    /**
     * Get Initiative
     * @return mixed
     */
    public function performAction(array $data)
    {
        $client = Context::client()->get();
        $user = Context::user()->get();

        $userSegments = $user->segments()->get();
        $userSegmentIds = $userSegments->pluck('id')->toArray();

        $segmentAllId = null;
        $segmentTypeWithCodeALL = SegmentType::where('id', SegmentTypesEnum::ALL)->first();
        if ($segmentTypeWithCodeALL) {
            $segmentALL = $segmentTypeWithCodeALL->segments()->byClient($client->id)->first();
            if (!empty($segmentALL)) {
                $userSegmentIds[] = $segmentALL->id;
            }
        }

        $initiatives = Initiative::whereHas('segments', function($q) use ($userSegmentIds) {
            return $q->whereIn('segment_id', $userSegmentIds);
        })->orderBy('created_at', 'desc')->get()->groupBy('status');

        return [
            'ongoing' => !empty($initiatives[0]) ? InitiativeResource::collection($initiatives[0]) : [],
            'completed' => !empty($initiatives[1]) ? InitiativeResource::collection($initiatives[1]) : []
        ];
    }
}
