<?php

namespace App\Services\Mobile\Event;

use App\Facades\Context;
use App\Helpers\DebugHelper;
use App\Helpers\FilterFluent;
use App\Models\Event\Event;
use App\Services\BaseService;

class GetEvent extends BaseService
{

    /**
     * Get list event
     *
     * @param array $options
     * @return mixed
     */
    public function performAction(array $options)
    {
        $user = Context::user()->get();
        $currentClient = Context::client()->get();
        
        $userEventQuery = $user->userEvent()->publish();
        $userEventQuery = $this->applyDateFilter($userEventQuery, $options);
        $userEventIds = $userEventQuery->pluck('id')->toArray();
        
        // Get all employees invited events
        $allEmployeesSegmentEventQuery = Event::ofClient($currentClient->getKey())->allEmployeesSegment()->publish();
        $allEmployeesSegmentEventQuery = $this->applyDateFilter($allEmployeesSegmentEventQuery, $options);
        $allEmployeesInvitedEventIds = $allEmployeesSegmentEventQuery->pluck('id')->toArray();

        $userEventIds = array_merge($userEventIds, $allEmployeesInvitedEventIds);

        // Get segment events
        if (isset($user->segments) && $user->segments->count() > 0) {
            foreach ($user->segments as $k => $segment) {
                $segmentEventQuery = $segment->events()->publish();
                $segmentEventQuery = $this->applyDateFilter($segmentEventQuery, $options);
                $segmentEventIds = $segmentEventQuery->pluck('id')->toArray();
                $userEventIds = array_merge($userEventIds, $segmentEventIds);
            }
        }

        return Event::findMany(array_unique($userEventIds));
    }
    
    public function applyDateFilter($query, array $options)
    {
        FilterFluent::init()
            ->setQuery($query)
            ->setFilterOptions($options)
            ->setAllowedFilters(['start_date', 'end_date'])
            ->validate()
            ->applyFilter();
        
        return $query;
    }
}
