<?php

namespace App\Services\Mobile\Event;

use App\Contracts\Validatable;
use App\Exceptions\UnauthorizedHttpException;
use App\Facades\Context;
use App\Models\Event\Event;
use App\Services\BaseService;
use App\Traits\Pageable;

class GetEventUsers extends BaseService implements Validatable
{
    use Pageable;

    public function getRules(array $args)
    {
        return [
            'code' => 'required|string'
        ];
    }

    public function performAction(array $args)
    {
        $event = Event::findByBusinessKey($args['code']);
        $currentUser = Context::user()->get();

        if (!$event->invitedUsers()->where("users.id", $currentUser->getKey())->get()) {
            throw new UnauthorizedHttpException();
        }

        $userQuery = $event->invitedUsers();

        $options = Context::request()->getOptions();

        return $this->applyPaging($options, $userQuery->with(['avatar', 'employee.team', 'employee.location']));
    }
}
