<?php


namespace App\Services\Mobile\Journey;


use App\Enum\SubmissionStatus;
use App\Models\ActionRequest\ActionRequest;
use App\Models\ActionRequest\ActionRequestSubmission;
use App\Models\Journey\Journey;
use App\Models\Journey\JourneyStep;
use App\Models\User\User;
use App\Services\InternalBaseService;

class GetJourneyUserCurrentStep extends InternalBaseService
{
    /**
     * @param Journey $journey
     * @param User $user
     * @return ActionRequest|null
     */
    public function execute(Journey $journey, User $user)
    {
        $actionRequestIds = $journey->steps()->with('actionRequest')->get()->pluck('actionRequest.id');

        //Get step rejected
        $submission = ActionRequestSubmission::query()
            ->where('user_id', $user->id)
            ->where('status', SubmissionStatus::REJECTED)
            ->whereIn('action_request_id', $actionRequestIds)->orderBy('id')->first();
        if ($submission) {
            $actionRequestResult = $submission->actionRequest;
        } else {
            $actionRequestResult = ActionRequest::query()
                ->where('actionable_type', JourneyStep::class)
                ->whereNotIn('id', ActionRequestSubmission::query()
                    ->where('user_id', $user->id)
                    ->whereIn('action_request_id', $actionRequestIds)->pluck('action_request_id'))
                ->whereIn('id', $actionRequestIds)
                ->orderBy('id')
                ->with('actionable')
                ->get()
                ->sortBy(function($item) {
                    return $item->actionable->step_order;
                })->first();;
        }
        return $actionRequestResult->actionable;
    }
}