<?php


namespace App\Services\Mobile\Message;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\ConversationTypes;
use App\Facades\Context;
use App\Services\BaseService;
use App\Services\Message\CreateConversation;
use Illuminate\Validation\Rule;

class CreateConversationEmployee extends BaseService implements Validatable, Performable
{
    /**
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'type' => ['required', Rule::in([ConversationTypes::DIRECT_MESSAGE, ConversationTypes::ANONYMOUS_MESSAGE])],
            'receiver_code'=> 'required'
        ];
    }

    /**
     * @return bool
     */
    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * @param array $args
     */
    public function performAction(array $args)
    {
        $args['force_create'] = false;
        if ($args['type'] === ConversationTypes::ANONYMOUS_MESSAGE) {
            $args['users'] = [
                "public_user" => $args['receiver_code'],
                "anonymous_user" => Context::user()->get()->getBusinessKey()
            ];
        }
        return app(CreateConversation::class)->execute($args);
    }
}