<?php


namespace App\Services\Mobile\Message;

use App\Enum\ConversationStatues;
use App\Enum\ConversationTypes;
use App\Enum\MessageableTypes;
use App\Enum\PlanConfigurations;
use App\Enum\QualeeStatus;
use App\Facades\Context;
use App\Models\Message\Conversation;
use App\Models\Message\Message;
use App\Models\User\User;
use App\Services\BaseService;
use App\Services\Subscription\CheckRemainPlanAction;
use App\Traits\Pageable;
use Illuminate\Support\Facades\DB;

class GetConversations extends BaseService
{
    use Pageable;

    /**
     * Get conversations of user
     *
     * @param  array  $data
     */
    public function performAction(array $args)
    {
        $options = Context::request()->getOptions();
        app(CheckRemainPlanAction::class)->execute(PlanConfigurations::PACKAGE_MESSAGE);
        $currentUser = Context::user()->get();
        $queryMessages = Message::select('conversation_id', DB::raw("max(messages.created_at) as message_created_at"))
            ->groupBy('messages.conversation_id');

        $status = $args['status'] ?? ConversationStatues::ACTIVE;

        $query = Conversation::query()
            ->join('messageables', 'conversations.id', '=', 'messageables.conversation_id')
            ->joinSub($queryMessages, 'messages', function ($join) {
                $join->on('conversations.id', 'messages.conversation_id');
                $join->on('messages.message_created_at', '>', 'messageables.last_available');
            })
            ->where('messageables.messageable_id', $currentUser->id)
            ->where('messageables.messageable_type', User::class)
            ->where('messageables.type', MessageableTypes::USER)
            ->where('messageables.status', QualeeStatus::ACTIVE)
            ->where(function ($q) {
                $typeToGet = [ConversationTypes::DIRECT_MESSAGE];
                if (app(CheckRemainPlanAction::class)->execute(
                    PlanConfigurations::PACKAGE_WHISTLEBLOWING_CAPABILITIES,
                    false
                )) {
                    $typeToGet[] = ConversationTypes::ANONYMOUS_MESSAGE;
                }
                return $q->where(function ($subQuery) {
                    return $subQuery->where('conversations.type', '=', ConversationTypes::NOTIFY_MESSAGE_EMPLOYEE)
                        ->where('conversations.owner_id', '!=', Context::user()->get()->getKey());
                })
                    ->orWhereIn('conversations.type', $typeToGet);
            })
            ->select('conversations.*', 'messages.message_created_at')
            ->orderBy('conversations.updated_at', 'DESC');

        if (isset($args['id'])) {
            $query->where('id', $args['id']);
            $query->firstOrFail();
        } else {
            $query->where('conversations.status', $status);
        }

        $query->with(['users', 'owner']);
        $conversations = $this->applyPaging($options, $query);

        return $conversations;
    }
}
