<?php


namespace App\Services\Mobile\QR;


use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Enum\QRTypes;
use App\Enum\QualeeResults;
use App\Events\QRCodeScanned;
use App\Exceptions\UnauthenticatedHttpException;
use App\Facades\Context;
use App\Models\Journey\Journey;
use App\Models\QR\ActionToken;
use App\Services\BaseService;
use App\Services\Mobile\Journey\IsUserBelongsToJourney;
use App\Services\QR\CheckTokenIsValid;
use Illuminate\Validation\Rule;

/**
 * Class ScanQRCode
 * @package App\Services\Mobile\QR
 */
class ScanQRCode extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'token' => 'string|required',
            'type'  => ['required', 'string', Rule::in(QRTypes::TYPES)],
            'action_id'  => 'integer|required'
        ];
    }

    /**
     * @param  array  $args
     */
    public function performAction(array $args)
    {
        $currentUser = Context::user()->get();

        $token = app(CheckTokenIsValid::class)->execute(['token' => $args['token']]);

        switch ($args['type'])
        {
            case QRTypes::JOURNEY:
                $model = Journey::findOrFail($args['action_id']);
                app(IsUserBelongsToJourney::class)->execute($args['action_id']);
                break;
        }
        $token->actionable()->associate($model);
        $token->user()->associate($currentUser);
        $token->type = $args['type'];
        $token->expires_at = now()->addDay(1);
        $token->save();

        broadcast(new QRCodeScanned(QualeeResults::SUCCESS, $args['type'], $model->code, $token->code))->toOthers();
    }

}