<?php

namespace App\Services\Mobile\Questionnaire;


use App\Facades\Context;
use App\Models\Language\Language;
use App\Models\Schedule\ScheduleFrequencyRound;
use App\Services\BaseService;
use App\Models\Questionnaire\Questionnaire;
use App\Models\Client\ClientValue;
use App\Models\Schedule\ScheduleRoundQuestionnaire;
use App\Http\Resources\Mobile\Questionnaire\Questionnaire as QuestionnaireResource;
use Illuminate\Database\Eloquent\Collection;

class GetQuestions extends BaseService
{
    /**
     * Get questions
     * @param array $data
     * @return mixed
     */
    public function performAction(array $data)
    {
        $round_id = $data['round_id'];
        $langCode = $data['language'];
        $user = Context::user()->get();

        $language = Language::where('code', $langCode)->first();
        $round = ScheduleFrequencyRound::findOrFail($round_id);
        $surveyRoundsDetail = ScheduleRoundQuestionnaire::where([
            'schedule_survey_id' => $round->schedule_survey_id,
            'user_id' => $user->id
        ])->first();

        if (empty($surveyRoundsDetail)) {
            return [];
        }

        $questionIds = !empty($surveyRoundsDetail->questionnaire_id[$round_id]) ? $surveyRoundsDetail->questionnaire_id[$round_id] : [];
        $valueIds = !empty($surveyRoundsDetail->client_value[$round_id]) ? $surveyRoundsDetail->client_value[$round_id] : [];

        $questionsInList = Questionnaire::query()->whereIn('questionnaires.id', $questionIds)->active();
        if (!empty($language)) {
            $questionsInList->translateQuestion($language->id);
        }
        $questionsInList = $questionsInList->get();
        $questionsMapping = $questionsInList->mapWithKeys(function ($item) {
            return [$item['id'] => $item];
        });

        $questions = new Collection();
        foreach ($questionIds as $qIndex => $qId) {
            if (!empty($questionsMapping[$qId])) {
                $addingQuestion = clone $questionsMapping[$qId];

                $answerValueId = !empty($valueIds) && !empty($valueIds[$qIndex]) ? $valueIds[$qIndex] : null;
                $answer = $addingQuestion->answer($round_id, $user->id, $answerValueId)->first();

                $addingQuestion->answer_question = $answer;

                if ( !empty($valueIds) && !empty($valueIds[$qIndex])) {
                    $clientValue = ClientValue::find($valueIds[$qIndex]);
                    if (!empty($clientValue)) {
                        $valueTranslate = $clientValue->translate()->where('language_id', $language->id)->first();
                        $clientValue->name = !empty($valueTranslate) && !empty($valueTranslate->name) ? $valueTranslate->name : $clientValue->name;
                        $clientValue->description = !empty($valueTranslate) && !empty($valueTranslate->description) ? $valueTranslate->description : $clientValue->description;

                        $addingQuestion->question_value = $clientValue;
                    }
                }
                $questions->push($addingQuestion);
            }
        }

        return QuestionnaireResource::collection($questions);
    }
}
