<?php

namespace App\Services\Mobile\Setting;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\DataTransferObject\StreamedFile;
use App\Enum\AllowedFileSizes;
use App\Enum\AllowedFileTypes;
use App\Enum\ErrorCode;
use App\Enum\ImageDimensions;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\ImageHelper;
use App\Helpers\ResourceLocationBuilder;
use App\Services\Attachment\CreateAttachment;
use App\Services\Attachment\UpdateAttachment;
use App\Services\BaseService;
use App\Services\Employee\UpdateAvatar as UpdateAvatarServices;

class UpdateAvatar extends BaseService implements Validatable, Performable
{
    /**
     * @return array
     */
    public function getRules($args)
    {
        return [
            'avatar' => 'nullable|mimes:' . AllowedFileTypes::IMAGE . '|max:' . AllowedFileSizes::IMAGE_SIZE
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check() && !Context::client()->get()->is_demo;
    }

    /**
     * Update profile information
     *
     * @return array
     */
    public function performAction($data): bool
    {
        //Save attachment
        $user = Context::user()->get();
        $avatar = $data['avatar'] ?? null;
        app(UpdateAvatarServices::class)->execute(['avatar' => $avatar, 'user_id' => $user->getKey()]);

        return true;
    }
}
