<?php

namespace App\Services\Mobile\Setting;

use App\Contracts\Validatable;
use App\Facades\Context;
use App\Services\BaseService;
use Illuminate\Support\Facades\Auth;

class UpdatePassword extends BaseService implements Validatable
{
    /**
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'old_password' => 'required',
            'new_password' => 'required',
        ];
    }

    /**
     * Update profile information
     *
     * @param array $data
     * @return mixed
     */
    public function performAction(array $data)
    {;
        $user = Context::user()->get();

        if(!!$data['old_password']) {
            $check  = Auth::guard('web')->attempt([
                'email' => $user->email,
                'password' => $data['old_password']
            ]);

            if($check && !!$data['new_password']) {
                $user->password = bcrypt($data['new_password']);
                $user->is_default = 0;
                $user->token()->revoke();
                $token = $user->createToken('newToken')->accessToken;
                $user->save();

                return ['token' => 'Bearer ' . $token];
            }
        }

        return false;
    }
}
