<?php

namespace App\Services\Mobile\Setting;

use App\Contracts\Validatable;
use App\Models\User\Employee;
use App\Models\User\User;
use App\Services\BaseService;
use Illuminate\Support\Facades\Auth;

class UpdateProfile extends BaseService implements Validatable
{
    /**
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'surname' => 'required|string',
            'first_name' => 'required|string',
            'bio' => 'string|nullable',
        ];
    }

    /**
     * Update profile information
     *
     * @param array $data
     * @return array
     */
    public function performAction(array $data): array
    {
        // Remove empty array values from the data
        $data = collect($data);
        Employee::where('user_id', Auth::id())
            ->update($data->only(['bio'])->toArray());

        User::where('id', Auth::id())
            ->update($data->only(['first_name', 'surname'])->toArray());

        return $data->toArray();
    }
}
