<?php


namespace App\Services\Mobile\Sync;


use App\Enum\AccessPermissions;
use App\Enum\ClientConfigurations;
use App\Enum\FilePaths;
use App\Enum\PlanConfigurations;
use App\Enum\Roles;
use App\Enum\SegmentTypes;
use App\Facades\Context;
use App\Helpers\ConfigurationHelper;
use App\Helpers\IntegrationHelper;
use App\Helpers\SegmentHelper;
use App\Http\Resources\Mobile\Attachment\Attachment;
use App\Http\Resources\Segment\Segment;
use App\Models\Attachment as AttachmentModel;
use App\Services\BaseService;
use App\Services\UserAccess\GetAccessByRole;
use App\Services\UserAccess\GetAllPermissions;

class GetSyncData extends BaseService
{
    /**
     * Get step detail by step id
     *
     * @param $data
     * @return mixed
     */
    public function performAction($data)
    {
        $user = Context::user()->get();
        $client = $user->getClient();

        $clientConfiguration = $client->clientConfigurations->mapWithKeys(function ($item, $key) {
            return [$item->name => ConfigurationHelper::convertDataByType($item->pivot->value, $item->type)];
        })->toArray();

        $subscriptionPlanConfiguration = $client->subscriptionPlan->planConfigurations->mapWithKeys(function ($item, $key) {
            return [$item->name => ConfigurationHelper::convertDataByType($item->pivot->value, $item->type)];
        })->toArray();

        //        $user = Context::user()->get();
        $permissions = app(GetAllPermissions::class)->execute();
        $permissionsName = $permissions->pluck('name')->toArray();
        $employeeAccess = app(GetAccessByRole::class)->execute(['role' => Roles::FRONT_USER]);
        $userAccess = [];
        foreach (AccessPermissions::MOBILE_ACCESS_GROUP_PERMISSIONS as $group => $groupPermission) {
            foreach ($groupPermission as $permission) {
                $userAccess[$group][$permission] = in_array($permission, $permissionsName);
            }
        }

        $type = "employee";
        $show_enps_chart = isset($clientConfiguration[ClientConfigurations::SHOW_ENPS_CHART_FOR_EMPLOYEES]) && $clientConfiguration[ClientConfigurations::SHOW_ENPS_CHART_FOR_EMPLOYEES];
        if ($user->hasRole(Roles::WHISTLEBLOWER_ADMIN)) {
            $type = "wb_admin";
        } else if ($user->hasRole(Roles::MANAGER)) {
            $show_enps_chart = isset($clientConfiguration[ClientConfigurations::SHOW_ENPS_CHART_FOR_MANAGERS]) && $clientConfiguration[ClientConfigurations::SHOW_ENPS_CHART_FOR_MANAGERS];
        } else if ($user->hasRole(Roles::ADMIN)) {
            $type = "admin";
            $show_enps_chart = true;
        }
        $employee = $user->employee;

        $userResource = [
            "profile" => [
                "location_id" => is_null($employee->location_id) ? null : $employee->location_id,
                "team_id" => is_null($employee->team_id) ? null : $employee->team_id,
                "department_id" => is_null($employee->department_id) ? null : $employee->department_id,
            ],
            "client" => [
                "logo" => AttachmentModel::find($client->logo_id),
                ClientConfigurations::CONFIG_PRIMARY_COLOUR => $clientConfiguration[ClientConfigurations::CONFIG_PRIMARY_COLOUR],
                ClientConfigurations::CONFIG_SECONDARY_COLOUR => $clientConfiguration[ClientConfigurations::CONFIG_SECONDARY_COLOUR],
                ClientConfigurations::IS_DEFAULT_COLOUR => isset($clientConfiguration[ClientConfigurations::IS_DEFAULT_COLOUR]) && $clientConfiguration[ClientConfigurations::IS_DEFAULT_COLOUR],
                "type" => $type,
                'show_enps_chart' => $show_enps_chart,
            ],
            "plan_configurations" => [
                PlanConfigurations::PACKAGE_CUSTOM_COLOUR => $subscriptionPlanConfiguration[PlanConfigurations::PACKAGE_CUSTOM_COLOUR],
                PlanConfigurations::PACKAGE_MESSAGE => $subscriptionPlanConfiguration[PlanConfigurations::PACKAGE_MESSAGE],
                PlanConfigurations::PACKAGE_ENGAGEMENT_MODULE => $subscriptionPlanConfiguration[PlanConfigurations::PACKAGE_ENGAGEMENT_MODULE],
                PlanConfigurations::PACKAGE_ID_VERIFICATION => $subscriptionPlanConfiguration[PlanConfigurations::PACKAGE_ID_VERIFICATION],
                PlanConfigurations::PACKAGE_AI_DOCUMENT_SEARCH => $subscriptionPlanConfiguration[PlanConfigurations::PACKAGE_AI_DOCUMENT_SEARCH],
                PlanConfigurations::PACKAGE_WHISTLEBLOWING_CAPABILITIES => $user->is_demo ? true : $subscriptionPlanConfiguration[PlanConfigurations::PACKAGE_WHISTLEBLOWING_CAPABILITIES],
            ],
            "permissions" => $userAccess,
            "restrict_employee" => [
                "employee_messages" => $employeeAccess[AccessPermissions::ACCESS_GROUP_EMPLOYEE_MESSAGES],
                "employee_directory" => $employeeAccess[AccessPermissions::ACCESS_GROUP_EMPLOYEE_DIRECTORY],
            ],
        ];

        $userResource['resource_urls'] = [];

        // Language Polish
        $polish = [
            'langKey' => 'pl',
        ];
        if (file_exists(public_path(FilePaths::TERM_AND_CONDITIONAL_PATH) . "MobileAppTermsofUse_pl.pdf")) {
            $polish['tnc_url'] = config('app.back_end_url')  . FilePaths::TERM_AND_CONDITIONAL_PATH . "MobileAppTermsofUse_pl.pdf";
        }
        if (file_exists(public_path(FilePaths::PRIVACY_PATH) . "Mobile_Privacy_Policy_pl.pdf")) {
            $polish['privacy_url'] = config('app.back_end_url')  . FilePaths::PRIVACY_PATH . "Mobile_Privacy_Policy_pl.pdf";
        }
        $userResource['resource_urls'][] = $polish;
        // End

        if (file_exists(public_path(FilePaths::TERM_AND_CONDITIONAL_PATH) . "MobileAppTermsofUse.pdf")) {
            $userResource['tnc_url'] = config('app.back_end_url')  . FilePaths::TERM_AND_CONDITIONAL_PATH . "MobileAppTermsofUse.pdf";
        } else {
            $userResource['tnc_url'] = null;
        }

        if (file_exists(public_path(FilePaths::PRIVACY_PATH) . "Mobile_Privacy_Policy.pdf")) {
            $userResource['privacy_url'] = config('app.back_end_url')  . FilePaths::PRIVACY_PATH . "Mobile_Privacy_Policy.pdf";
        } else {
            $userResource['privacy_url'] = null;
        }

        return $userResource;
    }
}