<?php


namespace App\Services\Mobile\Sync;


use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Services\BaseService;
use DateTimeZone;

class SyncTimezone extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'timezone' => "required|string"
        ];
    }

    public function performAction($data)
    {
        $timezone = $data['timezone'];
        if (!in_array($timezone, DateTimeZone::listIdentifiers())) {
            throw new InvalidRequestException('Timezone is undefined.', ErrorCode::UNDEFINED_TIMEZONE);
        }
        $user = Context::user()->get();
        $employee = $user->employee;
        $employee->timezone = $timezone;
        $employee->save();
        return $user->fresh();
    }
}