<?php


namespace App\Services\QR;


use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Exceptions\UnauthenticatedHttpException;
use App\Models\QR\ActionToken;
use App\Services\BaseService;

/**
 * Class CheckTokenIsValid
 * @package App\Services\QR
 */
class CheckTokenIsValid extends BaseService implements Validatable
{
    /**
     * @param  array  $args
     * @return string[]
     */
    public function getRules(array $args)
    {
        return [
            'token' => 'required|string'
        ];
    }

    /**
     * @param  array  $args
     * @return mixed
     */
    public function performAction(array $args)
    {
        $token = ActionToken::where('token', $args['token'])->first();
        if (!$token || $token->expires_at->lessThanOrEqualTo(now())) {
            throw new UnauthenticatedHttpException("Token expired", ErrorCode::TOKEN_EXPIRED);
        }

        return $token;
    }
}