<?php


namespace App\Services\Questionnaire;

use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\ResourceLocationBuilder;
use App\Models\Attachment;
use App\Models\Questionnaire\Questionnaire;
use App\Services\Attachment\CreateAttachment;
use App\Services\Attachment\DeleteAttachment;
use App\Services\BaseService;
use App\Services\Driver\EditDriver;

class EditQuestionnaire extends BaseService implements Validatable, Transactionable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    protected $rules;

    public function getRules(array $args): array
    {
        $rules = [
            'driver_id' => 'exists:drivers,id'
        ];

        // Update question status will not require "question" attribute
        if (!empty($args['question'])) {
            $rules['question'] = 'required';
            $rules['name'] = 'required';
        }
        return $rules;
    }



    /**
     * Edit questionnaire
     *
     * @param array $data
     * @return Questionnaire
     */
    public function performAction(array $data)
    {
        $questionnaire = Questionnaire::findOrFail($data['id']);
        $user = Context::user()->get();

        // Update driver information
        $driver = $questionnaire->driver()->first();
        $driverUpdateData = ['name' => $data['name'], 'description' => $data['description'], 'id' => $driver->id];
        app(EditDriver::class)->execute($driverUpdateData);

        $status = $questionnaire->update($data);

        // Upload illustration for question
        if ($status && !empty($data['illustration_file'])) {
            $oldIllustration = !empty($questionnaire->illustration_id) ? Attachment::find($questionnaire->illustration_id) : null;

            $fileDir = (new ResourceLocationBuilder())->getQuestionnairePath();
            $illustration =  app(CreateAttachment::class)->execute($data['illustration_file'], $fileDir, $user->id);

            if (!empty($illustration)) {
                $questionnaire->illustration()->associate($illustration);
                if ($questionnaire->save() && !empty($oldIllustration)) {
                    // Remove old asset
                    app(DeleteAttachment::class)->execute($oldIllustration);
                }
            }
        }

        return $questionnaire;
    }
}
