<?php


namespace App\Services\Questionnaire;

use App\Contracts\Performable;
use App\Enum\QuestionnaireEnum;
use App\Facades\Context;
use App\Models\Questionnaire\Questionnaire;
use App\Models\Questionnaire\QuestionnaireClientSetting;
use App\Services\BaseService;

class PublishQuestionnaire extends BaseService implements Performable
{

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Create questionnaire
     *
     * @param array $data
     * @return QuestionnaireClientSetting
     */
    public function performAction(array $data)
    {
        $questionId = $data['questionnaire'];
        $questionnaire = Questionnaire::findOrFail($questionId);
        $clientId = Context::client()->get()->getKey();

        $questionSetting = QuestionnaireClientSetting::where(['client_id' => $clientId, 'questionnaire_id' => $questionId])->first();
        $isPublish = !empty($questionSetting) && $questionSetting->status == QuestionnaireEnum::INACTIVE ? QuestionnaireEnum::ACTIVE : QuestionnaireEnum::INACTIVE;

        if (empty($questionSetting)) {
            $questionSetting = QuestionnaireClientSetting::create([
                'client_id' => $clientId,
                'questionnaire_id' => $questionnaire->id,
                'status' => $isPublish
            ]);
        } else {
            $questionSetting->update(['status' => $isPublish]);
        }

        return $questionSetting;
    }
}
