<?php

namespace App\Services\Questionnaire;

use Illuminate\Support\Arr;
use Illuminate\Support\Collection;
use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\ResourceLocationBuilder;
use App\Models\Attachment;
use App\Models\Questionnaire\Questionnaire;
use App\Services\Attachment\CreateAttachment;
use App\Services\Attachment\DeleteAttachment;
use App\Services\BaseService;

class UpdateIllustration extends BaseService implements Validatable, Transactionable
{
    public function getRules(array $args): array
    {
        return [
            'questionnaires.*.questionnaire_id' => 'required|exists:questionnaires,id',
            'questionnaires.*.illustration_file' => 'required|image',
        ];
    }

    /**
     * Update illustration
     *
     * @param array $options
     * @return mixed
     */
    public function performAction(array $data)
    {
        $currentUser = Context::user()->get();

        $result = new Collection();
        $questionnaireIds = Arr::pluck($data['questionnaires'], 'questionnaire_id');

        // Get Questions
        $questionnaires = Questionnaire::whereIn('id', $questionnaireIds)->get();
        $questionnairesMapping = $questionnaires->mapWithKeys(function ($item) {
            return [$item['id'] => $item];
        });

        // Get Attachments
        $attachmentIds = $questionnaires->pluck('illustration_id');
        $attachments = Attachment::whereIn('id', $attachmentIds)->get();
        $attachmentsMapping = $attachments->mapWithKeys(function ($item) {
            return [$item['id'] => $item];
        });

        // Loop form-data
        foreach ($data['questionnaires'] as $item) {
            $questionnaire = !empty($questionnairesMapping[$item['questionnaire_id']]) ? $questionnairesMapping[$item['questionnaire_id']] : null;
            if (empty($questionnaire)) continue;

            $oldIllustration = !empty($attachmentsMapping[$questionnaire->illustration_id]) ? $attachmentsMapping[$questionnaire->illustration_id] : null;

            // Upload new illustration
            $fileDir = (new ResourceLocationBuilder())->getQuestionnairePath();
            $illustration =  app(CreateAttachment::class)->execute($item['illustration_file'], $fileDir, $currentUser->id);

            if (!empty($illustration)) {
                $questionnaire->illustration()->associate($illustration);
                // Update new illustration
                if ($questionnaire->save() && !empty($oldIllustration)) {
                    // Remove old asset
                    app(DeleteAttachment::class)->execute($oldIllustration);
                }
            }
            $result->push($questionnaire);
        }

        return $result;
    }
}
