<?php


namespace App\Services\QuestionnaireAnswer;

use App\Facades\Context;
use App\Services\BaseService;
use App\Services\DataControl\GetDataControl;
use App\Services\Report\GetReportComment;
use Carbon\Carbon;

class GetSensitiveComment extends BaseService
{
    /**
     * Create questionnaire
     *
     * @param array $data
     * @return Questionnaire|null[]
     */
    public function performAction(array $data)
    {
        $dataControl = app(GetDataControl::class)->execute();
        $fromDate = Carbon::now()->subMonths($dataControl->data_referencing);
        $toDate = Carbon::now();

        $sensitiveComments = app(GetReportComment::class)->execute([
            'from_date' => $fromDate,
            'to_date' => $toDate,
            'comment_type' => 'sensitive'
        ]);

        $dateArray = $sensitiveComments->map(function($sensitiveComment){
            return $sensitiveComment['created_at']->toDateTimeString();
        })->toArray();

        if (!empty($dateArray)) {
            $fromDate = min(array_map('strtotime', $dateArray));
            $toDate = max(array_map('strtotime', $dateArray));

            return [
                'from_date' => date('Y-m-d', $fromDate),
                'to_date' => date('Y-m-d', $toDate)
            ];
        }

        return [
            'from_date' => null,
            'to_date' => null
        ];
    }
}
