<?php

namespace App\Services\QuestionnaireOption;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Services\BaseService;
use App\Models\Questionnaire\Questionnaire;

class CreateQuestionnaireOption extends BaseService implements Validatable, Performable
{
    protected $rules;

    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($data)
    {
        return [
            'questionnaire_id' => 'required|exists:questionnaires,id',
            'segment_ids.*' => 'required|exists:segments,id',
            'is_allow' => 'required',
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Create option
     *
     * @param array $data
     * @return Array
     */
    public function performAction(array $data)
    {
        try {
            $clientId = Context::client()->get()->getKey();

            $questionnaire = Questionnaire::find($data['questionnaire_id']);

            // Remove ids not in array
            $questionnaire->options()->isAllow($data['is_allow'])->whereNotIn('segment_id', $data['segment_ids'])->delete();

            // Get ids in array
            $existOptions = $questionnaire->options()->isAllow($data['is_allow'])->whereIn('segment_id', $data['segment_ids'])->get();
            $existOptionsId = !empty($existOptions) ? $existOptions->pluck('segment_id')->toArray() : [];

            // Add new ids
            $newSegIds = array_diff($data['segment_ids'], $existOptionsId);

            $newOpts = [];
            foreach ($newSegIds as $segId) {
                $newOpts[] = [
                    'segment_id' => $segId,
                    'is_allow' => $data['is_allow'],
                    'client_id' => $clientId
                ];
            }

            $existOptions = $questionnaire->options()->createMany($newOpts);
            return $existOptions;
        } catch (\Exception $e) {
            return ['status_code' => 500, 'message' => $e->getMessage()];
        }

    }
}
