<?php
namespace App\Services\Report;

use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Services\BaseService;
use Carbon\Carbon;

class DataControlReferencing extends BaseService implements Transactionable, Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules(array $args): array
    {
        return [
            'from_date' => 'required',
            'to_date' => 'required',
            'data_referencing' => 'required'
        ];
    }

    /**
     * get report comments
     *
     * @param array $data
     * @return Mix
     */
    public function performAction(array $data)
    {
        $data['from_date'] = !empty($data['from_date']) ? Carbon::parse($data['from_date'])->toDateString() : Carbon::now()->toDateString();
        $data['to_date'] = !empty($data['to_date']) ? Carbon::parse($data['to_date'])->toDateString() : Carbon::now()->toDateString();

        // Get start date based on data referencing
        $now = Carbon::now();
        $availableDate = Carbon::now()->subMonths($data['data_referencing']);

        ////////////// Data referencing //////////////
        // If request start date less than available date then start date is available date
        $fromDate = Carbon::parse($data['from_date'])->lessThan($availableDate) ? $availableDate : $data['from_date'];
        $toDate = Carbon::parse($data['to_date'])->greaterThan($now) ? $now : $data['to_date'];

        return ['from_date' => $fromDate, 'to_date' => $toDate];
    }
}
