<?php
namespace App\Services\Report;

use App\Facades\Context;
use App\Helpers\CsvHelper;
use App\Models\DataControl\DataControl;
use App\Services\BaseService;
use App\Contracts\Validatable;
use Carbon\Carbon;
use Illuminate\Support\Arr;

class DownloadHeatmapSegment extends BaseService implements Validatable
{
     /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules(array $args): array
    {
        return [
            'from_date' => 'date_format:Y-m-d',
            'to_date' => 'date_format:Y-m-d|after:from_date'
        ];
    }

    /**
     * calculation scoring average for eNPS
     * @param array $args
     * @return mixed
     * @throws \Illuminate\Validation\ValidationException
     */
    public function performAction(array $args)
    {
        $client = Context::client()->get();
        $isParticipation = false;

        if (empty($args['score_type'])) {
            $dataControl = DataControl::client($client->id)->first();
            $scoreType = !empty($dataControl) && $dataControl->engagement_score_default !== null
                ? ($dataControl->engagement_score_default == 1 ? 'average' : 'enps')
                : 'enps';
        } else {
            $scoreType = $args['score_type'];
        }

        // Get heatmap data
        $heatMapData = app(GetHeatmapSegment::class)->execute($args);

        if (empty($heatMapData)) return false;

        // Set header
        $now = Carbon::now()->format('Y-m-d');
        $topHeader = ['From', !empty($args['from_date']) ? $args['from_date'] : '', 'To', !empty($args['to_date']) ? $args['to_date'] : '', 'Report Date', $now];
        $header = ['Segments','Segment Options'];
        if ($isParticipation) {
            $header[] = "Participant (All time/ this cycle)";
        }

        $rows = [];
        if (empty($heatMapData[0]['drivers'])) return false;

        // Get driver name to push to header
        $driverName = Arr::pluck($heatMapData[0]['drivers'], 'name');
        $header = array_merge($header, $driverName);

        // Foreach to get row data
        foreach ($heatMapData as $key => $segment) {
            $rowData = [
                $segment->segmentType->name,
                $segment->name
            ];

            if ($isParticipation) {
                $rowData[] = (int)($segment['participate_rate']['all_time'] * 100) . '%/' . (int)($segment['participate_rate']['this_cycle'] * 100) .'%';
            }

            // Get data based on driver name
            foreach ($driverName as $driver) {
                $getDriverInfo = Arr::where($segment['drivers'], function ($value) use ($driver) {
                    return $value['name'] == $driver;
                });

                $score = null;
                if (!empty($getDriverInfo)) {
                    $score = $scoreType == 'enps'
                        ? array_values($getDriverInfo)[0]['scores']['driver_enps']
                        : array_values($getDriverInfo)[0]['scores']['driver_avg'];
                }
                $rowData[] = $score === null ? 'No data' : round($score, 1);
            }
            $rows[] = $rowData;
        }

        $path = config('filesystems.disks.local.root');
        $fileName = 'report-topic' . '_' . time() . '.csv';
        $filePath = $path . '/' . $fileName;
        $rows = array_merge([$header], $rows);

        CsvHelper::exportCsv($filePath, $rows, $topHeader);

        return response()->download($filePath)->deleteFileAfterSend();
    }
}
