<?php
namespace App\Services\Report;

use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Services\BaseService;
use App\Models\Driver\Driver;
use App\Services\Client\ClientValue\GetClientValue;
use App\Services\DataControl\GetDataControl;
use App\Services\Engagement\BaseDriverScore;
use App\Services\Engagement\GetScoreValues;
use App\Traits\Pageable;
use App\Traits\Sortable;
use App\Traits\Filterable;
use App\Facades\Context;

class GetDriverScoring extends BaseService implements Validatable, Transactionable
{
    use Sortable, Pageable, Filterable;

    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args): array
    {
        return [];
    }

    public function performAction(array $data)
    {
        $driverQuery = Driver::query();
        $driverQuery->with(['subDrivers']);
        $driverQuery->primary();

        if(!empty($data['drivers'])) {
            $driverIds = explode(",", $data['drivers']);
            $driverQuery->whereIn('drivers.id', $driverIds);
        }

        $dataControl = app(GetDataControl::class)->execute();
        $drivers = $this->applyPaging($data, $driverQuery);
        $driverIds = $drivers->pluck('id')->toArray();

        $driverScores = app(BaseDriverScore::class)->execute(
            array_merge($data, ['main_drivers' => $driverIds, 'data_control' => $dataControl])
        );
        $driverTrends = app(BaseDriverScore::class)->execute(
            array_merge($data, ['main_drivers' => $driverIds, 'data_control' => $dataControl, 'trend' => 'true'])
        );

        foreach ($drivers as $driver) {
            $scores = $driverScores[$driver->getKey()] ?? null;
            $trends = $driverTrends[$driver->getKey()] ?? null;
            if ($scores && $trends) {
                $trends = self::calculateTrendScores($scores, $trends);
            }

            $driver->scores = $scores;
            $driver->trends = $trends;
        }

        return $drivers;
    }

    public static function calculateTrendScores($scores, $trends)
    {
        $scoresTrending = array_combine($scores, $trends);
        $index = 0;
        foreach ($scoresTrending as $key => $value) {
            $trending = round((float)$key - (float)$value, 10);
            if ($trending > 0) {
                $trendingValue = "1";
            } elseif ($trending < 0) {
                $trendingValue = "-1";
            } elseif ($key !== "") {
                $trendingValue = "0";
            } else {
                $trendingValue = null;
            }

            if ($index === 0) {
                $trends['driver_avg'] = $trendingValue;
            } else {
                $trends['driver_enps'] = $trendingValue;
            }
            $index++;
        }

        return $trends;
    }
}
