<?php
namespace App\Services\Report;

use App\Facades\Context;
use App\Services\BaseService;
use App\Contracts\Validatable;
use App\Traits\Pageable;
use App\Traits\Sortable;
use App\Helpers\FilterFluent;
use Carbon\Carbon;
use App\Models\Questionnaire\Questionnaire;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Enum\QuestionnaireEnum;
use App\Enum\ScheduleEnum;
use Illuminate\Support\Facades\DB;
use App\Models\Schedule\ScheduleSurvey;
use App\Models\Schedule\ScheduleFrequencyRound;
use App\Models\User\User;
use App\Models\Driver\Driver;
use App\Models\Segment\Segment;
use App\Models\Segment\SegmentType;
use App\Services\DataControl\GetDataControl;
use App\Services\Engagement\BaseDriverScore;

class GetProgressOverTime extends BaseService implements Validatable
{
    use Sortable, Pageable;

     /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules(array $args): array
    {
        return [];
    }

    /**
     * calculation scoring average for eNPS
     * @param array $args
     * @return mixed
     * @throws \Illuminate\Validation\ValidationException
     */
    public function performAction(array $args)
    {
        $args['from_date'] = isset($args['from_date']) ? Carbon::parse($args['from_date'])->toDateString() : null;
        $args['to_date'] = isset($args['to_date']) ? Carbon::parse($args['to_date'])->toDateString() : null;

        $client = Context::client()->get();
        $questionValue = Questionnaire::questionValue()->first();
        $questionnaire_client_id = isset($questionValue->id) ? $questionValue->id : null;
        // Check empty data when first use
        $isEmpty = QuestionnaireAnswer::client($client->id)
            ->whereNull('skip_question_id')
            ->where('questionnaire_id', '!=', $questionnaire_client_id)
            ->count();
        if ($isEmpty == 0) return null;

        if (isset($args['segments_filter'])) {
            $data['segments_filter'] = $args['segments_filter'];
        }
        
        $progress_over_time = null;
        $dataControl = app(GetDataControl::class)->execute();
        for ($month=$dataControl->data_referencing; $month >= 0; $month--) {
            $data['by_month'] = Carbon::now()->subMonths($month)->format('Ym');
            $scores = app(BaseDriverScore::class)->execute(array_merge($data, ['progress_time' => true]));
            if(isset($args['enps_type']) && $args['enps_type'] == "avg"){
                $value = isset($scores['driver_avg']) ? $scores['driver_avg'] : null;
            } else {
                $value = isset($scores['driver_enps']) ? $scores['driver_enps'] : null;
            }
            if(isset($value)){
                $progress_over_time[] = [
                    'date' => Carbon::parse($data['by_month']."01"),
                    'value' => $value
                ];
            }
        }
        return $progress_over_time;
    }
}
