<?php
namespace App\Services\Report;

use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Services\BaseService;
use App\Models\Driver\Driver;
use App\Services\Client\ClientValue\GetClientValue;
use App\Services\DataControl\GetDataControl;
use App\Services\Engagement\BaseDriverScore;

class GetSubDriverScoring extends BaseService implements Validatable, Transactionable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args): array
    {
        return [
            'driver_id' => 'required'
        ];
    }

    public function performAction(array $data)
    {
        $driver = Driver::findOrFail($data['driver_id']);

        $dataControl = app(GetDataControl::class)->execute();

        $subDrivers = $driver->subDrivers;
        $subDriverIds = $driver->subDrivers->pluck('id')->toArray();

        $subDriverScores = app(BaseDriverScore::class)->execute(
            array_merge($data, [
                'sub_drivers' => $subDriverIds, 'parent_id' => $driver->getKey(), 'data_control' => $dataControl
            ])
        );
        $subDriverTrends = app(BaseDriverScore::class)->execute(
            array_merge($data, [
                'sub_drivers' => $subDriverIds,
                'parent_id' => $driver->getKey(),
                'data_control' => $dataControl,
                'trend' => 'true'
            ])
        );

        foreach ($subDrivers as $subDriver) {
            $scores = $subDriverScores[$subDriver->getKey()] ?? null;
            $trends = $subDriverTrends[$subDriver->getKey()] ?? null;
            if ($scores && $trends) {
                $trends = GetDriverScoring::calculateTrendScores($scores, $trends);
            }

            $subDriver->scores = $scores;
            $subDriver->trends = $trends;
        }

        return $subDrivers;
    }
}
