<?php

namespace App\Services\Report;

use App\Contracts\Validatable;
use App\Services\BaseService;
use App\Services\Client\ClientValue\GetClientValue;
use App\Services\DataControl\GetDataControl;
use App\Services\Engagement\BaseDriverScore;
use App\Services\Engagement\GetScoreValues;
use App\Traits\Pageable;
use App\Traits\Sortable;

class GetValuesDrivers extends BaseService implements Validatable
{

    use Sortable, Pageable;

    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args): array
    {
        return [];
    }

    /**
     * calculation scoring average for eNPS
     *
     * @param array $args
     * @return mixed
     */
    function performAction(array $args)
    {
        $dataControl = app(GetDataControl::class)->execute();

        $companyValues = app(GetClientValue::class)->execute();
        $companyValueIds = $companyValues->pluck('id')->toArray();

        $valueScores = app(GetScoreValues::class)->execute(
            array_merge([
                'main_drivers' => $companyValueIds, 'data_control' => $dataControl
            ], $args)
        );
        $valueTrends = app(GetScoreValues::class)->execute(
            array_merge([
                'main_drivers' => $companyValueIds, 'data_control' => $dataControl, 'trend' => 'true'
            ], $args)
        );

        $companyValueScores = null;
        foreach ($companyValues as $companyValue) {
            $scores = $valueScores[$companyValue->getKey()] ?? null;
            $trends = $valueTrends[$companyValue->getKey()] ?? null;
            $companyValueScores[] = array_merge($companyValue->toArray(), ['scores' => $scores, 'trends' => $trends]);
        }

        return $companyValueScores;
    }
}