<?php

namespace App\Services\Report;

use App\Contracts\Transactionable;
use App\Enum\AccessPermissions;
use App\Enum\ConversationTypes;
use App\Enum\EmailNotifications;
use App\Enum\NotificationTypes;
use App\Enum\Roles;
use App\Facades\Context;
use App\Jobs\SendNotification;
use App\Jobs\SendNotificationEmail;
use App\Models\Message\Message;
use App\Models\Questionnaire\QuestionnaireAnswer;
use App\Models\User\User;
use App\Services\BaseService;
use App\Services\Message\CreateCommentDiscussion;
use App\Services\Message\CreateMessage;
use App\Services\UserAccess\GetAccessByRole;
use Illuminate\Support\Facades\Auth;

class ReactComment extends BaseService implements Transactionable
{
    /**
     * React to comment
     *
     * @param array $data
     * @return Questionnaire
     */
    public function performAction(array $data)
    {
        $questionAnswer = QuestionnaireAnswer::findOrFail($data['id']);
        $user = Context::user()->get();

        $questionAnswer->reacted_by = $user->id;
        $questionAnswer->reaction = $data['reaction'];
        $questionAnswer->save();

        $receiver = User::find($questionAnswer->user_id);
        $conversation = app(CreateCommentDiscussion::class)->execute([
            'comment_id' => $data['id'],
            'comment_type' => $data['comment_type'],
            'receiver_code' => $receiver->getBusinessKey(),
            'type' => ConversationTypes::DIRECT_MESSAGE,
        ]);

        $message = Message::query()->where('sender_id', $user->id)
            ->where('conversation_id', $conversation->id)
            ->where('content_type', 'reaction')
            ->get()
            ->first();

        if (isset($message)) {
            $message->content = $data['reaction'];
            $message->conversation_id = $conversation->id;
            $message->save();
        } else {
            app(CreateMessage::class)->execute([
                'content' => $data['reaction'],
                'content_type' => 'reaction',
                'conversation_id' => $conversation->id
            ]);
        }
        $arguments = array(
            "userIds" => array($receiver->getBusinessKey()),
            "headings" => __("You've got a message"),
            "contents" => __('notify.new_message', ['name' => $receiver->getFullNameAttribute()]),
            "data" => [
                "type" => NotificationTypes::MESSAGE_RECEIVED,
                "conversation_id" => $conversation->id
            ],
            'send_after' => null
        );
        SendNotification::dispatch($arguments);

        // Send Invite Notifications to employees
        $employeeAccess = app(GetAccessByRole::class)->execute(['role' => Roles::FRONT_USER]);
        $accessEmployeePermissions = $employeeAccess[AccessPermissions::ACCESS_GROUP_NOTIFICATIONS];

        if ($accessEmployeePermissions[AccessPermissions::NOTIFICATION_EMAIL_EMPLOYEE_ENPS_COMMENT]) {
            SendNotificationEmail::dispatch($receiver, EmailNotifications::ENPS_REACTION, ['other' => $user->surname . ', ' . $user->first_name, 'content' => $data['reaction']]);
        }

        return $questionAnswer;
    }
}