<?php


namespace App\Services\SSO;


use App\Contracts\Validatable;
use App\Enum\ClientConfigurations;
use App\Enum\ErrorCode;
use App\Enum\PlanConfigurations;
use App\Exceptions\UnauthorizedHttpException;
use App\Facades\Context;
use App\Models\User\User;
use App\Services\BaseService;
use App\Services\Subscription\CheckRemainPlanAction;

/**
 * Class CheckConfigurationSSOValid
 * @package App\Services\SSO
 */
class CheckConfigurationSSOValid extends BaseService implements Validatable
{
    protected $clientConfiguration;

    /**
     * @param  array  $args
     * @return string[]
     */
    public function getRules(array $args)
    {
        return [
            'client' => 'required'
        ];
    }

    /**
     * @param  array  $args
     * @return array
     */
    public function performAction(array $args): array
    {

        $client = $args['client'];
        Context::client()->set($client);

        $isClientHavePlan = app(CheckRemainPlanAction::class)->execute(PlanConfigurations::PACKAGE_SSO, false);
        $this->clientConfiguration = $client->configurations;
        if (
            !$isClientHavePlan
            || !$this->isValidConfiguration(ClientConfigurations::IS_ENABLE_SSO)
            || !$this->isValidConfiguration(ClientConfigurations::SSO_LOG_IN_URL)
            || !$this->isValidConfiguration(ClientConfigurations::SSO_ENTITYID_URL)
            || !$this->isValidConfiguration(ClientConfigurations::SSO_CERTIFICATE)
        ) {
            throw new UnauthorizedHttpException(
                'User is not configured for sso',
                ErrorCode::USER_IS_NOT_ENABLE_SSO
            );
        }

        return $this->clientConfiguration;
    }

    public function isValidConfiguration($index)
    {
        return isset($this->clientConfiguration[$index]) && $this->clientConfiguration[$index];
    }
}