<?php


namespace App\Services\SSO;


use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Enum\Roles;
use App\Exceptions\UnauthorizedHttpException;
use App\Helpers\Saml2AuthHelper;
use App\Models\User\User;
use App\Services\BaseService;
use Illuminate\Support\Facades\Config;

/**
 * Class GetLoginUrl
 * @package App\Services\SSO
 */
class GetLoginUrl extends BaseService implements Validatable
{
    /**
     * @param  array  $args
     * @return string[]
     */
    public function getRules(array $args)
    {
        return [
            'email' => 'required'
        ];
    }

    /**
     * Get SSO login url
     * @param  array  $args
     * @return mixed
     */
    public function performAction(array $args)
    {
        $user = User::where('email', $args['email'])->first();
        if (!$user || !$user->hasRole(Roles::CLIENT_CONSOLE_ROLES)) {
            throw new UnauthorizedHttpException(
                'User is not configured for sso',
                ErrorCode::USER_IS_NOT_ENABLE_SSO
            );
        }
        Config::set('ssoClientCode', $user->getClient()->getBusinessKey());

        $saml2Auth = app(Saml2AuthHelper::class);

        return $saml2Auth->login(config('saml2_settings.loginRoute'), ['email' => $args['email']], false, false, true);
    }

}