<?php


namespace App\Services\SSO;


use App\Enum\ErrorCode;
use App\Exceptions\UnauthorizedHttpException;
use App\Helpers\Saml2AuthHelper;
use App\Models\User\User;
use App\Services\BaseService;

class ProcessSaml2AssertionRequest extends BaseService
{
    public function performAction(array $args)
    {
        $saml2Auth = app(Saml2AuthHelper::class);
        $errors = $saml2Auth->acs();

        if (!empty($errors)) {
            logger()->error('Saml2 error_detail', ['error' => $saml2Auth->getLastErrorReason()]);

            logger()->error('Saml2 error', $errors);

            throw new UnauthorizedHttpException(
                'Saml2 error',
                ErrorCode::SSO_ERROR
            );
        }
        $user = $saml2Auth->getSaml2User();

        $inputs = [
            'sso_user_id'  => $user->getUserId(),
            'username'     => $user->getAttribute('http://schemas.xmlsoap.org/ws/2005/05/identity/claims/name'),
            'email'        => $user->getAttribute('http://schemas.xmlsoap.org/ws/2005/05/identity/claims/emailaddress'),
            'first_name'   => $user->getAttribute('http://schemas.microsoft.com/identity/claims/displayname'),
            'last_name'    => $user->getAttribute('http://schemas.microsoft.com/identity/claims/displayname'),
        ];
        $user = User::where('email', $inputs['email'])->firstOrFail();
        if($user->getClient()->code !== Saml2AuthHelper::getCurrentClientCode()){
            throw new UnauthorizedHttpException(
                "Client code is wrong",
                ErrorCode::WRONG_CLIENT_CODE
            );
        }
        return $user;
    }
}