<?php


namespace App\Services\Schedule;

use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Services\BaseService;
use App\Models\Schedule\ScheduleFrequencyRound;
use App\Models\Schedule\ScheduleFrequencySetting;
use Carbon\Carbon;
use App\Models\Client\ClientValue;
use App\Enum\ScheduleEnum;
use App\Enum\QuestionnaireEnum;
use App\Models\Driver\Driver;
use App\Models\Questionnaire\QuestionnaireClientSetting;

class CreateRound extends BaseService implements Validatable
{
   /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args): array
    {
        return [
            'schedule_survey_id' => 'integer|exists:schedule_survey,id',
            'schedule_frequency_id' => 'required|exists:schedule_frequency,id'
        ];
    }


    /**
     * Create schedule rounds by frequency
     *
     * @param array $args
     * @return ScheduleFrequencyRound
     */
    public function performAction(array $args)
    {
        $user = Context::user()->get();
        $client = Context::client()->get();

        $schedule_frequency_id = $args['schedule_frequency_id'];
        $roundSetting = ScheduleFrequencySetting::where(
            'schedule_frequency_id', $schedule_frequency_id
        )->first()->toArray();
        $schedule_survey_id = $args['schedule_survey_id'];
        $roundSetting['schedule_survey_id'] = $schedule_survey_id;

        $start_date = $args['start_date'];

         //get client values
        $queryClient = ClientValue::query();
        if ($client) {
            $queryClient->where('client_id', $client->id);
        }
        $cntValues = $queryClient->count();

        // check questionnaires per client
        $main_drivers = Driver::pluck('id')->toArray();
        $client_drivers = QuestionnaireClientSetting::where([
            'client_id' => $client->id,
            'status' => QuestionnaireEnum::INACTIVE
        ])->pluck('questionnaire_id')->toArray();

        $total_master = count(array_diff($main_drivers, $client_drivers));
        $totalQ = $total_master + $cntValues;
        $cnt = 0;

        $round = 1;
        if($totalQ > (int) $roundSetting['round_first'] || (int) $roundSetting['next_round'] > 0) {
            $round = (ceil(($totalQ - (int) $roundSetting['round_first']) / (int) $roundSetting['next_round']) + 1);
        }

        for ($i=0; $i < $round; $i++) {
            $expire_date = $this->roundExpireDate(
                $start_date,
                (int) $roundSetting['period_day']
            );
            if($cnt == 0) {
                $roundSetting['start_date'] = $start_date;
            } else {
                $roundSetting['start_date'] = Carbon::parse($start_date)->addDays(1)->toDateTimeString();
            }
            $roundSetting['expire_date'] = $expire_date;
            $start_date = $expire_date;

            $roundSetting['status'] = ScheduleEnum::ACTIVE;
            $roundSetting['client_id'] = $client->id;
            $roundSetting['created_by'] = $user->id;
            ScheduleFrequencyRound::create($roundSetting);
            $cnt++;
        }
        return ['sucessful' => true];
    }

    /**
     * Get schedule exipire date
     * @param string $start_date
     * @param int $frequency_round_id
     * @param int $week_complete
     */
    public function roundExpireDate($start_date, $week_complete){
        $renewal_date = Carbon::parse($start_date)->addDays($week_complete);
        return $renewal_date->toDateTimeString();
    }
}
