<?php


namespace App\Services\Schedule;

use App\Contracts\Transactionable;
use App\Http\Resources\Schedule\ScheduleSurvey as ScheduleSurveyResource;
use App\Models\Schedule\ScheduleFrequencyRound;
use App\Services\BaseService;
use App\Models\Schedule\ScheduleSurvey;
use App\Services\Schedule\QuestionnaireDistributor;

class CreateScheduleRoundsAndDistributes extends BaseService implements Transactionable
{
    /**
     * Create schedule item
     *
     * @param array $args
     * @return ScheduleSurvey
     */
    public function performAction(array $request): ScheduleSurvey
    {
        $survey = app(CreateSchedule::class)->execute($request);

        $condition = array_merge($request, ['schedule_survey_id' => $survey->id]);
        // processing rounds by schedule
        app(CreateRound::class)->execute($condition);

        $rsRounds = ScheduleFrequencyRound::where('schedule_survey_id', $survey->id)->pluck('id');
        $rounds = array_values($rsRounds->toArray());
        // processing segments by schedule
        app(CreateSegments::class)->execute($condition);

        $condition = array_merge($condition, [
                'schedule_frequency_id' => $survey->schedule_frequency_id,
                'rounds' => $rounds
        ]);
        $headers = [
            'Access-Control-Allow-Origin' => config('app.front_end_url'),
            'Access-Control-Allow-Credentials' => 'true'
        ];
        response()->json(["data" => new ScheduleSurveyResource($survey)], 200, $headers)->send();
        // processing distribution by schedule
        app(QuestionnaireDistributor::class)->execute($condition);

        // save schedule segment user currently
        $sendToSegmentIds = array_filter(explode(",", $request['send_to']));
        $excludeSegmentIds = !empty($request['exclude_id']) ? array_filter(explode(",", $request['exclude_id'])) : [];
        $allSegmentSubmitted = array_merge($sendToSegmentIds, $excludeSegmentIds);

        app(ScheduleSegmentUser::class)->execute(['scheduleId' => $survey->id, 'segments' => $allSegmentSubmitted]);

        return $survey;
    }
}
