<?php


namespace App\Services\Schedule;

use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Services\BaseService;
use App\Models\Schedule\ScheduleSurvey;
use App\Models\Schedule\ScheduleSegments;
use App\Models\Segment\Segment;
use Carbon\Carbon;
use App\Enum\ScheduleEnum;

class CreateSegments extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
    */
    public function getRules(array $args): array
    {
        return [
            'schedule_survey_id' => 'integer|exists:schedule_survey,id',
            'send_to' => 'required|string',
            'exclude_id' => 'string|nullable',
        ];
    }
    /**
     * Send to segments by frequency
     *
     * @param array $args
     * @return ScheduleFrequencyRound
     */
    public function performAction(array $args)
    {
        $user = Context::user()->get();
        $client = Context::client()->get();

        $schedule_survey_id = $args['schedule_survey_id'];
        if(isset($args['send_to'])){
            $codes = explode(',', $args['send_to']);
            foreach ($codes as $key => $code) {
                $segment_id = Segment::findByBusinessKey($code)->toArray()['id'];
                $send_to[$segment_id] = $segment_id;
            }
        }
        if(isset($send_to)){
            $args['send_to'] = implode(",", $send_to);
        }

        if(isset($args['exclude_id'])){
            $codes = explode(',', $args['exclude_id']);
            foreach ($codes as $key => $code) {
                $segment_id = Segment::findByBusinessKey($code)->toArray()['id'];
                $exclude_id[$segment_id] = $segment_id;
            }
        }
        if(isset($exclude_id)){
            $args['exclude_id'] = implode(",", $exclude_id);
        }
        
        $args['status'] = ScheduleEnum::ACTIVE;
        $args['client_id'] = $client->id;
        $args['created_by'] = $user->id;
        ScheduleSegments::create($args);
        return ['successful' => true];
    }
}
