<?php


namespace App\Services\Schedule;


use App\Contracts\Validatable;
use App\Facades\Context;
use App\Models\Client\ClientValue;
use App\Models\Questionnaire\Questionnaire;
use App\Models\Questionnaire\QuestionnaireClientSetting;
use App\Models\Schedule\ScheduleFrequencySetting;
use App\Services\BaseService;

class GetDayNumberToCompleteSchedule extends BaseService implements Validatable
{
    public function getRules(array $args): array
    {
        return [
            'frequency_setting' => 'required'
        ];
    }

    /**
     * Generate Num Of Days To Complete
     * @param  array  $args  ['frequency_setting']
     *  Eg: weekly
     *   46 - 8 (first_round) = 38
     *   38 / 4 (next_round) = (9.5 + 1 first_found) => 10.5 * 7 (days) = 73.5 (days)
     * @return int
     */
    public function performAction(array $args): int
    {
        $frequencySetting = $args['frequency_setting'];
        $days_complete = 0;
        if ($frequencySetting) {
            $totalDefaultQuestionnaire = $this->getTotalQuestionnaire();
            $sub_days_complete = 1;

            //more than 1 round
            if ($totalDefaultQuestionnaire > $frequencySetting->round_first || $frequencySetting->next_round > 0) {
                $sub_days_complete = (ceil(($totalDefaultQuestionnaire - $frequencySetting->round_first) / $frequencySetting->next_round) + 1);
            }
            $days_complete = $sub_days_complete * $frequencySetting->period_day;
        }
        return $days_complete;
    }

    /*
     * Get Total Questionnaire
     */
    private function getTotalQuestionnaire(): int
    {
        $currentClient = Context::client()->get();
        $totalDefaultQuestionnaire = Questionnaire::query()
            ->whereNotNull('driver_id')
            ->whereNotIn('id', QuestionnaireClientSetting::query()
                ->where('client_id', $currentClient->getKey())
                ->where('status', '0')->pluck('questionnaire_id'))->count();

        $totalClientValue = ClientValue::query()
            ->where('client_id', $currentClient->getKey())->count();

        return $totalDefaultQuestionnaire + $totalClientValue;
    }

}