<?php

namespace App\Services\Schedule;

use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Models\Segment\Segment;
use App\Services\BaseService;
use App\Enum\ScheduleEnum;
use App\Enum\QuestionnaireEnum;
use Carbon\Carbon;
use App\Models\Schedule\ScheduleFrequencyRound;
use App\Models\Schedule\ScheduleFrequencySetting;
use App\Models\Schedule\ScheduleRoundQuestionnaire;
use App\Models\Client\ClientValue;
use App\Models\Segment\SegmentUser;
use App\Models\Schedule\ScheduleSegments;
use App\Models\Driver\Driver;
use App\Models\Questionnaire\QuestionnaireClientSetting;
use App\Models\Questionnaire\Questionnaire;
use Illuminate\Support\Facades\Log;

class QuestionnaireDistributor extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules(array $args): array
    {
        return [
            'schedule_survey_id' => 'integer|exists:schedule_survey,id',
            'schedule_frequency_id' => 'required|exists:schedule_frequency,id',
        ];
    }

    /**
     * Create round for frequency
     *
     * @param array $data
     * @return ScheduleFrequencyRound
     */
    public function performAction(array $data)
    {
        $client = Context::client()->get();
        $userInfo = Context::user()->get();

        $data['client_id'] = $client->id;
        $data['created_by'] = $userInfo->id;

        $frequency_round_id = $data['schedule_frequency_id'];
        $schedule_survey_id = $data['schedule_survey_id'];
        $roundSetting = ScheduleFrequencySetting::where(
            'schedule_frequency_id', $frequency_round_id
        )->first()->toArray();

        $roundSetting['schedule_survey_id'] = $data['schedule_survey_id'];
        $first_round = $roundSetting['round_first'];
        $next_round = $roundSetting['next_round'];

        $rounds = $data['rounds'];
        
        // get users by segment
        $segments = ScheduleSegments::where('schedule_survey_id', $data['schedule_survey_id']);
        $send_to = $segments->pluck('send_to')->toArray();
        $send_to = explode(",", $send_to[0]);
        $exclude_id = $segments->pluck('exclude_id')->toArray();
        $exclude_id = explode(",", $exclude_id[0]);

        $sendUsers = [];
        $includedSegments = Segment::whereIntegerInRaw('id', $send_to)->get();
        foreach ($includedSegments as $segment) {
            $segmentUserIds = $segment->includedCustomSegmentTypeUsers()->pluck('users.id')->toArray();
            $sendUsers = array_merge($sendUsers, $segmentUserIds);
        }

        $excludeUsers = [];
        $excludedSegments = Segment::whereIntegerInRaw('id', $exclude_id)->get();
        foreach ($excludedSegments as $segment) {
            $segmentUserIds = $segment->includedCustomSegmentTypeUsers()->pluck('users.id')->toArray();
            $excludeUsers = array_merge($excludeUsers, $segmentUserIds);
        }
        
        $users = array_diff(array_unique($sendUsers), array_unique($excludeUsers));
        
        //get client values
        $queryClient = ClientValue::query();
        $queryClient->where('client_id', $data['client_id']);
        $clientValues = $queryClient->pluck('id')->toArray();
        $clientQuestionnaire = null;

        // check questionnaires per client
        $main_client_drivers = QuestionnaireClientSetting::where([
            'client_id' => $client->id,
            'status' => QuestionnaireEnum::INACTIVE
        ])->pluck('questionnaire_id')->toArray();

        $client_questionnaire_id = Questionnaire::whereNull('driver_id')->first()->id;
        $totalQuestionnaire = Questionnaire::whereNotNull('driver_id')->count();
        // get main drivers and sub drivers
        $mainDrivers = Driver::where('parent_id', 0)->pluck('id')->toArray();
        $subDrivers = Driver::whereIn('parent_id', $mainDrivers)->pluck('id')->toArray();
        // define the question number values.
        $cntValue = (int)$client_questionnaire_id;
        foreach ($clientValues as $value) {
            $mainDrivers[] = $cntValue;
            $clientQuestionnaire[$value] = $cntValue;
            $cntValue++;
        }
        // get total drivers from main drivers + sub drivers - client drivers
        $mainDrivers = array_unique(array_merge($mainDrivers + $subDrivers));
        $mainDrivers = array_diff($mainDrivers, $main_client_drivers);
        $questionnaireRounds = [];
        foreach ($users as $user) {
            $questionnaires = null;
            $client_questionnaires = null;
            $main_drivers = $mainDrivers;
            shuffle($main_drivers);

            foreach ($rounds as $key => $value) {
                if($key == 0){
                    $define_round = $first_round;
                } else {
                    $define_round = $next_round;
                }
                if(count($main_drivers) < $define_round){
                    $define_round = count($main_drivers);
                }
                if(count($main_drivers) > 0){
                    // get sub-drivers base on the random and return number of questionnaires as define
                    $questionKeys = array_rand($main_drivers, $define_round);
                    $questionKeys = is_array($questionKeys) ? $questionKeys : [$questionKeys];
                    $questions = [];
                    foreach ($questionKeys as $questionKey) {
                        $questionnaire_id = $main_drivers[$questionKey];
                        $questions[] = $questionnaire_id;
                        unset($main_drivers[$questionKey]);
                    }
                    // define questionnaires values of client
                    if(!empty($clientQuestionnaire)){
                        $values_questions = $this->defineQuestionnaireByValues($questions, $clientQuestionnaire);
                        if(isset($values_questions)){
                            $client_questionnaires[$value] = array_values($values_questions);
                        }
                    }
                    $questionnaires[$value] = array_values($questions);
                }
            }

            $round_questionnaires = json_encode($questionnaires);
            $questionnaireRound = [
                'schedule_survey_id' => $schedule_survey_id,
                'questionnaire_id' => $round_questionnaires,
                'user_id' => $user,
                'created_at' => now(),
                'updated_at' => now(),
                'status' => ScheduleEnum::ACTIVE
            ];

            $questionnaires_client_values = json_encode($client_questionnaires);
            if($client_questionnaires){
                $questionnaireRound['client_value'] = $questionnaires_client_values;
            } else {
                $questionnaireRound['client_value'] = json_encode([]);
            }
            $questionnaireRounds[] = $questionnaireRound;
        }
        ScheduleRoundQuestionnaire::insert($questionnaireRounds);
        return ['secussful' => true];
    }

    public function defineQuestionnaireByValues(array $questions, array $client_values){
        $flag = false;
        $questions_values = null;
        foreach ($questions as $k => $val) {
            if(($removeIndex = array_search((int)$val, $client_values)) !== false) {
                $questions_values[$k] = $removeIndex;
                $flag = true;
            } else {
                $questions_values[$k] = null;
            }
        }

        if($flag){
            return $questions_values;
        } else {
            return null;
        }
    }
}
