<?php


namespace App\Services\Schedule;

use App\Contracts\Validatable;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Services\BaseService;
use Carbon\Carbon;
use App\Enum\ScheduleEnum;
use App\Models\Schedule\ScheduleSurvey;
use App\Models\Schedule\ScheduleFrequencySetting;
use Illuminate\Validation\ValidationException;

class ReconfigScheduleSurvey extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args): array
    {
        return [
            'data' => 'required',
            'survey_id' => 'required'
        ];
    }

    /**
     * Reconfig schedule survey
     *
     * @param array $args
     * @return ScheduleSurvey
     */
    public function performAction(array $args)
    {
        $survey = ScheduleSurvey::findOrFail($args['survey_id']);

        if($survey->status == ScheduleEnum::DEACTIVE){
            return app(CreateScheduleRoundsAndDistributes::class)->execute($args['data']);
        } else {
            throw new InvalidRequestException('Can not re-config on published survey');
        }
    }
}
