<?php

namespace App\Services\Schedule;

use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Services\BaseService;
use App\Models\Schedule\ScheduleSurvey;
use App\Enum\ScheduleEnum;
use App\Exceptions\InvalidRequestException;

/**
 * Class UpdateSurvey
 * @package App\Services\Tool\Survey
 */
class UnpublishSchedule extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules(array $args): array
    {
        return [
            'id' => 'required|integer',
        ];
    }

    /**
     * enable the schedule
     * 
     * @param array $args
     * @return ScheduleSurvey
     */
    public function performAction(array $args)
    {
        $user = Context::user()->get();
        $client = Context::client()->get();
        $survey = ScheduleSurvey::find($args['id']);
        if(!empty($survey)){
            $survey->update([
                'status' => ScheduleEnum::DEACTIVE,
                'client_id' => $client->id,
                'created_by' => $user->id
                ]
            );
            return $survey->refresh();
        } else {
            throw new InvalidRequestException('The schedule not found');
        }
    }
}