<?php

namespace App\Services\Schedule;

use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Services\BaseService;
use App\Models\Schedule\ScheduleFrequencyRound;
use App\Models\Schedule\ScheduleFrequencySetting;
use Illuminate\Validation\ValidationException;
use App\Models\Client\ClientValue;
use App\Enum\ScheduleEnum;
use Carbon\Carbon;

class UpdateRound extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules(array $args): array
    {
        return [
            'schedule_survey_id' => 'integer|exists:schedule_survey,id'
        ];
    }

    /**
     * reconfig the schedule
     * 
     * @param array $data
     * @return ScheduleSurvey
     */
    public function performAction(array $data)
    {
        $client = Context::client()->get();
        $user = Context::user()->get();

        $schedule_frequency_id = $data['schedule_frequency_id'];
        $roundSetting = ScheduleFrequencySetting::where(
            'schedule_frequency_id', $schedule_frequency_id
        )->first()->toArray();

        $roundSetting['schedule_survey_id'] = $data['schedule_survey_id'];
        $roundSetting['round_first'];
        $roundSetting['next_round'];
        $round = $roundSetting['next_round'];
        $start_date = $data['start_date'];
        $week_complete = $roundSetting['week_complete'];

        //get client values
        $queryClient = ClientValue::query();
        if ($client) {
            $queryClient->where('client_id', $client->id);
        }
        $cntValues = $queryClient->count();
        $cnt = 0;
        $rounds = ScheduleFrequencyRound::where('schedule_survey_id', (int)$data['schedule_surver_reconfig_id'])->pluck('id')->toArray();
        foreach ($rounds as $key => $value) {
            $data['id'] = $value;
            $expire_date = $this->roundExpireDate(
                $start_date,
                $week_complete
            );
            if($cnt == 0){
                $data['start_date'] = $start_date;
            } else {
                $data['start_date'] = Carbon::parse($start_date)->addDays(1)->toDateTimeString();
            }
            $data['expire_date'] = $expire_date;
            $start_date = $expire_date;
 
            $data['client_id'] = $client->id;
            $data['created_by'] = $user->id;
            $data['status'] = ScheduleEnum::ACTIVE;
            unset($data['schedule_frequency_id']);
            unset($data['schedule_surver_reconfig_id']);
            unset($data['client_id']);
            $round = ScheduleFrequencyRound::where(['id' => $value]);
            $round->update($data);
            $cnt++;
        }
        return ['sucessful' => true];
    }

    /**
     * Get schedule exipire date
     * @param string $start_date
     * @param int $frequency_round_id
     * @param int $week_complete
     */
    public function roundExpireDate($start_date, $week_complete){
        $renewal_date = Carbon::parse($start_date)->addDays($week_complete);
        return $renewal_date->toDateTimeString();
    }
}
