<?php


namespace App\Services\Schedule;

use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Services\BaseService;
use App\Exceptions\UnauthorizedHttpException;
use App\Models\Schedule\ScheduleSurvey;
use App\Services\Schedule\UnpublishSchedule;
use App\Enum\ScheduleEnum;

/**
 * Class UpdateSurvey
 * @package App\Services\Tool\Survey
 */
class UpdateSchedule extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
    */
    public function getRules(array $args): array
    {
        return [
            'name' => 'required|string|max:255',
            'description' => 'string|max:255',
            'schedule_frequency_id' => 'integer|exists:schedule_frequency,id',
            'client_id' => 'integer|exists:clients,id',
            'start_date' => 'required|date_format:Y-m-d'
        ];
    }

    /**
     * reconfig the schedule
     * 
     * @param array $data
     * @return ScheduleSurvey
     */
    public function performAction(array $data)
    {
        $client = Context::client()->get();
        $user = Context::user()->get();

        $survey = app(UnpublishSchedule::class)->execute(['id' => $data['id']]);
        unset($data['id']);
        $data['client_id'] = $client->id;
        $data['created_by'] = $user->id;
        $data['status'] = ScheduleEnum::ACTIVE;
        $survey = ScheduleSurvey::create($data);
        return $survey;
    }
}
