<?php

namespace App\Services\Segment;

use App\Contracts\Validatable;
use App\Enum\SegmentTypes;
use App\Models\Segment\Segment;
use App\Models\Segment\SegmentType;

class CreateAllEmployeeSegment extends SegmentService implements Validatable
{
    /**
     * @param array $data
     * @return array
     */
    public function getRules(array $data)
    {
        return [
            'client_id' => 'required|integer',
            'name' => 'nullable|string'
        ];
    }

    /**
     * Create "All employees" segment
     *
     * @param array $data
     * @return mixed
     */
    public function performAction(array $data)
    {
        $allSegmentType = SegmentType::findOrFail(SegmentTypes::ALL);

        return Segment::create([
            'segment_type_id' => $allSegmentType->getKey(),
            'name' => !empty($data['name']) ? $data['name'] : 'All employees',
            'client_id' => $data['client_id']
        ]);
    }
}
