<?php

namespace App\Services\Segment;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\ModelHelper;
use App\Models\Segment\Segment;
use App\Models\Segment\SegmentType;

class CreateSegment extends SegmentService implements Validatable, Performable
{
    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * @return array
     */
    public function getRules($data)
    {
        return [
            'segment_type_id' => 'required|string',
            'name' => 'required|string',
            'parent_code' => 'string'
        ];
    }



    /**
     * Get list quiz
     *
     * @param array $options
     * @return mixed
     */
    public function performAction(array $data)
    {
        $data['segment_type_id'] = ModelHelper::convertBusinessKeyToId(SegmentType::class, $data['segment_type_id']);
        $this->ensureSegmentBasic($data['segment_type_id']);
        if (isset($data['parent_code'])) {
            $data['parent_id'] = ModelHelper::convertBusinessKeyToId(Segment::class, $data['parent_code']);
        }
        $clientId = Context::client()->get()->getKey();

        $data['client_id'] = $clientId;

        $query = Segment::query()->where('segment_type_id', '=', $data['segment_type_id'])
                                    ->where('client_id', '=', $data['client_id'])
                                    ->where('name', '=', $data['name']);
        if (isset($data['parent_code'])) {
            $segments = $query->where('parent_id', '=', $data['parent_id'])->get();
        } else {
            $segments = $query->get();
        }
        if ($segments->count() > 0) {
            throw new \Exception("This value already exists in this segment. Please use a different name and try again!");
        }

        $segment = Segment::create($data);


        return $segment;
    }
}
