<?php

namespace App\Services\Segment\Employee;

use App\Contracts\Validatable;
use App\Helpers\ObjectHelper;
use App\Helpers\ModelHelper;
use App\Helpers\PermissionHelper;
use App\Models\Segment\Segment;
use App\Models\User\Employee;
use App\Models\User\User;
use App\Services\Segment\SegmentService;
use App\Models\Segment\SegmentType;

/**
 * Class AddSegmentEmployee
 * @package App\Services\Segment\Employee
 */
class AddSegmentEmployee extends SegmentService implements Validatable
{
    /**
     * @var
     */
    protected $segmentType;

    /**
     * @return array
     */
    public function getRules($data)
    {
        return [
            'segment_code' => 'required',
            'users' => 'required'
        ];
    }


    /**
     * Get list quiz
     *
     * @param array $options
     * @return mixed
     */
    public function performAction(array $data)
    {
        $segment = Segment::findByBusinessKey($data['segment_code']);

        $this->ensureSegmentBasic(ModelHelper::convertBusinessKeyToId(SegmentType::class, $data['segment_type_code']));

        $userIds = ObjectHelper::toArray(ModelHelper::convertBusinessKeyToId(User::class, $data['users']));

        $this->ensureUserOnClient($userIds);
        $this->removeUserFromOldSegment($data['users'], $segment, $data['segment_type_code']);

        $segment->users()->attach($userIds);
        $this->updateRelatedColumn($userIds, $segment);
        return $segment;
    }

    /**
     * Make sure all user is on current client
     * @param $userIds
     */
    public function ensureUserOnClient($userIds)
    {
        $users = User::whereIn('id', $userIds)->with('employee');
        foreach ($users as $user) {
            PermissionHelper::hasAccessOn($user->employee);
        }
    }

    /**
     * Remove user
     * User only belong to one segment in segment type
     */
    public function removeUserFromOldSegment(array $users, $segment, $segmentTypeCode)
    {
        $segmentsQuery = $segment->segmentType->segments();
        ModelHelper::setConditionFindByClient($segmentsQuery);
        $segmentsQuery->join('segment_user', function ($join) use ($users) {
            $userIds = ModelHelper::convertBusinessKeyToId(User::class, ObjectHelper::toArray($users));
            $join->on('segments.id', '=', 'segment_user.segment_id');
            $join->whereIn('segment_user.user_id', $userIds);
        });
        $segments = $segmentsQuery->get();
        foreach ($segments as $segment) {
            app(RemoveSegmentEmployee::class)->execute(["users" => $users, "segment_code" => $segment->getBusinessKey(), "segment_type_code" => $segmentTypeCode]);
        }
    }

    /**
     * Update segment user to related column
     */
    public function updateRelatedColumn(array $users, $segment)
    {
        Employee::whereIn('user_id', $users)->update([$segment->getRelatedColumn() => $segment->getKey()]);
    }

}
