<?php

namespace App\Services\Segment\Employee;

use App\Contracts\Validatable;
use App\Models\Segment\Segment;
use App\Models\Segment\SegmentUser;
use App\Models\User\User;
use App\Services\Segment\SegmentService;

/**
 * Class AddSegmentEmployee
 * @package App\Services\Segment\Employee
 */
class NotBelongToTeam extends SegmentService implements Validatable
{
    /**
     * @var
     */
    protected $segmentType;

    /**
     * @return array
     */
    public function getRules($data)
    {
        return [
            'segments' => 'required',
            'filter' => 'required'
        ];
    }

    /**
     * Get employees not belong to another team
     */
    public function performAction(array $data)
    {
        $segmentCodes = [];
        $userIds = [];
        $segmentCode = $data['filter'][0]['value'];
        $usersBelongToSegment = Segment::where('code', $segmentCode)->first()->users->pluck('id')->toArray();

        foreach ($data['segments']['data'] as $segment) {
            $segmentCodes[] = $segment->resource->code;
        }
        $segments = Segment::whereIn('code', $segmentCodes)->get();
        foreach ($segments as $segment) {
            $userIds[] = $segment->users->pluck('id')->toArray();
        }
        $usersBelongToTeam = array_merge(...$userIds);

        $userNotBelongToAnyTeam = array_diff($usersBelongToSegment, $usersBelongToTeam);

        return User::whereIn('id', $userNotBelongToAnyTeam)->get();
    }
}
