<?php

namespace App\Services\Segment\Employee;

use App\Contracts\Validatable;
use App\Helpers\ObjectHelper;
use App\Helpers\ModelHelper;
use App\Models\Segment\Segment;
use App\Models\User\Employee;
use App\Models\User\User;
use App\Models\Segment\SegmentType;
use App\Services\Segment\SegmentService;

/**
 * Class RemoveSegmentEmployee
 * @package App\Services\Segment\Employee
 */
class RemoveSegmentEmployee extends SegmentService implements Validatable
{
    /**
     * @return array
     */
    public function getRules($data)
    {
        return [
            'segment_code' => 'required',
            'users' => 'required'
        ];
    }

    /**
     * Get list quiz
     *
     * @param array $options
     * @return mixed
     */
    public function performAction(array $data)
    {
        //Only allow segment basic delete employee
        $this->ensureSegmentBasic(ModelHelper::convertBusinessKeyToId(SegmentType::class, $data['segment_type_code']));
        $segment = Segment::findByBusinessKey($data['segment_code']);
        $userIds = ModelHelper::convertBusinessKeyToId(User::class, ObjectHelper::toArray($data['users']));
        $segment->users()->detach($userIds);
        $this->updateRelatedColumn($userIds, $segment);
        return $segment;
    }

    /**
     * Update segment user to related column
     */
    public function updateRelatedColumn(array $userIds, $segment)
    {
        Employee::whereIn('user_id', $userIds)->update([$segment->getRelatedColumn() => null]);
    }
}
