<?php


namespace App\Services\Segment\SegmentType;


use App\Contracts\Validatable;
use App\Enum\AccessPermissions;
use App\Enum\SegmentTypes;
use App\Helpers\ModelHelper;
use App\Models\Segment\SegmentType;
use App\Services\BaseService;
use App\Traits\Pageable;

/**
 * Class GetSegmentTypeDetail
 * @package App\Services\Segment
 */
class GetSegmentTypeDetail extends BaseService implements Validatable
{
    use Pageable;

    /**
     * @return array|string[]
     */
    public function getRules(array $args)
    {
        return [
            'code' => 'required'
        ];
    }

    /**
     * @param array $options
     * @return mixed
     * @throws \Illuminate\Validation\ValidationException
     */
    public function performAction(array $options)
    {
        $data = $this->getSegmentTypeDetail($options);
        if(isset($options['segment_code']) && !is_null($options['segment_code'] ))
        {
            $data = $data->where('code',$options['segment_code']);
            if (isset($options['filter_on_mobile']) && $options['filter_on_mobile']) {
                ModelHelper::setConditionFindByEmployee($data, AccessPermissions::ACCESS_GROUP_EMPLOYEE_DIRECTORY);
            }
        }
        return $data;
    }

    /**
     * @param $options
     * @return mixed
     */
    public function getSegmentTypeDetail($options)
    {
        $segmentType = SegmentType::findByBusinessKey($options['code']);
        if (in_array($segmentType->id, SegmentTypes::SEGMENT_TYPES_BASIC)) {
            $result = app(GetSegmentTypeDetailBasic::class)->execute($options);
        } else if ($segmentType->id === SegmentTypes::MANAGER) {
            $result = app(GetSegmentTypeDetailManager::class)->execute($options);
        } else if ($segmentType->id === SegmentTypes::AGE) {
            $result = app(GetSegmentTypeDetailAge::class)->execute($options);
        } else if ($segmentType->id === SegmentTypes::EMPLOYMENT) {
            $result = app(GetSegmentTypeDetailEmploymentPhase::class)->execute($options);
        }
        return $result;
    }
}