<?php


namespace App\Services\Segment\SegmentType;


use App\Enum\EmployeeStatus;
use App\Enum\TimeTypes;
use App\Helpers\ModelHelper;
use App\Helpers\TimeHelper;
use App\Models\Segment\AgeSegment;
use App\Models\User\Employee;
use App\Services\BaseService;
use Carbon\Carbon;

class GetSegmentTypeDetailAge extends BaseService
{
    /**
     * @param array $options
     * @return mixed
     * @throws \Illuminate\Validation\ValidationException
     */
    public function performAction(array $options)
    {
        $segments = $this->getDataSegments();
        return $segments;
    }

    /**
     * @return array
     */
    public function getDataSegments()
    {

        $segments = AgeSegment::all();

        $employeesQuery = Employee::query()->has('user');
        ModelHelper::setConditionFindByClient($employeesQuery);
        $employees = $employeesQuery->get();

        $activeEmployeesQuery = Employee::query()->has('user')->where('status', EmployeeStatus::ACTIVE);
        ModelHelper::setConditionFindByClient($activeEmployeesQuery);
        $activeEmployees = $activeEmployeesQuery->get();

        $result = array();
        foreach ($segments as $key => $segment) {
            $segment->total_employee = $this->countEmployeeInRange($employees, $segment->min, $segment->max);
            $segment->active_employee = $this->countEmployeeInRange($activeEmployees, $segment->min, $segment->max);
            $result[] = $segment;
        }
        $result = collect($result);
        return $result;
    }

    /**
     * @param $employees
     * @param $min
     * @param $max
     * @return mixed
     */
    public function countEmployeeInRange($employees, $min, $max)
    {
        return $employees->filter(function($item) use ($min, $max) {
            if (!$item['date_of_birth']) {
                return false;
            }
            //Check Age is on range
            return TimeHelper::isTimeOnRange($item['date_of_birth'], Carbon::today(), $min, TimeTypes::YEAR, $max, TimeTypes::YEAR);
        })->count();
    }

}