<?php


namespace App\Services\Segment\SegmentType;


use App\Helpers\ModelHelper;
use App\Helpers\TimeHelper;
use App\Models\Segment\EmploymentPhaseSegment;
use App\Models\User\Employee;
use App\Services\AuthBaseService;
use Carbon\Carbon;

/**
 * Class GetSegmentTypeDetailEmploymentPhase
 * @package App\Services\Segment\SegmentType
 */
class GetSegmentTypeDetailEmploymentPhaseData extends AuthBaseService
{
    /**
     * @var array
     */
    protected $existedEmployee = array();

    /**
     * @param array $options
     * @return mixed
     * @throws \Illuminate\Validation\ValidationException
     */
    public function performAction($args)
    {
        $segments = $this->getDataSegments();
        return $segments;
    }

    /**
     * @param $clientId
     * @return array
     */
    public function getDataSegments()
    {
        //TODO: add order priority for this segment
        $segments = EmploymentPhaseSegment::all()->sortByDesc('id');

        $employeesQuery = Employee::query()->has('user');
        ModelHelper::setConditionFindByClient($employeesQuery);
        $employees = $employeesQuery->get();

        $result = array();
        foreach ($segments as $key => $segment) {
            $segment->employees = $this->getEmployeeInRange($employees, $segment);
            $result[] = $segment;
        }
        $result = collect(array_reverse($result));

        return $result;
    }

    /**
     * @param $employees
     * @param $min
     * @param $max
     * @return mixed
     */
    public function getEmployeeInRange($employees, $segment)
    {
        return $employees->filter(function($item) use ($segment) {
            $dateString = $item->{$segment->type};
            if (!$dateString) {
                return false;
            }
            $date = new Carbon($dateString);
            $isInSegment = TimeHelper::isTimeOnRange($date, Carbon::today(), $segment->min, $segment->type_min, $segment->max, $segment->type_max)
                && !in_array($item->getKey(), $this->existedEmployee);
            if ($isInSegment) {
                $this->existedEmployee[] = $item->getKey();
            }
            return $isInSegment;
        });
    }


}