<?php


namespace App\Services\Segment\SegmentType;


use App\Enum\EmployeeStatus;
use App\Helpers\ModelHelper;
use App\Helpers\SortFluent;
use App\Models\User\Employee;
use App\Models\User\User;
use App\Services\BaseService;
use App\Traits\Pageable;
use Illuminate\Support\Facades\DB;

/**
 * Class GetSegmentTypeDetail
 * @package App\Services\Segment
 */
class GetSegmentTypeDetailManager extends BaseService
{
    use Pageable;

    /**
     * @param array $options
     * @return mixed
     * @throws \Illuminate\Validation\ValidationException
     */
    public function performAction(array $options)
    {
        $query = User::manager();

        $query->select('users.first_name', 'users.surname', 'users.profile_pic', 'users.' . User::getBusinessKeyName());
        $query->leftJoin('employees', 'users.id', 'employees.user_id');


        ModelHelper::setConditionFindByClient($query);

        //count for total user
        $queryTotalEmployee = $this->getQueryTotalEmployee();

        $query->leftjoin(
            DB::raw("(" . $queryTotalEmployee->toSql() . ") as total_employee"),
            function($join) use ($queryTotalEmployee) {
                $join->on('users.id', '=', 'total_employee.user_id')
                    ->addBinding($queryTotalEmployee->getBindings());
                // bindings for sub-query WHERE added
            }
        );
        $query->addSelect('total_employee.count as total_employee');

        //count for total user active
        $queryTotalEmployeeActive = $this->getQueryTotalEmployee(EmployeeStatus::ACTIVE);

        $query->leftjoin(
            DB::raw("(" . $queryTotalEmployeeActive->toSql() . ") as active_employee"),
            function($join) use ($queryTotalEmployeeActive) {
                $join->on('users.id', '=', 'active_employee.user_id')
                    ->addBinding($queryTotalEmployeeActive->getBindings());
                // bindings for sub-query WHERE added
            }
        );
        $query->addSelect('active_employee.count as active_employee');


        SortFluent::init()
            ->setQuery($query)
            ->setTable('users')
            ->setSortOptions($options)
            ->setAllowedSorts(['name', 'active_employee', 'total_employee'])
            ->validate()
            ->removeSort(['name', 'active_employee', 'total_employee'])
            ->setCustomSort('name', function($query, $col, $direction) {
                SortFluent::applyBasicSort($query, 'first_name', $direction, 'users');
                SortFluent::applyBasicSort($query, 'surname', $direction, 'users');
            })
            ->setCustomSort('total_employee', function($query, $col, $direction) {
                SortFluent::applyBasicSort($query, 'total_employee', $direction);
            })
            ->setCustomSort('active_employee', function($query, $col, $direction) {
                SortFluent::applyBasicSort($query, 'active_employee', $direction);
            })
            ->applySort();

        return $this->applyPaging($options, $query);
    }


    /**
     * @param int $status
     * @return \Illuminate\Database\Eloquent\Builder|mixed
     */
    public function getQueryTotalEmployee(string $status = "")
    {
        $query = Employee::query()->has('user')
            ->groupBy('employees.manager_id')
            ->select(DB::raw('count(employees.id) as count, employees.manager_id as user_id'));
        if ($status) {
            $query->where('employees.status', $status);
        }
        ModelHelper::setConditionFindByClient($query);
        return $query;
    }
}