<?php

namespace App\Services\Subscription;

use App\Contracts\Validatable;
use App\Helpers\StripeHelper;
use App\Models\Client\Client;
use App\Services\BaseService;
use App\Services\Client\Traits\CheckStripe;
use Carbon\Carbon;
use Stripe\Exception\ApiErrorException;

class AddTrial extends BaseService implements Validatable
{
    use CheckStripe;
    
    public function getRules(array $args)
    {
        return [
            'code' => 'required',
            'month_interval' => 'required|integer'
        ];
    }

    /**
     * Add trial period for client subscription
     * 
     * @param array $data
     * @return bool|\Stripe\Subscription
     * @throws ApiErrorException
     */
    public function performAction(array $data)
    {
        $client = Client::findByBusinessKey($data['code']);
        
        if (!empty($client->stripe_cus_id)) {
            $subscription = $this->checkValidStripeCustomer($client->stripe_cus_id);
            if (!empty($subscription)) {
                if (empty($subscription->trial_end) || ($subscription->trial_end < Carbon::now()->unix())) {
                    $trialEnd = Carbon::now()->addMonths($data['month_interval'])->unix();
                } else {
                    $periodTrialStart = $subscription->trial_end;
                    $trialEnd = Carbon::createFromTimestamp($periodTrialStart)->addMonths($data['month_interval'])->unix();
                }
                
                $params = [
                    'trial_end' => $trialEnd,
                    'proration_behavior' => 'none',
                ];

                return (new StripeHelper())->updateSubscription($subscription->id, $params);
            }
        }

        return false;
    }
}
