<?php

namespace App\Services\Subscription;

use App\Contracts\Validatable;
use App\Events\CardChanged;
use App\Facades\Context;
use App\Helpers\StripeHelper;
use App\Services\BaseService;
use Stripe\Exception\ApiErrorException;

class ChangeCard extends BaseService implements Validatable
{

    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'token' => 'required'
        ];
    }
    
    /**
     * Change card
     * 
     * @param array $data
     * @return \Stripe\AlipayAccount|\Stripe\BankAccount|\Stripe\BitcoinReceiver|\Stripe\Card|\Stripe\Source
     * @throws ApiErrorException
     */
    public function performAction(array $data)
    {
        $currentClient = Context::client()->get();
        $stripeCustomerId = $currentClient->stripe_cus_id;
        
        $stripeHelper = new StripeHelper();
        $oldCards = $stripeHelper->getAllCustomerCards($stripeCustomerId);
        
        // Delete old cards
        foreach ($oldCards as $oldCard) {
            $stripeHelper->deleteCustomerSource($stripeCustomerId, $oldCard->id);
        }
        
        event(new CardChanged($currentClient));

        return $stripeHelper->createCustomerSource($stripeCustomerId, $data['token']);
    }
}
