<?php


namespace App\Services\Subscription;

use App\Enum\ConfigurationTypes;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Models\Subscription\PlanConfiguration;
use App\Services\InternalBaseService;

class CheckRemainPlanAction extends InternalBaseService
{
    /**
     * @var
     */
    protected $currentClient;
    /**
     * @var
     */
    protected $currentPlan;
    /**
     * @var
     */
    protected $currentConfigurations;

    /**
     * Get list plans
     * @param array $options
     * @return mixed
     */
    public function execute(string $model, $isThrowError = true)
    {
        $isAllowAction = $this->isAllowAction($model);
        if($isThrowError && !$isAllowAction)
        {
            throw new InvalidRequestException('Out of plan', ErrorCode::OUT_OF_PLAN);
        }
        return $isAllowAction;
    }

    /**
     * @param string $model
     * @return bool
     */
    private function isAllowAction(string $model)
    {
        if (Context::user()->check() && Context::user()->get()->isSuperAdmin()) {
            return true;
        }
        
        $planConfiguration = PlanConfiguration::where('name', $model)->first();
        $remainConfigurationPlan = app(GetRemainPlan::class)->execute(["model" => $model]);
        if ($planConfiguration->type === ConfigurationTypes::NUMBER) {
            return !($remainConfigurationPlan->{$model}["remain"] <= 0);
        } else {
            return $remainConfigurationPlan->{$model}["value"];
        }
    }
}
