<?php


namespace App\Services\Subscription;

use App\Contracts\Transactionable;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Models\Subscription\SubscriptionPlan;
use App\Services\BaseService;
use App\Traits\Pageable;
use App\Traits\Sortable;

class DeleteSubscriptionPlan extends BaseService implements Transactionable
{
    use Sortable, Pageable;
    /**
     * Get list plans
     * @param array $options
     * @return mixed
     */
    public function performAction(array $args)
    {

        $subscriptionPlan = SubscriptionPlan::findByBusinessKey($args['code']);
        if($subscriptionPlan->clients->count() > 0)
        {
            throw new InvalidRequestException(
                "This plan is being used by client. To delete this plan, please ensure this doesn't apply anywhere.",
                ErrorCode::PLAN_IN_USED
            );
        }
        $subscriptionPlan->planConfigurations()->detach();
        $subscriptionPlan->delete();
    }
}
