<?php


namespace App\Services\Subscription;

use App\Contracts\Transactionable;
use App\Facades\Context;
use App\Models\Subscription\SubscriptionPlan;
use App\Models\Survey\Survey;
use App\Services\BaseService;

/**
 * Class UpdateSurvey
 * @package App\Services\Tool\Survey
 */
class DuplicateSubscriptionPlan extends BaseService implements Transactionable
{
    const DUPLICATED_SURVEY_NAME = 'Copy of :plan';


    /**
     * Create survey
     *
     * @param array $data
     * @return Survey
     */
    public function performAction(array $args): SubscriptionPlan
    {
        $plan = SubscriptionPlan::findByBusinessKey($args['code']);

        $newPlan = $plan->replicate();
        $newPlanName = str_replace(':plan', $plan->name, self::DUPLICATED_SURVEY_NAME);
        $newPlan->name = $newPlanName;
        $newPlan->is_public = false;
        $newPlan->created_by = Context::user()->get()->getKey();
        $newPlan->save();

        foreach ($plan->planConfigurations as $planConfiguration) {
            $newPlan->planConfigurations()->attach($planConfiguration->getKey(), ['value' => $planConfiguration->pivot->value]);
        }

        return $newPlan->fresh();
    }


}
