<?php

namespace App\Services\Subscription;

use App\Contracts\Performable;
use App\Facades\Context;
use App\Helpers\StripeHelper;
use App\Services\BaseService;
use Stripe\Exception\ApiErrorException;

class GetInvoice extends BaseService implements Performable
{
    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Get customer invoices
     *
     * @param array $options
     * @return mixed
     * @throws ApiErrorException
     */
    public function performAction(array $options)
    {

        $currentClient = Context::client()->get();
        $stripeHelper = new StripeHelper();
        
        if (isset($options['page']['size'])) { 
            $invoices = $stripeHelper->getCustomerInvoices($currentClient->stripe_cus_id, $options['page']['size']);
        } else {
            $invoices = $stripeHelper->getCustomerInvoices($currentClient->stripe_cus_id);
        }
        
        return $invoices;
    }
}
