<?php


namespace App\Services\Subscription;


use App\Enum\ConfigurationTypes;
use App\Enum\PlanConfigurations;
use App\Enum\Roles;
use App\Helpers\ConfigurationHelper;
use App\Models\Journey\Journey;
use App\Models\Library\LibraryItem;
use App\Models\Quiz\Quiz;
use App\Models\Survey\Survey;
use App\Models\User\Employee;
use App\Services\BaseService;
use App\Services\Client\GetCompany;
use stdClass;

/**
 * Class GetAdminCurrentCompany
 * @package App\Services\Client
 */
class GetRemainPlan extends BaseService
{
    /**
     * @var
     */
    protected $currentClient;
    /**
     * @var
     */
    protected $currentPlan;
    /**
     * @var
     */
    protected $currentConfigurations;

    /**
     * @return mixed
     */
    public function performAction($options = [])
    {
        //TODO
        //Use client context
        //Add new plan context
        $this->currentClient = $this->getCurrentCompany();
        $this->currentPlan = $this->currentClient->subscriptionPlan;
        $this->currentConfigurations = $this->currentPlan->planConfigurations;
        $model = $options['model'] ?? '';
        return $this->getRemainPlan($model);
    }

    /**
     * @return mixed
     */
    public function getCurrentCompany()
    {
        return app(GetCompany::class)->execute();
    }

    /**
     * Get remain plan
     * @param string $configName
     * @return stdClass
     */
    public function getRemainPlan(string $configName = '')
    {
        $result = new stdClass();
        if ($configName) {
            $result->{$configName} = $this->getRemainConfig($configName);
        } else {
            foreach ($this->currentConfigurations as $configuration) {
                $result->{$configuration->name} = $this->getRemainConfig($configuration->name);
            }
        }
        return $result;

    }

    /**
     * Get remain by config
     * @param $configName
     * @return array
     */
    public function getRemainConfig($configName)
    {
        $plan = $this->currentConfigurations->where('name', $configName)->first();
        if ($plan->type === ConfigurationTypes::NUMBER) {
            return $this->getDataConfigCustom($plan);
        } else {
            return $this->getDataConfigBasic($plan);
        }
    }

    /**
     * Get data config for field need calculate
     * @param $plan
     * @return array
     * @throws \Exception
     */
    public function getDataConfigCustom($plan)
    {
        $value = $this->getPlanConfigurationValue($plan);
        $clientId = $this->currentClient->getKey();

        switch ($plan->name) {
            case PlanConfigurations::PACKAGE_EMPLOYEE:
                $currentValue = Employee::ofClient($clientId)->active()->count();
                break;
            case PlanConfigurations::PACKAGE_JOURNEY:
                $currentValue = Journey::ofClient($clientId)->where('is_published', true)->count();
                break;
            case PlanConfigurations::PACKAGE_DOCUMENT:
                $currentValue = LibraryItem::ofClient($clientId)->count();
                break;
            case PlanConfigurations::PACKAGE_QUIZ:
                $currentValue = Quiz::ofClient($clientId)->where('is_published', true)->count();
                break;
            case PlanConfigurations::PACKAGE_SURVEY:
                $currentValue = Survey::ofClient($clientId)->where('is_published', true)->count();
                break;
            case PlanConfigurations::PACKAGE_ADMINISTRATOR:
                $currentValue = Employee::ofClient($clientId)->active()
                    ->whereHas('user', function ($q) {
                        $q->role(Roles::ADMIN);
                    })
                    ->count();
                break;
            default:
                throw new \Exception('Undefined plan configuration');
        }
        $remain = $value - $currentValue;
        
        return [
            'value' => $value,
            'used' => $currentValue,
            'remain' => $remain
        ];
    }

    /**
     * @param $plan
     * @return array
     */
    public function getDataConfigBasic($plan)
    {
        return [
            'value' => $this->getPlanConfigurationValue($plan)
        ];
    }

    /**
     * @param $plan
     * @return bool|float|int|string
     */
    public function getPlanConfigurationValue($plan)
    {
        $value = ConfigurationHelper::convertDataByType($plan->pivot->value, $plan->type);
        return $value;
    }
}