<?php


namespace App\Services\Subscription;

use App\Facades\Context;
use App\Helpers\SortFluent;
use App\Models\Subscription\SubscriptionPlan;
use App\Services\BaseService;
use App\Traits\Pageable;
use App\Traits\Sortable;
use Illuminate\Validation\ValidationException;

class GetSubscriptionPlans extends BaseService
{
    use Sortable, Pageable;

    /**
     * Get plan list
     * 
     * @param array $options
     * @return mixed
     * @throws ValidationException
     */
    public function performAction(array $options)
    {
        $query = SubscriptionPlan::query();
        $currentUser = Context::user()->get();

        if (!$currentUser->isSuperAdmin()) {
            $currentPlan = app(GetCurrentPlan::class)->execute();
            $query->public()->orWhere('id', $currentPlan->getKey());
        }
        
        $query->withCount('clients');
        SortFluent::init()
            ->setQuery($query)
            ->setTable('plans')
            ->setSortOptions($options)
            ->setAllowedSorts(['name', 'description', 'cost', 'clients_count', 'created_at', 'updated_at'])
            ->validate()
            ->removeSort(['clients_count'])
            ->setCustomSort('clients_count', function ($query, $col, $direction) {
                SortFluent::applyBasicSort($query, 'clients_count', $direction);
            })
            ->applySort();
        
        return $this->applyPaging($options, $query);
    }
}
