<?php


namespace App\Services\Subscription;

use App\Contracts\Validatable;
use App\Enum\PackageSupportType;
use App\Enum\QualeeStatus;
use App\Models\Subscription\PlanConfiguration;
use App\Models\Subscription\SubscriptionPlan;
use App\Services\BaseService;
use App\Traits\Pageable;
use App\Traits\Sortable;

class UpdateSubscriptionPlan extends BaseService implements Validatable
{
    use Sortable, Pageable;

    public function getRules($args)
    {
        return [
            'code' => 'required|string',
            'name' => 'string',
            'description' => 'string',
            'cost' => 'numeric',
            'price_per_employee' => 'required',
            'stripe_price' => 'string',
            'stripe_prod' => 'string',
            'is_public' => 'boolean',
            'status' => ['string', function($attribute, $value, $fail) {
                if (!in_array($value, QualeeStatus::LIST_STATUS)) {
                    $fail(__('validation.invalid', ['attribute' => $attribute]));
                }
            }],
            'config' => 'required|array',
            'config.package_employee' => 'required|integer',
            'config.package_journey' => 'required|integer',
            'config.package_document' => 'required|integer',
            'config.package_quiz' => 'required|integer',
            'config.package_survey' => 'required|integer',
            'config.package_administrator' => 'required|integer',
            'config.package_support_type' => ['required', 'string', function($attribute, $value, $fail) {
                if (!in_array($value, PackageSupportType::LIST_TYPE)) {
                    $fail(__('validation.invalid', ['attribute' => $attribute]));
                }
            }],
            'config.package_dedicated_engagement_specialist' => 'required|boolean',
            'config.package_engagement_module' => 'required|boolean',
            'config.package_custom_colour' => 'required|boolean',
            'config.package_message' => 'required|boolean',
            'config.package_form' => 'required|boolean',
            'config.package_checklist' => 'required|boolean',
            'config.package_ai_document_search' => 'required|boolean',
            'config.package_id_verification' => 'required|boolean',
            'config.package_sso' => 'required|boolean',
            'config.package_integration' => 'required|boolean',
            'config.package_whistleblowing_capabilities' => 'required|boolean',
        ];
    }



    /**
     * Get list plans
     * @param array $options
     * @return mixed
     */
    public function performAction(array $data)
    {
        $data = collect($data);
        $subscriptionPlan = SubscriptionPlan::findByBusinessKey($data['code']);
        $subscriptionPlan->update($data->except('config')->toArray());
        $subscriptionPlan->planConfigurations()->detach();
        foreach ($data['config'] as $key => $config) {
            $planConfiguration = PlanConfiguration::where('name', $key)->first();
            if ($planConfiguration) {
                $subscriptionPlan->planConfigurations()->attach($planConfiguration->getKey(), ['value' => $config]);
            }
        }
        return $subscriptionPlan->fresh();
    }
}
