<?php

namespace App\Services\SuperAdmin\Actionable;

use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Exceptions\InvalidRequestException;
use App\Helpers\ActionRequestHelper;
use App\Helpers\PermissionHelper;
use App\Jobs\IndexPowerSearch;
use App\Models\Quiz\Quiz;
use App\Services\BaseService;

class DeleteQuiz extends BaseService implements Validatable, Transactionable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required',
        ];
    }

    /**
     * Delete quiz
     *
     * @param array $data
     * @return bool
     */
    public function performAction(array $data): bool
    {
        $quiz = Quiz::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($quiz);

        // Check if quiz is in-used
        if (count($quiz->actionRequests) > 0) {
            $firstActionRequest = $quiz->actionRequests->first();
            $actionName = ActionRequestHelper::getActionableName(
                $firstActionRequest->actionable_type, $firstActionRequest->actionable
            );
            $actionType = ActionRequestHelper::getActionableType($firstActionRequest->actionable_type);
            throw new InvalidRequestException("This quiz is used in $actionName $actionType. To Delete the quiz, please remove it from the $actionType first.");
        }

        foreach ($quiz->questions as $question) {
            $question->options()->delete();
            $question->delete();
        }
        IndexPowerSearch::dispatch($quiz->getBusinessKey(), PowerSearchTypes::QUIZ, PowerSearchActions::DELETE, $quiz->getClientId());
        $quiz->forceDelete();

        return true;
    }

}