<?php

namespace App\Services\SuperAdmin\Actionable;

use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Exceptions\InvalidRequestException;
use App\Helpers\ActionRequestHelper;
use App\Helpers\PermissionHelper;
use App\Jobs\IndexPowerSearch;
use App\Models\Survey\Survey;
use App\Services\BaseService;

class DeleteSurvey extends BaseService implements Validatable, Transactionable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required|string',
        ];
    }

    /**
     * Delete event
     *
     * @param array $data
     * @return bool
     */
    public function performAction(array $data): bool
    {

        $survey = Survey::findByBusinessKey($data['code']);

        PermissionHelper::hasAccessOn($survey);

        // Check if survey is in-used
        if (count($survey->actionRequests) > 0) {
            $firstActionRequest = $survey->actionRequests->first();
            $actionName = ActionRequestHelper::getActionableName(
                $firstActionRequest->actionable_type, $firstActionRequest->actionable
            );
            $actionType = ActionRequestHelper::getActionableType($firstActionRequest->actionable_type);
            throw new InvalidRequestException("This survey is used in $actionName $actionType. To Delete the survey, please remove it from the $actionType first.");
        }

        foreach ($survey->surveyQuestions as $surveyQuestion) {
            $surveyQuestion->surveyOptions()->delete();
            $surveyQuestion->delete();
        }
        IndexPowerSearch::dispatch($survey->getBusinessKey(), PowerSearchTypes::SURVEY, PowerSearchActions::DELETE, $survey->getClientId());
        $survey->forceDelete();

        return true;
    }
}
