<?php

namespace App\Services\Tool\Form;

use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\PandaDocHelper;
use App\Services\BaseService;
use App\Helpers\ObjectHelper;

class CheckValidTemplate extends BaseService implements Validatable
{

    public function getRules(array $data)
    {
        return [
            'template_id' => 'required|string',
            'replacements' => 'nullable|array',
            'is_throw' => 'nullable|boolean',
        ];
    }

    /**
     * Check valid form template
     * 
     * @param array $args
     * @return bool
     */
    public function performAction(array $args): bool
    {
        $client = Context::client()->get();

        $replacements = ObjectHelper::nullOrValue($args, 'replacements') ?? [];
        $isThrow = (bool) (ObjectHelper::nullOrValue($args, 'is_throw') ?? true);

        $formAuthenticate = $client->formAuthenticate;
        if (empty($formAuthenticate)) {
            if ($isThrow) {
                throw new InvalidRequestException('Form is not integrated', ErrorCode::FORM_NOT_INTEGRATED, $replacements);
            }
            return false;
        }
        $pandaDocHelper = (new PandaDocHelper())->setToken($formAuthenticate->access_token);
        $templateDetail = $pandaDocHelper->getTemplateDetail($args['template_id']);
        if (!$pandaDocHelper->checkTemplateHasSignerRole($templateDetail)) {
            if ($isThrow) {
                throw new InvalidRequestException(
                    "The template must have '" . PandaDocHelper::SIGNER_ROLE . "' role",
                    ErrorCode::FORM_TEMPLATE_MUST_HAVE_SIGNER_ROLE,
                    $replacements
                );
            }
            return false;
        }

        if (!$pandaDocHelper->checkTemplateHasAllFieldsAssigned($templateDetail)) {
            if ($isThrow) {
                throw new InvalidRequestException(
                    'The template has all fields were unassigned',
                    ErrorCode::FORM_TEMPLATE_HAS_ALL_FIELDS_UNASSIGNED,
                    $replacements
                );
            }
            return false;
        }

        return true;
    }
}