<?php

namespace App\Services\Tool\Form;

use App\Helpers\PandaDocHelper;
use App\Models\ActionRequest\ActionRequest;
use App\Models\Form\FormTemplate;
use App\Models\User\User;
use App\Services\BaseService;
use App\Services\InternalBaseService;

class CreatePandaDocument extends InternalBaseService
{
    const DOCUMENT_NAME_FORMAT = ':surname, :firstName - :templateName';

    /**
     * Create and send Panda document
     *
     * @param FormTemplate $template
     * @param User $user
     * @param ActionRequest $actionRequest
     * @param PandaDocHelper $pandaDocHelper
     * @return void
     */
    public function execute(FormTemplate $template, User $user, ActionRequest $actionRequest, PandaDocHelper $pandaDocHelper)
    {
        $recipients = [
            [
                'email' => $user->email,
                'first_name' => $user->first_name,
                'last_name' => $user->last_name,
                'role' => PandaDocHelper::SIGNER_ROLE
            ]
        ];

        $documentName = str_replace(
            [':surname', ':firstName', ':templateName'],
            [$user->surname, $user->first_name, $template->name],
            self::DOCUMENT_NAME_FORMAT
        );

        $createdDocument = $pandaDocHelper->createDocumentFromTemplate(
            $template->template_id,
            $documentName,
            $recipients
        );

        if ($createdDocument) {
            $sentDocument = $pandaDocHelper->sendDocument($createdDocument['id']);

            app(CreateDocument::class)->execute([
                'form_template_id' => $template->id,
                'user_id' => $user->id,
                'document_id' => $createdDocument['id'],
                'name' => $createdDocument['name'],
                'is_sent' => $sentDocument ?
                    ($sentDocument['status'] == $pandaDocHelper::DOCUMENT_SENT_STATUS) : false,
                'action_request_id' => $actionRequest->id
            ]);
        }
    }
}
