<?php

namespace App\Services\Tool\Form;

use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Enum\PlanConfigurations;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\PandaDocHelper;
use App\Models\Form\FormAuthenticate;
use App\Services\BaseService;
use App\Services\Subscription\CheckRemainPlanAction;

class IntegrateForm extends BaseService implements Validatable
{
    public function getRules(array $args): array
    {
        return [
            'code' => 'required|string',
        ];
    }

    /**
     * Integrate form
     *
     * @param array $args
     * @return FormAuthenticate
     */
    function performAction(array $args): FormAuthenticate
    {
        app(CheckRemainPlanAction::class)->execute(PlanConfigurations::PACKAGE_FORM);
        
        $client = Context::client()->get();
        $token = (new PandaDocHelper())->createAccessToken($args['code']);

        if (!$token) {
            throw new InvalidRequestException('Invalid authorization code', ErrorCode::INVALID_AUTH_CODE);
        }

        return FormAuthenticate::updateOrCreate(
            ['client_id' => $client->getKey()],
            [
                'client_id' => $client->getKey(),
                'access_token' => $token['access_token'],
                'token_type' => $token['token_type'],
                'expires_in' => $token['expires_in'],
                'scope' => $token['scope'],
                'refresh_token' => $token['refresh_token']
            ]);
    }
}
