<?php

namespace App\Services\Tool\Form;

use App\Contracts\Performable;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\PandaDocHelper;
use App\Models\Form\FormTemplate;
use App\Services\BaseService;

class SyncTemplates extends BaseService implements Performable
{
    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     *  Sync form templates
     *
     * @param  array  $data
     * @return array
     */
    public function performAction(array $data)
    {

        $currentClient = Context::client()->get();
        $formAuthenticate = $currentClient->formAuthenticate;

        if (empty($formAuthenticate)) {
            throw new InvalidRequestException('PandaDoc form is not integrated', ErrorCode::FORM_NOT_INTEGRATED);
        }

        $token = $formAuthenticate->access_token;

        // Get PandaDoc templates
        $pandaDocHelper = new PandaDocHelper();
        $pandaDocHelper->setToken($token);
        $templates = $pandaDocHelper->getTemplates();

        $newTemplates = [];
        //Delete old templates
        FormTemplate::where('client_id', $currentClient->id)->update(['is_active' => false]);
        foreach ($templates as $template) {
            $newTemplates[] = FormTemplate::updateOrCreate([
                'template_id' => $template['id'],
                'client_id'   => $currentClient->getKey(),
            ], [
                'template_id' => $template['id'],
                'name'        => $template['name'],
                'client_id'   => $currentClient->getKey(),
                'is_active'   => true
            ]);
        }

        return $newTemplates;
    }
}
