<?php

namespace App\Services\Tool\Journey;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Facades\Context;
use App\Jobs\IndexPowerSearch;
use App\Models\Journey\Journey;
use App\Services\BaseService;

class CreateJourney extends BaseService implements Validatable, Performable
{
    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($data)
    {
        return [
            'name' => 'required|string|max:255'
        ];
    }


    /**
     * Create journey
     *
     * @param array $data
     * @return Journey
     */
    public function performAction(array $data): Journey
    {
        $data['client_id'] = Context::client()->get()->getKey();
        $data['created_by'] = Context::user()->get()->getKey();

        $journey = Journey::create($data);
        IndexPowerSearch::dispatch($journey->getBusinessKey(), PowerSearchTypes::JOURNEY, PowerSearchActions::ADD, $journey->client_id);

        return $journey;
    }
}
