<?php

namespace App\Services\Tool\Journey;

use App\Contracts\Performable;
use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Helpers\UserAccessHelper;
use App\Jobs\IndexPowerSearch;
use App\Models\Journey\Journey;
use App\Services\ActionRequest\ClearActionRequestSubmission;
use App\Services\BaseService;
use Illuminate\Database\Eloquent\Model;

class DeleteJourney extends BaseService implements Validatable, Transactionable, Performable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'code' => 'required',
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Delete journey
     *
     * @param array $data
     * @return bool
     */
    public function performAction(array $data) : bool
    {
        $journey = Journey::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($journey);
        UserAccessHelper::hasAccessAsOwner($journey);

        foreach ($journey->steps as $step) {
            if ($step->actionRequest) {
                $this->clearActionRequestSubmission($step->actionRequest);
            }
            $step->actionRequest()->delete();
            $step->delete();
        }

        IndexPowerSearch::dispatch($journey->getBusinessKey(), PowerSearchTypes::JOURNEY, PowerSearchActions::DELETE, $journey->client_id);

        $journey->users()->detach();
        $journey->forceDelete();

        return true;
    }

    public function clearActionRequestSubmission(Model $actionRequest)
    {
        app(ClearActionRequestSubmission::class)->execute(['action_request' => $actionRequest]);
    }
}
