<?php

namespace App\Services\Tool\Journey;

use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Models\Journey\Journey;
use App\Services\ActionRequest\CreateActionRequest;
use App\Services\BaseService;

class DuplicateJourney extends BaseService implements Validatable
{
    const DUPLICATED_QUIZ_NAME = 'Copy of :journey';

    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'code' => 'required',
        ];
    }
    
    /**
     * Duplicate journey
     *
     * @param array $data
     * @return Journey
     */
    public function performAction(array $data): Journey
    {
        $journey = Journey::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($journey);
        
        $newJourney = $journey->replicate();
        $newJourneyName = str_replace(':journey', $journey->name, self::DUPLICATED_QUIZ_NAME);
        $newJourney->name = $newJourneyName;
        $newJourney->is_published = false;
        $newJourney->created_by = Context::user()->get()->getKey();
        $newJourney->save();

        foreach ($journey->steps as $step)
        {
            $newStep = $newJourney->steps()->create($step->toArray());
            
            $actionRequestData = $step->actionRequest->toArray();

            $contentableModel = $step->actionRequest->contentable;
            
            app(CreateActionRequest::class)->execute($actionRequestData, $newStep, $contentableModel);
        }

        return $newJourney->refresh();
    }
}
