<?php

namespace App\Services\Tool\Journey;

use App\Contracts\Validatable;
use App\Helpers\ModelHelper;
use App\Helpers\PermissionHelper;
use App\Models\Journey\Journey;
use App\Models\User\User;
use App\Services\ActionRequest\GetUserSubmission;
use App\Services\BaseService;

class GetEmployeeSubmission extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'code' => 'required', 
            'employee_code' => 'required'
        ];
    }

    /**
     * Get employee submission
     *
     * @param array $data
     * @return array
     * @throws \Exception
     */
    public function performAction(array $data)
    {
        $journey = Journey::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($journey);
        
        $userId = ModelHelper::convertBusinessKeyToId(User::class, $data['employee_code']);
        
        $stepSubmission = [];
        
        $journeysSteps = $journey->steps()->with('actionRequest')->get();
        foreach ($journeysSteps as $step) {
            $stepSubmission[] = [
                'step' => $step,
                'submission' => app(GetUserSubmission::class)->execute($step->actionRequest, $userId)
            ];
        }
        
        return $stepSubmission;
    }
}
