<?php

namespace App\Services\Tool\Journey;

use App\Enum\LibraryItemType;
use App\Facades\Context;
use App\Helpers\FilterFluent;
use App\Helpers\ModelHelper;
use App\Helpers\SortFluent;
use App\Helpers\UserAccessHelper;
use App\Models\Attachment;
use App\Models\Journey\Journey;
use App\Models\Journey\JourneyUser;
use App\Models\User\User;
use App\Services\BaseService;
use App\Traits\Pageable;
use App\Traits\Sortable;

class GetJourney extends BaseService
{
    use Sortable, Pageable;

    /**
     * List journey
     *
     * @param array $args
     * @return mixed
     */
    public function performAction(array $args)
    {
        $user = Context::user()->get();
        $options = Context::request()->getOptions();
        
        $query = Journey::query()->with(['steps.actionRequest', 'users', 'creator.avatar']);

        if (UserAccessHelper::isManager($user)) {
            $query->where('created_by', $user->getKey())
                ->orWhereIntegerInRaw('id', $this->getManagerJourneyIds($user));
        }

        FilterFluent::init()
            ->setQuery($query)
            ->setTable('journeys')
            ->setFilterOptions($options)
            ->setAllowedFilters(['name'])
            ->validate()->applyFilter();

        ModelHelper::setConditionFindByClient($query);

        $this->applySorting($options, $query);

        return $this->applyPaging($options, $query);
    }

    public function getManagerJourneyIds(User $manager): array
    {
        $staffUsers = UserAccessHelper::getManagerStaffUsers($manager);
        $journeyIds = JourneyUser::whereIntegerInRaw('user_id', $staffUsers->pluck('id')->toArray())
            ->pluck('journey_id')->toArray();

        return array_unique($journeyIds);
    }
}
