<?php


namespace App\Services\Tool\Journey;


use App\Contracts\Validatable;
use App\Enum\SubmissionStatus;
use App\Helpers\PermissionHelper;
use App\Models\Journey\Journey;
use App\Services\BaseService;

/**
 * Class GetJourneyProgress
 * @package App\Services\Tool\Journey
 */
class GetJourneyProgress extends BaseService implements Validatable
{
    /**
     * @var
     */
    protected $journeySteps;
    protected $journeyUsers;
    /**
     * Get the validation rules that apply to the service.
     *
     * @param  array  $args
     * @return array
     */
    public function getRules(array $args): array
    {
        return [
            'code' => 'required',
        ];
    }

    /**
     * Get journey detail
     *
     * @param  array  $args
     * @return mixed
     */
    public function performAction(array $args)
    {
        $journey = Journey::findByBusinessKey($args['code']);
        PermissionHelper::hasAccessOn($journey);
        //Get step by order
        $this->journeySteps = $journey->steps->sortBy('step_order')->load('actionRequest.submissions');
        $this->journeyUsers = $journey->users;

        $this->countUserBySubmissionStep();

        //first_step will include all remain users
        $this->journeySteps[0]->number_employee += $this->journeyUsers->count();
        return $this->journeySteps->sortBy('step_order');
    }

    /**
     * No need this function
     * If user have reject step, current progress will be this step
     */
    public function countUserByRejectStep(): void
    {
        //If have rejected step, user progress will be this step
        $this->journeySteps->each(function ($step,$stepKey) {
            $step->number_employee = 0;
            $rejectUsers = $step->actionRequest->submissions
                ->where('status', SubmissionStatus::REJECTED)
                ->pluck('user_id')
                ->toArray();
            //Exclude user have progress
            $this->journeyUsers = $this->journeyUsers->reject(function ($item) use ($rejectUsers, $stepKey) {
                //Check user have reject step
                $isHaveRejectStep = in_array($item->getKey(), $rejectUsers);
                if ($isHaveRejectStep) {
                    $this->journeySteps[$stepKey]->number_employee++;
                }
                return $isHaveRejectStep;
            });
        });
    }

    /**
     * If user don't have reject step, current progress will be at latest step
     */
    public function countUserBySubmissionStep(): void
    {
        $this->journeySteps = $this->journeySteps->sortByDesc('step_order');
        $this->journeySteps->each(function ($step, $key)  {
            $usersCurrentStepSubmission = $step->actionRequest->submissions
                ->pluck('user_id')
                ->toArray();
            //Exclude user have progress
            $this->journeyUsers = $this->journeyUsers->reject(function ($item) use ($usersCurrentStepSubmission,$key) {
                //Check user have submission
                $isUserHaveSubmissionInCurrentStep = in_array($item->getKey(), $usersCurrentStepSubmission);
                if ($isUserHaveSubmissionInCurrentStep) {
                    $this->increaseUserByStep($key);
                }
                return $isUserHaveSubmissionInCurrentStep;
            });
        });
    }

    /**
     * If user finish all step, his progress will be at last step
     * If user doesn't finish all step, his progress will be the latest step have submission + 1
     * If user doesn't do anything, his progress will be step 1
     * @param $key
     */
    public function increaseUserByStep($key): void
    {
        $this->journeySteps[$key]->number_employee++;
    }
}