<?php

namespace App\Services\Tool\Journey;

use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Enum\PlanConfigurations;
use App\Events\JourneyUpdated;
use App\Exceptions\InvalidRequestException;
use App\Helpers\PermissionHelper;
use App\Models\Journey\Journey;
use App\Services\BaseService;
use App\Services\Subscription\CheckRemainPlanAction;
use Carbon\Carbon;

class PublishJourney extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'code' => 'required'
        ];
    }
    

    /**
     * Publish journey
     *
     * @param array $data
     * @return Journey
     */
    public function performAction(array $data): Journey
    {
        app(CheckRemainPlanAction::class)->execute(PlanConfigurations::PACKAGE_JOURNEY);

        $journey = Journey::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($journey);
        
        if ($journey->steps()->count() === 0) {
            throw new InvalidRequestException('No journey steps to publish', ErrorCode::NO_STEPS_TO_PUBLISH);
        }
        
        $journey->is_published = true;
        $journey->published_at = Carbon::now();
        $journey->save();

        event(new JourneyUpdated($journey));
        
        return $journey->refresh();
    }
    
}
