<?php


namespace App\Services\Tool\Journey\QR;


use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Enum\QRTypes;
use App\Exceptions\InvalidRequestException;
use App\Models\QR\ActionToken;
use App\Services\BaseService;
use App\Services\Mobile\Journey\IsUserBelongsToJourney;

class GetJourneyDetailByQRToken extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'token' => 'required|string',
        ];
    }

    public function performAction(array $args)
    {
        $token = ActionToken::where('token', $args['token'])->firstOrFail();
        if ($token->type !== QRTypes::JOURNEY) {
            throw new InvalidRequestException('Invalid request', ErrorCode::INVALID_REQUEST);
        }
        $journey = $token->actionable;
        app(IsUserBelongsToJourney::class)->execute($journey->id);
        return $journey;
    }
}