<?php


namespace App\Services\Tool\Journey\QR;


use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Helpers\ActionRequestHelper;
use App\Helpers\PermissionHelper;
use App\Models\ActionRequest\ActionRequest;
use App\Models\Journey\JourneyStep;
use App\Services\BaseService;

class GetJourneyStepByQRToken extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'token' => 'required|string',
            'id' => 'required|int'
        ];
    }

    public function performAction(array $args)
    {
        //Check journey is valid
        $journey = app(GetJourneyDetailByQRToken::class)->execute($args);
        $actionRequest = ActionRequest::findOrFail($args['id']);
        if(!is_a($actionRequest->actionable, JourneyStep::class) || $actionRequest->actionable->journey_id !== $journey->id){
            throw new InvalidRequestException('Invalid request', ErrorCode::INVALID_REQUEST);
        }

        PermissionHelper::hasAccessOn($actionRequest);

        return $actionRequest;
    }
}