<?php


namespace App\Services\Tool\Journey\QR;


use App\Contracts\Performable;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Models\Journey\JourneyStep;
use App\Services\BaseService;
use App\Services\Mobile\ActionRequestSubmission\CreateActionRequestSubmission;
use App\Services\Mobile\Journey\IsStepAvailable;

class SubmitJourneyStepByQRToken extends BaseService implements Performable
{
    /**
     * @inheritDoc
     */
    public function canPerform(): bool
    {
        return Context::client()->check() && !Context::client()->get()->is_demo;
    }


    public function performAction($data)
    {
        $actionRequest = app(GetJourneyStepByQRToken::class)->execute($data);
        $isAvailable = $this->checkStepIsAvailable($actionRequest);
        if (!$isAvailable) {
            throw new InvalidRequestException('Journey step is not available', ErrorCode::JOURNEY_STEP_NOT_AVAILABLE);
        }
        PermissionHelper::hasAccessOn($actionRequest);
        unset($data['token']);
        return $this->createActionRequestSubmission($data, $actionRequest);
    }

    public function createActionRequestSubmission($content, $actionRequest)
    {
        return app(CreateActionRequestSubmission::class)->execute($content, $actionRequest);
    }

    public function checkStepIsAvailable($actionRequest)
    {
        $isAvailable = true;
        if (is_a($actionRequest->actionable, JourneyStep::class)) {
            $isAvailableObject = app(IsStepAvailable::class)->execute(['step' => $actionRequest->actionable]);
            $isAvailable = $isAvailableObject['status'];
        }
        return $isAvailable;
    }


}