<?php

namespace App\Services\Tool\Journey;

use App\Contracts\Validatable;
use App\Helpers\PermissionHelper;
use App\Models\Journey\Journey;
use App\Models\User\User;
use App\Services\BaseService;

class RemoveEmployee extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'code' => 'required', 
            'employee_code' => 'required'
        ];
    }
    

    /**
     * Remove employee from journey
     *
     * @param array $data
     * @return bool
     */
    public function performAction(array $data)
    {
        $journey = Journey::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($journey);
        
        $user = User::findByBusinessKey($data['employee_code']);

        $journey->users()->detach($user->getKey());

        $businessKeyName = config('app.bussiness_key_name');
        app(RestartJourneyUser::class)->execute(
            ['code' => $journey->{$businessKeyName}, 'employee_code' => $user->{$businessKeyName}]
        );
        
        return true;
    }
}
