<?php


namespace App\Services\Tool\Journey;


use App\Contracts\Validatable;
use App\Enum\NotificationTypes;
use App\Events\JourneyUpdated;
use App\Helpers\PermissionHelper;
use App\Jobs\SendNotification;
use App\Models\Journey\Journey;
use App\Services\ActionRequest\ClearActionRequestSubmission;
use App\Services\BaseService;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Auth;

class RestartJourney extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required|string'
        ];
    }

    /**
     * Restart all user submission of journey
     * 
     * @param array $data
     */
    public function performAction(array $data)
    {
        $journey = Journey::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($journey);

        foreach ($journey->steps as $step) {
            if ($step->actionRequest) {
                $this->clearActionRequestSubmission($step->actionRequest);
            }
        }
        $userIds = $journey->users->pluck('code')->toArray();
        if (!empty($userIds)) {
            $arguments = array(
                'sender' => Auth::user()->id,
                "userIds" => $userIds,
                "headings" => __("Your journey has restarted"),
                "contents" => __("New updates have been added. Tap to view."),
                "data" => [
                    "type" => NotificationTypes::JOURNEY_RESTARTED,
                    "code" => $data['code'],
                    "id" => $journey->id
                ],
                'send_after' => null
            );
            SendNotification::dispatch($arguments);
        }


        app(MarkJourneyUserAsInCompleted::class)->execute(['journey_id' => $journey->getKey()]);

        event(new JourneyUpdated($journey));
    }

    public function clearActionRequestSubmission(Model $actionRequest)
    {
        app(ClearActionRequestSubmission::class)->execute(['action_request' => $actionRequest]);
    }
}