<?php


namespace App\Services\Tool\Journey;


use App\Contracts\Validatable;
use App\Events\JourneyUpdated;
use App\Helpers\ModelHelper;
use App\Helpers\PermissionHelper;
use App\Models\Journey\Journey;
use App\Models\User\User;
use App\Services\ActionRequest\ClearActionRequestSubmission;
use App\Services\BaseService;
use Illuminate\Database\Eloquent\Model;

class RestartJourneyUser extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required|string',
            'employee_code' => 'required|string'
        ];
    }



    /**
     * Restart user submission
     * 
     * @param array $data
     */
    public function performAction(array $data)
    {
        $journey = Journey::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($journey);
        $userId = ModelHelper::convertBusinessKeyToId(User::class, $data['employee_code']);
        foreach ($journey->steps as $step) {
            if ($step->actionRequest) {
                $this->clearActionRequestSubmission($step->actionRequest, $userId);
            }
        }

        app(MarkJourneyUserAsInCompleted::class)->execute([
            'journey_id' => $journey->getKey(),
            'user_id' => $userId
        ]);

        event(new JourneyUpdated($journey));
    }

    public function clearActionRequestSubmission(Model $actionRequest, int $userId)
    {
        app(ClearActionRequestSubmission::class)->execute(['action_request' => $actionRequest, 'user_id' => $userId]);
    }
}