<?php


namespace App\Services\Tool\Journey;


use App\Contracts\Validatable;
use App\Enum\NotificationTypes;
use App\Exceptions\InvalidRequestException;
use App\Helpers\PermissionHelper;
use App\Jobs\SendNotification;
use App\Models\Journey\Journey;
use App\Models\User\User;
use App\Services\BaseService;
use Illuminate\Support\Facades\Auth;

class SendReminderUser extends BaseService implements Validatable
{
    public function getRules($args)
    {
        return [
            "user" => 'required|string',
            "journey_code" => "required|string"
        ];
    }

    /**
     * List journey
     *
     * @param array $options
     * @return mixed
     */
    public function performAction(array $data)
    {
        $journey = Journey::findByBusinessKey($data['journey_code']);
        PermissionHelper::hasAccessOn($journey);

        $user = User::findByBusinessKey($data['user']);
        $journey->users->find($user->id);
        //Check user belong to journey
        if (!$journey->users->contains($user->id)) {
            throw new InvalidRequestException(__("User does not belong to journey"));
        }
        $arguments = array(
            'sender' => Auth::user()->id,
            "userIds" => $user->getBusinessKey(),
            "headings" => __("A journey is pending"),
            "contents" => __("You need to complete your :name journey", ["name" => $journey->name]),
            "data"=>[
                "type" => NotificationTypes::JOURNEY_STEP_AVAILABLE,
                "id" => $journey->getKey()
            ]
        );
        SendNotification::dispatch($arguments);
    }
}