<?php

namespace App\Services\Tool\Journey;

use App\Contracts\Transactionable;
use App\Contracts\Validatable;
use App\Helpers\PermissionHelper;
use App\Models\Journey\Journey;
use App\Services\BaseService;

class UnpublishJourney extends BaseService implements Validatable, Transactionable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'code' => 'required'
        ];
    }

    /**
     * Unpublish journey
     *
     * @param array $data
     * @return Journey
     */
    public function performAction(array $data): Journey
    {
        $journey = Journey::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($journey);
        
        $journey->is_published = false;
        $journey->users()->detach();
        $journey->save();

        app(RestartJourney::class)->execute(['code' => $journey->code]);
        
        return $journey->refresh();
    }
    
}
