<?php

namespace App\Services\Tool\Journey;

use App\Contracts\Validatable;
use App\Enum\NotificationTypes;
use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Helpers\PermissionHelper;
use App\Helpers\UserAccessHelper;
use App\Jobs\IndexPowerSearch;
use App\Jobs\SendNotification;
use App\Models\Journey\Journey;
use App\Services\BaseService;
use Illuminate\Support\Facades\Auth;

class UpdateJourney extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($data)
    {
        return [
            'code' => 'required',
            'name' => 'required|string|max:255',
            'client_id' => 'integer|exists:clients,id'
        ];
    }


    /**
     * Update journey
     *
     * @param array $data
     * @return Journey
     */
    public function performAction(array $data): Journey
    {
        $journey = Journey::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($journey);
        UserAccessHelper::hasAccessAsOwner($journey);

        $journey->update($data);
        IndexPowerSearch::dispatch($journey->getBusinessKey(), PowerSearchTypes::JOURNEY, PowerSearchActions::ADD, $journey->client_id);
        $userIds = $journey->users->pluck('code')->toArray();
        if (!empty($userIds)) {
            $arguments = array(
                'sender' => Auth::user()->id,
                "userIds" => $userIds,
                "headings" => __("Your journey has been updated"),
                "contents" => __("Tap to view the changes"),
                "data" => [
                    "type" => NotificationTypes::JOURNEY_UPDATED,
                    "id" => $journey->id,
                ],
                'send_after' => null
            );
            SendNotification::dispatch($arguments);
        }

        return $journey->refresh();
    }
}
