<?php

namespace App\Services\Tool\Quiz;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Facades\Context;
use App\Jobs\IndexPowerSearch;
use App\Models\Quiz\Quiz;
use App\Services\BaseService;

class CreateQuiz extends BaseService implements Performable, Validatable
{
    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($data)
    {
        return [
            'name' => 'required|string|max:255'
        ];
    }
    /**
     * Create quiz
     *
     * @param array $data
     * @return Quiz
     */
    public function performAction(array $data): Quiz
    {

        $clientId = Context::client()->get()->getKey();
        $data['client_id'] = $clientId;
        $data['created_by'] = Context::user()->get()->getKey();
        $quiz = Quiz::create($data);
        IndexPowerSearch::dispatch($quiz->getBusinessKey(), PowerSearchTypes::QUIZ, PowerSearchActions::ADD, $quiz->getClientId());
        return $quiz;
    }
}
