<?php

namespace App\Services\Tool\Quiz;

use App\Contracts\Validatable;
use App\Helpers\ActionRequestHelper;
use App\Helpers\CsvHelper;
use App\Helpers\PermissionHelper;
use App\Http\Resources\Tool\Quiz\QuizQuestionDownload;
use App\Models\Action\Action;
use App\Models\Quiz\Quiz;
use App\Services\BaseService;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class DownloadQuiz extends BaseService implements Validatable
{

    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'code' => 'required',
        ];
    }

    /**
     * Get quiz detail
     *
     * @param array $data
     * @return Quiz
     */
    public function performAction(array $data)
    {
        $quiz = Quiz::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($quiz);

        $questions = QuizQuestionDownload::collection($quiz->questions()->with('options')->ordered()->get())->jsonSerialize();

        $header = ['Question', 'First name', 'Last name', 'Answer', 'Is correct', 'Journey', 'Action', 'Submitted at'];
        $folderName = Str::uuid();

        // Make it download
        Storage::disk('local')->makeDirectory($folderName);
        $folderPath = config('filesystems.disks.local.root') . '/' . $folderName;
        $filePath = $folderPath . '/' . $quiz->name . '.csv';

        $rows = [];
        foreach ($questions as $question) {
            foreach ($question['options'] as $option) {
                foreach ($option['report'] as $answer) {
                    $row = [$question['title'], $answer['first_name'], $answer['surname'], $option['content']];
                    $row[] = $option['is_correct'] ? 'Yes' : 'No';
                    $row[] = isset($answer['journey_name']) ? $answer['journey_name'] : '';
                    $actionName = '';
                    if (empty($actionName) && isset($answer['action_sequence_name'])) {
                        $actionName = $answer['action_sequence_name'];
                    } else if(isset($answer['actionable_type']) && $answer['actionable_type'] === Action::class) {
                        $actionName = ActionRequestHelper::getTypeNameByContentType($answer['contentable_type']);
                    }
                    $row[] = $actionName;
                    $row[] = date('y-n-j', strtotime($answer['created_at']));
                    $rows[] = $row;
                }
            }
        }
        CsvHelper::exportCsv($filePath, $rows, $header);
        return response()->download($filePath)->deleteFileAfterSend();
    }
}