<?php

namespace App\Services\Tool\Quiz;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Models\Quiz\Quiz;
use App\Services\BaseService;

class DuplicateQuiz extends BaseService implements Validatable, Performable
{
    const DUPLICATED_QUIZ_NAME = 'Copy of :quiz';
    
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required',
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Duplicate quiz
     *
     * @param array $data
     * @return Quiz
     */
    public function performAction(array $data): Quiz
    {
        $quiz = Quiz::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($quiz);
        
        $newQuiz = $quiz->replicate();
        $newQuizName = str_replace(':quiz', $quiz->name, self::DUPLICATED_QUIZ_NAME);
        $newQuiz->name = $newQuizName;
        $newQuiz->is_published = false;
        $newQuiz->created_by = Context::user()->get()->getKey();
        $newQuiz->save();

        foreach ($quiz->questions as $question)
        {
            $newQuestion = $newQuiz->questions()->create($question->toArray());

            foreach ($question->options as $option)
            {
                $newQuestion->options()->create($option->toArray());
            }
        }

        return $newQuiz->refresh();
    }
    
}
