<?php

namespace App\Services\Tool\Quiz;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Enum\PlanConfigurations;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Models\Quiz\Quiz;
use App\Services\BaseService;
use App\Services\Subscription\CheckRemainPlanAction;
use Carbon\Carbon;

class PublishQuiz extends BaseService implements Validatable, Performable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'code' => 'required'
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Publish quiz
     *
     * @param array $data
     * @return Quiz
     */
    public function performAction(array $data): Quiz
    {
        app(CheckRemainPlanAction::class)->execute(PlanConfigurations::PACKAGE_QUIZ);

        $quiz = Quiz::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($quiz);

        if ($quiz->questions()->count() === 0) {
            throw new InvalidRequestException('No questions to publish', ErrorCode::NO_QUESTIONS_TO_PUBLISH);
        }
        
        $quiz->is_published = true;
        $quiz->published_at = Carbon::now();
        $quiz->save();
        
        return $quiz->refresh();
    }
    
}
