<?php

namespace App\Services\Tool\Quiz;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Helpers\UserAccessHelper;
use App\Jobs\IndexPowerSearch;
use App\Models\Quiz\Quiz;
use App\Services\BaseService;

class UpdateQuiz extends BaseService implements Validatable, Performable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $data
     * @return array
     */
    public function getRules(array $data)
    {
        return [
            'code' => 'required',
            'name' => 'required|string|max:255',
            'client_id' => 'integer|exists:clients,id'
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Update quiz
     *
     * @param array $data
     * @return Quiz
     */
    public function performAction(array $data): Quiz
    {
        $quiz = Quiz::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($quiz);
        UserAccessHelper::hasAccessAsOwner($quiz);
        
        $quiz->update($data);
        
        IndexPowerSearch::dispatch($quiz->getBusinessKey(), PowerSearchTypes::QUIZ, PowerSearchActions::ADD, $quiz->getClientId());
        
        return $quiz->refresh();
    }
}
