<?php


namespace App\Services\Tool\Survey;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\PowerSearchActions;
use App\Enum\PowerSearchTypes;
use App\Facades\Context;
use App\Jobs\IndexPowerSearch;
use App\Models\Survey\Survey;
use App\Services\BaseService;

class CreateSurvey extends BaseService implements Validatable, Performable
{
    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'name' => 'required|string|max:255',
            'client_id' => 'integer|exists:clients,id'
        ];
    }

    /**
     * Create survey
     *
     * @param array $data
     * @return Survey
     */
    public function performAction(array $data): Survey
    {
        $survey = Survey::create($this->ensureData($data));
        IndexPowerSearch::dispatch($survey->getBusinessKey(), PowerSearchTypes::SURVEY, PowerSearchActions::ADD, $survey->getClientId());
        return $survey;
    }

    public function ensureData(array $data): array
    {
        $data['client_id'] = Context::client()->get()->getKey();
        $data['created_by'] = Context::user()->get()->getKey();
        //Default unpublish when create
        $data['is_published'] = 0;
        return $data;
    }

}
