<?php

namespace App\Services\Tool\Survey;

use App\Contracts\Validatable;
use App\Helpers\ActionRequestHelper;
use App\Helpers\CsvHelper;
use App\Helpers\PermissionHelper;
use App\Http\Resources\Tool\Survey\SurveyQuestionDownload;
use App\Models\Action\Action;
use App\Models\Survey\Survey;
use App\Services\BaseService;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class DownloadSurvey extends BaseService implements Validatable
{

    function performAction(array $args)
    {
        $survey = Survey::findByBusinessKey($args['code']);
        PermissionHelper::hasAccessOn($survey);

        $questions = SurveyQuestionDownload::collection($survey->surveyQuestions()->ordered()->get())->jsonSerialize();

        $header = ['Question', 'Type', 'First name', 'Last name', 'Answer', 'Score', 'Sentiment', 'Journey', 'Action', 'Submitted at'];
        $folderName = Str::uuid();

        // Make it download
        Storage::disk('local')->makeDirectory($folderName);
        $folderPath = config('filesystems.disks.local.root') . '/' . $folderName;
        $filePath = $folderPath . '/' . $survey->name . '.csv';

        $rows = [];
        foreach ($questions as $question) {
            foreach ($question['results'] as $result) {
                $row = [$question['title'], $question['type'], $result['first_name'], $result['surname']];
                switch ($question['type']) {
                    case 'rating':
                        $row[] = $result['rating'];
                        break;
                    case 'multi-choice':
                        $row[] = $result['content'];
                        break;
                    case 'text':
                        $row[] = $result['text'];
                        break;
                    default:
                        break;
                }
                $row[] = isset($result['positive_score']) ? $result['positive_score'] : '';
                $row[] = isset($result['sentiment']) ? $result['sentiment'] : '';
                $row[] = isset($result['journey_name']) ? $result['journey_name'] : '';
                $actionName = '';
                if (empty($actionName) && isset($result['action_sequence_name'])) {
                    $actionName = $result['action_sequence_name'];
                } else if(isset($result['actionable_type']) && $result['actionable_type'] === Action::class) {
                    $actionName = ActionRequestHelper::getTypeNameByContentType($result['contentable_type']);
                }
                $row[] = $actionName;
                $row[] = date('y-n-j', strtotime($result['created_at']));
                $rows[] = $row;
            }
        }
        CsvHelper::exportCsv($filePath, $rows, $header);
        return response()->download($filePath)->deleteFileAfterSend();
    }

    public function getRules(array $args)
    {
        return [
            'code' => 'required|string',
        ];
    }
}