<?php


namespace App\Services\Tool\Survey;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Models\Survey\Survey;
use App\Services\BaseService;

/**
 * Class UpdateSurvey
 * @package App\Services\Tool\Survey
 */
class DuplicateSurvey extends BaseService implements Validatable, Performable
{
    const DUPLICATED_SURVEY_NAME = 'Copy of :survey';

    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required|string',
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Create survey
     *
     * @param array $data
     * @return Survey
     */
    public function performAction(array $data): Survey
    {
        $survey = Survey::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($survey);

        $newSurvey = $survey->replicate();
        $newSurveyName = str_replace(':survey', $survey->name, self::DUPLICATED_SURVEY_NAME);
        $newSurvey->name = $newSurveyName;
        $newSurvey->is_published = false;
        $newSurvey->created_by = Context::user()->get()->getKey();
        $newSurvey->save();

        foreach ($survey->surveyQuestions as $question) {
            $newQuestion = $newSurvey->surveyQuestions()->create($question->toArray());

            foreach ($question->surveyOptions as $option) {
                $newQuestion->surveyOptions()->create($option->toArray());
            }
        }

        return $newSurvey->fresh();
    }


}
