<?php


namespace App\Services\Tool\Survey;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Enum\PlanConfigurations;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Models\Survey\Survey;
use App\Services\BaseService;
use App\Services\Subscription\CheckRemainPlanAction;
use Carbon\Carbon;

/**
 * Class UpdateSurvey
 * @package App\Services\Tool\Survey
 */
class PublishSurvey extends BaseService implements Validatable, Performable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required|string',
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Create survey
     *
     * @param array $data
     * @return Survey
     */
    public function performAction(array $data): Survey
    {
        app(CheckRemainPlanAction::class)->execute(PlanConfigurations::PACKAGE_SURVEY);

        $survey = Survey::findByBusinessKey($data['code']);

        PermissionHelper::hasAccessOn($survey);

        if ($survey->surveyQuestions()->count() === 0) {
            throw new InvalidRequestException('No questions to publish', ErrorCode::NO_QUESTIONS_TO_PUBLISH);
        }

        $survey->is_published = 1;
        $survey->published_at = Carbon::now();
        $survey->save();
        return $survey;
    }
}
