<?php


namespace App\Services\Tool\Survey;

use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\Facades\Context;
use App\Helpers\PermissionHelper;
use App\Helpers\UserAccessHelper;
use App\Models\Survey\Survey;
use App\Services\BaseService;

/**
 * Class UpdateSurvey
 * @package App\Services\Tool\Survey
 */
class UpdateSurvey extends BaseService implements Validatable, Performable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @return array
     */
    public function getRules($args)
    {
        return [
            'code' => 'required|string|max:255',
            'name' => 'string',
            'client_id' => 'integer|exists:clients,id'
        ];
    }

    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    /**
     * Create survey
     *
     * @param array $data
     * @return Survey
     */
    public function performAction(array $data): Survey
    {
        $survey = Survey::findByBusinessKey($data['code']);
        PermissionHelper::hasAccessOn($survey);
        UserAccessHelper::hasAccessAsOwner($survey);
        $survey->update($data);

        return $survey->fresh();
    }

}
