<?php

namespace App\Services\TwoFactorAuthentication;

use App\Enum\ClientConfigurations;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Models\Client\ClientConfiguration;
use App\Models\User\User;
use App\Services\InternalBaseService;

class Disable2FA extends InternalBaseService
{

    /**
     * Disable user 2FA
     *
     * @param User $user
     * @return User
     */
    public function execute(User $user) : User
    {
        // Prevent trying to disable 2fa when the client require enabling 2fa
        $client = $user->getClient();
        $clientConfiguration = ClientConfiguration::where('name', ClientConfigurations::CONFIG_REQUEST_TWO_FACTOR)->first();
        if (!empty($clientConfiguration)) {
            $configurationDetail = $client->clientConfigurations()
                ->where('configuration_id', $clientConfiguration->getKey())
                ->first();
            if (!empty($configurationDetail->pivot->value)) {
                throw new InvalidRequestException('Enabling two factor authentication is required', ErrorCode::ENABLING_2FA_REQUIRED);
            }
        }
        
        $user->google2fa_enable = false;
        $user->google2fa_secret = null;
        $user->save();

        return $user;
    }
}
