<?php

namespace App\Services\TwoFactorAuthentication;

use App\Exceptions\InvalidRequestException;
use App\Models\User\User;
use App\Services\InternalBaseService;

class Prepare2FA extends InternalBaseService
{

    /**
     * Enable 2FA code
     * 
     * @param User $user
     * @return array
     */
    public function execute(User $user)
    {
        if ($user->google2fa_enable) {
            throw new InvalidRequestException('2FA already enabled');
        }
        
        $google2FA = app('pragmarx.google2fa');
        $secret =  $google2FA->generateSecretKey();
        
        // Save temp secret key
        $user->google2fa_secret = $secret;
        $user->save();
        
        return $google2FA->getQRCodeInline(config('app.name'), $user->email, $secret);
    }
}
