<?php

namespace App\Services\TwoFactorAuthentication;

use App\Contracts\Validatable;
use App\Enum\ErrorCode;
use App\Exceptions\InvalidRequestException;
use App\Services\BaseService;
use Illuminate\Validation\ValidationException;

class Verify2FA extends BaseService implements Validatable
{
    /**
     * Get the validation rules that apply to the service.
     *
     * @param array $args
     * @return array
     */
    public function getRules(array $args)
    {
        return [
            'secret' => 'required',
            'one_time_password' => 'required|digits:6',
            'old_timestamp' => 'required|integer'
        ];
    }

    /**
     * Verify 2FA code
     * 
     * @param array $data
     * @return bool
     */
    public function performAction(array $data)
    {
        $google2FA = app('pragmarx.google2fa');
        $verified = $google2FA->verifyKeyNewer($data['secret'], $data['one_time_password'], $data['old_timestamp']);
        if (!$verified) {
            throw new InvalidRequestException('Invalid one time password code.', ErrorCode::INVALID_OTP);
        }

        return $verified;
    }
}
