<?php

namespace App\Services\User\Expiring;

use App\Enum\ClientConfigurations;
use App\Facades\Context;
use App\Helpers\ObjectHelper;
use App\Models\Client\ClientConfiguration;
use App\Models\User\User;
use App\Services\BaseService;
use Carbon\Carbon;


class Check2FAIsExpiring extends BaseService
{
    /**
     * @param array $args
     * @return bool|Carbon
     * @throws \Exception
     */
    function performAction(array $args) 
    {
        $user = $args['user'] ?? Context::user()->get();
        $dayInterval = $args['day_interval'] ?? 0;
        ObjectHelper::instanceOfClass($args['user'], User::class);

        $client = $user->getClient();
        $clientConfiguration = ClientConfiguration::where('name', ClientConfigurations::CONFIG_REQUEST_TWO_FACTOR)->first();
        if (!empty($clientConfiguration)) {
            $configurationDetail = $client->clientConfigurations()
                ->where('configuration_id', $clientConfiguration->getKey())
                ->first();
            if (!empty($configurationDetail->pivot->applied_date)) {
                $applied2FADate = Carbon::parse($configurationDetail->pivot->applied_date);
                $is2FAEnabled = $configurationDetail->pivot->value;
                if ($is2FAEnabled && !$user->google2fa_enable && $applied2FADate->lessThanOrEqualTo(Carbon::now())) {
                    return $applied2FADate->addDays($dayInterval);
                }
            }
        }

        return false;
    }
}
