<?php

namespace App\Services\User\Expiring;

use App\Facades\Context;
use App\Helpers\ObjectHelper;
use App\Helpers\StripeHelper;
use App\Models\User\User;
use App\Services\BaseService;
use Carbon\Carbon;
use Stripe\Exception\ApiErrorException;


class CheckCardIsExpiring extends BaseService
{
    /**
     * Check card is expiring
     *
     * @param array $args
     * @return bool|array
     * @throws ApiErrorException
     * @throws \Exception
     */
    function performAction(array $args) 
    {
        $user = $args['user'] ?? Context::user()->get();
        $dayInterval = $args['day_interval'] ?? 0;
        ObjectHelper::instanceOfClass($args['user'], User::class);

        $client = $user->getClient();
        if (!empty($client->stripe_cus_id)) {
            $card = (new StripeHelper())->getCustomerDefaultCard($client->stripe_cus_id);
            if (!empty($card)) {
                $cardExpMonth = $card->exp_month;
                $cardExpYear = $card->exp_year;
                if (!empty($cardExpMonth) && !empty($cardExpYear)) {
                    $cardExpiryDate = Carbon::createFromFormat('Y-m', "$cardExpYear-$cardExpMonth")->endOfMonth();
                    if ($cardExpiryDate->lessThanOrEqualTo(Carbon::now()->addDays($dayInterval))) {
                        return [
                            'expiry_date' => $cardExpiryDate,
                            'card' => $card
                        ];
                    }
                }
            }
        }

        return false;
    }
}
