<?php

namespace App\Services\User\Expiring;

use App\Enum\ClientConfigurations;
use App\Facades\Context;
use App\Helpers\ObjectHelper;
use App\Models\Client\ClientConfiguration;
use App\Models\User\User;
use App\Services\BaseService;
use Carbon\Carbon;


class CheckPasswordIsExpiring extends BaseService
{
    /**
     * Check user password is expiring
     * 
     * @param array $args
     * @return bool|Carbon
     * @throws \Exception
     */
    function performAction(array $args) 
    {
        $user = $args['user'] ?? Context::user()->get();
        $dayInterval = $args['day_interval'] ?? 0;
        ObjectHelper::instanceOfClass($args['user'], User::class);
        
        $clientConfiguration = ClientConfiguration::where('name', ClientConfigurations::CONFIG_ADMIN_PASSWORD_RESET)->first();
        $client = $user->getClient();
        if (!empty($clientConfiguration) && $client) {
            $configurationDetail = $client->clientConfigurations()
                ->where('configuration_id', $clientConfiguration->getKey())
                ->first();

            if (!empty($configurationDetail)) {
                $monthInterval = $configurationDetail->pivot->value;
                if (is_numeric($monthInterval)) {
                    $passwordUpdatedDate = $user->password_updated_at ?? $user->created_at;
                    $passwordExpiryDate = $passwordUpdatedDate->addMonths($monthInterval);
                    if ($passwordExpiryDate->lessThanOrEqualTo(Carbon::now()->addDays($dayInterval))) {
                        return $passwordExpiryDate;
                    }
                }
            }
        }

        return false;
    }
}
