<?php

namespace App\Services\User;
use App\Enum\Roles;
use App\Helpers\FilterFluent;
use App\Helpers\ModelHelper;
use App\Models\User\User;
use App\Services\BaseService;
use App\Traits\Filterable;
use App\Traits\Pageable;
use App\Traits\Sortable;
use Illuminate\Support\Facades\DB;

class GetAdminOrManagerUsers extends BaseService
{

    use Sortable, Pageable, Filterable;

    private $allowFilters = ['name'];

    /**
     * Get list event
     * @param array $options
     * @return mixed
     */
    public function performAction(array $options)
    {

        $queryResult = $this->getQueryUser($options);
        $this->applySorting($options, $queryResult);
        return $this->applyPaging($options, $queryResult);
    }

    public function getQueryUser($options)
    {
        $queryUser = User::query()->role([Roles::MANAGER, Roles::ADMIN]);
        //Only allow search admin and front user role
        $queryUser->has('employee');
        //If current user is admin, only allow get user belong to current client
        $queryUser->whereHas('employee', function ($query) {
            ModelHelper::setConditionFindByClient($query, "employees");
        });
        $queryUser->select('code', DB::raw("CONCAT(surname, ', ', first_name) as name "), 'attachment.path AS avatar', DB::raw("'user' as type"))
            ->leftJoin('attachment', 'profile_pic', 'attachment.id');

        FilterFluent::init()
            ->setQuery($queryUser)
            ->setFilterOptions($options)
            ->setAllowedFilters($this->allowFilters)
            ->removeFilter('name')
            ->validate()
            ->setCustomFilter('name', function($query, $type, $col, $value) {
                FilterFluent::applyCombinedColumnFilter($query, $type, 'surname', 'first_name', $value, 'users');
            })
            ->applyFilter();
        return $queryUser;
    }
}