<?php


namespace App\Services\User;

use App\Facades\Context;
use App\Helpers\FilterFluent;
use App\Helpers\ModelHelper;
use App\Models\Segment\Segment;
use App\Models\User\User;
use App\Services\BaseService;
use App\Traits\Filterable;
use App\Traits\Pageable;
use App\Traits\Sortable;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class GetSegmentAndUser extends BaseService
{
    use Sortable, Pageable, Filterable;

    private $allowFilters = ['name'];

    const TYPE_USER = 'user';
    const TYPE_SEGMENT = 'segment';

    /**
     * Get list event
     * @param array $options
     * @return mixed
     */
    public function performAction(array $options)
    {

        $queryResult = $this->getQueryResult($options);
        $this->applySorting($options, $queryResult);
        return $this->applyPaging($options, $queryResult);
    }

    public function getQueryResult($options)
    {
        $type = $options['type'] ?? "";

        switch ($type) {
            case self::TYPE_USER:
                $queryResult = $this->getQueryUser($options);
                break;
            case self::TYPE_SEGMENT:
                $queryResult = $this->getQuerySegment($options);
                break;
            default:
                $queryUser = $this->getQueryUser($options);
                $querySegment = $this->getQuerySegment($options);
                $queryResult = $querySegment->union($queryUser);
                break;
        }
        return $queryResult;
    }

    public function getQueryUser($options)
    {
        $client = Context::client()->get();

        //If current user is admin, only allow get user belong to current client
        $queryUser = User::query()
            ->join('employees', 'users.id', 'employees.user_id')
            ->leftJoin('attachment', 'users.profile_pic', 'attachment.id')
            ->select('code', DB::raw("CONCAT(users.surname, ', ', users.first_name) as name "), 'attachment.path AS avatar', DB::raw("'user' as type"))
            ->where('employees.client_id', '=', $client->getKey())
            ->whereNull('employees.deleted_at')
            ->whereNull('users.deleted_at');

        FilterFluent::init()
            ->setQuery($queryUser)
            ->setFilterOptions($options)
            ->setAllowedFilters($this->allowFilters)
            ->removeFilter('name')
            ->validate()
            ->setCustomFilter('name', function($query, $type, $col, $value) {
                FilterFluent::applyCombinedColumnFilter($query, $type, 'surname', 'first_name', $value, 'users');
            })
            ->applyFilter();
        return $queryUser;
    }

    public function getQuerySegment($options)
    {

        $querySegment = Segment::query();
        ModelHelper::setConditionFindByClient($querySegment);
        $querySegment->select('code', 'name', DB::raw("null as avatar"), DB::raw("'segment' as type"));

        $this->applyFilters($options, $querySegment, $this->allowFilters);
        return $querySegment;

    }
}
