<?php

namespace App\Services\User;

use App\Contracts\Validatable;
use App\Events\PasswordUpdated;
use App\Models\User\User;
use App\Rules\PasswordRule;
use App\Services\BaseService;
use Illuminate\Support\Facades\Auth as Auth;
use Illuminate\Support\Facades\Hash;

class UpdatePassword extends BaseService implements Validatable
{
    public function getRules(array $args): array
    {
        return [
            'password' => 'required|password:api',
            'new_password' => ['required', 'different:password', 'min:8', 'confirmed', new PasswordRule()]
        ];
    }

    /**
     * Update user password
     * 
     * @param array $args
     * @return User
     */
    function performAction(array $args) : User
    {
        $user = Auth::user();
        $user->password = Hash::make($args['new_password']);
        $user->save();

        app(RevokeUserToken::class)->execute($user);

        event(new PasswordUpdated($user));
        
        return $user->fresh();
    }
}
