<?php


namespace App\Services\User;


use App\Contracts\Performable;
use App\Contracts\Validatable;
use App\DataTransferObject\StreamedFile;
use App\Enum\AllowedFileSizes;
use App\Enum\AllowedFileTypes;
use App\Enum\ErrorCode;
use App\Enum\ImageDimensions;
use App\Exceptions\InvalidRequestException;
use App\Facades\Context;
use App\Helpers\ImageHelper;
use App\Helpers\ObjectHelper;
use App\Helpers\ResourceLocationBuilder;
use App\Models\Language\Language;
use App\Services\Attachment\CreateAttachment;
use App\Services\Attachment\UpdateAttachment;
use App\Services\BaseService;
use App\Services\Employee\DeleteAvatar;
use App\Services\Employee\UpdateAvatar;

class UpdateProfile extends BaseService implements Performable, Validatable
{
    public function getRules(array $args)
    {
        return [
            'avatar' => 'nullable|mimes:'. AllowedFileTypes::IMAGE . '|max:' . AllowedFileSizes::IMAGE_SIZE,
            'is_avatar_removed' => 'nullable|boolean'
        ];
    }
    
    public function canPerform(): bool
    {
        return Context::client()->check();
    }

    public function performAction(array $args)
    {
        $currentUser = Context::user()->get();

        if (ObjectHelper::nullOrValue($args, 'is_avatar_removed')) {
            // Delete avatar
            app(DeleteAvatar::class)->execute(['user_id' => $currentUser->getKey()]);
        } else {
            // Update avatar
            $avatar = $args['avatar'] ?? null;
            app(UpdateAvatar::class)->execute(['avatar' => $avatar, 'user_id' => $currentUser->getKey()]);
        }

        if(isset($args['language_id'])){
            $language = Language::findOrFail($args['language_id']);
            $currentUser->language()->associate($language);
        }
        $currentUser->save();
        return $currentUser->fresh();
    }
}