<?php


namespace App\Services\UserAccess;


use App\Contracts\Validatable;
use App\Enum\AccessPermissions;
use App\Facades\Context;
use App\Services\BaseService;

class GetAccessByRole extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'role' => 'required|string'
        ];
    }

    /**
     * Get manager access permissions
     *
     * @param  array  $args
     * @return array
     */
    public function performAction(array $args)
    {

        $clientManagerPermissionNames = app(GetClientRoleAccessNames::class)->execute(['role' => $args['role']]);

        $roleAccess = [];
        foreach (AccessPermissions::ALL_ACCESS_GROUP_PERMISSIONS as $group => $groupPermission) {
            foreach ($groupPermission as $permission) {
                $roleAccess[$group][$permission] = in_array($permission, $clientManagerPermissionNames);
            }
        }
        $client = Context::client()->get();
        $roleAccess['client']['client.NOTIFICATION_CONSOLE_UPCOMING'] = $client['NOTIFICATION_CONSOLE_UPCOMING'];

        return $roleAccess;
    }
}
