<?php


namespace App\Services\UserAccess;


use App\Contracts\Validatable;
use App\Enum\Roles;
use App\Facades\Context;
use App\Models\UserAccess\ClientAccess;
use App\Services\BaseService;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;

class GetClientRoleAccessNames extends BaseService implements Validatable
{
    public function getRules(array $args)
    {
        return [
            'role' => 'required|string'
        ];
    }

    /**
     * Get manager access permissions
     *
     * @param array $args
     * @return array
     */
    public function performAction(array $args)
    {
        $client = $args['client'] ?? Context::client()->get();

        $role = Role::firstWhere('name', $args['role']);
        $clientManagerPermissionIds = ClientAccess::where([
            'client_id' => $client->getKey(),
            'role_id' => $role->getKey(),
        ])->pluck('permission_id')->toArray();
        $clientPermissionNames = Permission::whereIntegerInRaw('id', $clientManagerPermissionIds)
            ->pluck('name')->toArray();

        return $clientPermissionNames;
    }
}
