<?php
namespace App\Traits;

use App\Helpers\ObjectHelper;
use App\Helpers\StringHelper;


trait HasBusinessKey
{
    private static $key = 'code';

    /**
     * Boot trait business key
     */
    public static function bootHasBusinessKey() {
        //while creating/inserting item into db
        $businessKeyName = static::getBusinessKeyName();
        static::creating(function ($item) use($businessKeyName) {
            $businessKey = static::generateBusinessKey();
            $item->{$businessKeyName} = $businessKey;
        });

        static::updating(function ($item) use($businessKeyName) {
            $businessKey = static::generateBusinessKey();
            //If current model don't have business key, add it
            if(!$item->{$businessKeyName})
            {
                $item->{$businessKeyName} = $businessKey;
            }
        });
    }

    /**
     * @return string
     */
    public static function getBusinessKeyName(): string
    {
        return config('app.bussiness_key_name') ?? static::$key;
    }

    /**
     * Generate business key
     * @return string
     * @throws \Exception
     */
    public static function generateBusinessKey()
    {
        $time=0;
        $businessKeyName = static::getBusinessKeyName();
        do {
            $time++;
            $businessKey = StringHelper::generateRandomString(10);
            $isExistBusinessKey = !!static::where($businessKeyName, $businessKey)->first();
            $businessKey = $isExistBusinessKey ? '' : $businessKey;
        } while ($isExistBusinessKey && $time <= 10);
        if($businessKey === '')
        {
            throw new \Exception("Failed on create business key");
        }
        return $businessKey;
    }

    /**
     * Find by business key
     *
     * @param string $key
     * @return mixed
     */
    public static function findByBusinessKey(string $key)
    {
        $businessKeyName = static::getBusinessKeyName();
        return static::where($businessKeyName, $key)->firstOrFail();
    }

    public static function findAllByBusinessKey($keys = [], $excludeLastLogin = false)
    {
        $businessKeyName = static::getBusinessKeyName();
        $res = static::whereIn($businessKeyName, $keys);
        if($excludeLastLogin) {
            $res = $res->where('last_login', null);
        }
        return $res->get();
    }

    /**
     * Generate missing code
     * @throws \Exception
     */
    public static function genarateMissingBusinessKey()
    {
        $businessKeyName = static::getBusinessKeyName();
        $models = static::whereNull($businessKeyName)->orWhere($businessKeyName,'')->get();
        foreach($models as $model){
            $businessKey = static::generateBusinessKey();
            $model->{$businessKeyName} = $businessKey;
            $model->save();
        }
    }

    /**
     * This method is called upon instantiation of the Eloquent Model.
     * It adds the businessKeyName field to the "$guarded" array of the model.
     * This will prevent user try to update code by mass asigment
     *
     * @return void
     */
    public function initializeHasBusinessKey()
    {
        $this->guarded[] = static::getBusinessKeyName();
    }

    public function getBusinessKey()
    {
        return $this->{self::getBusinessKeyName()};
    }
}