<?php

use App\Database\Migrations\AppMigration;
use App\Models\Client\ClientConfiguration;
use  Illuminate\Support\Facades\DB;
use App\Models\Client\Client;
class MigrateClientData extends AppMigration
{

    const CLIENT_COLUMNS = [
        'name',
        'status',
        'is_subscription',
        'added_by',
        'email_verified_at',
        'package_id',
        'industry_id',
        'document_heading_id',
        'document_profile_heading_id',
        'form_heading_id',
        'quiz_heading_id',
        'survey_heading_id',
        'subscription_volume',
        'renewal_date',
        'is_photo_id_enabled',
        'is_profile_photo_enabled',
        'support_type',
    ];

    const CONFIG_DATAS = [
        ['name'=>'action_image','type'=>ClientConfiguration::TYPE_FILE],
        ['name'=>'company_logo','type'=>ClientConfiguration::TYPE_FILE],
        ['name'=>'background_image','type'=>ClientConfiguration::TYPE_FILE],
        ['name'=>'background_color','type'=>ClientConfiguration::TYPE_FILE],
        ['name'=>'menu_font_color','type'=>ClientConfiguration::TYPE_COLOR],
        ['name'=>'message_image','type'=>ClientConfiguration::TYPE_FILE],
        ['name'=>'document_image','type'=>ClientConfiguration::TYPE_FILE],
        ['name'=>'my_team_image','type'=>ClientConfiguration::TYPE_FILE],
        ['name'=>'profile_background_top','type'=>ClientConfiguration::TYPE_FILE],
        ['name'=>'is_demo','type'=>ClientConfiguration::TYPE_BOOL],
        ['name'=>'profile_background_bottom','type'=>ClientConfiguration::TYPE_FILE],
        ['name'=>'password_strength','type'=>ClientConfiguration::TYPE_TEXT],
        ['name'=>'change_password_after','type'=>ClientConfiguration::TYPE_TEXT],
        ['name'=>'purge_content_after','type'=>ClientConfiguration::TYPE_TEXT],
        ['name'=>'login_timeout','type'=>ClientConfiguration::TYPE_TEXT],
        ['name'=>'app_document_download','type'=>ClientConfiguration::TYPE_TEXT],
        ['name'=>'app_document_printing','type'=>ClientConfiguration::TYPE_TEXT],
        ['name'=>'google_2FA','type'=>ClientConfiguration::TYPE_BOOL],
        ['name'=>'linkedin_profile_url','type'=>ClientConfiguration::TYPE_TEXT],
        ['name'=>'linkedin_first_name','type'=>ClientConfiguration::TYPE_TEXT],
        ['name'=>'linkedin_last_name','type'=>ClientConfiguration::TYPE_TEXT],
        ['name'=>'linkedin_location','type'=>ClientConfiguration::TYPE_TEXT],
        ['name'=>'linkedin_position','type'=>ClientConfiguration::TYPE_TEXT],
        ['name'=>'linkedin_profile_id','type'=>ClientConfiguration::TYPE_TEXT],
        ['name'=>'two_step_login_verification','type'=>ClientConfiguration::TYPE_BOOL],
        ['name'=>'profile_pic','type'=>ClientConfiguration::TYPE_FILE]
    ];
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        $config_datas = self::CONFIG_DATAS;
        //Migrate column to key-value type
        foreach($config_datas as &$config){
            $clientConfiguration = new ClientConfiguration;
            $clientConfiguration->name = $config['name'];
            $clientConfiguration->type = $config['type'];
            $clientConfiguration->save();
            $config['id'] = $clientConfiguration->id;

        }

        //Only run when migrate from old to new database
        if(Schema::hasTable('assigned_roles'))
        {
            //get all client from user table
            $clients = DB::table('users')
                ->join('assigned_roles','users.id','=','assigned_roles.entity_id')
                ->join('roles','assigned_roles.role_id','=','roles.id')
                ->join('user_details','users.id','=','user_details.user_id')
                ->where('assigned_roles.entity_type','App\\User')
                ->where('roles.name','client')
                ->select('users.id as userid','users.*','user_details.*')->get();
            foreach($clients as $client)
            {
                $newClient = new Client;
                foreach(self::CLIENT_COLUMNS as $client_column){
                    $newClient->{$client_column} = $client->{$client_column};
                }
                $newClient->id = $client->userid;
                $newClient->save();
                foreach ($config_datas as $config_data) {
                    $newClient->clientConfigurations()->attach($config_data['id'], ['value' => $client->{$config_data['name']}]);
                }
                if(Schema::hasTable('user_admin_details')) {
                    DB::table('user_admin_details')
                        ->where('client_id',$client->userid)
                        ->update(['client_id'=> $newClient->id]);
                }

                if(Schema::hasTable('front_user_details')) {
                    DB::table('front_user_details')
                        ->where('client_id',$client->userid)
                        ->update(['client_id'=>$newClient->id]);
                }
            }
        }

    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        //
    }
}
