<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;
use App\Enum\Roles as RolesEnum;
use Spatie\Permission\Models\Permission;


class UpdateEventPermissionsNameConvention extends AppMigration
{
    const ADMIN_PERMISSIONS = ['edit', 'delete', 'read'];
    const FRONT_USER_PERMISSIONS = ['read'];
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        $this->revokePermissionTo(RolesEnum::ADMIN, 'events', self::ADMIN_PERMISSIONS);
        $this->revokePermissionTo(RolesEnum::FRONT_USER, 'events', self::FRONT_USER_PERMISSIONS);
        //Delete old permission
        foreach(self::ADMIN_PERMISSIONS as $permission){
            Permission::where(['name' => 'events.' . $permission])->delete();
        }
        $this->givePermissionTo(RolesEnum::ADMIN, 'event', self::ADMIN_PERMISSIONS);
        $this->givePermissionTo(RolesEnum::FRONT_USER, 'event', self::FRONT_USER_PERMISSIONS);
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        $this->givePermissionTo(RolesEnum::ADMIN, 'events', self::ADMIN_PERMISSIONS);
        $this->givePermissionTo(RolesEnum::FRONT_USER, 'events', self::FRONT_USER_PERMISSIONS);

        $this->revokePermissionTo(RolesEnum::ADMIN, 'event', self::ADMIN_PERMISSIONS);
        $this->revokePermissionTo(RolesEnum::FRONT_USER, 'event', self::FRONT_USER_PERMISSIONS);
    }
}
