<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;

class CreateQuizStructure extends AppMigration
{
    const BACKUP_TABLES = [
        'quiz_names',
        'questions',
        'question_answers'
    ];
    
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('quizzes', function(Blueprint $table)
        {
            $table->increments('id');
            $table->unsignedInteger('client_id')->nullable();
            $table->string('name',self::MEDIUM_TEXT);
            $table->boolean('is_publish')->default(0);
            $table->unsignedInteger('created_by')->nullable();
            $table->boolean('is_demo')->default(0);
            $table->softDeletes();
            $table->timestamps();
            $table->hasBusinessKey();
        });

        Schema::create('quiz_questions', function(Blueprint $table)
        {
            $table->increments('id');
            $table->unsignedInteger('quiz_id')->nullable();
            $table->text('title');
            $table->boolean('status')->nullable();
            $table->softDeletes();
            $table->timestamps();
        });

        Schema::create('quiz_options', function(Blueprint $table)
        {
            $table->increments('id');
            $table->unsignedInteger('quiz_question_id');
            $table->string('content', self::MEDIUM_TEXT);
            $table->boolean('is_correct')->nullable();
            $table->boolean('is_demo')->default(0);
            $table->softDeletes();
            $table->timestamps();  
        });
        
        // Backup tables
        foreach (self::BACKUP_TABLES as $table)
        {
            if (Schema::hasTable($table)) {
                Schema::rename($table, $table . '_bck');
            }
        }
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('quizzes');
        Schema::dropIfExists('quiz_questions');
        Schema::dropIfExists('quiz_options');

        foreach (self::BACKUP_TABLES as $table)
        {
            if (Schema::hasTable($table . '_bck')) {
                Schema::rename($table . '_bck', $table);
            }
        }
    }
}
