<?php
// create...

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;

class CreateSurveyStructure extends AppMigration
{
    protected $dateMigrationCreated = '20201102';
    const BASE_TABLE = [
        'survey_names',
        'survey_configurations',
        'survey_question_types',
        'survey_questions',
        'survey_answers',
    ];

    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        foreach (self::BASE_TABLE as $table) {
            if (Schema::hasTable($table)) {
                Schema::rename($table, $table . '_bck' . $this->dateMigrationCreated);
            }
        }

        Schema::create('surveys', function(Blueprint $table) {
            $table->increments('id');
            $table->hasBusinessKey();
            $table->string('name', self::MEDIUM_TEXT);
            $table->unsignedInteger('created_by');
            $table->softDeletes();
            $table->unsignedInteger('client_id')->nullable();
            $table->boolean('is_published')->default(0);
            $table->boolean('is_demo')->default(0);
            $table->timestamps();
        });

        Schema::create('survey_questions', function(Blueprint $table) {
            $table->increments('id');
            $table->string('type', self::SHORT_TEXT);
            $table->unsignedInteger('survey_id');
            $table->text('title');
            $table->timestamps();
            $table->unsignedInteger('created_by')->nullable();
            $table->boolean('is_demo')->default(0);
        });

        Schema::create('survey_options', function(Blueprint $table) {
            $table->increments('id');
            $table->unsignedInteger('survey_question_id');
            $table->string('content', self::MEDIUM_TEXT);
            $table->unsignedInteger('created_by')->nullable();
            $table->timestamps();
            $table->boolean('is_demo')->default(0);
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('surveys');
        Schema::dropIfExists('survey_questions');
        Schema::dropIfExists('survey_options');
        foreach (self::BASE_TABLE as $table) {
            $tableFormatName = $table . '_bck' . $this->dateMigrationCreated;
            if (Schema::hasTable($tableFormatName)) {
                Schema::rename($tableFormatName, $table);
            }
        }
    }
}
