<?php
// create...

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;

class CreateJourneyStructure extends AppMigration
{
    const CREATED_DATE = '20201106';
    
    const BACKUP_TABLES = [
        'configure_clients',
        'configure_client_steps',
        'configure_client_content_steps'
    ];
    
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('journeys', function (Blueprint $table) {
            $table->increments('id');
            $table->unsignedInteger('client_id');
            $table->string('name', self::MEDIUM_TEXT)->nullable();
            $table->boolean('is_published')->default(0);
            $table->unsignedInteger('created_by')->nullable();
            $table->timestamps();
            $table->softDeletes();
            $table->hasBusinessKey();
        });

        Schema::create('journey_steps', function(Blueprint $table)
        {
            $table->increments('id');
            $table->unsignedInteger('journey_id'); 
            $table->string('name', self::MEDIUM_TEXT);
            $table->boolean('is_available_immediately')->default(1);
            $table->unsignedInteger('available_days')->nullable();
            $table->string('available_term', self::SHORT_TEXT)->nullable();
            $table->unsignedInteger('header_image_id')->nullable();
            $table->text('message')->nullable();
            $table->unsignedInteger('step_order')->nullable(); 
            $table->timestamps();
        });
 
        Schema::create('action_requests', function (Blueprint $table) {
            $table->increments('id');
            $table->morphs('actionable');
            $table->morphs('contentable');
            $table->string('status', self::SHORT_TEXT)->nullable();
            $table->timestamps();
        });

        Schema::create('journey_user', function (Blueprint $table) {
            $table->unsignedInteger('journey_id');
            $table->unsignedInteger('user_id');
            $table->primary(['journey_id','user_id']);
        });
        
        // Backup tables
        foreach (self::BACKUP_TABLES as $table)
        {
            if (Schema::hasTable($table)) {
                Schema::rename($table, $table . '_bck' . self::CREATED_DATE);
            }
        }
        
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('journeys');
        Schema::dropIfExists('journey_steps');
        Schema::dropIfExists('action_requests');
        Schema::dropIfExists('journey_users');

        $postfix = '_bck' . self::CREATED_DATE;
        foreach (self::BACKUP_TABLES as $table)
        {
            if (Schema::hasTable($table . $postfix)) {
                Schema::rename($table . $postfix, $table);
            }
        }
    }
}
