<?php
// create...

use App\Enum\ActionRequestTypes;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;

class CreateActionRequestTypesStructure extends AppMigration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('content_texts', function (Blueprint $table) {
            $table->increments('id');
            $table->hasBusinessKey();
            $table->string('name', self::MEDIUM_TEXT);
            $table->string('status', self::SHORT_TEXT)->nullable();
            $table->timestamps();
            $table->softDeletes();
        });
        
        Schema::create('id_verifications', function (Blueprint $table) {
            $table->increments('id');
            $table->hasBusinessKey();
            $table->string('name', self::MEDIUM_TEXT);
            $table->string('status', self::SHORT_TEXT)->nullable();
            $table->timestamps();
            $table->softDeletes();
        });
        
        Schema::create('content_photos', function (Blueprint $table) {
            $table->increments('id');
            $table->hasBusinessKey();
            $table->string('name', self::MEDIUM_TEXT);
            $table->string('status', self::SHORT_TEXT)->nullable();
            $table->timestamps();
            $table->softDeletes();
        });

        // Insert master data
        $now = Carbon::now();
        $businessKey = config('app.bussiness_key_name') ?? 'code';
        
        DB::table('content_texts')->insert(
            [
                $businessKey => ActionRequestTypes::TEXT,
                'name' => 'Text',
                'status' => null,
                'created_at' => $now
            ]
        );

        DB::table('id_verifications')->insert(
            [
                [
                    $businessKey => ActionRequestTypes::ID_VERIFICATION_PASSPORT,
                    'name' => 'Passport',
                    'status' => null,
                    'created_at' => Carbon::now()
                ],
                [
                    $businessKey => ActionRequestTypes::ID_VERIFICATION_DRIVER_LICENSE,
                    'name' => 'Drivers License',
                    'status' => null,
                    'created_at' => Carbon::now()
                ],
                [
                    $businessKey => ActionRequestTypes::ID_VERIFICATION_NATIONAL_ID,
                    'name' => 'National ID',
                    'status' => null, 
                    'created_at' => Carbon::now()
                ]
            ]
        );

        DB::table('content_photos')->insert(
            [
                $businessKey => ActionRequestTypes::HEADSHOT_PHOTO,
                'name' => 'Headshot Photo',
                'status' => null,
                'created_at' => Carbon::now()
            ]
        );
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('content_texts');
        Schema::dropIfExists('id_verifications');
        Schema::dropIfExists('content_photos');
    }
}
