<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;



class AddFormStructure extends AppMigration
{
    const BACKUP_TABLES = [
        'signature_authenticate',
        'signature_document',
        'signature_template',
        'forms',
        'form_details'
    ];
    
    const BACKUP_POSTFIX = '_bck20201119';
    
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('form_authenticates', function (Blueprint $table) {
            $table->increments('id');
            $table->string('client_id');
            $table->string('access_token');
            $table->string('token_type');
            $table->integer('expires_in');
            $table->string('scope');
            $table->string('refresh_token');
            $table->timestamps();
        });
        
        Schema::create('form_templates', function (Blueprint $table) {
            $table->increments('id');
            $table->string('template_id');
            $table->integer('client_id');
            $table->string('name');
            $table->timestamps();
        });

        Schema::create('form_documents', function (Blueprint $table) {
            $table->increments('id');
            $table->integer('form_template_id');
            $table->integer('user_id');
            $table->string('document_id');
            $table->string('name');
            $table->boolean('is_sent')->default(0);
            $table->timestamps();
        });

        Schema::create('form_results', function (Blueprint $table) {
            $table->increments('id');
            $table->unsignedInteger('submission_id');
            $table->unsignedInteger('form_document_id');
            $table->timestamps();
        });

        // Backup tables
        foreach (self::BACKUP_TABLES as $table)
        {
            if (Schema::hasTable($table)) {
                Schema::rename($table, $table . self::BACKUP_POSTFIX);
            }
        }
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('form_authenticates');
        Schema::dropIfExists('form_templates');
        Schema::dropIfExists('form_documents');
        Schema::dropIfExists('form_results');
        
        foreach (self::BACKUP_TABLES as $table)
        {
            if (Schema::hasTable($table . self::BACKUP_POSTFIX)) {
                Schema::rename($table . self::BACKUP_POSTFIX, $table);
            }
        }
    }
}
