<?php
// create...

use App\Models\Segment\EmploymentPhaseSegment;
use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;
use App\Enum\TimeTypes;
use App\Enum\EmploymentPhaseTypes;

class CreateEmploymentPhaseSegmentsTable extends AppMigration
{
    CONST EMPLOYMENT_PHASE_SEGMENTS_DATA = [
        ["name" => "Pre-boarding", "min" => null, "type_min" => null, "max" => 1, "type_max" => TimeTypes::DAY, "description" => "Before day 1", "type" => EmploymentPhaseTypes::START_DATE],
        ["name" => "Onboarding", "min" => 1, "type_min" => TimeTypes::DAY, "max" => 3, "type_max" => TimeTypes::MONTH, "description" => "First three months", "type" => EmploymentPhaseTypes::START_DATE],
        ["name" => "Development", "min" => 3, "type_min" => TimeTypes::MONTH, "max" => 2, "type_max" => TimeTypes::YEAR, "description" => "Three months to two years", "type" => EmploymentPhaseTypes::START_DATE],
        ["name" => "Retention", "min" => 2, "type_min" => TimeTypes::YEAR, "max" => null, "type_max" => null, "description" => "More than two years", "type" => EmploymentPhaseTypes::START_DATE],
        ["name" => "Offboarding", "min" => null, "type_min" => null, "max" => 3, "type_max" => TimeTypes::MONTH, "description" => "Final three months", "type" => EmploymentPhaseTypes::END_DATE],
    ];

    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('employment_phase_segments', function (Blueprint $table) {
            $table->increments('id');
            $table->hasBusinessKey();
            $table->string('name', self::MEDIUM_TEXT);
            $table->integer('min')->nullable();
            $table->string('type_min', self::SHORT_TEXT)->nullable();
            $table->integer('max')->nullable();
            $table->string('type_max', self::SHORT_TEXT)->nullable();
            $table->string('description', self::LONG_TEXT)->nullable();
            $table->string('type', self::SHORT_TEXT);
            $table->timestamps();
        });
        foreach (self::EMPLOYMENT_PHASE_SEGMENTS_DATA as $employmentPhaseSegments) {
            EmploymentPhaseSegment::create($employmentPhaseSegments);
        }

    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('employment_phase_segments');
    }
}
