<?php
// create...

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;

class CreateActionStructure extends AppMigration
{
    const BACKUP_TABLES = [
        'client_actions',
    ];
    
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('actions', function (Blueprint $table) {
            $table->increments('id');
            $table->unsignedInteger('client_id');
            $table->boolean('is_send_immediately')->default(1);
            $table->timestamp('send_on')->nullable();
            $table->timestamp('due_by')->nullable();
            $table->unsignedInteger('created_by')->nullable();
            $table->timestamps();
        });

        Schema::create('action_user', function (Blueprint $table) {
            $table->unsignedInteger('action_id');
            $table->unsignedInteger('user_id');
            $table->boolean('is_completed')->nullable()->default(0);
            $table->timestamps();
            $table->primary(['action_id','user_id']);
        });

        Schema::create('action_approver', function (Blueprint $table) {
            $table->unsignedInteger('action_id');
            $table->unsignedInteger('user_id');
            $table->primary(['action_id','user_id']);
        });

        // Backup tables
        foreach (self::BACKUP_TABLES as $table)
        {
            if (Schema::hasTable($table)) {
                Schema::rename($table, $table . '_bck');
            }
        }
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('actions');
        Schema::dropIfExists('action_user');
        Schema::dropIfExists('action_approver');
        
        foreach (self::BACKUP_TABLES as $table)
        {
            if (Schema::hasTable($table . '_bck')) {
                Schema::rename($table . '_bck', $table);
            }
        }
    }
}
