<?php

use App\Enum\ConfigurationTypes;
use App\Models\Subscription\PlanConfiguration;
use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;


class UpdateConstructPlan extends AppMigration
{
    const COLUMN_CONFIGURATIONS = [
        ["name" => "package_employee", "type" => ConfigurationTypes::NUMBER],
        ["name" => "package_journey", "type" => ConfigurationTypes::NUMBER],
        ["name" => "package_document", "type" => ConfigurationTypes::NUMBER],
        ["name" => "package_quiz", "type" => ConfigurationTypes::NUMBER],
        ["name" => "package_survey", "type" => ConfigurationTypes::NUMBER],
        ["name" => "package_administrator", "type" => ConfigurationTypes::NUMBER],
        ["name" => "package_support_type", "type" => ConfigurationTypes::NUMBER],
        ["name" => "package_dedicated_engagement_specialist", "type" => ConfigurationTypes::BOOLEAN],
        ["name" => "package_ad_free", "type" => ConfigurationTypes::BOOLEAN],
        ["name" => "package_custom_logo", "type" => ConfigurationTypes::BOOLEAN],
        ["name" => "package_custom_colour", "type" => ConfigurationTypes::BOOLEAN],
        ["name" => "package_message", "type" => ConfigurationTypes::BOOLEAN],
        ["name" => "package_form", "type" => ConfigurationTypes::BOOLEAN],
        ["name" => "package_doc_profile", "type" => ConfigurationTypes::BOOLEAN],
        ["name" => "package_engagement_module", "type" => ConfigurationTypes::BOOLEAN],
        ["name" => "package_checklist", "type" => ConfigurationTypes::BOOLEAN],
        ["name" => "package_ai_document_search", "type" => ConfigurationTypes::BOOLEAN],
        ["name" => "package_id_verification", "type" => ConfigurationTypes::BOOLEAN],
        ["name" => "package_customisable", "type" => ConfigurationTypes::BOOLEAN],
        ["name" => "package_stock_surveys", "type" => ConfigurationTypes::BOOLEAN],
    ];

    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::dropIfExists('plans');
        Schema::create('plans', function($table) {
            $table->increments('id');
            $table->string('name', self::MEDIUM_TEXT);
            $table->text('description')->nullable();
            $table->string('status', self::SHORT_TEXT);
            $table->timestamps();
            $table->string('stripe_price', self::LONG_TEXT)->nullable();
            $table->string('stripe_prod', self::LONG_TEXT)->nullable();
            $table->float('cost', 10, 0)->nullable();
            $table->boolean('is_default')->nullable();
            $table->boolean('is_public')->nullable();
            $table->unsignedInteger('created_by')->nullable();
            $table->softDeletes();
            $table->unsignedInteger('order')->default(0);
            $table->hasBusinessKey();
        });
        Schema::create('plan_configurations', function($table) {
            $table->increments('id');
            $table->string('name', self::MEDIUM_TEXT);
            $table->string('type', self::MEDIUM_TEXT);
            $table->timestamps();
        });
        foreach(self::COLUMN_CONFIGURATIONS as $column_configuration)
        {
            PlanConfiguration::create($column_configuration);
        }
        Schema::create('plan_configuration_detail', function (Blueprint $table) {
            $table->unsignedInteger('plan_id');
            $table->unsignedInteger('configuration_id');
            $table->string('value',self::LONG_TEXT)->nullable();
            $table->primary(['plan_id','configuration_id']);
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('plan_configuration_detail');
        Schema::dropIfExists('plans');
        Schema::dropIfExists('plan_configurations');
    }
}
