<?php

use App\Enum\ClientConfigurations;
use App\Enum\ConfigurationTypes;
use App\Models\Client\Client;
use App\Models\Client\ClientConfiguration;
use App\Models\Subscription\PlanConfiguration;
use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;
use Illuminate\Support\Facades\DB;

class UpdateConfigurationClient extends AppMigration
{
    const COLUMN_CONFIGURATIONS = [
        ["name" => ClientConfigurations::CONFIG_REQUEST_TWO_FACTOR, "type" => ConfigurationTypes::BOOLEAN, "default_value" => "0"],
        ["name" => ClientConfigurations::CONFIG_ADMIN_PASSWORD_RESET, "type" => ConfigurationTypes::TEXT, "default_value" => "Every 6 months"],
        ["name" => ClientConfigurations::CONFIG_DELETE_FORMER_EMPLOYEES_AFTER, "type" => ConfigurationTypes::TEXT, "default_value" => "90 days"],
        ["name" => ClientConfigurations::CONFIG_CONSOLE_LOGIN_TIMEOUT, "type" => ConfigurationTypes::TEXT, "default_value" => "30 days"],
        ["name" => ClientConfigurations::CONFIG_ENABLE_APP_DOCUMENT_DOWNLOAD_AND_PRINTING, "type" => ConfigurationTypes::BOOLEAN, "default_value" => "1"],
    ];

    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::table('client_configurations', function(Blueprint $table) {
            $table->string('default_value', self::LONG_TEXT);
        });
        PlanConfiguration::where('name', 'package_support_type')->update(['type' => ConfigurationTypes::TEXT]);

        $tableBackupName = "client_configurations" . "_bak";
        $this->cloneTable("client_configurations", $tableBackupName, true);

        $tableBackupName = "client_configuration_detail" . "_bak" ;
        $this->cloneTable("client_configuration_detail", $tableBackupName, true);

        DB::table('client_configurations')->delete();
        DB::table('client_configuration_detail')->delete();

        foreach (self::COLUMN_CONFIGURATIONS as $column_configuration) {
            ClientConfiguration::create($column_configuration);
        }

        $clients = Client::all();
        $clientConfigurations = ClientConfiguration::all();
        foreach ($clients as $client) {
            $this->updateClientConfigurations($client, $clientConfigurations);
        }

    }

    public function updateClientConfigurations($client, $clientConfigurations)
    {
        foreach ($clientConfigurations as $clientConfiguration) {
            $client->clientConfigurations()->attach($clientConfiguration->getKey(), ['value' => $clientConfiguration->default_value]);
        }
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        //
    }
}
