<?php
// create...

use App\Enum\AlertMessage;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;

class CreateAlertMessagesTable extends AppMigration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('alert_messages', function (Blueprint $table) {
            $table->increments('id');
            $table->string('message', self::LONG_TEXT);
            $table->timestamp('display_on')->nullable();
            $table->timestamp('expire_on')->nullable();
            $table->string('type', self::SHORT_TEXT);
            $table->tinyInteger('priority')->default(0);
            $table->timestamps();
        });

        $now = Carbon::now();
        DB::table('alert_messages')->insert(
            [
                'message' => AlertMessage::EXPIRING_PASSWORD_MESSAGE,
                'type' => AlertMessage::AUTOMATIC_TYPE,
                'priority' => 1,
                'created_at' => $now,
                'updated_at' => $now
            ]
        );

        DB::table('alert_messages')->insert(
            [
                'message' => AlertMessage::DISABLING_2FA_MESSAGE,
                'type' => AlertMessage::AUTOMATIC_TYPE,
                'priority' => 2,
                'created_at' => $now,
                'updated_at' => $now
            ]
        );

        DB::table('alert_messages')->insert(
            [
                'message' => AlertMessage::EXPIRING_CARD_MESSAGE,
                'type' => AlertMessage::AUTOMATIC_TYPE,
                'priority' => 3,
                'created_at' => $now,
                'updated_at' => $now
            ]
        );
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('alert_messages');
    }
}
