<?php

use App\Enum\EmploymentPhaseTypes;
use App\Enum\TimeTypes;
use App\Models\Segment\AgeSegment;
use App\Models\Segment\EmploymentPhaseSegment;
use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;


class UpdateSegmentData extends AppMigration
{
    CONST AGE_SEGMENTS_DATA = [
        ["name" => "16-24", "min" => 16, "max" => 25],
        ["name" => "25-34", "min" => 25, "max" => 35],
        ["name" => "35-44", "min" => 35, "max" => 45],
        ["name" => "45-54", "min" => 45, "max" => 55],
        ["name" => "55-64", "min" => 55, "max" => 65],
        ["name" => "Over 65", "min" => 65, "max" => 999],
    ];

    CONST EMPLOYMENT_PHASE_SEGMENTS_DATA = [
        ["name" => "Preboard", "min" => -3, "type_min" => TimeTypes::MONTH, "max" => 1, "type_max" => TimeTypes::DAY, "description" => "Before day 1", "type" => EmploymentPhaseTypes::START_DATE],
        ["name" => "Onboard", "min" => 1, "type_min" => TimeTypes::DAY, "max" => 12, "type_max" => TimeTypes::MONTH, "description" => "First year", "type" => EmploymentPhaseTypes::START_DATE],
        ["name" => "Retain", "min" => 1, "type_min" => TimeTypes::YEAR, "max" => 5, "type_max" => TimeTypes::YEAR, "description" => "One year to four years", "type" => EmploymentPhaseTypes::START_DATE],
        ["name" => "Develop", "min" => 5, "type_min" => TimeTypes::YEAR, "max" => 14, "type_max" => TimeTypes::YEAR, "description" => "Five years to fourteen years", "type" => EmploymentPhaseTypes::START_DATE],
        ["name" => "Offboard", "min" => -1, "type_min" => TimeTypes::MONTH, "max" => 1, "type_max" => TimeTypes::DAY, "description" => "Last month", "type" => EmploymentPhaseTypes::END_DATE],
        ["name" => "Alumni", "min" => 1, "type_min" => TimeTypes::DAY, "max" => null, "type_max" => TimeTypes::DAY, "description" => "After leaving", "type" => EmploymentPhaseTypes::END_DATE],
    ];

    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        AgeSegment::truncate();
        foreach (self::AGE_SEGMENTS_DATA as $ageSegment) {
            AgeSegment::create($ageSegment);
        }
        EmploymentPhaseSegment::truncate();
        foreach (self::EMPLOYMENT_PHASE_SEGMENTS_DATA as $employmentPhaseSegments) {
            EmploymentPhaseSegment::create($employmentPhaseSegments);
        }
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        //
    }
}
