<?php

use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;
use App\Models\Segment\SegmentType;
use App\Models\Segment\Segment;
use App\Enum\SegmentTypes;
use App\Models\Client\Client;
use App\Services\Segment\CreateAllEmployeeSegment;

class CreateAllEmployeeSegments extends AppMigration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        $segmentTypes = SegmentType::find(SegmentTypes::ALL);
        // Create "All" segment type
        if(!$segmentTypes){
            DB::table('segment_types')->insert([
                'id' => SegmentTypes::ALL,
                'name' => 'All',
                'code' => 'ALL',
                'created_at' => Carbon::now(),
                'updated_at' => Carbon::now(),
                'order' => 0,
                'is_hidden' => 1
            ]);
        }else{
            $segmentTypes->code = 'All';
            $segmentTypes->name = 'ALL';
            $segmentTypes->order = 0;
            $segmentTypes->is_hidden = 1;
            $segmentTypes->save();
        }

        
        // Create "All employees" segment for all clients
        $clients = Client::all();
        foreach ($clients as $client) {
            app(CreateAllEmployeeSegment::Class)->execute(['client_id' => $client->getKey()]);
        }
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        $allSegmentType = SegmentType::findOrFail(SegmentTypes::ALL);
        Segment::where('segment_type_id', $allSegmentType->getKey())->delete();
        $allSegmentType->delete();
    }
}
