<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;
use App\Models\User\User;
use App\Models\Driver\Driver;
use App\Models\Questionnaire\Questionnaire;
use App\Services\Driver\CreateDriver;
use App\Services\Driver\EditDriver;
use Illuminate\Support\Str;

class UpdateDriverData extends AppMigration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        $driverData = [
            [
                'name' => 'Strategy',
                'description' => "Impacting the goals of all employees, the success of a strategy is subject to their understanding and belief in it.",
                'question' => 'The goals and strategies created by senior leaders are progressing the company in the right direction',
                'weight' => 0.4,
                'score_rating_type' => 0,
                'priority' => 2,
                'children' => [
                    [
                        'name' => 'Communication',
                        'description' => "Evaluates the communication of the company's strategy. Managers must ensure that team members understand how the strategy impacts their role, and how they individually contribute to the strategy.",
                        'question' => 'The company does a good job of communicating the priorities and goals set by senior management',
                        'weight' => 0.3,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Mission',
                        'description' => "Measures the connectedness between an individual's role and the company's mission.",
                        'question' => "I am inspired by the purpose and mission of our company",
                        'weight' => 0.3,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ]
                ]
            ],
            [
                'name' => 'Workload',
                'description' => "When people feel that their workload is unreasonably high, this can be a source of stress or even burnout. The amount of work people can handle is also dependent on the resources available to them. Time, manager support, and tools are examples of resources that can help reduce the strain of a heavy workload.",
                'question' => 'I consider my workload to be manageable',
                'weight' => 1,
                'score_rating_type' => 1,
                'priority' => 2,
                'children' => [
                ]
            ]
        ];

        $admin = User::first();

        if (empty($admin)) {
            \Log::error('Can not find admin account');
            return;
        }

        foreach($driverData as $data) {
            $data['created_by'] = $admin->id;

            $driver = $this->createDriverAndQuestinnaire($data);

            // Check sub-driver
            if (!empty($driver) && isset($data['children']) && !empty($data['children'])) {
                foreach($data['children'] as $child) {
                    $child['parent_id'] = $driver['id'];
                    $child['created_by'] = $admin->id;
                    $this->createDriverAndQuestinnaire($child);
                }
            }
        }
        return true;
    }

    /**
     * createDriverAndQuestinnaire
     *
     * @param $data
     * @return |null
     */
    public function createDriverAndQuestinnaire($data)
    {
        //Create client value question
        if (!empty($data['is_question_value'])) {
            $this->updateOrCreateQuestionnaire([
                'question' => $data['question'],
                'created_by' => $data['created_by'],
                'is_question_value' => $data['is_question_value'],
                'score_rating_type' => $data['score_rating_type'],
                'status' => 1
            ]);
            return null;
        }

        $driver = $this->updateOrCreateDriver($data);

        if (!empty($driver)) {
            $this->updateOrCreateQuestionnaire([
                'driver_id' => $driver['id'],
                'question' => $data['question'],
                'created_by' => $data['created_by'],
                'score_rating_type' => $data['score_rating_type'],
                'status' => 1
            ]);
        }

        return $driver;
    }

    /**
     * updateOrCreateQuestionnaire
     *
     * @param $data
     * @return mixed
     */
    public function updateOrCreateQuestionnaire($data)
    {
        $questionnaireModel = new Questionnaire();
        $question = $questionnaireModel->where('question', $data['question'])->first();
        if (!empty($question)) {
            $question->update($data);
        } else {
            $question = $questionnaireModel->create($data);
        }
        return $question;
    }

    public function updateOrCreateDriver($data)
    {
        $driverModel = new Driver();
        $driver = $driverModel->where('name', $data['name'])->first();

        $driverData = [
            'parent_id' => !empty($data['parent_id']) ? $data['parent_id'] : 0,
            'name' => $data['name'],
            'description' => $data['description'],
            'status' => 1,
            'priority' => $data['priority'],
            'weight' => $data['weight'],
            'icon' => Str::slug($data['name'], '_'),
        ];

        if (empty($driver)) {
            $driver = app(CreateDriver::class)->execute($driverData);
        } else {
            $driverData['id'] = $driver->id;
            $driver = app(EditDriver::class)->execute($driverData);
        }
        return $driver;
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        //
    }
}
