<?php
// update...

use App\Enum\AccessPermissions;
use App\Enum\Roles;
use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;
use Spatie\Permission\Models\Permission;

class AddMissingModulePermissionsToAdminAndManagerRoles extends AppMigration
{

    public const MODULE_PERMISSIONS = [
        AccessPermissions::ACCESS_JOURNEY,
        AccessPermissions::ACCESS_SURVEY,
        AccessPermissions::ACCESS_QUIZ,
        AccessPermissions::ACCESS_CHECKLIST,
        AccessPermissions::ACCESS_EMPLOYEE,
        AccessPermissions::ACCESS_SEGMENT,
        AccessPermissions::ACCESS_COMPANY_DETAIL,
        AccessPermissions::ACCESS_APP_DESIGN,
        AccessPermissions::ACCESS_SECURITY,
        AccessPermissions::ACCESS_INITIATIVES,
        AccessPermissions::ACCESS_SSO,
    ];

    public const DEFAULT_MANAGER_PERMISSIONS = [
        AccessPermissions::ACCESS_JOURNEY,
        AccessPermissions::ACCESS_SURVEY,
        AccessPermissions::ACCESS_QUIZ,
        AccessPermissions::ACCESS_CHECKLIST,
        AccessPermissions::ACCESS_EMPLOYEE,
        AccessPermissions::ACCESS_SEGMENT,
        AccessPermissions::ACCESS_COMPANY_DETAIL,
        AccessPermissions::ACCESS_APP_DESIGN,
        AccessPermissions::ACCESS_INITIATIVES,
    ];

    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        foreach (self::MODULE_PERMISSIONS as $permission) {
            if(!Permission::where('name', $permission)->exists()) {
                Permission::create(['name' => $permission]);
            }
        }

        $this->givePermissionToRole(Roles::ADMIN, self::MODULE_PERMISSIONS);
        $this->givePermissionToRole(Roles::MANAGER, self::DEFAULT_MANAGER_PERMISSIONS);
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        $this->revokePermissionToRole(Roles::ADMIN, self::MODULE_PERMISSIONS);
        $this->revokePermissionToRole(Roles::MANAGER, self::DEFAULT_MANAGER_PERMISSIONS);

        Permission::whereIn('name', self::MODULE_PERMISSIONS)->delete();
    }
}
