<?php

use App\Models\Questionnaire\QuestionnaireCommentAnalyze;
use App\Models\Questionnaire\QuestionnaireTopic;
use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use App\Database\Migrations\AppMigration;

class CreateEngagementTopicStructure extends AppMigration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('questionnaire_topics', function (Blueprint $table) {
            $table->increments('id');
            $table->string('topic', self::LONG_TEXT);
            $table->unsignedInteger('client_id');
            $table->string('type')->nullable();
            $table->timestamps();
        });

        Schema::create('questionnaire_topic_answer', function (Blueprint $table) {
            $table->unsignedInteger('topic_id');
            $table->unsignedInteger('answer_id');
            $table->timestamps();
            $table->primary(['answer_id', 'topic_id']);
        });


        // Migrate old topic data to new structure
        $analyzedComments = QuestionnaireCommentAnalyze::leftJoin(
            'questionnaire_answers',
            'questionnaire_answers.id',
            'questionnaire_comment_analyze.questionnaire_answer_id'
        )
            ->where('questionnaire_comment_analyze.words', '!=', '[]')
            ->get();

        foreach ($analyzedComments as $analyzedComment)
        {
            $analyzedCommentArr = $analyzedComment->toArray();

            if (empty($analyzedCommentArr['comment'])) {
                continue;
            }

            $clientId = $analyzedCommentArr['client_id'];
            foreach ($analyzedCommentArr['words'] as $word) {
                $topic = QuestionnaireTopic::where('client_id', $clientId)->where('topic', 'LIKE', $word)->first();
                if (!$topic) {
                    $topic = QuestionnaireTopic::create([
                        'topic' => $word,
                        'client_id' => $clientId
                    ]);
                }
                $topic->questionnaireAnswers()->attach($analyzedCommentArr['questionnaire_answer_id']);
            }
        }
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('questionnaire_topics');
        Schema::dropIfExists('questionnaire_topic_answer');
    }
}
