<?php

use App\Database\Migrations\AppMigration;
use App\Enum\AccessPermissions;
use Illuminate\Support\Facades\DB;
use Spatie\Permission\Models\Permission;

class AddAccessPermissionsForNotificationsAccess extends AppMigration
{
    const ACCESS_PERMISSIONS = [
        AccessPermissions::NOTIFICATION_CONSOLE_BIRTHDAY,
        AccessPermissions::NOTIFICATION_CONSOLE_WORK_ANNIVERSARY,
        AccessPermissions::NOTIFICATION_CONSOLE_MENTION,
        AccessPermissions::NOTIFICATION_CONSOLE_EMPLOYEE_ACTION,
        AccessPermissions::NOTIFICATION_CONSOLE_EMPLOYEE_JOURNEY,
        //AccessPermissions::NOTIFICATION_CONSOLE_UPCOMING,

        //AccessPermissions::NOTIFICATION_APP_BIRTHDAY,
        //AccessPermissions::NOTIFICATION_APP_WORK_ANNIVERSARY,
        AccessPermissions::NOTIFICATION_APP_MENTION,
        AccessPermissions::NOTIFICATION_APP_EMPLOYEE_ACTION,
        AccessPermissions::NOTIFICATION_APP_EMPLOYEE_JOURNEY,

        //AccessPermissions::NOTIFICATION_EMAIL_BIRTHDAY,
        //AccessPermissions::NOTIFICATION_EMAIL_WORK_ANNIVERSARY,
        AccessPermissions::NOTIFICATION_EMAIL_MENTION,
        AccessPermissions::NOTIFICATION_EMAIL_EMPLOYEE_ACTION,
        AccessPermissions::NOTIFICATION_EMAIL_EMPLOYEE_JOURNEY,
    ];
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        //
        Permission::where('name', 'notifications.birthday.send')->update(['name' => AccessPermissions::NOTIFICATION_APP_BIRTHDAY]);
        Permission::where('name', 'notifications.work_anniversary.send')->update(['name' => AccessPermissions::NOTIFICATION_APP_WORK_ANNIVERSARY]);
        Permission::where('name', 'notifications.birthday.send.email')->update(['name' => AccessPermissions::NOTIFICATION_EMAIL_BIRTHDAY]);
        Permission::where('name', 'notifications.work_anniversary.send.email')->update(['name' => AccessPermissions::NOTIFICATION_EMAIL_WORK_ANNIVERSARY]);
        Permission::where('name', 'notifications.alert.upcoming.event')->update(['name' => AccessPermissions::NOTIFICATION_CONSOLE_UPCOMING]);

        foreach (self::ACCESS_PERMISSIONS as $permission) {
            Permission::create(['name' => $permission]);
        }
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        //
        DB::table('permissions')->whereIn('name', self::ACCESS_PERMISSIONS)->delete();

        Permission::where('name', AccessPermissions::NOTIFICATION_APP_BIRTHDAY)->update(['name' => 'notifications.birthday.send']);
        Permission::where('name', AccessPermissions::NOTIFICATION_APP_WORK_ANNIVERSARY)->update(['name' => 'notifications.work_anniversary.send']);
        Permission::where('name', AccessPermissions::NOTIFICATION_EMAIL_BIRTHDAY)->update(['name' => 'notifications.birthday.send.email']);
        Permission::where('name', AccessPermissions::NOTIFICATION_EMAIL_WORK_ANNIVERSARY)->update(['name' => 'notifications.work_anniversary.send.email']);
        Permission::where('name', AccessPermissions::NOTIFICATION_CONSOLE_UPCOMING)->update(['name' => 'notifications.alert.upcoming.event']);
    }
}
