<?php

use App\Services\QuestionnaireTranslate\CreateQuestionnaireTranslate;
use Illuminate\Database\Seeder;
use App\Models\Questionnaire\Questionnaire;
use App\Models\Language\Language;

class QuestionValueTranslateSeeder extends Seeder
{
    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        $questionValue = Questionnaire::whereNull('driver_id')->first();
        if (empty($questionValue)) return;

        $languages = Language::all();
        $languagesMap = $languages->mapWithKeys(function ($item) {
            return [$item['code'] => $item];
        });

        $transData = [
            [
                'language_code' => 'en',
                'question' => 'Does your regular experience at work feel consistent with the company value below?'
            ],
            [
                'language_code' => 'id',
                'question' => 'Apakah pengalaman rutin Anda di tempat kerja terasa sesuai dengan nilai perusahaan di bawah?'
            ],
            [
                'language_code' => 'ko',
                'question' => '직장에서의 일상적인 경험이 아래의 회사 가치와 일치한다고 느끼십니까?'
            ],
            [
                'language_code' => 'zh-Hans',
                'question' => '您的常规工作经验是否与下面的公司价值观一致？'
            ],
            [
                'language_code' => 'zh-Hant',
                'question' => '您的常規工作經驗是否與下面的公司價值觀一致？'
            ],
            [
                'language_code' => 'nl',
                'question' => 'Voelt uw normale werkervaring aan in overeenstemming met de onderstaande bedrijfswaarde?'
            ],
            [
                'language_code' => 'fil',
                'question' => 'Ang iyong regular na karanasan ba sa trabaho ay nararamdamang naaayon sa halaga ng kumpanya sa ibaba?'
            ],
            [
                'language_code' => 'fr',
                'question' => "Votre expérience de travail régulière correspond-elle à la valeur de l'entreprise ci-dessous?"
            ],
            [
                'language_code' => 'de',
                'question' => "Entspricht Ihre regelmäßige Arbeitserfahrung dem unten aufgeführten Unternehmenswert?"
            ],
            [
                'language_code' => 'hi',
                'question' => "क्या काम पर आपका नियमित अनुभव कंपनी के मूल्य के अनुरूप है?"
            ],
            [
                'language_code' => 'ja',
                'question' => "職場でのあなたの定期的な経験は、以下の会社の価値と一致していると感じますか？"
            ],
            [
                'language_code' => 'ms',
                'question' => "Adakah pengalaman biasa anda di tempat kerja sesuai dengan nilai syarikat di bawah?"
            ],
            [
                'language_code' => 'es',
                'question' => "¿Su experiencia laboral habitual se siente coherente con el valor de la empresa que se indica a continuación?"
            ],
            [
                'language_code' => 'vi',
                'question' => "Kinh nghiệm thường xuyên của bạn tại nơi làm việc có phù hợp với giá trị công ty dưới đây không?"
            ],
            [
                'language_code' => 'ta',
                'question' => "பணியில் உங்கள் வழக்கமான அனுபவம் கீழே உள்ள நிறுவனத்தின் மதிப்புடன் ஒத்துப்போகிறதா?"
            ],
            [
                'language_code' => 'th',
                'question' => "ประสบการณ์ประจำของคุณในการทำงานสอดคล้องกับมูลค่า บริษัท ด้านล่างหรือไม่?"
            ],
        ];

        foreach ($transData as $data) {
            $language = !empty($languagesMap[$data['language_code']]) ? $languagesMap[$data['language_code']] : null;
            if (empty($language)) continue;

            $questionValueTransData = [
                'questionnaire_id' => $questionValue->id,
                'language_id' => $language->id,
                'question' => $data['question'],
            ];

            app(CreateQuestionnaireTranslate::class)->execute($questionValueTransData);
        }

        return true;
    }
}
