<?php

use Illuminate\Database\Seeder;
use App\Models\User\User;
use App\Models\Driver\Driver;
use App\Models\Questionnaire\Questionnaire;
use App\Services\Driver\CreateDriver;
use App\Services\Driver\EditDriver;
use Illuminate\Support\Str;

class QuestionnaireSeeder extends Seeder
{
    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        $driverData = [
            [
                'name' => 'Accomplishment',
                'description' => 'Successfully achieving a significant task demonstrates competency. A belief of competence motivates people to apply their skills more broadly.',
                'question' => 'I regularly feel a sense of accomplishment from my work',
                'weight' => 0.6,
                'score_rating_type' => 0,
                'priority' => 1,
                'children' => [
                    [
                        'name' => 'Challenging',
                        'description' => 'Assesses if individuals are challenged by their role. A sense of competence is not improved by completing simple assignments. Instead, people require a certain amount of challenge in order to experience a sense of accomplishment.',
                        'question' => 'I am provided with challenging opportunities at work',
                        'weight' => 0.4,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ]
                ]
            ],
            [
                'name' => 'Autonomy',
                'description' => 'The degree to which employees are provided an ability to self-govern the way they do their work.',
                'question' => 'I am given appropriate freedom in deciding how to complete my work',
                'weight' => 0.333,
                'score_rating_type' => 0,
                'priority' => 0,
                'children' => [
                    [
                        'name' => 'Flexibility',
                        'description' => "Tests for individuals' belief that their work schedules have flexibility. Flexible employment helps employees combine work and personal responsibilities.",
                        'question' => 'I have enough flexibility in my work schedule to manage my family or personal life',
                        'weight' => 0.333,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Remote Work',
                        'description' => "Tests whether employees believe they have a fair degree of flexibility to work remotely, supported by policies and guidelines. The company's culture as unspoken rules, are equally important.",
                        'question' => 'I have a suitable work from home policy',
                        'weight' => 0.333,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ]
                ]
            ],
            [
                'name' => 'Environment',
                'description' => 'A positive work environment empowers people to collaborate and complete their work effectively. Physical attributes such as temperature, lighting and furniture all contribute to the work environment.',
                'question' => 'The conditions of my workplace allows me to concentrate on my work',
                'weight' => 0.2,
                'score_rating_type' => 0,
                'priority' => 0,
                'children' => [
                    [
                        'name' => 'Equipment',
                        'description' => "Assesses if individuals believe they have the tools and infrastructure they need to do their job well.",
                        'question' => 'I have the necessary equipment and tools needed to do my work well',
                        'weight' => 0.4,
                        'score_rating_type' => 0,
                        'priority' => 1,
                    ],
                    [
                        'name' => 'Collaboration Space',
                        'description' => "Tests whether individuals believe they have appropriate spaces to collaborate with colleagues.",
                        'question' => 'I can quickly find space for discussion and cooperation with others away from my desk',
                        'weight' => 0.2,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Informal Space',
                        'description' => "Applies to employees feeling that there are spaces for them to socialize with others. Being able to relate personally with co-workers is crucial in forming good team relationships.",
                        'question' => 'My workplace has places to talk and relax with others when I need a break',
                        'weight' => 0.2,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ]
                ]
            ],
            [
                'name' => 'Freedom of Opinions',
                'description' => "A manager's style influences whether employees feel they have a voice, are listened to and can express their opinions.",
                'question' => 'At work, it appears that my views matter',
                'weight' => 0.333,
                'score_rating_type' => 0,
                'priority' => 0,
                'children' => [
                    [
                        'name' => 'Team',
                        'description' => "Assesses if the employee is motivated by their team to share feedback. Diverse perspectives are embraced by a healthy team atmosphere, which encourages learning and promotes innovation.",
                        'question' => 'My colleagues appreciate views that are different from their own',
                        'weight' => 0.333,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Manager',
                        'description' => "Test whether employees feel that their manager considers their thoughts, concerns and viewpoints . A manager's style can strongly influence how freely employees express their views.",
                        'question' => 'My supervisor values my views',
                        'weight' => 0.333,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ]
                ]
            ],
            [
                'name' => 'Goal-Setting',
                'description' => "Clear expectations are set by thoughtfully formulated goals, which help employees understand the importance of their work and impact of their achievements.",
                'question' => 'Every day at work, I know what is expected of me',
                'weight' => 0.4,
                'score_rating_type' => 0,
                'priority' => 0,
                'children' => [
                    [
                        'name' => 'Alignment',
                        'description' => "If employees are satisfied with the goals of their team, they have a greater sense of why their own goals are important. This measures how individuals feel that their work contributes to their team's broader goals. ",
                        'question' => 'I recognise how my job serves my team and department\'s objectives',
                        'weight' => 0.6,
                        'score_rating_type' => 0,
                        'priority' => 1,
                    ]
                ]
            ],
            [
                'name' => 'Growth',
                'description' => "All humans need to feel a sense of growth. Meaningful work with appropriate support and opportunities for professional development promote this.",
                'question' => "I feel I am developing professionally",
                'weight' => 0.5,
                'score_rating_type' => 0,
                'priority' => 2,
                'children' => [
                    [
                        'name' => 'Career Path',
                        'description' => "Assesses if individuals believe they have opportunities for advancing their career within the company.",
                        'question' => 'I know how I am able to advance my career in this organisation',
                        'weight' => 0.167,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Mentoring',
                        'description' => "Measures whether individuals can find mentors that can help them progress, improve their skills and achieve their long term goals.",
                        'question' => 'My manager or mentor promotes and supports my development',
                        'weight' => 0.167,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Learning',
                        'description' => "Tests if individuals believe like they can learn new abilities and skills on the job. This is influenced by whether a company has processes and strategies that offer learning opportunities.",
                        'question' => 'My job allows me to learn new skills and develop them',
                        'weight' => 0.167,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ]
                ]
            ],
            [
                'name' => 'Management Support',
                'description' => "The support of managers is multi-dimensional. They can offer their staff help or guidance in specific tasks, and they can demonstrate empathy and flexibility during challenging scenarios.",
                'question' => 'My manager offers me the assistance I need to finish my work',
                'weight' => 0.4,
                'score_rating_type' => 0,
                'priority' => 1,
                'children' => [
                    [
                        'name' => 'Caring',
                        'description' => "This tests if a individual thinks that their manager is genuinely interested in them as a person, instead of only as a resource.",
                        'question' => 'My manager cares about me as a person',
                        'weight' => 0.3,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Openness',
                        'description' => "Evaluates if individuals believe that their manager openly shares information, especially when it concerns them.",
                        'question' => 'My manager communicates with me openly and genuinely',
                        'weight' => 0.3,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ]
                ]
            ],
            [
                'name' => 'Meaningful Work',
                'description' => "Employees can find meaning in work that has impact and creates the most value to their colleagues, the organisation and its clients.",
                'question' => 'The work I do is meaningful to me',
                'weight' => 0.4,
                'score_rating_type' => 0,
                'priority' => 1,
                'children' => [
                    [
                        'name' => 'Significance',
                        'description' => "Evaluates the connection between an individual's work and the benefit a customer receives from using the company's product or service.",
                        'question' => 'In my team, I make a difference',
                        'weight' => 0.3,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Fit',
                        'description' => "Applies to the connection between the talent of an individual and the activities they perform. A close fit can make work feel more meaningful as it encourages a person to utilise their strengths.",
                        'question' => 'I have the opportunity to do what I do best at work, every day',
                        'weight' => 0.3,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ]
                ]
            ],
            [
                'name' => 'Organisational Fit',
                'description' => "Describes the alignment between an individuals values and the organisation. This includes providing clarity in how employees should behave and make decisions in the workplace.",
                'question' => "<Company>'s values match well with things that are important to me in life",
                'weight' => 0.25,
                'score_rating_type' => 0,
                'priority' => 1,
                'children' => [
                    [
                        'name' => 'Support',
                        'description' => "Tests if individuals feel that their company supports their mental health.",
                        'question' => "<Company> genuinely cares about my mental wellbeing",
                        'weight' => 0.185,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Health',
                        'description' => "Measure the employees' belief that the company proactively protects their physical well-being.",
                        'question' => 'I believe that I can live a physically healthy lifestyle by working here',
                        'weight' => 0.185,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Equality',
                        'description' => "Evaluates whether employees believe the company provides opportunities fairly and effectively prevents discrimination.",
                        'question' => "At <Company>, people from all backgrounds are treated equally",
                        'weight' => 0.185,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Response',
                        'description' => "Assesses employee confidence in the company's ability and willingness to act responsibly to any allegation of misconduct.",
                        'question' => "I am confident that if I encountered significant misconduct at work, <Company> would take steps to remedy the situation",
                        'weight' => 0.185,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ]
                ]
            ],
            [
                'name' => 'Peer Relationships',
                'description' => "Peer relationships thrive with trust and support, allowing colleagues to count on each for collaboration and providing a fulfilled life at work.",
                'question' => 'I can rely on my colleagues to help out when necessary',
                'weight' => 0.2,
                'score_rating_type' => 0,
                'priority' => 0,
                'children' => [
                    [
                        'name' => 'Quality',
                        'description' => "Associated with whether individuals feel that their peers are committed to doing high-quality work for initiatives that impact the team.",
                        'question' => 'My colleagues are dedicated to doing quality work',
                        'weight' => 0.4,
                        'score_rating_type' => 0,
                        'priority' => 1,
                    ],
                    [
                        'name' => 'Friends',
                        'description' => "Related to whether people believe they can have rewarding friendships at work. This helps in developing a sense of belonging with their colleagues.",
                        'question' => 'I consider the individuals I interact with frequently at work to be my friends',
                        'weight' => 0.4,
                        'score_rating_type' => 0,
                        'priority' => 1,
                    ]
                ]
            ],
            [
                'name' => 'Recognition',
                'description' => "The validation of ones contribution and effort towards a goal is an important need of every person. Done well, recognition enhances a sense of competence and acknowledges the impact made by those involved.",
                'question' => 'I know I will be recognised when I do great work',
                'weight' => 0.6,
                'score_rating_type' => 0,
                'priority' => 1,
                'children' => [
                    [
                        'name' => 'Performance',
                        'description' => "Assesses the individual's satisfaction regarding feedback they receive. This includes both positive and constructive feedback.",
                        'question' => "I get sufficient feedback to know if I am doing my job well",
                        'weight' => 0.4,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ]
                ]
            ],
            [
                'name' => 'Reward',
                'description' => "The sense of fairness and satisfaction with an individual's total reward, including salary, benefits and  other forms of compensation. The process of determination should be fair and transparent in order to maximise employee confidence.",
                'question' => "For my contributions to <Company>, I am fairly compensated (e.g. salary, bonuses, benefits)",
                'weight' => 0.4,
                'score_rating_type' => 0,
                'priority' => 1,
                'children' => [
                    [
                        'name' => 'Process',
                        'description' => "Assesses if employees agree that the pay determination procedures are based on objective standards, and are applied fairly to prevent anyone being unfairly disadvantaged.",
                        'question' => "The company's methods for calculating pay seem fair and objective",
                        'weight' => 0.2,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Discussion',
                        'description' => "Transparency in compensation conversations is strongly correlated with a sense of fairness. This tests if individuals believe they can have honest, informative dialogue about compensation with their manager. ",
                        'question' => 'I can have informed and positive discussions about pay with my manager',
                        'weight' => 0.2,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Fairness',
                        'description' => "This tests if individuals consider that their wage in comparison to their contribution is equitable.",
                        'question' => 'I believe that my commitment, ability and experience are appropriately reflected in my total compensation',
                        'weight' => 0.2,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ]
                ]
            ],
            [
                'name' => 'Strategy',
                'description' => "Impacting the goals of all employees, the success of a strategy is subject to their understanding and belief in it.",
                'question' => 'The goals and strategies created by senior leaders are progressing the company in the right direction',
                'weight' => 0.4,
                'score_rating_type' => 0,
                'priority' => 2,
                'children' => [
                    [
                        'name' => 'Communication',
                        'description' => "Evaluates the communication of the company's strategy. Managers must ensure that team members understand how the strategy impacts their role, and how they individually contribute to the strategy.",
                        'question' => 'The company does a good job of communicating the priorities and goals set by senior management',
                        'weight' => 0.300,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ],
                    [
                        'name' => 'Mission',
                        'description' => "Measures the connectedness between an individual's role and the company's mission.",
                        'question' => "I am inspired by the purpose and mission of our company",
                        'weight' => 0.300,
                        'score_rating_type' => 0,
                        'priority' => 0,
                    ]
                ]
            ],
            [
                'name' => 'Workload',
                'description' => "When people feel that their workload is unreasonably high, this can be a source of stress or even burnout. The amount of work people can handle is also dependent on the resources available to them. Time, manager support, and tools are examples of resources that can help reduce the strain of a heavy workload.",
                'question' => 'I consider my workload to be manageable',
                'weight' => 1,
                'score_rating_type' => 1,
                'priority' => 2,
                'children' => [
                ]
            ],
            [
                'name' => 'Advocacy',
                'description' => "The degree to which employees support or recommend the company as a place to work to family or friends.",
                'question' => 'How likely is it you would recommend <Company> as a place to work?',
                'weight' => 1,
                'score_rating_type' => 1,
                'priority' => 2,
                'children' => [
                ]
            ],
            [
                'name' => 'Belief',
                'description' => "The extent to which an employee with recommend the products and services of their organisation to those close to them.",
                'question' => "How likely is it you would recommend <Company>'s products or services to friends and family?",
                'weight' => 1,
                'score_rating_type' => 1,
                'priority' => 2,
                'children' => [
                ]
            ],
            [
                'name' => 'Loyalty',
                'description' => "Loyal employees are devoted to the success of their organisation and believe that being an employee of this organisation is in their best interest.",
                'question' => 'How likely would you remain at <Company> if you were given the same position at another organization?',
                'weight' => 1,
                'score_rating_type' => 1,
                'priority' => 2,
                'children' => [
                ]
            ],
            [
                'name' => 'Satisfaction',
                'description' => "A measure of an employee's contentedness with their work and the role it plays in their life.",
                'question' => 'Overall, how satisfied are you working at <Company>?',
                'weight' => 1,
                'score_rating_type' => 2,
                'priority' => 2,
                'children' => [
                ]
            ],
            [
                'name' => '',
                'description' => "",
                'question' => 'Does your daily work experience feel aligned with this value?',
                'is_question_value' => 1,
                'weight' => 0,
                'score_rating_type' => 0,
                'priority' => 0,
                'children' => [
                ]
            ]
        ];

        $admin = User::first();

        if (empty($admin)) {
            \Log::error('Can not find admin account');
            return;
        }

        foreach($driverData as $data) {
            $data['created_by'] = $admin->id;

            $driver = $this->createDriverAndQuestinnaire($data);

            // Check sub-driver
            if (!empty($driver) && isset($data['children']) && !empty($data['children'])) {
                foreach($data['children'] as $child) {
                    $child['parent_id'] = $driver['id'];
                    $child['created_by'] = $admin->id;
                    $this->createDriverAndQuestinnaire($child);
                }
            }
        }
        return true;
    }

    /**
     * createDriverAndQuestinnaire
     *
     * @param $data
     * @return |null
     */
    public function createDriverAndQuestinnaire($data)
    {
        //Create client value question
        if (!empty($data['is_question_value'])) {
            $this->updateOrCreateQuestionnaire([
                'question' => $data['question'],
                'created_by' => $data['created_by'],
                'is_question_value' => $data['is_question_value'],
                'score_rating_type' => $data['score_rating_type'],
                'status' => 1
            ]);
            return null;
        }

        $driver = $this->updateOrCreateDriver($data);

        if (!empty($driver)) {
            $this->updateOrCreateQuestionnaire([
                'driver_id' => $driver['id'],
                'question' => $data['question'],
                'created_by' => $data['created_by'],
                'score_rating_type' => $data['score_rating_type'],
                'status' => 1
            ]);
        }

        return $driver;
    }

    /**
     * updateOrCreateQuestionnaire
     *
     * @param $data
     * @return mixed
     */
    public function updateOrCreateQuestionnaire($data)
    {
        $questionnaireModel = new Questionnaire();
        $question = $questionnaireModel->where('question', $data['question'])->first();
        if (!empty($question)) {
            $question->update($data);
        } else {
            $question = $questionnaireModel->create($data);
        }
        return $question;
    }

    public function updateOrCreateDriver($data)
    {
        $driverModel = new Driver();
        $driver = $driverModel->where('name', $data['name'])->first();

        $driverData = [
            'parent_id' => !empty($data['parent_id']) ? $data['parent_id'] : 0,
            'name' => $data['name'],
            'description' => $data['description'],
            'status' => 1,
            'priority' => $data['priority'],
            'weight' => $data['weight'],
            'icon' => Str::slug($data['name'], '_'),
        ];

        if (empty($driver)) {
            $driver = app(CreateDriver::class)->execute($driverData);
        } else {
            $driverData['id'] = $driver->id;
            $driver = app(EditDriver::class)->execute($driverData);
        }
        return $driver;
    }
}
