<?php

use Illuminate\Database\Seeder;
use App\Enum\QuestionnaireSkipStatus;
use App\Models\Questionnaire\QuestionnaireSkipQuestion;
use App\Models\Language\Language;

class QuestionnaireSkipSeeder extends Seeder
{
    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        $skips = [
            [
                'title' => "It doesn't apply to me",
                'status' => QuestionnaireSkipStatus::ACTIVE,
                'translate' => [
                    [
                        'code' => 'en',
                        'title' => "It doesn't apply to me"
                    ],[
                        'code' => 'id',
                        'title' => "Itu tidak berlaku untuk saya"
                    ],[
                        'code' => 'ko',
                        'title' => "나에게 적용되지 않음"
                    ],[
                        'code' => 'zh-CN',
                        'title' => "它不适用于我"
                    ],[
                        'code' => 'zh-TW',
                        'title' => "它不適用於我"
                    ],[
                        'code' => 'nl',
                        'title' => "Het is niet op mij van toepassing"
                    ],[
                        'code' => 'tl',
                        'title' => "Hindi ito naaangkop sa akin"
                    ],[
                        'code' => 'fr',
                        'title' => "Cela ne s'applique pas à moi"
                    ],[
                        'code' => 'de',
                        'title' => "Es trifft nicht auf mich zu"
                    ],[
                        'code' => 'hi',
                        'title' => "यह मेरे लिए लागू नहीं होता है"
                    ],[
                        'code' => 'ja',
                        'title' => "それは私には当てはまりません"
                    ],[
                        'code' => 'ms',
                        'title' => "Itu tidak berlaku untuk saya"
                    ],[
                        'code' => 'es',
                        'title' => "No se aplica a mi"
                    ],[
                        'code' => 'vi',
                        'title' => "Nó không áp dụng cho tôi"
                    ],[
                        'code' => 'ta',
                        'title' => "இது எனக்கு பொருந்தாது"
                    ],[
                        'code' => 'th',
                        'title' => "มันใช้ไม่ได้กับฉัน"
                    ]
                ]
            ],
            [
                'title' => "I don't understand it",
                'status' => QuestionnaireSkipStatus::ACTIVE,
                'translate' => [
                    [
                        'code' => 'en',
                        'title' => "I don't understand it"
                    ],[
                        'code' => 'id',
                        'title' => "Saya tidak mengerti"
                    ],[
                        'code' => 'ko',
                        'title' => "이해가 안 돼"
                    ],[
                        'code' => 'zh-CN',
                        'title' => "我不明白"
                    ],[
                        'code' => 'zh-TW',
                        'title' => "我不明白"
                    ],[
                        'code' => 'nl',
                        'title' => "Ik begrijp het niet"
                    ],[
                        'code' => 'tl',
                        'title' => "Hindi ko maintindihan"
                    ],[
                        'code' => 'fr',
                        'title' => "Je ne comprends pas"
                    ],[
                        'code' => 'de',
                        'title' => "Ich verstehe es nicht"
                    ],[
                        'code' => 'hi',
                        'title' => "मैं इसे नहीं समझता"
                    ],[
                        'code' => 'ja',
                        'title' => "分かりません"
                    ],[
                        'code' => 'ms',
                        'title' => "Saya tidak memahaminya"
                    ],[
                        'code' => 'es',
                        'title' => "No lo entiendo"
                    ],[
                        'code' => 'vi',
                        'title' => "Tôi không hiểu nó"
                    ],[
                        'code' => 'ta',
                        'title' => "எனக்கு அது புரியவில்லை"
                    ],[
                        'code' => 'th',
                        'title' => "ฉันไม่เข้าใจมัน"
                    ]
                ]
            ],
            [
                'title' => "I don't have an opinion",
                'status' => QuestionnaireSkipStatus::ACTIVE,
                'translate' => [
                    [
                        'code' => 'en',
                        'title' => "I don't have an opinion"
                    ],[
                        'code' => 'id',
                        'title' => "Saya tidak punya pendapat"
                    ],[
                        'code' => 'ko',
                        'title' => "나는 의견이 없다"
                    ],[
                        'code' => 'zh-CN',
                        'title' => "我没有意见"
                    ],[
                        'code' => 'zh-TW',
                        'title' => "我沒有意見"
                    ],[
                        'code' => 'nl',
                        'title' => "Ik heb geen mening"
                    ],[
                        'code' => 'tl',
                        'title' => "Wala akong opinion"
                    ],[
                        'code' => 'fr',
                        'title' => "Je n'ai pas d'opinion"
                    ],[
                        'code' => 'de',
                        'title' => "Ich habe keine Meinung"
                    ],[
                        'code' => 'hi',
                        'title' => "मेरे पास एक राय नहीं है"
                    ],[
                        'code' => 'ja',
                        'title' => "意見がありません"
                    ],[
                        'code' => 'ms',
                        'title' => "Saya tidak mempunyai pendapat"
                    ],[
                        'code' => 'es',
                        'title' => "No tengo una opinion"
                    ],[
                        'code' => 'vi',
                        'title' => "Tôi không có ý kiến"
                    ],[
                        'code' => 'ta',
                        'title' => "எனக்கு ஒரு கருத்து இல்லை"
                    ],[
                        'code' => 'th',
                        'title' => "ฉันไม่มีความเห็น"
                    ]
                ]
            ],
            [
                'title' => "Other",
                'status' => QuestionnaireSkipStatus::ACTIVE,
                'translate' => [
                    [
                        'code' => 'en',
                        'title' => "Other"
                    ],[
                        'code' => 'id',
                        'title' => "Lain"
                    ],[
                        'code' => 'ko',
                        'title' => "다른"
                    ],[
                        'code' => 'zh-CN',
                        'title' => "其他"
                    ],[
                        'code' => 'zh-TW',
                        'title' => "其他"
                    ],[
                        'code' => 'nl',
                        'title' => "Andere"
                    ],[
                        'code' => 'tl',
                        'title' => "Iba pa"
                    ],[
                        'code' => 'fr',
                        'title' => "Autre"
                    ],[
                        'code' => 'de',
                        'title' => "Andere"
                    ],[
                        'code' => 'hi',
                        'title' => "अन्य"
                    ],[
                        'code' => 'ja',
                        'title' => "その他"
                    ],[
                        'code' => 'ms',
                        'title' => "Yang lain"
                    ],[
                        'code' => 'es',
                        'title' => "Otra"
                    ],[
                        'code' => 'vi',
                        'title' => "Khác"
                    ],[
                        'code' => 'ta',
                        'title' => "மற்றவை"
                    ],[
                        'code' => 'th',
                        'title' => "อื่น ๆ"
                    ]
                ]
            ],
        ];

        $skipModel = new QuestionnaireSkipQuestion();
        $languages = Language::all();
        $languageMap = $languages->mapWithKeys(function($item) {
            return [$item['code'] => $item];
        });

        foreach($skips as $skipData) {
            $skip = $skipModel->updateOrCreate(['title' => $skipData['title']], ['status' => $skipData['status']]);

            foreach ($skipData['translate'] as $transData) {
                if (empty($languageMap[$transData['code']])) continue;

                $isTranslated = $skip->translates()->where('language_id', $languageMap[$transData['code']]['id'])->first();
                if (empty($isTranslated)) {
                    $skip->translates()->create([
                        'language_id' => $languageMap[$transData['code']]['id'],
                        'title' => $transData['title']
                    ]);
                }
            }
        }

        return $skip;
    }
}
