<?php

use App\Models\Client\Client;
use App\Models\Segment\Segment;
use App\Models\Segment\SegmentType;
use App\Models\User\UserAdminDetail;
use Illuminate\Database\Seeder;
use App\Models\User\User;
use Illuminate\Support\Facades\Hash;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Schema;
use App\Enum\Roles as EnumRoles;
class UserSeeder extends Seeder
{
    /**
     * Seed the application's database.
     *
     * @return void
     */
    public function run()
    {
        //Create default role and user
        $tablePermissionNames = config('permission.table_names');
        if(!Schema::hasTable($tablePermissionNames['roles']))
            throw new Exception("Don't have table roles, please run migrate first");

        // Create super_admin user
        $superAdmin = User::create([
            'name' => 'Vipula Samarkoon',
            'first_name' => 'Qualee',
            'last_name' => 'Super Admin',
            'email' => 'superadmin@qualee.com',
            'password' => Hash::make('test'),
            'status' => 1,
            'is_subscription' => 0,
            'phone' => '8527171757',
            'profile_pic' => '1569824866QUALEE-Logo-Mark-Blue-Gradient.png',
            'is_default' => 1,
            'remaining' => 0,
            'complete' => 1,
            'trial_ends_at' => new DateTime('2222-03-15 11:15:00'),
        ]);
        $superAdmin->assignRole(EnumRoles::SUPER_ADMIN);

        //Create client
        $client = Client::create([
            "code"=>'ABCDEF',
            "name"=>'Qualee',
            "status"=>'1',
            "is_subscription"=>'1',
            "created_by"=>$superAdmin->id,
            "email_verified_at"=>now(),
            "is_photo_id_enabled"=>0,
            "is_profile_photo_enabled"=>0,
            "support_type"=>'email',
        ]);

        $admin = User::create([
            'name' => 'Vipula Samarkoon',
            'first_name' => 'Qualee',
            'last_name' => 'Admin',
            'email' => 'admin@qualee.com',
            'password' =>Hash::make('test'),
            'status' => 1,
            'is_subscription' => 0,
            'phone' => '8527171757',
            'profile_pic' => '1569824866QUALEE-Logo-Mark-Blue-Gradient.png',
            'is_default' => 1,
            'remaining' => 0,
            'complete' => 1,
            'trial_ends_at' => new DateTime('2222-03-15 11:15:00'),
        ]);
        $admin->assignRole(EnumRoles::ADMIN);

        UserAdminDetail::create([
            "user_id"=>$admin->id,
            "department_id"=>'34',
            "city_id"=>'1',
            "client_id"=>$client->id,
            "preffered_name"=>'',
            "business_phone"=>'123456',
            "job_title"=>'Admin',
            "profile_url"=>'',
            "two_step_login"=>'0',
            "linkedinprofilepic"=>'',
            "profile_pic"=>'',
            "is_access_setup_enabled"=>1,

        ]);

        $segmentType = SegmentType::create([
            'name'=>'Gender'
        ]);
        Segment::create([
            'segment_type_id'=>$segmentType->id,
            'client_id'=>$client->id,
            'name'=>'Female'
        ]);
        $segment = Segment::create([
            'segment_type_id'=>$segmentType->id,
            'client_id'=>$client->id,
            'name'=>'Male'
        ]);
        $admin->segments()->attach($segment);
    }
}
