#!/usr/bin/env bash

# checks if branch has something pending
function parse_git_dirty() {
  git diff --quiet --ignore-submodules HEAD 2>/dev/null; [ $? -eq 1 ]
}

# gets the current git branch
function parse_git_branch() {
  git branch --no-color 2> /dev/null | sed -e '/^[^*]/d' -e "s/* \(.*\)/\1$(parse_git_dirty)/"
}

# get last commit hash prepended with @ (i.e. @8a323d0)
function parse_git_hash() {
  git rev-parse --short HEAD 2> /dev/null | sed "s/\(.*\)/-\1/"
}

GIT_BRANCH=dev-$(parse_git_branch)$(parse_git_hash)

export AWS_PROFILE=qualee
aws ecr get-login-password --region ap-southeast-1 | docker login --username AWS --password-stdin 541696823175.dkr.ecr.ap-southeast-1.amazonaws.com

docker build -t qualee-api-v3 .
docker tag qualee-api-v3:latest 541696823175.dkr.ecr.ap-southeast-1.amazonaws.com/qualee-api-v3:${GIT_BRANCH}
docker push 541696823175.dkr.ecr.ap-southeast-1.amazonaws.com/qualee-api-v3:${GIT_BRANCH}

IMG_VERSION=${GIT_BRANCH}
TASK_FAMILY="qualee-api"
CLUSTER_NAME="qualee-v3-fargate"
SERVICE_NAME="QualeeV3APIServers"

CONTAINER_DEFINITION_FILE=$(cat ./.docker/dev-qualee-api-v3.container-definition.json)
CONTAINER_DEFINITION="${CONTAINER_DEFINITION_FILE//<IMGAGE_VERSION>/$IMG_VERSION}"

export TASK_VERSION=$(aws ecs register-task-definition --family ${TASK_FAMILY} --cpu 1024 --memory 2048 --requires-compatibilities FARGATE EC2 --network-mode awsvpc --execution-role-arn arn:aws:iam::541696823175:role/ecsTaskExecutionRole --container-definitions "$CONTAINER_DEFINITION" | jq --raw-output '.taskDefinition.revision')
echo "Registered ECS Task Definition: " $TASK_VERSION

if [ -n "$TASK_VERSION" ]; then
    echo "Update ECS Cluster: " $CLUSTER_NAME
    echo "Service: " $SERVICE_NAME
    echo "Task Definition: " $TASK_FAMILY:$TASK_VERSION
    
    DEPLOYED_SERVICE=$(aws ecs update-service --cluster $CLUSTER_NAME --service $SERVICE_NAME --task-definition $TASK_FAMILY:$TASK_VERSION | jq --raw-output '.service.serviceName')
    echo "Deployment of $DEPLOYED_SERVICE complete"

else
    echo "exit: No task definition"
    exit;
fi

docker rmi -f 541696823175.dkr.ecr.ap-southeast-1.amazonaws.com/qualee-api-v3:${GIT_BRANCH}