# App context

Context is the current thing in a request.

For example, when a user is authenticated, all of the data should be scoped to the current user. 
A user should only be able to see their own inbox messages.

In qualee, when client admin or employee access the app, they should see data that belong to their client.

How context defined in api web app.

## Context Manager

This is class that manages all context in the app. There is `get` method to access all contexts by its name. 
We introduce `Context` facade to access ContextManager in static way. To access a context:
`Context::get('contextName')`

We may introduce some specific methods to quickly access popular context like:

```php
/**
 * @return UserContext
 * @throws Exception
 */
public function user(): UserContext
{
    return $this->get('user');
}
```

## Context

Context is a simply class to keep data, Context must register via `AppProvider`

```php
protected function registerContextHandler()
{
    $this->app->singleton(ClientContext::class, function () {
        return new ClientContext;
    });

    $this->app->singleton(UserContext::class, function () {
        return new UserContext;
    });

    $this->app->singleton(RequestContext::class, function () {
        return new RequestContext;
    });

    $this->app->singleton('context', function () {
        return new ContextManager([
            'client' => ClientContext::class,
            'user' => UserContext::class,
            'request' => RequestContext::class
        ]);
    });
}
```

## Guard

Instead of repeating business rule everywhere, using Guard to define single place to handle business rules.
Guard can be used in Context, Service...

