#### Database
 - Use string length constant in `AppMigration`:
```php
    const LONG_TEXT = 1023;
    const MEDIUM_TEXT = 255;
    const SHORT_TEXT = 63;
```
 - To give permission to user in migration file, we use `givePermissionTo` function.
 ```php
 $this->givePermissionTo(RolesEnum::ADMIN, 'event',self::ADMIN_PERMISSIONS);
```
- To revoke permission from user in migration file, we use `givePermissionTo` function.
 ```php
$this->revokePermissionTo(RolesEnum::ADMIN, 'event',self::ADMIN_PERMISSIONS);
```
 - Other naming convention in DB:
    - Boolean will start with `is_`. Eg:`is_active`...
    - For created user, we use `created_by` field.
    - For description, we use `description` field 
 
#### Business key
 - When models are has business key, saving model generates automatically business key. For using business key for model, use `App\Traits\HasBusinessKey` trait on the model:
 ```php
 <?php
 
 namespace App\Models;
 
 use Illuminate\Database\Eloquent\Model;
 use App\Traits\HasBusinessKey;
 
 class Flight extends Model
 {
     use HasBusinessKey;
 }
 ```
 - You should also add the `business_key` column to your database table. We build a new helper method to create this column:
 ```php
 public function up()
 {
     Schema::table('users', function (Blueprint $table) {
         $table->hasBusinessKey();
     });
 }
 ```
 - For changing business key, modify `bussiness_key_name` option on `Config/app.php` 
 ```php
 [
  'bussiness_key_name'=> 'business_key',
 ]
 ``` 
#### Business key
 - When models are has business key, saving model generates automatically business key. For using business key for model, use `App\Traits\HasBusinessKey` trait on the model:
 ```php
 <?php
 
 namespace App\Models;
 
 use Illuminate\Database\Eloquent\Model;
 use App\Traits\HasBusinessKey;
 
 class Flight extends Model
 {
     use HasBusinessKey;
 }
 ```
 - You should also add the `business_key` column to your database table. We build a new helper method to create this column:
 ```php
 public function up()
 {
     Schema::table('users', function (Blueprint $table) {
         $table->hasBusinessKey();
     });
 }
 ```
  - For changing business key, modify `bussiness_key_name` option on `Config/app.php` 
 ```php
 [
  'bussiness_key_name'=> 'business_key',
 ]
 ``` 