# Exceptions

There is 2 type of exception, `RuntimeException` and `HttpException`. `RuntimeException` will return error 500 in response. `HttpException` will return error in range 4xx.

`HttpException` must be inherited from `BaseHttpException`;

## Understanding response of exceptions

### ErrorCode

ErrorCode is string that represent for error type. example `DELETE_NOT_ALLOWED`.
All error codes must define in ErrorCode enum. Error code will be used for business handling and translation in front-end. 

#### Example flow

`DELETE_NOT_ALLOWED` will be defined in frontend like this: `Object is being used in :references`;

- To pass token data translation, use `replacements`
- To provide extra info, use `extras`.

```php 
/**
 * Exception thrown if the request data is not valid.
 */
class BaseHttpException extends HttpException
{
    public $errorCode;
    public $extras = array();
    public $replacements = array();

    /**
     * @param int $statusCode
     * @param string|null $message Code or message exception message
     * @param string|null $errorCode
     * @param array $replacements To replace tokens in error message
     * @param array $extras Extra info to handle in frontend
     */
    public function __construct(int $statusCode, string $message, string $errorCode = null, array $replacements = array(), array $extras = array())
    {
        $this->errorCode = $errorCode;
        $this->extras = $extras;
        $this->replacements = $replacements;
        parent::__construct($statusCode, $message, null, [], $statusCode);
    }
}
```