### Usage
#### Route
 - New qualee version is using Dingo for api, for more information, please visit this [link](https://github.com/dingo/api/wiki)
#### Controller
##### Create new controller

 - Use `php artisan make:api-controller [options] [--] <name>`.
 - For more information, use `php artisan help make:api-controller`
 - Example: `php artisan make:api-controller User/TestController --apiVersion=v2`.
##### How to use
 - In simple cases, such as single select model, logic should be put on a controller.
 - For more complex one, logic code should be separated to service layer files.
#### Service layer
##### Create new service 
 - In general, one service layer does exactly one job. If logic code contains more than one job, separate it into 2 services.
##### Validate
 - Validating data for service layer is put in `rules()` function and called in `validate($data)` function
#### Response
 - Data structure repsonse is writen in `Http/Resources` folder
### Coding convention
#### Business key
 - When models are has business key, saving model generates automatically business key. For using business key for model, use `App\Traits\HasBusinessKey` trait on the model:
```php
<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use App\Traits\HasBusinessKey;

class Flight extends Model
{
    use HasBusinessKey;
}
```
 -You should also add the `business_key` column to your database table. We build a new helper method to create this column:
```php
public function up()
{
    Schema::table('users', function (Blueprint $table) {
        $table->hasBusinessKey();
    });
}
```
 -For changing business key, modify `bussiness_key_name` option on `Config/app.php` 
```php
[
 'bussiness_key_name'=> 'business_key',
]
``` 
### Naming convention
#### Database
 - Use string length constant in `AppMigration`:
```php
    const LONG_TEXT = 1023;
    const MEDIUM_TEXT = 255;
    const SHORT_TEXT = 63;
``` 
 - Other naming convention in DB:
    - Boolean will start with `is_`. Eg:`is_active`...
    - For created user, we use `created_user` field.
    - For description, we use `description` field 
### Power search
 - Use `php artisan  reindex:powersearch` for reindex all data to power search.