<?php

namespace Qualee\AiDocSearch\Services;

use App\Document;
use App\Facades\Context;
use Exception;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\ClientException;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\App;
use Str;

class ServerlessService
{
    public function addDoc($args)
    {
        try {
            $file = $args['file'];
            $filePath = $args['file_path'];
            $filePathInfo = pathinfo($filePath);

            $path = Storage::disk('s3AiDocSearch')->putFileAs(
                $this->getFilePathInAIDocSearchRepo($filePathInfo['dirname']),
                $file,
                $filePathInfo['basename'],
                'public'
            );
        } catch (Exception $e) {
            Log::error($e);
            return $e->getMessage();
        }
        return $path;
    }

    public function updateDoc(array $args)
    {
        $user = Context::user()->get();
        $doc_name = $args['name'];
        $client_id = $args['client_id'];
        $profile_id = $args['document_profile_id'];
        $filePath = $this->getFilePathInAIDocSearchRepo($args['file_path']);

        $this->deleteFromS3($this->getFilePathInAIDocSearchRepo($args['old_file_path']));
        $this->addDoc($args);
        $this->deleteRelatedInfo($args);
    }

    public function deleteDoc($document)
    {
        try {
            $env = config('qualee-ai-doc-search.ads_env');
            $filePath = $this->getFilePathInAIDocSearchRepo($document->linkable->path);
            $client = new Client(['headers' => ['Accept' => 'application/json', 'Content-type' => 'application/json']]);
            $body = [
                'datecreated' => null,
                'docname' => $filePath,
                'client_id' => $document->client_id,
                'profile_id' => $document->document_profile_id,
                'env' => $env,
                'uid' => $document->uid
            ];
            $client->request(
                'POST',
                config('qualee-ai-doc-search.ads_lambda_search_domain') . '/deletedoc',
                [
                    'body' => json_encode($body)
                ]
            );
        } catch (Exception $e) {
            Log::error($e);
            return $e->getMessage();
        }
    }

    public function updateESDoc($document)
    {
        try {
            $env = config('qualee-ai-doc-search.ads_env');
            $client = new Client(['headers' => ['Accept' => 'application/json', 'Content-type' => 'application/json']]);
            $body = [
                'client_id' => $document->client_id,
                'uid' => $document->uid,
                'title' => $document->name,
                'env' => $env
            ];
            $client->request(
                'POST',
                config('qualee-ai-doc-search.ads_lambda_search_domain') . '/updateesdoc',
                [
                    'body' => json_encode($body)
                ]
            );
            
        } catch (Exception $e) {
            Log::error($e);
            return $e->getMessage();
        }
    }

    public function deleteFromS3($filePath)
    {
        try {
            Storage::disk('s3AiDocSearch')->delete($filePath);
        } catch (Exception $e) {
            Log::error($e);
            return $e->getMessage();
        }
    }

    public function deleteRelatedInfo($args)
    {
        try {
            $env =  config('qualee-ai-doc-search.ads_env');
            $client = new Client(['headers' => ['Accept' => 'application/json', 'Content-type' => 'application/json']]);
            $body = [
                'datecreated' => null,
                'docname' => $this->getFilePathInAIDocSearchRepo($args['old_file_path']),
                'client_id' => $args['client_id'],
                'profile_id' => $args['profile_id'],
                'uid' => $args['uid'],
                'env' => $env
            ];
            $client->request(
                'POST',
                config('qualee-ai-doc-search.ads_lambda_search_domain') . '/deletedoc',
                [
                    'body' => json_encode($body)
                ]
            );
        } catch (Exception $e) {
            Log::error($e);
            return $e->getMessage();
        }
    }

    public function startDetectTextract($args)
    {
        $env = config('qualee-ai-doc-search.ads_env');
        $uid = $args['uid'];
        $client_id = $args['client_id'];
        $profile_id = $args['document_profile_id'];
        $title = $args['name'];
        $filePath = $args['file_path'];

        try {
            $client = new Client(['headers' => ['Accept' => 'application/json', 'Content-type' => 'application/json']]);
            $body = [
                'client_id' => $client_id,
                'docname' => $this->getFilePathInAIDocSearchRepo($filePath),
                'profile_id' => $profile_id,
                'title' => $title,
                'env' => $env,
                'uid' => $uid
            ];

            $client->request(
                'POST',
                config('qualee-ai-doc-search.ads_lambda_search_domain') . '/startdetecttexract',
                [
                    'body' => json_encode($body)
                ]
            );
        } catch (ClientException $e) {
            Log::error($e);
            return $e->getMessage();
        }
    }

    // CREATE PREFIX BY ENVIRONMENT FOR ELASTICSEARCH INDEX KEY
    public function prefixForIndex($id) {
        return config('qualee-ai-doc-search.ads_env');
    }

    private function getFilePathInAIDocSearchRepo($fileName) {
        return config('qualee-ai-doc-search.ads_env') . '/' . $fileName;
    }
}
