from requests_aws4auth import AWS4Auth
import boto3
import json
import requests
import time

# FULFILL WITH OWNER IAM (OR ROOT USER) CREDENTIALS:
host = "https://search-docs-search-demo-vtonyisdo2be7mfhv7wfcwpfba.ap-southeast-1.es.amazonaws.com/"  # For example, my-test-domain.us-east-1.es.amazonaws.com
region = "ap-southeast-1"  # e.g. us-west-1
service = "es"
credentials = boto3.Session(
    aws_access_key_id="",  # ACCESS KEY
    aws_secret_access_key="",  # SECRET KEY
).get_credentials()

# DEBUGGGING: PRINT TO VERIFY THE KEYS
print("access_key: " + credentials.access_key)
print("secret_key: " + credentials.secret_key)

# INITIALISE AWS SESSION:
awsauth = AWS4Auth(
    credentials.access_key,
    credentials.secret_key,
    region,
    service,
    session_token=credentials.token,
)


def uploadToElastics(data, comprehend, docname, clientid, profileid, uid, title, env):
    print('start uploadToElastics')
    timestamp = int(time.time() * 1000)
    path = str(env) + '_client_' + str(clientid) + "/_doc/" + str(timestamp)
    url = host + path

    payload = {
        "profileid": str(profileid),
        "uid": str(uid),
        "timestamp": timestamp,
        "body": data,
        "comprehend": comprehend,
        "env": env,
        "title": title,
        "docname": docname
    }

    resp = requests.put(
        url, auth=awsauth, json=payload
    )  # requests.get, post, and delete have similar syntax

    return resp.text


def deleteFromElastics(clientid, profileid, uid, env):
    # FROM DATA ES:
    url = host + str(env) + '_client_' + str(clientid) + "/_delete_by_query"
    query1 = {"query": {"bool": {"must": [{"match": {"uid": str(uid)}}]}}}
    r1 = requests.post(
        url,
        auth=awsauth,
        json=query1,
        headers={"Content-Type": "application/json"},
    )
    print(r1.text)

    # FROM KEYWORDS ES:
    pathKeywords = str(env) + '_client_' + str(clientid) + "_keywords" +"/_delete_by_query"
    url = host + pathKeywords
    query2 = {"query": {"bool": {"must": [{"match": {"uid": str(uid)}}]}}}
    r2 = requests.post(
        url,
        auth=awsauth,
        json=query2,
        headers={"Content-Type": "application/json"},
    )
    print(r2.text)
    return r2.text

def updateDocTitleElastics(clientid, uid, title, env):
    # FROM DATA ES:
    url = host + str(env) + '_client_' + str(clientid) + "/_update_by_query"
    query1 = {"script": { "source": "ctx._source.title='"+title+"'", "lang": "painless"}, "query": {"bool": {"must": [{"match": {"uid": str(uid)}}]}}}
    r1 = requests.post(
        url,
        auth=awsauth,
        json=query1,
        headers={"Content-Type": "application/json"},
    )
    print(r1.text)
    return r1.text

def uploadKeywordToElastics(data: str, type: str, fromDoc: str, keyIds: dict):
    timestamp = int(time.time() * 1000)
    prepared_keyword = "_".join(data.split()).lower()
    path = str(keyIds.get('env')) + '_client_' + str(keyIds.get('clientid')) + "_keywords" + "/_doc/" + prepared_keyword
    url = host + path
    payload = {
        "profileid": str(keyIds.get('profileid')),
        "uid": str(keyIds.get('uid')),
        "timestamp": timestamp,
        "body": data,
        "type": type,
        "from": fromDoc,
    }

    r1 = requests.put(url, auth=awsauth, json=payload)
    return r1.text


def startsearch(query: str, clientid: str, profileid: str, env: str):
    url = host + str(env) + '_client_'+ str(clientid) + "/_search?explain"
    print(url)
    print(query + "*")

    # Support for searching by a list of content profile
    try:
        object_iterator = iter(profileid)
    except TypeError as te:
        profile_query = profileid
    else:
        profile_query = profileid if isinstance(profileid, str) else " OR ".join(map(str, profileid))

    query = {
        "query": {
            "query_string": {
                "fields": ["body", "title", "uid", "docname"],
                "query": "profileid:(" + str(profile_query) + ") AND env:" + str(env) + " AND (body:" + query + "* OR title:" + query + "*)",
                "analyze_wildcard": True,
            }
        }
    }
    print(query)
    r2 = requests.get(
        url,
        auth=awsauth,
        data=json.dumps(query),
        headers={"Content-Type": "application/json"},
    )
    return r2.text


def startshowingsuggests(query: str, clientid: str):
    url = host + str(clientid) + "_keywords" + "/_search?explain"
    query = {
        "query": {
            "multi_match": {
                "query": query,
                "type": "cross_fields",
                "fields": ["comprehend"],
                "operator": "and",
            }
        }
    }
    print(url)
    response = requests.get(
        url,
        auth=awsauth,
        data=json.dumps(query),
        headers={"Content-Type": "application/json"},
    )
    print(response.text)
    return response.text


def startsuggest(str_query: str, clientid: str, profileid: str):
    url = host + str(clientid) + "_keywords" + "/_search?pretty=true"
    query = {
        "query": {
            "query_string": {
                "fields": ["body"],
                "query": "profileid:" + str(profileid) + " AND body:" + str_query + "*",
                "analyze_wildcard": True,
            }
        }
    }
    r2 = requests.get(
        url,
        auth=awsauth,
        data=json.dumps(query),
        headers={"Content-Type": "application/json"},
    )
    print(r2.text)
    return r2.text


def listAllInElasticsearch(nodename: str):
    url = host + nodename + "/_search?q=*:*"
    r2 = requests.get(
        url,
        auth=awsauth,
        headers={"Content-Type": "application/json"},
    )
    print(r2.text)
    return r2.text
