<?php

use App\Enum\AccessPermissions;
use App\Enum\Roles;
use Dingo\Api\Routing\Router;

/** @var Router $api */
$api = app(Router::class);

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

$api->version('v1', ['middleware' => 'api.throttle'], function (Router $api) {

    // Mobile APIs
    $api->group(['prefix' => 'm', 'namespace' => 'App\Http\Controllers\Api\Mobile_V1'], function (Router $api) {
        // Auth
        $api->group(['prefix' => 'demo'], function (Router $api) {
            $api->post('login', 'Auth\AuthDemoController@demoLogin');
            $api->group(['middleware' => ['auth:api']], function (Router $api) {
                $api->post('logout', 'Auth\AuthDemoController@demoLogout');
            });
        });
        $api->group(['prefix' => 'auth'], function (Router $api) {
            $api->post('login', 'Auth\AuthController@login');
            $api->post('forgot', 'Auth\ForgotPasswordController@forgot');
            $api->post('reset', 'Auth\ForgotPasswordController@reset');
            $api->group(['middleware' => ['auth:api']], function (Router $api) {
                $api->post('logout', 'Auth\AuthController@logout');
                $api->post('sync', 'Auth\AuthController@sync');
                $api->post('resetDefault', 'Auth\ForgotPasswordController@resetDefaultPassword');
            });
        });

        $api->group(['middleware' => ['auth:api', 'auth.employee.context']], function (Router $api) {
            $api->group(['prefix' => 'auth'], function (Router $api) {
                $api->post('logout', 'Auth\AuthController@logout');
                $api->post('sync', 'Auth\AuthController@sync');
                $api->post('resetDefault', 'Auth\ForgotPasswordController@resetDefaultPassword');
            });

            $api->group(['prefix' => 'qr'], function (Router $api) {
                $api->post('/', 'QR\QRController@scanQRCode');
            });

            $api->group(['prefix' => 'journey'], function (Router $api) {
                $api->get('/', 'Journey\JourneyController@get');
                $api->get('/steps', 'Journey\JourneyController@getSteps');
                $api->get('/step', 'Journey\JourneyController@getStepDetail');
                $api->post('/submit', 'Journey\JourneyController@submitStepDetails');
                $api->post('/skip', 'Journey\JourneyController@skipStep');
                $api->get('/result', 'Journey\JourneyController@getStepResults');
                $api->get('/document/{documentId}/status', 'Journey\JourneyController@getFormDocumentStatus');
            });

            // Questionnaire
            $api->group(['prefix' => 'questionnaire'], function (Router $api) {
                $api->get('/round/{round_id}', 'Questionnaire\QuestionnaireController@getQuestions');
                $api->post('/round/{round_id}/answer', 'Questionnaire\QuestionnaireController@answer');
                $api->get('/round/{round_id}/summary', 'Questionnaire\QuestionnaireController@summary');
                $api->get('/skip-question', 'Questionnaire\QuestionnaireSkipQuestionController@getSkipQuestions');
            });

            // Engage
            $api->group(['prefix' => 'engage'], function (Router $api) {
                //Initiative
                $api->get('initiative', 'Engage\EngageController@getInitiative');
                $api->get('archive', 'Engage\EngageController@getArchive');
                $api->get('enps', 'Engage\EngageController@geteNPS');
            });

            // Event
            $api->group(['prefix' => 'event'], function (Router $api) {
                $api->get('', 'Event\EventController@getAll');
                $api->get('{code}/users', 'Event\EventController@getEventUser');
            });

            $api->group(['prefix' => 'message'], function (Router $api) {
                $api->post('', 'Message\MessageController@store');
                $api->get('/unread', 'Message\MessageController@getNumberUnreadMessage');
                $api->post('/{id}/translate', 'Message\MessageController@translateMessage');
            });

            $api->group(['prefix' => 'conversation'], function (Router $api) {
                $api->get('', 'Message\MessageController@getConversations');
                $api->get('/{id}/message', 'Message\MessageController@getMessageConversation');
                $api->get('/{id}', 'Message\MessageController@getConversationDetail');
                $api->post('/{id}/mark-as-read', 'Message\MessageController@markConversationAsRead');
                $api->post('/{id}/whistleblowing', 'Message\MessageController@manageWhistlegblowingCategoryConversation');
                $api->post('/{id}/transfer-whistleblower', 'Message\MessageController@transferWhistleblower');
                $api->post('/{id}/close', 'Message\MessageController@closeAnonymousConversation');
                $api->post('/{id}/open', 'Message\MessageController@reopenAnonymousConversation');
                $api->delete('/{id}', 'Message\MessageController@deleteConversation');
                $api->post('', 'Message\MessageController@createConversationEmployee');
            });
            // Setting
            $api->group(['prefix' => 'setting'], function (Router $api) {
                $api->get('profile', 'Setting\SettingController@getProfile');
                $api->post('profile', 'Setting\SettingController@updateProfile');
                $api->post('bug/report', 'Setting\SettingController@reportBug');
                $api->post('password/update', 'Setting\SettingController@updatePassword');
                $api->post('avatar/update', 'Setting\SettingController@updateAvatar');
            });

            //User
            $api->group(['prefix' => 'user'], function (Router $api) {
                $api->get('pending-actions', 'User\UserController@getPendingActions');
                $api->get('pending-action', 'User\UserController@getPendingAction');
                $api->get('pending-action/results', 'User\UserController@getPendingActionResults');
            });

            // Dashboard
            $api->group(['prefix' => 'dashboard'], function (Router $api) {
                $api->get('user', 'Dashboard\DashboardController@getUserInfo');
            });

            // Employee
            $api->group(['prefix' => 'employee'], function (Router $api) {
                $api->get('/', 'User\UserController@getEmployees');
                $api->get('/segments', 'Segment\SegmentController@getSegments');
                $api->get('segment', 'Segment\SegmentController@getSegmentTeams');
                $api->get('segment/{segmentCode}/employee', 'Segment\SegmentController@getSegmentEmployees');
                $api->get('segment/search', 'Segment\SegmentController@searchEmployee');
                $api->get('/{employeeCode}', 'Segment\SegmentController@getEmployeeByCode');
            });

            // In app rating
            $api->group(['middleware' => ['auth:api'], 'prefix' => 'rating'], function (Router $api) {
                $api->post('/', 'AppRating\AppRatingController@submit');
            });

            //Action sequence
            $api->group(['prefix' => 'action-sequence'], function (Router $api) {
                $api->get('', 'Action\ActionController@getActionSequence');
            });

            //Action
            $api->group(['prefix' => 'action'], function (Router $api) {
                $api->get('', 'Action\ActionController@getActionSequence');
            });

            //Sync fresh data
            $api->group(['prefix' => 'sync'], function (Router $api) {
                $api->get('', 'Sync\SyncController@sync');
                $api->post('timezone', 'Sync\SyncController@syncTimezone');
            });

            // Library
            $api->group(['prefix' => 'library'], function (Router $api) {
                $api->get('get', 'Library\LibraryController@getDocuments');
                $api->get('signed-document', 'Library\LibraryController@getSignedDocuments');
            });

            $api->get('anonymous-conversation-category', 'Message\MessageController@getAnonymousConversationCategory');
        });
    });

    //Web console APIs
    $api->group([], function (Router $api) {
        // Email verification
        $api->get('email/verify/{id}/{hash}', 'App\Http\Controllers\Api\v1\Auth\VerificationController@verify')
            ->name('verification.verify');

        //        $api->get('test', 'App\Http\Controllers\Api\v1\Auth\VerificationController@test')
        //            ->name('test');
        //        $api->get('test2', 'App\Http\Controllers\Api\v1\Auth\VerificationController@test2')
        //            ->name('test2');
        $api->get('detectSentiment', 'App\Http\Controllers\Api\v1\Auth\VerificationController@detectSentiment')->name('detectSentiment');
        $api->get('batchLanguages', 'App\Http\Controllers\Api\v1\Auth\VerificationController@batchLanguages')->name('batchLanguages');
        $api->get('batchDetectSentiment/{language}', 'App\Http\Controllers\Api\v1\Auth\VerificationController@batchDetectSentiment')->name('batchDetectSentiment');

        // Download CSV
        $api->get('download-csv/{id}', 'App\Http\Controllers\Api\v1\Employee\DownloadCsvController@download')->name('downloadCsv');
        $api->post('save-csv/{id}', 'App\Http\Controllers\Api\v1\Employee\DownloadCsvController@save')->name('saveCsv');

        $api->get('/', 'App\Http\Controllers\Api\ApiController@success')->name('apiSuccess');
        $api->group(['prefix' => 'auth', 'namespace' => 'App\Http\Controllers\Api\v1'], function (Router $api) {
            $api->post('login', 'Auth\AuthController@login');
            $api->post('login-2fa', 'Auth\AuthController@loginWith2FA');
            $api->post('/magic-link', 'Auth\AuthController@loginMagicLink');
        });
        $api->group(['namespace' => 'App\Http\Controllers\Api\v1', 'prefix' => 'saml2'], function (Router $api) {
            $api->group([], function (Router $api) {
                $api->post('{clientCode}/acs', 'SSO\Saml2Controller@acs')->name('saml2_acs');
                $api->get('{clientCode}/metadata', 'SSO\Saml2Controller@metadata')->name('saml2_metadata');
            });
            $api->post('login', 'SSO\Saml2Controller@login')->name('saml2_login');
        });

        $api->group(['namespace' => 'App\Http\Controllers\Api\v1'], function (Router $api) {
            $api->post('/user/forgotpassword', 'Auth\ForgotPasswordController@forgot');
            $api->post('/user/resetpassword', 'Auth\ForgotPasswordController@reset');
            $api->post('/user/2fa/reset', 'Auth\TwoFactorAuthenticationController@reset');
        });

        // Integration Webhooks
        $api->post('integration/webhook', 'App\Http\Controllers\Api\v1\Integration\IntegrationController@syncIntegration');

        $api->group(['prefix' => 'qr', 'namespace' => 'App\Http\Controllers\Api\v1'], function (Router $api) {
            $api->post('', 'QR\QRController@createNewToken');
            $api->post('/getOtpToken', 'QR\QRController@getOtpToken');
            $api->get('/{sessionId}/verifaiResult', 'QR\QRController@verifaiResult');
            $api->delete('/{sessionId}/delete', 'QR\QRController@deleteSessionData');
            $api->group(['middleware' => 'qr.token'], function (Router $api) {
                $api->get('user/detail', 'QR\QRController@getUserDetailByQRToken');
                $api->group(['prefix' => 'journeys'], function (Router $api) {
                    $api->get('/steps/{id}/result', 'QR\QRController@getJourneyStepResult');
                    $api->get('/steps/{id}', 'QR\QRController@getJourneyStepDetail');
                    $api->post('/steps/{id}', 'QR\QRController@submitJourneyStepDetail');
                    $api->get('/', 'QR\QRController@getJourneyDetail');
                });
            });
        });

        $api->post('auth/websocket', 'App\Http\Controllers\Api\v1\Auth\AuthController@authWebsocket');

        $api->group(['middleware' => ['auth:api'], 'namespace' => 'App\Http\Controllers\Api\v1'], function (Router $api) {
            $api->group(['prefix' => 'user'], function (Router $api) {
                $api->get('current', 'User\UserController@getCurrentUser');
                $api->post('logout', 'Auth\AuthController@logout');
                $api->post('password', 'User\UserController@updatePassword');
            });
            $api->group(['prefix' => 'saml2'], function (Router $api) {
                $api->get('{clientCode}/sls', 'SSO\Saml2Controller@sls')->name('saml2_sls');
            });


            $api->group(['prefix' => 'language'], function (Router $api) {
                $api->get('/', 'Language\LanguageController@index');
            });

            $api->group(['prefix' => 'master-data'], function (Router $api) {
                $api->get('industry', 'MasterData\MasterDataController@getIndustries');
                $api->get('city', 'MasterData\MasterDataController@getCities');
                $api->get('anonymous-conversation-category', 'Message\AnonymousConversationCategoryController@index');
            });

            // Client context
            $api->group(['prefix' => 'client/{clientCode}', 'middleware' => ['auth.client_admin.context']], function (Router $api) {
                $api->group(['prefix' => 'asset'], function (Router $api) {
                    $api->get('', 'AssetController@getAll');
                    $api->post('', 'AssetController@create');
                    $api->delete('{id}', 'AssetController@delete');
                });
                $api->group(['prefix' => 'user'], function (Router $api) {
                    $api->get('/search/user-segment', 'User\UserController@getSegmentAndUser');
                    $api->get('/search/user-admin-or-manager', 'User\UserController@getAdminAndManager');
                });
                // User
                $api->group(['prefix' => 'user'], function (Router $api) {
                    $api->group(['prefix' => '2fa'], function (Router $api) {
                        $api->post('prepare', 'Auth\TwoFactorAuthenticationController@prepare');
                        $api->post('enable', 'Auth\TwoFactorAuthenticationController@enable');
                        $api->post('disable', 'Auth\TwoFactorAuthenticationController@disable');
                    });
                    $api->post('/profile', 'User\UserController@updateProfile');
                });

                // Event
                $api->group(['prefix' => 'event'], function (Router $api) {
                    $api->group(
                        [
                            'middleware' =>
                            ['access:' . AccessPermissions::ACCESS_COMPANY_EVENT . '|' . AccessPermissions::ACCESS_OWNER_EVENT]
                        ],
                        function (Router $api) {
                            $api->get('/place/eventPage', 'Event\EventController@getAll');
                            $api->get('/place/dashboard', 'Event\EventController@getNearestAll');
                            $api->get('{id}', 'Event\EventController@get');
                            $api->group(['middleware' => ['access:' . AccessPermissions::SYNC_THIRD_PARTY_EVENT]], function (Router $api) {
                                $api->post('sync', 'Event\EventController@sync');
                            });
                            $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_EDIT_DELETE_EVENT]], function (Router $api) {
                                $api->post('', 'Event\EventController@create');
                                $api->post('{id}', 'Event\EventController@update');
                                $api->delete('{id}', 'Event\EventController@delete');
                            });
                        }
                    );
                });

                $api->group(['prefix' => 'library-item'], function (Router $api) {
                    $api->group(
                        [
                            'middleware' =>
                            ['access:' . AccessPermissions::ACCESS_COMPANY_LIBRARY . '|' . AccessPermissions::ACCESS_CONTENT_PROFILE_LIBRARY]
                        ],
                        function (Router $api) {
                            $api->get('', 'Library\LibraryController@getAll');
                            $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_EDIT_DELETE_LIBRARY]], function (Router $api) {
                                $api->post('', 'Library\LibraryController@create');
                                $api->post('bulk-upload', 'Library\LibraryController@bulkUploadFileToLibrary');
                                $api->post('delete-multiple', 'Library\LibraryController@deleteMultiple');
                                $api->post('{id}', 'Library\LibraryController@update');
                                $api->delete('{id}', 'Library\LibraryController@delete');
                            });
                        }
                    );
                });

                $api->group(['prefix' => 'document-profile'], function (Router $api) {
                    $api->get('', 'Library\LibraryController@getDocumentProfiles');
                    $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_EDIT_DELETE_LIBRARY]], function (Router $api) {
                        $api->group(['middleware' => ['access:' . AccessPermissions::ACCESS_COMPANY_LIBRARY]], function (Router $api) {
                            $api->post('', 'Library\LibraryController@createDocumentProfile');
                            $api->post('/{id}', 'Library\LibraryController@updateDocumentProfile');
                            $api->delete('{id}', 'Library\LibraryController@deleteDocumentProfile');
                        });
                    });
                });

                $api->group(
                    ['prefix' => 'quiz', 'middleware' => ['access:' . AccessPermissions::ACCESS_QUIZ]],
                    function (Router $api) {
                        $api->get('', 'Quiz\QuizController@getAll');
                        $api->get('{code}', 'Quiz\QuizController@detail');
                        $api->get('/{code}/download', 'Quiz\QuizController@download');
                        $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_EDIT_QUIZ]], function (Router $api) {
                            $api->post('', 'Quiz\QuizController@create');
                            $api->post('{code}', 'Quiz\QuizController@update');
                            $api->post('{code}/questions', 'Quiz\QuizController@saveQuizQuestion');
                            $api->post('{code}/publish', 'Quiz\QuizController@publish');
                            $api->post('{code}/unpublish', 'Quiz\QuizController@unpublish');
                            $api->post('{code}/duplicate', 'Quiz\QuizController@duplicate');
                            $api->delete('{code}', 'Quiz\QuizController@delete');
                        });
                    }
                );

                $api->group(['prefix' => 'message'], function (Router $api) {
                    $api->get('', 'Message\MessageController@get');
                    $api->post('', 'Message\MessageController@store');
                    $api->get('/unread', 'Message\MessageController@getNumberUnreadMessage');
                    $api->post('/{id}/translate', 'Message\MessageController@translateMessage');
                });

                $api->group(['prefix' => 'conversation'], function (Router $api) {
                    $api->get('', 'Message\MessageController@getConversations');
                    $api->get('/{id}', 'Message\MessageController@getConversationDetail');
                    $api->get('/{id}/message', 'Message\MessageController@getMessageConversation');
                    $api->post('/{id}/mark-as-read', 'Message\MessageController@markConversationAsRead');
                    $api->post('/{id}/whistleblowing', 'Message\MessageController@manageWhistlegblowingCategoryConversation');
                    $api->post('/{id}/transfer-whistleblower', 'Message\MessageController@transferWhistleblower');
                    $api->get('/{id}/export-whistleblowing', 'Message\MessageController@downloadAnonymousConversation');
                    $api->post('/{id}/close', 'Message\MessageController@closeAnonymousConversation');
                    $api->post('/{id}/open', 'Message\MessageController@reopenAnonymousConversation');
                    $api->post('/{id}/status/{status}', 'Message\MessageController@updateStatusAnonymousConversation');
                    $api->post('/sensitive-comment', 'Message\MessageController@createSensitiveCommentDiscussion');
                    $api->post('/comment', 'Message\MessageController@createCommentDiscussion');
                    $api->post('', 'Message\MessageController@createConversationAdmin');
                    $api->delete('/{id}', 'Message\MessageController@deleteConversation');
                });

                $api->group(['prefix' => 'notification'], function (Router $api) {
                    $api->get('', 'Message\MessageController@getNotifications');
                    $api->post('', 'Message\MessageController@readAllNotifications');
                    $api->post('/{id}', 'Message\MessageController@readNotification');
                });

                $api->group(['prefix' => 'comment'], function (Router $api) {
                    $api->post('/note', 'Message\MessageController@sendCommentNote');
                    $api->get('/{id}/note', 'Message\MessageController@getCommentNotes');
                });

                $api->group(
                    ['prefix' => 'survey', 'namespace' => 'Survey', 'middleware' => ['access:' . AccessPermissions::ACCESS_SURVEY]],
                    function (Router $api) {
                        $api->get('', 'SurveyController@getAll');
                        $api->get('/{code}', 'SurveyController@get');
                        $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_EDIT_SURVEY]], function (Router $api) {
                            $api->post('', 'SurveyController@create');
                            $api->post('/{code}', 'SurveyController@update');
                            $api->get('/{code}/report', 'SurveyController@report');
                            $api->get('/{code}/download', 'SurveyController@download');
                            $api->post('/{code}/question', 'SurveyController@question');
                            $api->post('/{code}/publish', 'SurveyController@publish');
                            $api->post('/{code}/unpublish', 'SurveyController@unpublish');
                            $api->post('/{code}/duplicate', 'SurveyController@duplicate');
                            $api->delete('/{code}', 'SurveyController@delete');
                        });
                    }
                );

                $api->group(
                    ['prefix' => 'journey', 'middleware' => ['access:' . AccessPermissions::ACCESS_JOURNEY]],
                    function (Router $api) {
                        $api->group(['middleware' => ['access:' . AccessPermissions::ACCESS_JOURNEY_STATISTICS]], function (Router $api) {
                            $api->get('{code}/progress', 'Journey\JourneyController@getJourneyProgress');
                        });
                        $api->get('', 'Journey\JourneyController@getAll');
                        $api->get('{code}', 'Journey\JourneyController@detail');
                        $api->get('{code}/employees', 'Journey\JourneyController@getEmployees');
                        $api->get('{code}/steps', 'Journey\JourneyController@getSteps');
                        $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_EDIT_JOURNEY]], function (Router $api) {
                            $api->post('', 'Journey\JourneyController@create');
                            $api->post('{code}', 'Journey\JourneyController@update');
                            $api->post('{code}/steps', 'Journey\JourneyController@saveStep');
                            $api->post('{code}/duplicate', 'Journey\JourneyController@duplicate');
                            $api->post('/{code}/publish', 'Journey\JourneyController@publish');
                            $api->post('/{code}/unpublish', 'Journey\JourneyController@unpublish');
                            $api->delete('{code}', 'Journey\JourneyController@delete');
                        });
                        $api->post('{code}/employees', 'Journey\JourneyController@addEmployees');
                        $api->post('{code}/restart', 'Journey\JourneyController@restartJourney');
                        $api->post('{code}/restart/{employeeCode}', 'Journey\JourneyController@restartJourneyUser');
                        $api->post('{code}/restartSelectedUsers/{employeesCode}', 'Journey\JourneyController@restartJourneyUsers');
                        $api->post('{code}/reminder/{employeeCode}', 'Journey\JourneyController@sendReminderUser');
                        $api->post('{code}/reminders/{employeesCode}', 'Journey\JourneyController@sendReminderUsers');
                        $api->post('{code}/resend-documents', 'Journey\JourneyController@createFormDocument');
                        $api->get('{code}/employees/{employeeCode}', 'Journey\JourneyController@getEmployeeSubmission');
                        $api->get(
                            '{code}/employees/{employeeCode}/download',
                            'Journey\JourneyController@downloadEmployeeSubmission'
                        );
                        $api->get(
                            '{code}/employees/{employeesCode}/downloads',
                            'Journey\JourneyController@downloadEmployeesSubmission'
                        );
                        $api->delete('{code}/employees/{employeeCode}', 'Journey\JourneyController@removeEmployee');
                        $api->delete('{code}/removeSelectedEmployees/{employeesCode}', 'Journey\JourneyController@removeEmployees');
                    }
                );

                $api->group(['prefix' => 'form'], function (Router $api) {
                    $api->get('templates', 'Form\FormController@getTemplates');
                    $api->get('integration-check', 'Form\FormController@checkIntegration');
                    $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_EDIT_FORM]], function (Router $api) {
                        $api->post('integration', 'Form\FormController@integrate');
                        $api->delete('integration', 'Form\FormController@removeIntegration');
                    });
                });

                $api->group(['prefix' => 'dashboard'], function (Router $api) {
                    $api->group(['prefix' => 'engagement'], function (Router $api) {
                        $api->get('/', 'Dashboard\DashboardController@engagement');
                    });
                    $api->group(
                        ['prefix' => 'whistleblowing', 'middleware' => ['access:' . AccessPermissions::ACCESS_WB_DASHBOARD]],
                        function (Router $api) {
                            $api->get('', 'Dashboard\DashboardController@getWhistleblowingDashboardData');
                        }
                    );
                    $api->get('statistics', 'Dashboard\DashboardController@getStatistics');
                });

                $api->group(['prefix' => 'driver'], function (Router $api) {
                    $api->get('', 'Driver\DriverController@index');
                });

                $api->group(
                    ['prefix' => 'questionnaire', 'middleware' => ['access:' . AccessPermissions::ACCESS_QUESTIONNAIRE]],
                    function (Router $api) {
                        $api->get('', 'Questionnaire\QuestionnaireController@index');
                        $api->put('{questionnaire}/publish', 'Questionnaire\QuestionnaireController@publishQuestion');
                    }
                );

                $api->group(['prefix' => 'segment', 'namespace' => 'Segment'], function (Router $api) {
                    $api->get('', 'SegmentController@index');
                });

                // Segment
                $api->group(
                    [
                        'prefix' => 'segment-type',
                        'namespace' => 'Segment',
                        'middleware' => ['access:' . AccessPermissions::ACCESS_SEGMENT]
                    ],
                    function (Router $api) {
                        $api->get('', 'SegmentController@getSegmentTypes');
                        $api->get('/{code}', 'SegmentController@getSegmentTypeDetail');
                        $api->get('/{code}/segment/{segmentCode}', 'SegmentController@getSegmentDetail');
                        $api->get('/{code}/segment/{segmentCode}/employee/', 'SegmentController@getSegmentEmployee');
                        $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_EDIT_SEGMENT]], function (Router $api) {
                            $api->post('/{code}/segment/{segmentCode}', 'SegmentController@updateSegment');
                            $api->post('/{code}', 'SegmentController@addSegment');
                            $api->delete('/{code}/segment/{segmentCode}', 'SegmentController@deleteSegment');
                        });
                        $api->post('/{code}/segment/{segmentCode}/employee', 'SegmentController@addSegmentEmployee');
                        $api->post('/{code}/segment/{segmentCode}/employee/delete', 'SegmentController@deleteSegmentEmployee');
                    }
                );

                // Client values
                $api->group(
                    [
                        'prefix' => 'client',
                        'middleware' => ['access:' . AccessPermissions::ACCESS_VALUES]
                    ],
                    function (Router $api) {
                        $api->resource('/value', 'Client\ClientValueController');
                        $api->group(['prefix' => 'value'], function (Router $api) {
                            $api->group(['prefix' => '{value}'], function (Router $api) {
                                $api->get('translate', 'Client\ClientValueTranslateController@index');
                                $api->post('translate', 'Client\ClientValueTranslateController@translate');
                            });
                        });
                    }
                );
                $api->get('employee-lite', 'Employee\EmployeeController@getEmployeeLite');
                $api->group(
                    ['prefix' => 'employee', 'middleware' => ['access:' . AccessPermissions::ACCESS_EMPLOYEE]],
                    function (Router $api) {
                        $api->group(['middleware' => ['access:' . AccessPermissions::ACCESS_JOURNEY_STATISTICS]], function (Router $api) {
                            $api->get('starting-next', 'Employee\EmployeeController@getStartingNext');
                        });
                        $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_EMPLOYEE]], function (Router $api) {
                            $api->post('', 'Employee\EmployeeController@create');
                            $api->post('import', 'Employee\EmployeeController@import');
                            $api->get('import/{code}', 'Employee\EmployeeController@importStatus');
                        });
                        $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_ADMIN]], function (Router $api) {
                            $api->post('admin', 'Employee\EmployeeController@createAdmin');
                        });
                        $api->group(['middleware' => ['access:' . AccessPermissions::EDIT_EMPLOYEE]], function (Router $api) {
                            $api->post('{code}', 'Employee\EmployeeController@update');
                            $api->post('{code}/enable', 'Employee\EmployeeController@enable');
                            $api->post('{code}/disable', 'Employee\EmployeeController@disable');
                            $api->post('{code}/quick-update', 'Employee\EmployeeController@quickUpdate');
                            $api->post('{code}/bulk-re-verify-email', 'Employee\EmployeeController@bulkReVerifyEmail');
                            $api->post('{code}/bulk-enable-or-disable', 'Employee\EmployeeController@bulkEnableOrDisableEmployee');
                            $api->post('{code}/bulk-delete', 'Employee\EmployeeController@bulkDeleteEmployee');
                            $api->post('{code}/bulk-update-content-profiles', 'Employee\EmployeeController@bulkUpdateContentProfiles');
                            $api->get('update-status/{code}', 'Employee\EmployeeController@updateStatus');
                            $api->post('{code}/bulk-passwords-email', 'Employee\EmployeeController@bulkPasswordsEmail');
                        });
                        $api->group(['middleware' => ['access:' . AccessPermissions::DELETE_EMPLOYEE]], function (Router $api) {
                            $api->delete('{code}', 'Employee\EmployeeController@delete');
                        });
                        $api->group(['middleware' => ['access:' . AccessPermissions::ACCESS_ACTIVITY]], function (Router $api) {
                            $api->get('{code}/download-activity', 'Employee\EmployeeController@downloadAdminActivities');
                        });
                        $api->get('download-template', 'Employee\EmployeeController@downloadTemplate');
                        $api->get('{code}/export-employees', 'Employee\EmployeeController@exportEmployees');
                        $api->post('{code}/re-verify', 'Employee\EmployeeController@resendVerifyEmail');
                        $api->get('', 'Employee\EmployeeController@getEmployee');
                        $api->get('{code}', 'Employee\EmployeeController@getEmployeeDetail');
                        $api->get('{code}/journeys', 'Employee\EmployeeController@getJourneys');
                        $api->get('{code}/journeys/{journeysCode}/download', 'Employee\EmployeeController@downloadEmployeesSubmissionInAllJourneys');
                        $api->get('{code}/journey/{journeyCode}/download', 'Employee\EmployeeController@downloadEmployeeSubmission');
                    }
                );

                $api->group(['prefix' => 'company'], function (Router $api) {
                    $api->get('', 'Client\ClientController@getCompany');
                    $api->get('/remain-plan', 'Client\ClientController@getCompanyRemainPlan');
                    $api->get('/plan', 'Subscription\SubscriptionController@getSubscriptionPlansWithDetail');
                    $api->get('/current-plan', 'Subscription\SubscriptionController@getCurrentPlan');
                    $api->group(['middleware' => ['access:' . AccessPermissions::ACCESS_BILLING_PAYMENT]], function (Router $api) {
                        $api->get('/invoices', 'Subscription\SubscriptionController@getInvoices');
                        $api->get('/upcoming-invoice', 'Subscription\SubscriptionController@getUpcomingInvoice');
                        $api->get('/card', 'Subscription\SubscriptionController@getCard');
                        $api->post('/change-card', 'Subscription\SubscriptionController@changeCard');
                        $api->post('/change-plan', 'Subscription\SubscriptionController@changePlan');
                    });
                    $api->group(
                        [
                            'middleware' =>
                            ['access:' . AccessPermissions::EDIT_COMPANY_DETAIL . '|' . AccessPermissions::EDIT_APP_DESIGN]
                        ],
                        function (Router $api) {
                            $api->post('', 'Client\ClientController@updateCompany');
                        }
                    );
                    $api->get('/user/{type?}', 'Client\ClientController@getUserCurrentCompany');
                    $api->get('/user/{role?}/denied', 'Client\ClientController@getDeniedUserAccess');
                    $api->group(['middleware' => ['access:' . AccessPermissions::ACCESS_USER_ACCESS]], function (Router $api) {
                        $api->post('/admin', 'Client\ClientController@grantAdminAccess');
                        $api->post('/admin/remove', 'Client\ClientController@removeAdminAccess');
                        $api->post('/manager', 'Client\ClientController@grantManagerAccess');
                        $api->post('/manager/remove', 'Client\ClientController@removeManagerAccess');
                        $api->post('/whistleblower', 'Client\ClientController@grantWhistleblowerAccess');
                        $api->post('/whistleblower/remove', 'Client\ClientController@removeWhistleblowerAccess');
                    });
                });

                $api->group(['prefix' => 'app-rating'], function (Router $api) {
                    $api->get('', 'AppRating\AppRatingController@getAppRating');
                });

                $api->group(['prefix' => 'data-control',], function (Router $api) {
                    $api->get('/', 'DataControl\DataControlController@getDataControl');
                    $api->group(['middleware' => ['access:' . AccessPermissions::ACCESS_DATA_CONTROL]], function (Router $api) {
                        $api->post('/', 'DataControl\DataControlController@updateDataControl');
                    });
                });

                $api->group(
                    ['prefix' => 'action', 'middleware' => ['access:' . AccessPermissions::READ_ACTION]],
                    function (Router $api) {
                        $api->get('pending-reviews', 'Action\ActionController@getPendingReviews');
                        $api->get('employees', 'Action\ActionController@getEmployees');
                        $api->get(
                            '{code}/employees/{employeeCode}',
                            'Action\ActionController@getEmployeeActionSubmission'
                        );
                        $api->get(
                            '{code}/employees/{employeeCode}/download',
                            'Action\ActionController@downloadEmployeeActionSubmission'
                        );
                        $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_EDIT_DELETE_ACTION]], function (Router $api) {
                            $api->post('', 'Action\ActionController@create');
                            $api->post(
                                '{code}/employees/{employeeCode}/cancel',
                                'Action\ActionController@cancelUserAction'
                            );
                        });
                        $api->post('submission/{id}/approve', 'Action\ActionController@approveSubmission');
                        $api->post('submission/{id}/reject', 'Action\ActionController@rejectSubmission');
                        $api->post(
                            '{code}/employees/{employeeCode}/reminder',
                            'Action\ActionController@sendUserActionReminder'
                        );
                    }
                );

                $api->group(
                    ['prefix' => 'action-sequence', 'middleware' => ['access:' . AccessPermissions::READ_ACTION]],
                    function (Router $api) {
                        $api->get('', 'Action\ActionController@getActionSequence');
                        $api->get('{code}', 'Action\ActionController@getActionSequenceDetail');
                        $api->get('{code}/steps', 'Action\ActionController@getSteps');
                        $api->get('{code}/employees/{employeeCode}', 'Action\ActionController@getEmployeeSubmission');
                        $api->get(
                            '{code}/employees/{employeeCode}/download',
                            'Action\ActionController@downloadEmployeeSubmission'
                        );
                        $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_EDIT_DELETE_ACTION]], function (Router $api) {
                            $api->post('', 'Action\ActionController@createActionSequence');
                            $api->post('{code}', 'Action\ActionController@updateActionSequence');
                            $api->post('{code}/steps', 'Action\ActionController@saveStep');
                            $api->post(
                                '{code}/employees/{employeeCode}/cancel',
                                'Action\ActionController@cancelUserActionSequence'
                            );
                            $api->delete('{code}', 'Action\ActionController@deleteActionSequence');
                        });
                        $api->post('{code}/employees', 'Action\ActionController@addEmployees');
                        $api->post(
                            '{code}/employees/{employeeCode}/reminder',
                            'Action\ActionController@sendUserActionSequenceReminder'
                        );
                    }
                );

                // Initiative
                $api->group(
                    ['prefix' => 'initiative', 'middleware' => ['access:' . AccessPermissions::ACCESS_INITIATIVES]],
                    function (Router $api) {
                        $api->get('', 'Initiative\InitiativeController@index');
                        $api->group(['middleware' => ['access:' . AccessPermissions::CREATE_EDIT_INITIATIVES]], function (Router $api) {
                            $api->post('', 'Initiative\InitiativeController@store');
                            $api->put('{initiative}', 'Initiative\InitiativeController@update');
                            $api->delete('{initiative}', 'Initiative\InitiativeController@destroy');
                            $api->put('{initiative}/completed', 'Initiative\InitiativeController@updateCompleted');
                        });
                    }
                );

                $api->get('power-search', 'PowerSearch\PowerSearchController@search');


                // Report
                $api->group(['prefix' => 'report'], function (Router $api) {
                    $api->group(
                        [
                            'middleware' =>
                            ['access:' . AccessPermissions::ACCESS_COMPANY_COMMENT . '|' . AccessPermissions::ACCESS_TEAM_COMMENT]
                        ],
                        function (Router $api) {
                            $api->get('comment/{comment_type?}', 'Report\ReportController@comment');
                            $api->put('comment/{id}/acknowledge', 'Report\ReportController@acknowledgeSensitiveComment');
                        }
                    );
                    $api->group(
                        ['middleware' => ['access:' . AccessPermissions::ACCESS_COMMENT_REACT]],
                        function (Router $api) {
                            $api->put('comment/{id}/react', 'Report\ReportController@reactComment');
                        }
                    );
                    $api->group(['prefix' => 'heatmap', 'middleware' => ['access:' . AccessPermissions::ACCESS_HEATMAPS]], function (Router $api) {
                        $api->get('', 'Report\ReportController@heatmap');
                        $api->get('download', 'Report\ReportController@downloadHeatmap');
                        $api->get('participate-report', 'Report\ReportController@getParticipateScoreForHeatmapReport');
                    });

                    $api->group(['prefix' => 'topics', 'middleware' => ['access:' . AccessPermissions::ACCESS_TOPICS]], function (Router $api) {
                        $api->get('', 'Report\ReportController@topics');
                        $api->get('drivers/{id}/analyze', 'Report\ReportController@getTopicCommentAnalyze');
                    });
                    $api->group(['prefix' => 'boards', 'middleware' => ['access:' . AccessPermissions::ACCESS_BOARDS]], function (Router $api) {
                        $api->get('', 'Report\ReportController@boards');
                        $api->get('download', 'Report\ReportController@downloadBoards');
                        $api->get('participate-report', 'Report\ReportController@getParticipateScoreForBoardReport');
                        $api->get('segment/{code}/progress-over-time', 'Report\ReportController@boardSegmentProgressOverTime');
                    });
                    $api->group(['middleware' => ['access:' . AccessPermissions::ACCESS_COMPANY_QUIZ_SURVEY_REPORT]], function (Router $api) {
                        $api->get('quizzes-surveys-url', 'Report\ReportController@getQuizzesAndSurveysReportEmbedUrl');
                    });
                    $api->group(
                        ['prefix' => 'drivers', 'middleware' => ['access:' . AccessPermissions::ACCESS_DRIVER]],
                        function (Router $api) {
                            $api->get('', 'Report\ReportController@drivers');
                            $api->get('{id}/sub-drivers', 'Report\ReportController@getSubDrivers');
                        }
                    );
                    $api->get('segment-type', 'Segment\SegmentController@index');
                });

                // Schedule
                $api->group(
                    [
                        'prefix' => 'schedule',
                        'namespace' => 'Schedule',
                        'middleware' => ['access:' . AccessPermissions::ACCESS_SCHEDULE]
                    ],
                    function (Router $api) {
                        $api->get('', 'ScheduleController@getAll');
                        $api->get('/frequency', 'ScheduleController@getScheduleFrequency');
                        $api->get('/{id}', 'ScheduleController@get');
                        $api->get('/{id}/drivers', 'ScheduleController@getDriversByScheduleId');
                        $api->get('/{id}/employees', 'ScheduleController@getEmployeesByScheduleId');
                        $api->get('/{id}/employees/download', 'ScheduleController@getEmployeesReportDownload');
                        $api->post('', 'ScheduleController@create');
                        $api->post('/{id}', 'ScheduleController@update');
                        $api->post('/{id}/publish', 'ScheduleController@publish');
                        $api->post('/{id}/unpublish', 'ScheduleController@unpublish');
                        $api->post('/{id}/reconfig', 'ScheduleController@reconfig');
                        $api->delete('/{id}/destroy', 'ScheduleController@delete');
                    }
                );

                // Engage
                $api->group(['prefix' => 'engagement', 'namespace' => 'Dashboard'], function (Router $api) {
                    $api->group(
                        [
                            'middleware' =>
                            [
                                'access:' . AccessPermissions::ACCESS_ENGAGEMENT_TEAM_STATISTICS . '|' .
                                    AccessPermissions::ACCESS_ENGAGEMENT_COMPANY_STATISTICS
                            ]
                        ],
                        function (Router $api) {
                            $api->get('/enps', 'DashboardController@enpScoring');
                            $api->get('/processing', 'DashboardController@getProgressOverTime');
                        }
                    );
                });

                // Engagement
                $api->group(['prefix' => 'engagement', 'namespace' => 'Engagement'], function (Router $api) {
                    $api->group(
                        [
                            'middleware' =>
                            [
                                'access:' . AccessPermissions::ACCESS_ENGAGEMENT_TEAM_STATISTICS . '|' .
                                    AccessPermissions::ACCESS_ENGAGEMENT_COMPANY_STATISTICS
                            ]
                        ],
                        function (Router $api) {
                            $api->get('/performance', 'eNPSController@getDriverPerformance');
                            $api->get('/participate', 'eNPSController@getParticipate');
                        }
                    );
                    $api->get('/pre_enps', 'eNPSController@getENPScoring');
                    $api->get('/drivers', 'eNPSController@getByDrivers');
                    $api->get('/pre_processing', 'eNPSController@getProgressOverTime');
                });

                // Sensitive word
                $api->get('sensitive-word', 'SensitiveWord\SensitiveWordController@index');

                // Alert message
                $api->group(['prefix' => 'alert-message'], function (Router $api) {
                    $api->get('', 'AlertMessage\AlertMessageController@getAlertMessages');
                    $api->post('{id}/mark-as-read', 'AlertMessage\AlertMessageController@markAsRead');
                });

                $api->group(['prefix' => 'segments'], function (Router $api) {
                    $api->get('group', 'Segment\SegmentController@getSegmentGroup');
                });

                // User access
                $api->group(['prefix' => 'user-access'], function (Router $api) {
                    $api->get('admin', 'UserAccess\UserAccessController@getAdminAccess');
                    $api->get('manager', 'UserAccess\UserAccessController@getManagerAccess');
                    $api->get('employee', 'UserAccess\UserAccessController@getEmployeeAccess');
                    $api->get('whistleblower', 'UserAccess\UserAccessController@getWhistleblowerAccess');
                    $api->get('permissions', 'UserAccess\UserAccessController@getAllPermissions');
                    $api->group(['middleware' => ['access:' . AccessPermissions::ACCESS_USER_ACCESS]], function (Router $api) {
                        $api->post('admin', 'UserAccess\UserAccessController@updateAdminAccess');
                        $api->post('manager', 'UserAccess\UserAccessController@updateManagerAccess');
                        $api->post('employee', 'UserAccess\UserAccessController@updateEmployeeAccess');
                        $api->post('whistleblower', 'UserAccess\UserAccessController@updateWhistleblowerAccess');
                        $api->post('whistleblower/user', 'UserAccess\UserAccessController@updateOneUserAccess');
                    });
                });

                $api->group(
                    ['prefix' => 'sso', 'middleware' => ['access:' . AccessPermissions::ACCESS_SSO]],
                    function (Router $api) {
                        $api->get('config-url', 'SSO\Saml2Controller@getConfigUrl');
                    }
                );

                // Integration
                $api->group([
                    'prefix' => 'integration',
                    'middleware' => ['access:' . AccessPermissions::ACCESS_THIRD_PARTY_INTEGRATION]
                ], function (Router $api) {
                    $api->get('', 'Integration\IntegrationController@get');
                    $api->get('token', 'Integration\IntegrationController@getLinkToken');
                    $api->post('authorize', 'Integration\IntegrationController@authorizeIntegration');
                    $api->post('{slug}/{isHris}/{isAts}/{isCrm}', 'Integration\IntegrationController@disconnect');
                });

                // Document OCR
                $api->group(['prefix' => 'attachment'], function (Router $api) {
                    $api->get('{id}/ocr', 'Attachment\AttachmentController@getDocumentOCR');
                    $api->get('{id}/ocr/download', 'Attachment\AttachmentController@downloadDocumentOCR');
                });
            });

            // Super admin context
            $api->group(['middleware' => ['auth.super_admin.context']], function (Router $api) {
                // Master data
                $api->group(['prefix' => 'demo'], function (Router $api) {
                    $api->post('/magic-login', 'Auth\AuthController@getLoginMagicLink');
                });

                $api->group(['prefix' => 'master-data'], function (Router $api) {
                    $api->post('industry', 'MasterData\MasterDataController@createIndustry');
                    $api->post('industry/{id}', 'MasterData\MasterDataController@updateIndustry');
                    $api->delete('industry/{id}', 'MasterData\MasterDataController@deleteIndustry');

                    $api->group(['prefix' => 'anonymous-conversation-category'], function (Router $api) {
                        $api->post('', 'Message\AnonymousConversationCategoryController@create');
                        $api->post('{id}', 'Message\AnonymousConversationCategoryController@update');
                        $api->delete('{id}', 'Message\AnonymousConversationCategoryController@delete');
                    });
                });
                //Client
                $api->group(['prefix' => 'client'], function (Router $api) {
                    $api->get('', 'Client\ClientController@getClientWithAdmins');
                    $api->get('/subscription', 'Client\ClientController@getClientSubscriptions');
                    $api->get('{code}', 'Client\ClientController@getClientDetail');
                    $api->post('', 'Client\ClientController@createClient');
                    $api->post('{code}', 'Client\ClientController@updateClient');
                    $api->post('{code}/suspend', 'Client\ClientController@suspendClient');
                    $api->post('{code}/activate', 'Client\ClientController@activateClient');
                    $api->post('/subscription/add-trial', 'Client\ClientController@addSubscriptionTrial');
                    $api->delete('{code}', 'Client\ClientController@deleteClient');
                });

                $api->group(['prefix' => 'subscription'], function (Router $api) {
                    $api->group(['middleware' => ['role:' . Roles::SUPER_ADMIN]], function (Router $api) {
                        $api->get('plan', 'Subscription\SubscriptionController@getSubscriptionPlans');
                        $api->get('stripe-plan', 'Subscription\SubscriptionController@getStripePlans');
                        $api->get('plan/{code}', 'Subscription\SubscriptionController@GetDetailSubscriptionPlan');
                        $api->post('plan', 'Subscription\SubscriptionController@createSubscriptionPlan');
                        $api->post('plan/{code}', 'Subscription\SubscriptionController@updateSubscriptionPlan');
                        $api->post('plan/{code}/duplicate', 'Subscription\SubscriptionController@duplicateSubscriptionPlan');
                        $api->delete('plan/{code}', 'Subscription\SubscriptionController@deleteSubscriptionPlan');
                    });
                });

                //Questionnaire
                $api->group(['prefix' => 'questionnaire'], function (Router $api) {
                    $api->get('', 'Questionnaire\QuestionnaireController@index');
                    $api->post('', 'Questionnaire\QuestionnaireController@store');
                    $api->put('illustration', 'Questionnaire\QuestionnaireController@updateIllustration');

                    $api->group(['prefix' => '{questionnaire}'], function (Router $api) {
                        $api->put('/', 'Questionnaire\QuestionnaireController@update');
                        $api->delete('/', 'Questionnaire\QuestionnaireController@destroy');
                        $api->resource('translate', 'Questionnaire\QuestionnaireTranslateController');
                    });
                });

                //Sensitive words
                $api->group(['prefix' => 'sensitive-word'], function (Router $api) {
                    $api->get('/', 'SensitiveWord\SensitiveWordController@index');
                    $api->post('/', 'SensitiveWord\SensitiveWordController@store');
                    $api->put('{id}', 'SensitiveWord\SensitiveWordController@update');
                    $api->delete('{id}', 'SensitiveWord\SensitiveWordController@destroy');
                });

                $api->group(['prefix' => 'app-rating'], function (Router $api) {
                    $api->get('', 'AppRating\AppRatingController@getAppRating');
                    $api->get('rating-over-time-by-platform', 'AppRating\AppRatingController@getRatingOverTimeByPlatform');
                    $api->get('reviews', 'AppRating\AppRatingController@getReviews');
                    $api->get('reviews/download', 'AppRating\AppRatingController@downloadReviews');
                });

                // Stripe
                $api->group(['prefix' => 'stripe'], function (Router $api) {
                    $api->get('customer', 'Subscription\SubscriptionController@getStripeCustomers');
                });

                // Alert message
                $api->group(['prefix' => 'alert-message'], function (Router $api) {
                    $api->post('', 'AlertMessage\AlertMessageController@create');
                    $api->post('{id}', 'AlertMessage\AlertMessageController@update');
                    $api->delete('{id}', 'AlertMessage\AlertMessageController@delete');
                    $api->get('', 'AlertMessage\AlertMessageController@getSAAlertMessages');
                });
            });
        });
    });
});
